#ifndef __BNX2X_INIT_VALUES_H__
#define __BNX2X_INIT_VALUES_H__

/* This array contains the list of operations needed to initialize the chip.
 *
 * For each block in the chip there are three init stages:
 * common - HW used by both ports,
 * port1 and port2 - initialization for a specific Ethernet port.
 * When a port is opened or closed, the management CPU tells the driver
 * whether to init/disable common HW in addition to the port HW.
 * This way the first port going up will first initializes the common HW,
 * and the last port going down also resets the common HW
 *
 * For each init stage/block there is a list of actions needed in a format:
 * {operation, register, data}
 * where:
 * OP_WR - write a value to the chip.
 * OP_RD - read a register (usually a clear on read register).
 * OP_SW - string write, write a section of consecutive addresses to the chip.
 * OP_SI - copy a string using indirect writes.
 * OP_ZR - clear a range of memory.
 * OP_ZP - unzip and copy using DMAE.
 * OP_WB - string copy using DMAE.
 *
 * The #defines mark the stages.
 *
 */

static const struct raw_op init_ops[] = {
#define PRS_COMMON_START        0
	{OP_WR, PRS_REG_INC_VALUE, 0xf},
	{OP_WR, PRS_REG_EVENT_ID_1, 0x45},
	{OP_WR, PRS_REG_EVENT_ID_2, 0x84},
	{OP_WR, PRS_REG_EVENT_ID_3, 0x6},
	{OP_WR, PRS_REG_NO_MATCH_EVENT_ID, 0x4},
	{OP_WR, PRS_REG_CM_HDR_TYPE_0, 0x0},
	{OP_WR, PRS_REG_CM_HDR_TYPE_1, 0x12170000},
	{OP_WR, PRS_REG_CM_HDR_TYPE_2, 0x22170000},
	{OP_WR, PRS_REG_CM_HDR_TYPE_3, 0x32170000},
	{OP_ZR, PRS_REG_CM_HDR_TYPE_4, 0x5},
	{OP_WR, PRS_REG_CM_HDR_LOOPBACK_TYPE_1, 0x12150000},
	{OP_WR, PRS_REG_CM_HDR_LOOPBACK_TYPE_2, 0x22150000},
	{OP_WR, PRS_REG_CM_HDR_LOOPBACK_TYPE_3, 0x32150000},
	{OP_ZR, PRS_REG_CM_HDR_LOOPBACK_TYPE_4, 0x4},
	{OP_WR, PRS_REG_CM_NO_MATCH_HDR, 0x2100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_0, 0x100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_1, 0x10100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_2, 0x20100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_3, 0x30100000},
	{OP_ZR, PRS_REG_CM_HDR_FLUSH_NO_LOAD_TYPE_4, 0x4},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_0, 0x100000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_1, 0x12140000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_2, 0x22140000},
	{OP_WR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_3, 0x32140000},
	{OP_ZR, PRS_REG_CM_HDR_FLUSH_LOAD_TYPE_4, 0x4},
	{OP_RD, PRS_REG_NUM_OF_PACKETS, 0x0},
	{OP_RD, PRS_REG_NUM_OF_CFC_FLUSH_MESSAGES, 0x0},
	{OP_RD, PRS_REG_NUM_OF_TRANSPARENT_FLUSH_MESSAGES, 0x0},
	{OP_RD, PRS_REG_NUM_OF_DEAD_CYCLES, 0x0},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_0, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_1, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_2, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_3, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_4, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_5, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_6, 0xff},
	{OP_WR, PRS_REG_FLUSH_REGIONS_TYPE_7, 0xff},
	{OP_WR, PRS_REG_PURE_REGIONS, 0x3e},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_0, 0x0},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_1, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_2, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_3, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_4, 0x0},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_5, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_6, 0x3f},
	{OP_WR, PRS_REG_PACKET_REGIONS_TYPE_7, 0x3f},
#define PRS_COMMON_END          46
#define PRS_PORT0_START         46
	{OP_WR_E1, PRS_REG_CID_PORT_0, 0x0},
#define PRS_PORT0_END           47
#define PRS_PORT1_START         47
	{OP_WR_E1, PRS_REG_CID_PORT_1, 0x800000},
#define PRS_PORT1_END           48
#define SRCH_COMMON_START       48
	{OP_WR_E1H, SRC_REG_E1HMF_ENABLE, 0x1},
#define SRCH_COMMON_END         49
#define TSDM_COMMON_START       49
	{OP_WR_E1, TSDM_REG_CFC_RSP_START_ADDR, 0x411},
	{OP_WR_E1H, TSDM_REG_CFC_RSP_START_ADDR, 0x211},
	{OP_WR_E1, TSDM_REG_CMP_COUNTER_START_ADDR, 0x400},
	{OP_WR_E1H, TSDM_REG_CMP_COUNTER_START_ADDR, 0x200},
	{OP_WR_E1, TSDM_REG_Q_COUNTER_START_ADDR, 0x404},
	{OP_WR_E1H, TSDM_REG_Q_COUNTER_START_ADDR, 0x204},
	{OP_WR_E1, TSDM_REG_PCK_END_MSG_START_ADDR, 0x419},
	{OP_WR_E1H, TSDM_REG_PCK_END_MSG_START_ADDR, 0x219},
	{OP_WR, TSDM_REG_CMP_COUNTER_MAX0, 0xffff},
	{OP_WR, TSDM_REG_CMP_COUNTER_MAX1, 0xffff},
	{OP_WR, TSDM_REG_CMP_COUNTER_MAX2, 0xffff},
	{OP_WR, TSDM_REG_CMP_COUNTER_MAX3, 0xffff},
	{OP_ZR, TSDM_REG_AGG_INT_EVENT_0, 0x2},
	{OP_WR, TSDM_REG_AGG_INT_EVENT_2, 0x34},
	{OP_WR, TSDM_REG_AGG_INT_EVENT_3, 0x35},
	{OP_ZR, TSDM_REG_AGG_INT_EVENT_4, 0x7c},
	{OP_WR, TSDM_REG_ENABLE_IN1, 0x7ffffff},
	{OP_WR, TSDM_REG_ENABLE_IN2, 0x3f},
	{OP_WR, TSDM_REG_ENABLE_OUT1, 0x7ffffff},
	{OP_WR, TSDM_REG_ENABLE_OUT2, 0xf},
	{OP_RD, TSDM_REG_NUM_OF_Q0_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q1_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q3_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q4_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q5_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q6_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q7_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q8_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q9_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q10_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_Q11_CMD, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_PKT_END_MSG, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_PXP_ASYNC_REQ, 0x0},
	{OP_RD, TSDM_REG_NUM_OF_ACK_AFTER_PLACE, 0x0},
	{OP_WR_E1, TSDM_REG_INIT_CREDIT_PXP_CTRL, 0x1},
	{OP_WR_ASIC, TSDM_REG_TIMER_TICK, 0x3e8},
	{OP_WR_EMUL, TSDM_REG_TIMER_TICK, 0x1},
	{OP_WR_FPGA, TSDM_REG_TIMER_TICK, 0xa},
#define TSDM_COMMON_END         87
#define TCM_COMMON_START        87
	{OP_WR, TCM_REG_XX_MAX_LL_SZ, 0x20},
	{OP_WR, TCM_REG_XX_OVFL_EVNT_ID, 0x32},
	{OP_WR, TCM_REG_TQM_TCM_HDR_P, 0x2150020},
	{OP_WR, TCM_REG_TQM_TCM_HDR_S, 0x2150020},
	{OP_WR, TCM_REG_TM_TCM_HDR, 0x30},
	{OP_WR, TCM_REG_ERR_TCM_HDR, 0x8100000},
	{OP_WR, TCM_REG_ERR_EVNT_ID, 0x33},
	{OP_WR, TCM_REG_EXPR_EVNT_ID, 0x30},
	{OP_WR, TCM_REG_STOP_EVNT_ID, 0x31},
	{OP_WR, TCM_REG_PRS_WEIGHT, 0x4},
	{OP_WR, TCM_REG_PBF_WEIGHT, 0x5},
	{OP_WR, TCM_REG_CP_WEIGHT, 0x0},
	{OP_WR, TCM_REG_TSDM_WEIGHT, 0x4},
	{OP_WR, TCM_REG_TCM_TQM_USE_Q, 0x1},
	{OP_WR, TCM_REG_GR_ARB_TYPE, 0x1},
	{OP_WR, TCM_REG_GR_LD0_PR, 0x1},
	{OP_WR, TCM_REG_GR_LD1_PR, 0x2},
	{OP_WR, TCM_REG_CFC_INIT_CRD, 0x1},
	{OP_WR, TCM_REG_FIC0_INIT_CRD, 0x40},
	{OP_WR, TCM_REG_FIC1_INIT_CRD, 0x40},
	{OP_WR, TCM_REG_TQM_INIT_CRD, 0x20},
	{OP_WR, TCM_REG_XX_INIT_CRD, 0x13},
	{OP_WR, TCM_REG_XX_MSG_NUM, 0x20},
	{OP_ZR, TCM_REG_XX_TABLE, 0xa},
	{OP_SW, TCM_REG_XX_DESCR_TABLE, 0x200000},
	{OP_WR, TCM_REG_N_SM_CTX_LD_0, 0x7},
	{OP_WR, TCM_REG_N_SM_CTX_LD_1, 0x7},
	{OP_WR, TCM_REG_N_SM_CTX_LD_2, 0x8},
	{OP_WR, TCM_REG_N_SM_CTX_LD_3, 0x8},
	{OP_ZR, TCM_REG_N_SM_CTX_LD_4, 0x4},
	{OP_WR, TCM_REG_TCM_REG0_SZ, 0x6},
	{OP_WR_E1, TCM_REG_PHYS_QNUM0_0, 0xd},
	{OP_WR_E1, TCM_REG_PHYS_QNUM0_1, 0x2d},
	{OP_WR_E1, TCM_REG_PHYS_QNUM1_0, 0x7},
	{OP_WR_E1, TCM_REG_PHYS_QNUM1_1, 0x27},
	{OP_WR_E1, TCM_REG_PHYS_QNUM2_0, 0x7},
	{OP_WR_E1, TCM_REG_PHYS_QNUM2_1, 0x27},
	{OP_WR_E1, TCM_REG_PHYS_QNUM3_0, 0x7},
	{OP_WR_E1, TCM_REG_PHYS_QNUM3_1, 0x27},
	{OP_WR, TCM_REG_TCM_STORM0_IFEN, 0x1},
	{OP_WR, TCM_REG_TCM_STORM1_IFEN, 0x1},
	{OP_WR, TCM_REG_TCM_TQM_IFEN, 0x1},
	{OP_WR, TCM_REG_STORM_TCM_IFEN, 0x1},
	{OP_WR, TCM_REG_TQM_TCM_IFEN, 0x1},
	{OP_WR, TCM_REG_TSDM_IFEN, 0x1},
	{OP_WR, TCM_REG_TM_TCM_IFEN, 0x1},
	{OP_WR, TCM_REG_PRS_IFEN, 0x1},
	{OP_WR, TCM_REG_PBF_IFEN, 0x1},
	{OP_WR, TCM_REG_USEM_IFEN, 0x1},
	{OP_WR, TCM_REG_CSEM_IFEN, 0x1},
	{OP_WR, TCM_REG_CDU_AG_WR_IFEN, 0x1},
	{OP_WR, TCM_REG_CDU_AG_RD_IFEN, 0x1},
	{OP_WR, TCM_REG_CDU_SM_WR_IFEN, 0x1},
	{OP_WR, TCM_REG_CDU_SM_RD_IFEN, 0x1},
	{OP_WR, TCM_REG_TCM_CFC_IFEN, 0x1},
#define TCM_COMMON_END          142
#define TCM_FUNC0_START         142
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_0, 0xd},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_0, 0x7},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_0, 0x7},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_0, 0x7},
#define TCM_FUNC0_END           146
#define TCM_FUNC1_START         146
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_1, 0x2d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_1, 0x27},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_1, 0x27},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_1, 0x27},
#define TCM_FUNC1_END           150
#define TCM_FUNC2_START         150
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_0, 0x1d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_0, 0x17},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_0, 0x17},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_0, 0x17},
#define TCM_FUNC2_END           154
#define TCM_FUNC3_START         154
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_1, 0x3d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_1, 0x37},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_1, 0x37},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_1, 0x37},
#define TCM_FUNC3_END           158
#define TCM_FUNC4_START         158
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_0, 0x4d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_0, 0x47},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_0, 0x47},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_0, 0x47},
#define TCM_FUNC4_END           162
#define TCM_FUNC5_START         162
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_1, 0x6d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_1, 0x67},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_1, 0x67},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_1, 0x67},
#define TCM_FUNC5_END           166
#define TCM_FUNC6_START         166
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_0, 0x5d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_0, 0x57},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_0, 0x57},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_0, 0x57},
#define TCM_FUNC6_END           170
#define TCM_FUNC7_START         170
	{OP_WR_E1H, TCM_REG_PHYS_QNUM0_1, 0x7d},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM1_1, 0x77},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM2_1, 0x77},
	{OP_WR_E1H, TCM_REG_PHYS_QNUM3_1, 0x77},
#define TCM_FUNC7_END           174
#define BRB1_COMMON_START       174
	{OP_SW, BRB1_REG_LL_RAM, 0x2000020},
	{OP_WR, BRB1_REG_SOFT_RESET, 0x1},
	{OP_WR_E1, BRB1_REG_PAUSE_LOW_THRESHOLD_0, 0xb8},
	{OP_WR_E1, BRB1_REG_PAUSE_LOW_THRESHOLD_1, 0xb8},
	{OP_WR_E1, BRB1_REG_PAUSE_LOW_THRESHOLD_2, 0xb8},
	{OP_WR_E1, BRB1_REG_PAUSE_LOW_THRESHOLD_3, 0xb8},
	{OP_WR_E1, BRB1_REG_PAUSE_HIGH_THRESHOLD_0, 0x114},
	{OP_WR_E1, BRB1_REG_PAUSE_HIGH_THRESHOLD_1, 0x114},
	{OP_WR_E1, BRB1_REG_PAUSE_HIGH_THRESHOLD_2, 0x114},
	{OP_WR_E1, BRB1_REG_PAUSE_HIGH_THRESHOLD_3, 0x114},
	{OP_RD_E1, BRB1_REG_NUM_OF_PAUSE_CYCLES_0, 0x0},
	{OP_RD_E1, BRB1_REG_NUM_OF_PAUSE_CYCLES_1, 0x0},
	{OP_RD_E1, BRB1_REG_NUM_OF_PAUSE_CYCLES_2, 0x0},
	{OP_RD_E1, BRB1_REG_NUM_OF_PAUSE_CYCLES_3, 0x0},
	{OP_RD_E1, BRB1_REG_NUM_OF_FULL_CYCLES_0, 0x0},
	{OP_RD_E1, BRB1_REG_NUM_OF_FULL_CYCLES_1, 0x0},
	{OP_RD_E1, BRB1_REG_NUM_OF_FULL_CYCLES_2, 0x0},
	{OP_RD_E1, BRB1_REG_NUM_OF_FULL_CYCLES_3, 0x0},
	{OP_RD, BRB1_REG_NUM_OF_FULL_CYCLES_4, 0x0},
	{OP_SW, BRB1_REG_FREE_LIST_PRS_CRDT, 0x30220},
	{OP_WR, BRB1_REG_SOFT_RESET, 0x0},
#define BRB1_COMMON_END         195
#define BRB1_PORT0_START        195
	{OP_RD_E1H, BRB1_REG_NUM_OF_PAUSE_CYCLES_0, 0x0},
	{OP_RD_E1H, BRB1_REG_NUM_OF_FULL_CYCLES_0, 0x0},
#define BRB1_PORT0_END          197
#define BRB1_PORT1_START        197
	{OP_RD_E1H, BRB1_REG_NUM_OF_PAUSE_CYCLES_1, 0x0},
	{OP_RD_E1H, BRB1_REG_NUM_OF_FULL_CYCLES_1, 0x0},
#define BRB1_PORT1_END          199
#define TSEM_COMMON_START       199
	{OP_RD, TSEM_REG_MSG_NUM_FIC0, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FIC1, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FOC0, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FOC1, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FOC2, 0x0},
	{OP_RD, TSEM_REG_MSG_NUM_FOC3, 0x0},
	{OP_WR, TSEM_REG_ARB_ELEMENT0, 0x1},
	{OP_WR, TSEM_REG_ARB_ELEMENT1, 0x2},
	{OP_WR, TSEM_REG_ARB_ELEMENT2, 0x3},
	{OP_WR, TSEM_REG_ARB_ELEMENT3, 0x0},
	{OP_WR, TSEM_REG_ARB_ELEMENT4, 0x4},
	{OP_WR, TSEM_REG_ARB_CYCLE_SIZE, 0x1},
	{OP_WR, TSEM_REG_TS_0_AS, 0x0},
	{OP_WR, TSEM_REG_TS_1_AS, 0x1},
	{OP_WR, TSEM_REG_TS_2_AS, 0x4},
	{OP_WR, TSEM_REG_TS_3_AS, 0x0},
	{OP_WR, TSEM_REG_TS_4_AS, 0x1},
	{OP_WR, TSEM_REG_TS_5_AS, 0x3},
	{OP_WR, TSEM_REG_TS_6_AS, 0x0},
	{OP_WR, TSEM_REG_TS_7_AS, 0x1},
	{OP_WR, TSEM_REG_TS_8_AS, 0x4},
	{OP_WR, TSEM_REG_TS_9_AS, 0x0},
	{OP_WR, TSEM_REG_TS_10_AS, 0x1},
	{OP_WR, TSEM_REG_TS_11_AS, 0x3},
	{OP_WR, TSEM_REG_TS_12_AS, 0x0},
	{OP_WR, TSEM_REG_TS_13_AS, 0x1},
	{OP_WR, TSEM_REG_TS_14_AS, 0x4},
	{OP_WR, TSEM_REG_TS_15_AS, 0x0},
	{OP_WR, TSEM_REG_TS_16_AS, 0x4},
	{OP_WR, TSEM_REG_TS_17_AS, 0x3},
	{OP_ZR, TSEM_REG_TS_18_AS, 0x2},
	{OP_WR, TSEM_REG_ENABLE_IN, 0x3fff},
	{OP_WR, TSEM_REG_ENABLE_OUT, 0x3ff},
	{OP_WR, TSEM_REG_FIC0_DISABLE, 0x0},
	{OP_WR, TSEM_REG_FIC1_DISABLE, 0x0},
	{OP_WR, TSEM_REG_PAS_DISABLE, 0x0},
	{OP_WR, TSEM_REG_THREADS_LIST, 0xff},
	{OP_ZR, TSEM_REG_PASSIVE_BUFFER, 0x400},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x18bc0, 0x1},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x18000, 0x34},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x18040, 0x18},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x18080, 0xc},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x180c0, 0x20},
	{OP_WR_ASIC, TSEM_REG_FAST_MEMORY + 0x18300, 0x7a120},
	{OP_WR_EMUL, TSEM_REG_FAST_MEMORY + 0x18300, 0x138},
	{OP_WR_FPGA, TSEM_REG_FAST_MEMORY + 0x18300, 0x1388},
	{OP_WR, TSEM_REG_FAST_MEMORY + 0x183c0, 0x1f4},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x2000, 0xb2},
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x11480, 0x1},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x23c8, 0xc1},
	{OP_WR_EMUL_E1H, TSEM_REG_FAST_MEMORY + 0x11480, 0x0},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x23c8 + 0x304, 0x10223},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x1000, 0x2b3},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1020, 0xc8},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x1000 + 0xacc, 0x10223},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1000, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xa020, 0xc8},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1c18, 0x4},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xa000, 0x2},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x800, 0x2},
	{OP_WR_E1H, TSEM_REG_FAST_MEMORY + 0x1ad0, 0x0},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x808, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x38f8, 0x4},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x810, 0x4},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5000, 0x2},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x1fb0, 0x40224},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5008, 0x4},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x4cb0, 0x80228},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5018, 0x4},
	{OP_ZP_E1, TSEM_REG_INT_TABLE, 0x980230},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5028, 0x4},
	{OP_ZP_E1, TSEM_REG_PRAM, 0x31880256},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5038, 0x4},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x8000, 0x338d0eb8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5048, 0x4},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x10000, 0x9571b9c},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5058, 0x4},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x18000, 0x5a1df2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5068, 0x4},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x20000, 0x5a1e09},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5078, 0x2},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x28000, 0x5a1e20},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x4000, 0x2},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x30000, 0x5a1e37},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x4008, 0x2},
	{OP_ZP_E1, TSEM_REG_PRAM + 0x38000, 0x5a1e4e},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x6140, 0x200224},
	{OP_ZP_E1H, TSEM_REG_INT_TABLE, 0x950244},
	{OP_ZP_E1H, TSEM_REG_PRAM, 0x31c0026a},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x8000, 0x34050eda},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x10000, 0xa831bdc},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x18000, 0x5a1e7d},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x20000, 0x5a1e94},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x28000, 0x5a1eab},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x30000, 0x5a1ec2},
	{OP_ZP_E1H, TSEM_REG_PRAM + 0x38000, 0x5a1ed9},
#define TSEM_COMMON_END         295
#define TSEM_PORT0_START        295
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x22c8, 0x20},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x2000, 0x148},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x4000, 0x148},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x2000 + 0x520, 0x21ef0},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x4000 + 0x520, 0x21e65},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xb000, 0x28},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1400, 0xa},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xb140, 0xc},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1450, 0x6},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x32c0, 0x12},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1500, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3350, 0xb4},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1570, 0x12},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5080, 0x10},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x9c0, 0xb4},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x5080 + 0x40, 0x21ef2},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x800, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x8108, 0x2},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x820, 0x10},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x820 + 0x40, 0x21e67},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x1fb0, 0x21e69},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x2908, 0x2},
#define TSEM_PORT0_END          317
#define TSEM_PORT1_START        317
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x2348, 0x20},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x2528, 0x148},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x4528, 0x148},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x2528 + 0x520, 0x21ef4},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x4528 + 0x520, 0x21e6b},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xb0a0, 0x28},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1428, 0xa},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0xb170, 0xc},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1468, 0x6},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3308, 0x12},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x1538, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3620, 0xb4},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x15b8, 0x12},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x50c8, 0x10},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0xc90, 0xb4},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x50c8 + 0x40, 0x21ef6},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x808, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x8110, 0x2},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x868, 0x10},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x868 + 0x40, 0x21e6d},
	{OP_SW_E1, TSEM_REG_FAST_MEMORY + 0x1fb8, 0x21e6f},
	{OP_ZR_E1, TSEM_REG_FAST_MEMORY + 0x2910, 0x2},
#define TSEM_PORT1_END          339
#define TSEM_FUNC0_START        339
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3000, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x31c0, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5000, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x4000, 0x2},
#define TSEM_FUNC0_END          343
#define TSEM_FUNC1_START        343
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3038, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x31e0, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5010, 0x2},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x4008, 0x2},
#define TSEM_FUNC1_END          347
#define TSEM_FUNC2_START        347
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3070, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3200, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5020, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4010, 0x21ef8},
#define TSEM_FUNC2_END          351
#define TSEM_FUNC3_START        351
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x30a8, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3220, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5030, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4018, 0x21efa},
#define TSEM_FUNC3_END          355
#define TSEM_FUNC4_START        355
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x30e0, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3240, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5040, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4020, 0x21efc},
#define TSEM_FUNC4_END          359
#define TSEM_FUNC5_START        359
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3118, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3260, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5050, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4028, 0x21efe},
#define TSEM_FUNC5_END          363
#define TSEM_FUNC6_START        363
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3150, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3280, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5060, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4030, 0x21f00},
#define TSEM_FUNC6_END          367
#define TSEM_FUNC7_START        367
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x3188, 0xe},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x32a0, 0x8},
	{OP_ZR_E1H, TSEM_REG_FAST_MEMORY + 0x5070, 0x2},
	{OP_SW_E1H, TSEM_REG_FAST_MEMORY + 0x4038, 0x21f02},
#define TSEM_FUNC7_END          371
#define MISC_COMMON_START       371
	{OP_WR_E1, MISC_REG_GRC_TIMEOUT_EN, 0x1},
	{OP_WR, MISC_REG_PLL_STORM_CTRL_1, 0x71d2911},
	{OP_WR, MISC_REG_PLL_STORM_CTRL_2, 0x0},
	{OP_WR, MISC_REG_PLL_STORM_CTRL_3, 0x9c0424},
	{OP_WR, MISC_REG_PLL_STORM_CTRL_4, 0x0},
	{OP_WR, MISC_REG_LCPLL_CTRL_1, 0x209},
#define MISC_COMMON_END         377
#define MISC_FUNC0_START        377
	{OP_WR_E1H, MISC_REG_NIG_WOL_P0, 0x0},
#define MISC_FUNC0_END          378
#define MISC_FUNC1_START        378
	{OP_WR_E1H, MISC_REG_NIG_WOL_P1, 0x0},
#define MISC_FUNC1_END          379
#define MISC_FUNC2_START        379
	{OP_WR_E1H, MISC_REG_NIG_WOL_P0, 0x0},
#define MISC_FUNC2_END          380
#define MISC_FUNC3_START        380
	{OP_WR_E1H, MISC_REG_NIG_WOL_P1, 0x0},
#define MISC_FUNC3_END          381
#define MISC_FUNC4_START        381
	{OP_WR_E1H, MISC_REG_NIG_WOL_P0, 0x0},
#define MISC_FUNC4_END          382
#define MISC_FUNC5_START        382
	{OP_WR_E1H, MISC_REG_NIG_WOL_P1, 0x0},
#define MISC_FUNC5_END          383
#define MISC_FUNC6_START        383
	{OP_WR_E1H, MISC_REG_NIG_WOL_P0, 0x0},
#define MISC_FUNC6_END          384
#define MISC_FUNC7_START        384
	{OP_WR_E1H, MISC_REG_NIG_WOL_P1, 0x0},
#define MISC_FUNC7_END          385
#define NIG_COMMON_START        385
	{OP_WR, NIG_REG_PBF_LB_IN_EN, 0x1},
	{OP_WR, NIG_REG_PRS_REQ_IN_EN, 0x1},
	{OP_WR, NIG_REG_EGRESS_DEBUG_IN_EN, 0x1},
	{OP_WR, NIG_REG_BRB_LB_OUT_EN, 0x1},
	{OP_WR, NIG_REG_PRS_EOP_OUT_EN, 0x1},
#define NIG_COMMON_END          390
#define NIG_PORT0_START         390
	{OP_WR, NIG_REG_LLH0_CM_HEADER, 0x300000},
	{OP_WR, NIG_REG_LLH0_EVENT_ID, 0x26},
	{OP_WR, NIG_REG_LLH0_ERROR_MASK, 0x0},
	{OP_WR, NIG_REG_LLH0_XCM_MASK, 0x4},
	{OP_WR, NIG_REG_LLH0_BRB1_NOT_MCP, 0x1},
	{OP_WR, NIG_REG_STATUS_INTERRUPT_PORT0, 0x0},
	{OP_WR_E1H, NIG_REG_LLH0_CLS_TYPE, 0x1},
	{OP_WR, NIG_REG_LLH0_XCM_INIT_CREDIT, 0x30},
	{OP_WR, NIG_REG_BRB0_PAUSE_IN_EN, 0x1},
	{OP_WR, NIG_REG_EGRESS_PBF0_IN_EN, 0x1},
	{OP_WR, NIG_REG_BRB0_OUT_EN, 0x1},
	{OP_WR, NIG_REG_XCM0_OUT_EN, 0x1},
#define NIG_PORT0_END           402
#define NIG_PORT1_START         402
	{OP_WR, NIG_REG_LLH1_CM_HEADER, 0x300000},
	{OP_WR, NIG_REG_LLH1_EVENT_ID, 0x26},
	{OP_WR, NIG_REG_LLH1_ERROR_MASK, 0x0},
	{OP_WR, NIG_REG_LLH1_XCM_MASK, 0x4},
	{OP_WR, NIG_REG_LLH1_BRB1_NOT_MCP, 0x1},
	{OP_WR, NIG_REG_STATUS_INTERRUPT_PORT1, 0x0},
	{OP_WR_E1H, NIG_REG_LLH1_CLS_TYPE, 0x1},
	{OP_WR, NIG_REG_LLH1_XCM_INIT_CREDIT, 0x30},
	{OP_WR, NIG_REG_BRB1_PAUSE_IN_EN, 0x1},
	{OP_WR, NIG_REG_EGRESS_PBF1_IN_EN, 0x1},
	{OP_WR, NIG_REG_BRB1_OUT_EN, 0x1},
	{OP_WR, NIG_REG_XCM1_OUT_EN, 0x1},
#define NIG_PORT1_END           414
#define UPB_COMMON_START        414
	{OP_WR, GRCBASE_UPB + PB_REG_CONTROL, 0x20},
#define UPB_COMMON_END          415
#define CSDM_COMMON_START       415
	{OP_WR_E1, CSDM_REG_CFC_RSP_START_ADDR, 0xa11},
	{OP_WR_E1H, CSDM_REG_CFC_RSP_START_ADDR, 0x211},
	{OP_WR_E1, CSDM_REG_CMP_COUNTER_START_ADDR, 0xa00},
	{OP_WR_E1H, CSDM_REG_CMP_COUNTER_START_ADDR, 0x200},
	{OP_WR_E1, CSDM_REG_Q_COUNTER_START_ADDR, 0xa04},
	{OP_WR_E1H, CSDM_REG_Q_COUNTER_START_ADDR, 0x204},
	{OP_WR, CSDM_REG_CMP_COUNTER_MAX0, 0xffff},
	{OP_WR, CSDM_REG_CMP_COUNTER_MAX1, 0xffff},
	{OP_WR, CSDM_REG_CMP_COUNTER_MAX2, 0xffff},
	{OP_WR, CSDM_REG_CMP_COUNTER_MAX3, 0xffff},
	{OP_ZR, CSDM_REG_AGG_INT_EVENT_0, 0x2},
	{OP_WR, CSDM_REG_AGG_INT_EVENT_2, 0x34},
	{OP_WR, CSDM_REG_AGG_INT_EVENT_3, 0x35},
	{OP_ZR, CSDM_REG_AGG_INT_EVENT_4, 0x7c},
	{OP_WR, CSDM_REG_ENABLE_IN1, 0x7ffffff},
	{OP_WR, CSDM_REG_ENABLE_IN2, 0x3f},
	{OP_WR, CSDM_REG_ENABLE_OUT1, 0x7ffffff},
	{OP_WR, CSDM_REG_ENABLE_OUT2, 0xf},
	{OP_RD, CSDM_REG_NUM_OF_Q0_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q1_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q3_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q4_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q5_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q6_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q7_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q8_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q9_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q10_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_Q11_CMD, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_PKT_END_MSG, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_PXP_ASYNC_REQ, 0x0},
	{OP_RD, CSDM_REG_NUM_OF_ACK_AFTER_PLACE, 0x0},
	{OP_WR_E1, CSDM_REG_INIT_CREDIT_PXP_CTRL, 0x1},
	{OP_WR_ASIC, CSDM_REG_TIMER_TICK, 0x3e8},
	{OP_WR_EMUL, CSDM_REG_TIMER_TICK, 0x1},
	{OP_WR_FPGA, CSDM_REG_TIMER_TICK, 0xa},
#define CSDM_COMMON_END         451
#define USDM_COMMON_START       451
	{OP_WR_E1, USDM_REG_CFC_RSP_START_ADDR, 0xa11},
	{OP_WR_E1H, USDM_REG_CFC_RSP_START_ADDR, 0x411},
	{OP_WR_E1, USDM_REG_CMP_COUNTER_START_ADDR, 0xa00},
	{OP_WR_E1H, USDM_REG_CMP_COUNTER_START_ADDR, 0x400},
	{OP_WR_E1, USDM_REG_Q_COUNTER_START_ADDR, 0xa04},
	{OP_WR_E1H, USDM_REG_Q_COUNTER_START_ADDR, 0x404},
	{OP_WR_E1, USDM_REG_PCK_END_MSG_START_ADDR, 0xa21},
	{OP_WR_E1H, USDM_REG_PCK_END_MSG_START_ADDR, 0x421},
	{OP_WR, USDM_REG_CMP_COUNTER_MAX0, 0xffff},
	{OP_WR, USDM_REG_CMP_COUNTER_MAX1, 0xffff},
	{OP_WR, USDM_REG_CMP_COUNTER_MAX2, 0xffff},
	{OP_WR, USDM_REG_CMP_COUNTER_MAX3, 0xffff},
	{OP_WR, USDM_REG_AGG_INT_EVENT_0, 0x46},
	{OP_WR, USDM_REG_AGG_INT_EVENT_1, 0x5},
	{OP_WR, USDM_REG_AGG_INT_EVENT_2, 0x34},
	{OP_WR, USDM_REG_AGG_INT_EVENT_3, 0x35},
	{OP_ZR, USDM_REG_AGG_INT_EVENT_4, 0x5c},
	{OP_WR, USDM_REG_AGG_INT_MODE_0, 0x1},
	{OP_ZR, USDM_REG_AGG_INT_MODE_1, 0x1f},
	{OP_WR, USDM_REG_ENABLE_IN1, 0x7ffffff},
	{OP_WR, USDM_REG_ENABLE_IN2, 0x3f},
	{OP_WR, USDM_REG_ENABLE_OUT1, 0x7ffffff},
	{OP_WR, USDM_REG_ENABLE_OUT2, 0xf},
	{OP_RD, USDM_REG_NUM_OF_Q0_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q1_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q2_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q3_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q4_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q5_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q6_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q7_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q8_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q9_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q10_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_Q11_CMD, 0x0},
	{OP_RD, USDM_REG_NUM_OF_PKT_END_MSG, 0x0},
	{OP_RD, USDM_REG_NUM_OF_PXP_ASYNC_REQ, 0x0},
	{OP_RD, USDM_REG_NUM_OF_ACK_AFTER_PLACE, 0x0},
	{OP_WR_E1, USDM_REG_INIT_CREDIT_PXP_CTRL, 0x1},
	{OP_WR_ASIC, USDM_REG_TIMER_TICK, 0x3e8},
	{OP_WR_EMUL, USDM_REG_TIMER_TICK, 0x1},
	{OP_WR_FPGA, USDM_REG_TIMER_TICK, 0xa},
#define USDM_COMMON_END         493
#define CCM_COMMON_START        493
	{OP_WR, CCM_REG_XX_OVFL_EVNT_ID, 0x32},
	{OP_WR, CCM_REG_CQM_CCM_HDR_P, 0x2150020},
	{OP_WR, CCM_REG_CQM_CCM_HDR_S, 0x2150020},
	{OP_WR, CCM_REG_ERR_CCM_HDR, 0x8100000},
	{OP_WR, CCM_REG_ERR_EVNT_ID, 0x33},
	{OP_WR, CCM_REG_TSEM_WEIGHT, 0x0},
	{OP_WR, CCM_REG_XSEM_WEIGHT, 0x4},
	{OP_WR, CCM_REG_USEM_WEIGHT, 0x4},
	{OP_ZR, CCM_REG_PBF_WEIGHT, 0x2},
	{OP_WR, CCM_REG_CQM_P_WEIGHT, 0x2},
	{OP_WR, CCM_REG_CCM_CQM_USE_Q, 0x1},
	{OP_WR, CCM_REG_CNT_AUX1_Q, 0x2},
	{OP_WR, CCM_REG_CNT_AUX2_Q, 0x2},
	{OP_WR, CCM_REG_INV_DONE_Q, 0x1},
	{OP_WR, CCM_REG_GR_ARB_TYPE, 0x1},
	{OP_WR, CCM_REG_GR_LD0_PR, 0x1},
	{OP_WR, CCM_REG_GR_LD1_PR, 0x2},
	{OP_WR, CCM_REG_CFC_INIT_CRD, 0x1},
	{OP_WR, CCM_REG_CQM_INIT_CRD, 0x20},
	{OP_WR, CCM_REG_FIC0_INIT_CRD, 0x40},
	{OP_WR, CCM_REG_FIC1_INIT_CRD, 0x40},
	{OP_WR, CCM_REG_XX_INIT_CRD, 0x3},
	{OP_WR, CCM_REG_XX_MSG_NUM, 0x18},
	{OP_ZR, CCM_REG_XX_TABLE, 0x12},
	{OP_SW_E1, CCM_REG_XX_DESCR_TABLE, 0x241e71},
	{OP_SW_E1H, CCM_REG_XX_DESCR_TABLE, 0x241f04},
	{OP_WR, CCM_REG_N_SM_CTX_LD_0, 0x1},
	{OP_WR, CCM_REG_N_SM_CTX_LD_1, 0x2},
	{OP_WR, CCM_REG_N_SM_CTX_LD_2, 0x8},
	{OP_WR, CCM_REG_N_SM_CTX_LD_3, 0x8},
	{OP_ZR, CCM_REG_N_SM_CTX_LD_4, 0x4},
	{OP_WR, CCM_REG_CCM_REG0_SZ, 0x4},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM0_0, 0x9},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM0_1, 0x29},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM1_0, 0xa},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM1_1, 0x2a},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM2_0, 0x7},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM2_1, 0x27},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM3_0, 0x7},
	{OP_WR_E1, CCM_REG_QOS_PHYS_QNUM3_1, 0x27},
	{OP_WR_E1, CCM_REG_PHYS_QNUM1_0, 0xc},
	{OP_WR_E1, CCM_REG_PHYS_QNUM1_1, 0x2c},
	{OP_WR_E1, CCM_REG_PHYS_QNUM2_0, 0xc},
	{OP_WR_E1, CCM_REG_PHYS_QNUM2_1, 0x2c},
	{OP_WR_E1, CCM_REG_PHYS_QNUM3_0, 0xc},
	{OP_WR_E1, CCM_REG_PHYS_QNUM3_1, 0x2c},
	{OP_WR, CCM_REG_CCM_STORM0_IFEN, 0x1},
	{OP_WR, CCM_REG_CCM_STORM1_IFEN, 0x1},
	{OP_WR, CCM_REG_CCM_CQM_IFEN, 0x1},
	{OP_WR, CCM_REG_STORM_CCM_IFEN, 0x1},
	{OP_WR, CCM_REG_CQM_CCM_IFEN, 0x1},
	{OP_WR, CCM_REG_CSDM_IFEN, 0x1},
	{OP_WR, CCM_REG_TSEM_IFEN, 0x1},
	{OP_WR, CCM_REG_XSEM_IFEN, 0x1},
	{OP_WR, CCM_REG_USEM_IFEN, 0x1},
	{OP_WR, CCM_REG_PBF_IFEN, 0x1},
	{OP_WR, CCM_REG_CDU_AG_WR_IFEN, 0x1},
	{OP_WR, CCM_REG_CDU_AG_RD_IFEN, 0x1},
	{OP_WR, CCM_REG_CDU_SM_WR_IFEN, 0x1},
	{OP_WR, CCM_REG_CDU_SM_RD_IFEN, 0x1},
	{OP_WR, CCM_REG_CCM_CFC_IFEN, 0x1},
#define CCM_COMMON_END          554
#define CCM_FUNC0_START         554
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_0, 0x9},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_0, 0xa},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_0, 0x7},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_0, 0x7},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_0, 0xc},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_0, 0xb},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_0, 0x7},
#define CCM_FUNC0_END           561
#define CCM_FUNC1_START         561
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_1, 0x29},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_1, 0x2a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_1, 0x27},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_1, 0x27},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_1, 0x2c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_1, 0x2b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_1, 0x27},
#define CCM_FUNC1_END           568
#define CCM_FUNC2_START         568
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_0, 0x19},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_0, 0x1a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_0, 0x17},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_0, 0x17},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_0, 0x1c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_0, 0x1b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_0, 0x17},
#define CCM_FUNC2_END           575
#define CCM_FUNC3_START         575
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_1, 0x39},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_1, 0x3a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_1, 0x37},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_1, 0x37},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_1, 0x3c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_1, 0x3b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_1, 0x37},
#define CCM_FUNC3_END           582
#define CCM_FUNC4_START         582
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_0, 0x49},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_0, 0x4a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_0, 0x47},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_0, 0x47},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_0, 0x4c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_0, 0x4b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_0, 0x47},
#define CCM_FUNC4_END           589
#define CCM_FUNC5_START         589
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_1, 0x69},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_1, 0x6a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_1, 0x67},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_1, 0x67},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_1, 0x6c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_1, 0x6b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_1, 0x67},
#define CCM_FUNC5_END           596
#define CCM_FUNC6_START         596
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_0, 0x59},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_0, 0x5a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_0, 0x57},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_0, 0x57},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_0, 0x5c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_0, 0x5b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_0, 0x57},
#define CCM_FUNC6_END           603
#define CCM_FUNC7_START         603
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM0_1, 0x79},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM1_1, 0x7a},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM2_1, 0x77},
	{OP_WR_E1H, CCM_REG_QOS_PHYS_QNUM3_1, 0x77},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM1_1, 0x7c},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM2_1, 0x7b},
	{OP_WR_E1H, CCM_REG_PHYS_QNUM3_1, 0x77},
#define CCM_FUNC7_END           610
#define UCM_COMMON_START        610
	{OP_WR, UCM_REG_XX_OVFL_EVNT_ID, 0x32},
	{OP_WR, UCM_REG_UQM_UCM_HDR_P, 0x2150020},
	{OP_WR, UCM_REG_UQM_UCM_HDR_S, 0x2150020},
	{OP_WR, UCM_REG_TM_UCM_HDR, 0x30},
	{OP_WR, UCM_REG_ERR_UCM_HDR, 0x8100000},
	{OP_WR, UCM_REG_ERR_EVNT_ID, 0x33},
	{OP_WR, UCM_REG_EXPR_EVNT_ID, 0x30},
	{OP_WR, UCM_REG_STOP_EVNT_ID, 0x31},
	{OP_WR, UCM_REG_TSEM_WEIGHT, 0x3},
	{OP_WR, UCM_REG_CSEM_WEIGHT, 0x0},
	{OP_WR, UCM_REG_CP_WEIGHT, 0x0},
	{OP_WR, UCM_REG_UQM_P_WEIGHT, 0x6},
	{OP_WR, UCM_REG_UCM_UQM_USE_Q, 0x1},
	{OP_WR, UCM_REG_INV_CFLG_Q, 0x1},
	{OP_WR, UCM_REG_GR_ARB_TYPE, 0x1},
	{OP_WR, UCM_REG_GR_LD0_PR, 0x1},
	{OP_WR, UCM_REG_GR_LD1_PR, 0x2},
	{OP_WR, UCM_REG_CFC_INIT_CRD, 0x1},
	{OP_WR, UCM_REG_FIC0_INIT_CRD, 0x40},
	{OP_WR, UCM_REG_FIC1_INIT_CRD, 0x40},
	{OP_WR, UCM_REG_TM_INIT_CRD, 0x4},
	{OP_WR, UCM_REG_UQM_INIT_CRD, 0x20},
	{OP_WR, UCM_REG_XX_INIT_CRD, 0xe},
	{OP_WR, UCM_REG_XX_MSG_NUM, 0x1b},
	{OP_ZR, UCM_REG_XX_TABLE, 0x12},
	{OP_SW_E1, UCM_REG_XX_DESCR_TABLE, 0x1b1e95},
	{OP_SW_E1H, UCM_REG_XX_DESCR_TABLE, 0x1b1f28},
	{OP_WR, UCM_REG_N_SM_CTX_LD_0, 0x10},
	{OP_WR, UCM_REG_N_SM_CTX_LD_1, 0x7},
	{OP_WR, UCM_REG_N_SM_CTX_LD_2, 0xf},
	{OP_WR, UCM_REG_N_SM_CTX_LD_3, 0x10},
	{OP_ZR, UCM_REG_N_SM_CTX_LD_4, 0x4},
	{OP_WR, UCM_REG_UCM_REG0_SZ, 0x3},
	{OP_WR_E1, UCM_REG_PHYS_QNUM0_0, 0xf},
	{OP_WR_E1, UCM_REG_PHYS_QNUM0_1, 0x2f},
	{OP_WR_E1, UCM_REG_PHYS_QNUM1_0, 0xe},
	{OP_WR_E1, UCM_REG_PHYS_QNUM1_1, 0x2e},
	{OP_WR, UCM_REG_UCM_STORM0_IFEN, 0x1},
	{OP_WR, UCM_REG_UCM_STORM1_IFEN, 0x1},
	{OP_WR, UCM_REG_UCM_UQM_IFEN, 0x1},
	{OP_WR, UCM_REG_STORM_UCM_IFEN, 0x1},
	{OP_WR, UCM_REG_UQM_UCM_IFEN, 0x1},
	{OP_WR, UCM_REG_USDM_IFEN, 0x1},
	{OP_WR, UCM_REG_TM_UCM_IFEN, 0x1},
	{OP_WR, UCM_REG_UCM_TM_IFEN, 0x1},
	{OP_WR, UCM_REG_TSEM_IFEN, 0x1},
	{OP_WR, UCM_REG_CSEM_IFEN, 0x1},
	{OP_WR, UCM_REG_XSEM_IFEN, 0x1},
	{OP_WR, UCM_REG_DORQ_IFEN, 0x1},
	{OP_WR, UCM_REG_CDU_AG_WR_IFEN, 0x1},
	{OP_WR, UCM_REG_CDU_AG_RD_IFEN, 0x1},
	{OP_WR, UCM_REG_CDU_SM_WR_IFEN, 0x1},
	{OP_WR, UCM_REG_CDU_SM_RD_IFEN, 0x1},
	{OP_WR, UCM_REG_UCM_CFC_IFEN, 0x1},
#define UCM_COMMON_END          664
#define UCM_FUNC0_START         664
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_0, 0xf},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_0, 0xe},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_0, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_0, 0x0},
#define UCM_FUNC0_END           668
#define UCM_FUNC1_START         668
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_1, 0x2f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_1, 0x2e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_1, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_1, 0x0},
#define UCM_FUNC1_END           672
#define UCM_FUNC2_START         672
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_0, 0x1f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_0, 0x1e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_0, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_0, 0x0},
#define UCM_FUNC2_END           676
#define UCM_FUNC3_START         676
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_1, 0x3f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_1, 0x3e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_1, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_1, 0x0},
#define UCM_FUNC3_END           680
#define UCM_FUNC4_START         680
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_0, 0x4f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_0, 0x4e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_0, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_0, 0x0},
#define UCM_FUNC4_END           684
#define UCM_FUNC5_START         684
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_1, 0x6f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_1, 0x6e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_1, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_1, 0x0},
#define UCM_FUNC5_END           688
#define UCM_FUNC6_START         688
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_0, 0x5f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_0, 0x5e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_0, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_0, 0x0},
#define UCM_FUNC6_END           692
#define UCM_FUNC7_START         692
	{OP_WR_E1H, UCM_REG_PHYS_QNUM0_1, 0x7f},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM1_1, 0x7e},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM2_1, 0x0},
	{OP_WR_E1H, UCM_REG_PHYS_QNUM3_1, 0x0},
#define UCM_FUNC7_END           696
#define USEM_COMMON_START       696
	{OP_RD, USEM_REG_MSG_NUM_FIC0, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FIC1, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FOC0, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FOC1, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FOC2, 0x0},
	{OP_RD, USEM_REG_MSG_NUM_FOC3, 0x0},
	{OP_WR, USEM_REG_ARB_ELEMENT0, 0x1},
	{OP_WR, USEM_REG_ARB_ELEMENT1, 0x2},
	{OP_WR, USEM_REG_ARB_ELEMENT2, 0x3},
	{OP_WR, USEM_REG_ARB_ELEMENT3, 0x0},
	{OP_WR, USEM_REG_ARB_ELEMENT4, 0x4},
	{OP_WR, USEM_REG_ARB_CYCLE_SIZE, 0x1},
	{OP_WR, USEM_REG_TS_0_AS, 0x0},
	{OP_WR, USEM_REG_TS_1_AS, 0x1},
	{OP_WR, USEM_REG_TS_2_AS, 0x4},
	{OP_WR, USEM_REG_TS_3_AS, 0x0},
	{OP_WR, USEM_REG_TS_4_AS, 0x1},
	{OP_WR, USEM_REG_TS_5_AS, 0x3},
	{OP_WR, USEM_REG_TS_6_AS, 0x0},
	{OP_WR, USEM_REG_TS_7_AS, 0x1},
	{OP_WR, USEM_REG_TS_8_AS, 0x4},
	{OP_WR, USEM_REG_TS_9_AS, 0x0},
	{OP_WR, USEM_REG_TS_10_AS, 0x1},
	{OP_WR, USEM_REG_TS_11_AS, 0x3},
	{OP_WR, USEM_REG_TS_12_AS, 0x0},
	{OP_WR, USEM_REG_TS_13_AS, 0x1},
	{OP_WR, USEM_REG_TS_14_AS, 0x4},
	{OP_WR, USEM_REG_TS_15_AS, 0x0},
	{OP_WR, USEM_REG_TS_16_AS, 0x4},
	{OP_WR, USEM_REG_TS_17_AS, 0x3},
	{OP_ZR, USEM_REG_TS_18_AS, 0x2},
	{OP_WR, USEM_REG_ENABLE_IN, 0x3fff},
	{OP_WR, USEM_REG_ENABLE_OUT, 0x3ff},
	{OP_WR, USEM_REG_FIC0_DISABLE, 0x0},
	{OP_WR, USEM_REG_FIC1_DISABLE, 0x0},
	{OP_WR, USEM_REG_PAS_DISABLE, 0x0},
	{OP_WR, USEM_REG_THREADS_LIST, 0xffff},
	{OP_ZR, USEM_REG_PASSIVE_BUFFER, 0x800},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x18bc0, 0x1},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x18000, 0x1a},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x18040, 0x4e},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x18080, 0x10},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x180c0, 0x20},
	{OP_WR_ASIC, USEM_REG_FAST_MEMORY + 0x18300, 0x7a120},
	{OP_WR_EMUL, USEM_REG_FAST_MEMORY + 0x18300, 0x138},
	{OP_WR_FPGA, USEM_REG_FAST_MEMORY + 0x18300, 0x1388},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x183c0, 0x1f4},
	{OP_WR_ASIC, USEM_REG_FAST_MEMORY + 0x18380, 0x1dcd6500},
	{OP_WR_EMUL, USEM_REG_FAST_MEMORY + 0x18380, 0x4c4b4},
	{OP_WR_FPGA, USEM_REG_FAST_MEMORY + 0x18380, 0x4c4b40},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x5000, 0x102},
	{OP_WR_EMUL_E1H, USEM_REG_FAST_MEMORY + 0x11480, 0x0},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1020, 0xc8},
	{OP_WR_E1H, USEM_REG_FAST_MEMORY + 0x11480, 0x1},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1000, 0x2},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x2000, 0x102},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x57a0, 0xa},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x8020, 0xc8},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1e20, 0x42},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x8000, 0x2},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4b68, 0x2},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x35e8, 0xe},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x4b68 + 0x8, 0x21eb0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3180, 0x42},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4b10, 0x2},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5000, 0x400},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x2830, 0x21eb2},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4000, 0x2},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x4000 + 0x8, 0x21f43},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6b68, 0x2},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x6b68 + 0x8, 0x21f45},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6b10, 0x2},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x74c0, 0x21f47},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x10800, 0x1000000},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x10c00, 0x101eb4},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x10c00, 0x101f49},
	{OP_WR, USEM_REG_FAST_MEMORY + 0x10800, 0x0},
	{OP_SW_E1, USEM_REG_FAST_MEMORY + 0x10c40, 0x101ec4},
	{OP_SW_E1H, USEM_REG_FAST_MEMORY + 0x10c40, 0x101f59},
	{OP_ZP_E1, USEM_REG_INT_TABLE, 0xc41ed4},
	{OP_ZP_E1H, USEM_REG_INT_TABLE, 0xc71f69},
	{OP_ZP_E1, USEM_REG_PRAM, 0x312c1f05},
	{OP_ZP_E1H, USEM_REG_PRAM, 0x31131f9b},
	{OP_ZP_E1, USEM_REG_PRAM + 0x8000, 0x33352b50},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x8000, 0x330d2be0},
	{OP_ZP_E1, USEM_REG_PRAM + 0x10000, 0x3812381e},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x10000, 0x384a38a4},
	{OP_ZP_E1, USEM_REG_PRAM + 0x18000, 0x594623},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x18000, 0x14746b7},
	{OP_ZP_E1, USEM_REG_PRAM + 0x20000, 0x59463a},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x20000, 0x594709},
	{OP_ZP_E1, USEM_REG_PRAM + 0x28000, 0x594651},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x28000, 0x594720},
	{OP_ZP_E1, USEM_REG_PRAM + 0x30000, 0x594668},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x30000, 0x594737},
	{OP_ZP_E1, USEM_REG_PRAM + 0x38000, 0x59467f},
	{OP_ZP_E1H, USEM_REG_PRAM + 0x38000, 0x59474e},
#define USEM_COMMON_END         793
#define USEM_PORT0_START        793
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1400, 0xa0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9000, 0xa0},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1900, 0xa},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9500, 0x28},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1950, 0x2e},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9640, 0x34},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1d00, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3080, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1d20, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3288, 0x6c},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x5440, 0x6c},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5000, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4b78, 0x52},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5100, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4e08, 0xc},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5200, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5300, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5400, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5500, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5600, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5700, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5800, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5900, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5a00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5b00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5c00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5d00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5e00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5f00, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6b78, 0x52},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6e08, 0xc},
#define USEM_PORT0_END          824
#define USEM_PORT1_START        824
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1680, 0xa0},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9280, 0xa0},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1928, 0xa},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x95a0, 0x28},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1a08, 0x2e},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x9710, 0x34},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1d10, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3100, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x1da0, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3438, 0x6c},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x55f0, 0x6c},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5080, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4cc0, 0x52},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5180, 0x20},
	{OP_ZR_E1, USEM_REG_FAST_MEMORY + 0x4e38, 0xc},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5280, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5380, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5480, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5580, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5680, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5780, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5880, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5980, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5a80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5b80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5c80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5d80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5e80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x5f80, 0x20},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6cc0, 0x52},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x6e38, 0xc},
#define USEM_PORT1_END          855
#define USEM_FUNC0_START        855
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3000, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4010, 0x2},
#define USEM_FUNC0_END          857
#define USEM_FUNC1_START        857
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3010, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4020, 0x2},
#define USEM_FUNC1_END          859
#define USEM_FUNC2_START        859
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3020, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4030, 0x2},
#define USEM_FUNC2_END          861
#define USEM_FUNC3_START        861
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3030, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4040, 0x2},
#define USEM_FUNC3_END          863
#define USEM_FUNC4_START        863
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3040, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4050, 0x2},
#define USEM_FUNC4_END          865
#define USEM_FUNC5_START        865
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3050, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4060, 0x2},
#define USEM_FUNC5_END          867
#define USEM_FUNC6_START        867
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3060, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4070, 0x2},
#define USEM_FUNC6_END          869
#define USEM_FUNC7_START        869
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x3070, 0x4},
	{OP_ZR_E1H, USEM_REG_FAST_MEMORY + 0x4080, 0x2},
#define USEM_FUNC7_END          871
#define CSEM_COMMON_START       871
	{OP_RD, CSEM_REG_MSG_NUM_FIC0, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FIC1, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FOC0, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FOC1, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FOC2, 0x0},
	{OP_RD, CSEM_REG_MSG_NUM_FOC3, 0x0},
	{OP_WR, CSEM_REG_ARB_ELEMENT0, 0x1},
	{OP_WR, CSEM_REG_ARB_ELEMENT1, 0x2},
	{OP_WR, CSEM_REG_ARB_ELEMENT2, 0x3},
	{OP_WR, CSEM_REG_ARB_ELEMENT3, 0x0},
	{OP_WR, CSEM_REG_ARB_ELEMENT4, 0x4},
	{OP_WR, CSEM_REG_ARB_CYCLE_SIZE, 0x1},
	{OP_WR, CSEM_REG_TS_0_AS, 0x0},
	{OP_WR, CSEM_REG_TS_1_AS, 0x1},
	{OP_WR, CSEM_REG_TS_2_AS, 0x4},
	{OP_WR, CSEM_REG_TS_3_AS, 0x0},
	{OP_WR, CSEM_REG_TS_4_AS, 0x1},
	{OP_WR, CSEM_REG_TS_5_AS, 0x3},
	{OP_WR, CSEM_REG_TS_6_AS, 0x0},
	{OP_WR, CSEM_REG_TS_7_AS, 0x1},
	{OP_WR, CSEM_REG_TS_8_AS, 0x4},
	{OP_WR, CSEM_REG_TS_9_AS, 0x0},
	{OP_WR, CSEM_REG_TS_10_AS, 0x1},
	{OP_WR, CSEM_REG_TS_11_AS, 0x3},
	{OP_WR, CSEM_REG_TS_12_AS, 0x0},
	{OP_WR, CSEM_REG_TS_13_AS, 0x1},
	{OP_WR, CSEM_REG_TS_14_AS, 0x4},
	{OP_WR, CSEM_REG_TS_15_AS, 0x0},
	{OP_WR, CSEM_REG_TS_16_AS, 0x4},
	{OP_WR, CSEM_REG_TS_17_AS, 0x3},
	{OP_ZR, CSEM_REG_TS_18_AS, 0x2},
	{OP_WR, CSEM_REG_ENABLE_IN, 0x3fff},
	{OP_WR, CSEM_REG_ENABLE_OUT, 0x3ff},
	{OP_WR, CSEM_REG_FIC0_DISABLE, 0x0},
	{OP_WR, CSEM_REG_FIC1_DISABLE, 0x0},
	{OP_WR, CSEM_REG_PAS_DISABLE, 0x0},
	{OP_WR, CSEM_REG_THREADS_LIST, 0xffff},
	{OP_ZR, CSEM_REG_PASSIVE_BUFFER, 0x800},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x18bc0, 0x1},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x18000, 0x10},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x18040, 0x12},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x18080, 0x30},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x180c0, 0xe},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x183c0, 0x1f4},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x5000, 0x42},
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x11480, 0x1},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1020, 0xc8},
	{OP_WR_EMUL_E1H, CSEM_REG_FAST_MEMORY + 0x11480, 0x0},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1000, 0x2},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x1000, 0x42},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x2000, 0xc0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x7020, 0xc8},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x3070, 0x80},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x7000, 0x2},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x4280, 0x4},
	{OP_WR_E1H, CSEM_REG_FAST_MEMORY + 0x11c8, 0x0},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x25c0, 0x240},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3000, 0xc0},
	{OP_SW_E1, CSEM_REG_FAST_MEMORY + 0x2ec8, 0x84696},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x4070, 0x80},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x5280, 0x4},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x6280, 0x240},
	{OP_SW_E1H, CSEM_REG_FAST_MEMORY + 0x6b88, 0x204765},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x10800, 0x13fffff},
	{OP_SW_E1, CSEM_REG_FAST_MEMORY + 0x10c00, 0x10469e},
	{OP_SW_E1H, CSEM_REG_FAST_MEMORY + 0x10c00, 0x104785},
	{OP_WR, CSEM_REG_FAST_MEMORY + 0x10800, 0x0},
	{OP_SW_E1, CSEM_REG_FAST_MEMORY + 0x10c40, 0x1046ae},
	{OP_SW_E1H, CSEM_REG_FAST_MEMORY + 0x10c40, 0x104795},
	{OP_ZP_E1, CSEM_REG_INT_TABLE, 0x7146be},
	{OP_ZP_E1H, CSEM_REG_INT_TABLE, 0x7247a5},
	{OP_ZP_E1, CSEM_REG_PRAM, 0x328046db},
	{OP_ZP_E1H, CSEM_REG_PRAM, 0x322e47c2},
	{OP_ZP_E1, CSEM_REG_PRAM + 0x8000, 0x17ba537b},
	{OP_ZP_E1H, CSEM_REG_PRAM + 0x8000, 0x184d544e},
	{OP_ZP_E1, CSEM_REG_PRAM + 0x10000, 0x59596a},
	{OP_ZP_E1H, CSEM_REG_PRAM + 0x10000, 0x5a5a62},
	{OP_ZP_E1, CSEM_REG_PRAM + 0x18000, 0x595981},
	{OP_ZP_E1H, CSEM_REG_PRAM + 0x18000, 0x5a5a79},
	{OP_ZP_E1, CSEM_REG_PRAM + 0x20000, 0x595998},
	{OP_ZP_E1H, CSEM_REG_PRAM + 0x20000, 0x5a5a90},
	{OP_ZP_E1, CSEM_REG_PRAM + 0x28000, 0x5959af},
	{OP_ZP_E1H, CSEM_REG_PRAM + 0x28000, 0x5a5aa7},
	{OP_ZP_E1, CSEM_REG_PRAM + 0x30000, 0x5959c6},
	{OP_ZP_E1H, CSEM_REG_PRAM + 0x30000, 0x5a5abe},
	{OP_ZP_E1, CSEM_REG_PRAM + 0x38000, 0x5559dd},
	{OP_ZP_E1H, CSEM_REG_PRAM + 0x38000, 0x565ad5},
#define CSEM_COMMON_END         958
#define CSEM_PORT0_START        958
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1400, 0xa0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8000, 0xa0},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1900, 0x10},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8500, 0x40},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1980, 0x30},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8700, 0x3c},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x2300, 0x2},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3300, 0x2},
	{OP_SW_E1, CSEM_REG_FAST_MEMORY + 0x2300 + 0x8, 0x259f3},
	{OP_SW_E1H, CSEM_REG_FAST_MEMORY + 0x3300 + 0x8, 0x25aeb},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x3040, 0x6},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x4040, 0x6},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x2410, 0x30},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x6040, 0x30},
#define CSEM_PORT0_END          972
#define CSEM_PORT1_START        972
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1680, 0xa0},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8280, 0xa0},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1940, 0x10},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x8600, 0x40},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x1a40, 0x30},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x87f0, 0x3c},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x2310, 0x2},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x3310, 0x2},
	{OP_SW_E1, CSEM_REG_FAST_MEMORY + 0x2310 + 0x8, 0x259f5},
	{OP_SW_E1H, CSEM_REG_FAST_MEMORY + 0x3310 + 0x8, 0x25aed},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x3058, 0x6},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x4058, 0x6},
	{OP_ZR_E1, CSEM_REG_FAST_MEMORY + 0x24d0, 0x30},
	{OP_ZR_E1H, CSEM_REG_FAST_MEMORY + 0x6100, 0x30},
#define CSEM_PORT1_END          986
#define XPB_COMMON_START        986
	{OP_WR, GRCBASE_XPB + PB_REG_CONTROL, 0x20},
#define XPB_COMMON_END          987
#define DQ_COMMON_START         987
	{OP_WR, DORQ_REG_MODE_ACT, 0x2},
	{OP_WR, DORQ_REG_NORM_CID_OFST, 0x3},
	{OP_WR, DORQ_REG_OUTST_REQ, 0x4},
	{OP_WR, DORQ_REG_DPM_CID_ADDR, 0x8},
	{OP_WR, DORQ_REG_RSP_INIT_CRD, 0x2},
	{OP_WR, DORQ_REG_NORM_CMHEAD_TX, 0x90},
	{OP_WR, DORQ_REG_CMHEAD_RX, 0x90},
	{OP_WR, DORQ_REG_SHRT_CMHEAD, 0x800090},
	{OP_WR, DORQ_REG_ERR_CMHEAD, 0x8140000},
	{OP_WR, DORQ_REG_AGG_CMD0, 0x8a},
	{OP_WR, DORQ_REG_AGG_CMD1, 0x80},
	{OP_WR, DORQ_REG_AGG_CMD2, 0x90},
	{OP_WR, DORQ_REG_AGG_CMD3, 0x80},
	{OP_WR, DORQ_REG_SHRT_ACT_CNT, 0x6},
	{OP_WR, DORQ_REG_DQ_FIFO_FULL_TH, 0x7d0},
	{OP_WR, DORQ_REG_DQ_FIFO_AFULL_TH, 0x76c},
	{OP_WR, DORQ_REG_REGN, 0x7c1004},
	{OP_WR, DORQ_REG_IF_EN, 0xf},
#define DQ_COMMON_END           1005
#define TIMERS_COMMON_START     1005
	{OP_ZR, TM_REG_CLIN_PRIOR0_CLIENT, 0x2},
	{OP_WR, TM_REG_LIN_SETCLR_FIFO_ALFULL_THR, 0x1c},
	{OP_WR, TM_REG_CFC_AC_CRDCNT_VAL, 0x1},
	{OP_WR, TM_REG_CFC_CLD_CRDCNT_VAL, 0x1},
	{OP_WR, TM_REG_CLOUT_CRDCNT0_VAL, 0x1},
	{OP_WR, TM_REG_CLOUT_CRDCNT1_VAL, 0x1},
	{OP_WR, TM_REG_CLOUT_CRDCNT2_VAL, 0x1},
	{OP_WR, TM_REG_EXP_CRDCNT_VAL, 0x1},
	{OP_WR_E1, TM_REG_PCIARB_CRDCNT_VAL, 0x1},
	{OP_WR_E1H, TM_REG_PCIARB_CRDCNT_VAL, 0x2},
	{OP_WR_ASIC, TM_REG_TIMER_TICK_SIZE, 0x3d090},
	{OP_WR_EMUL, TM_REG_TIMER_TICK_SIZE, 0x9c},
	{OP_WR_FPGA, TM_REG_TIMER_TICK_SIZE, 0x9c4},
	{OP_WR, TM_REG_CL0_CONT_REGION, 0x8},
	{OP_WR, TM_REG_CL1_CONT_REGION, 0xc},
	{OP_WR, TM_REG_CL2_CONT_REGION, 0x10},
	{OP_WR, TM_REG_TM_CONTEXT_REGION, 0x20},
	{OP_WR, TM_REG_EN_TIMERS, 0x1},
	{OP_WR, TM_REG_EN_REAL_TIME_CNT, 0x1},
	{OP_WR, TM_REG_EN_CL0_INPUT, 0x1},
	{OP_WR, TM_REG_EN_CL1_INPUT, 0x1},
	{OP_WR, TM_REG_EN_CL2_INPUT, 0x1},
#define TIMERS_COMMON_END       1027
#define TIMERS_PORT0_START      1027
	{OP_ZR, TM_REG_LIN0_PHY_ADDR, 0x2},
#define TIMERS_PORT0_END        1028
#define TIMERS_PORT1_START      1028
	{OP_ZR, TM_REG_LIN1_PHY_ADDR, 0x2},
#define TIMERS_PORT1_END        1029
#define XSDM_COMMON_START       1029
	{OP_WR_E1, XSDM_REG_CFC_RSP_START_ADDR, 0xa14},
	{OP_WR_E1H, XSDM_REG_CFC_RSP_START_ADDR, 0x424},
	{OP_WR_E1, XSDM_REG_CMP_COUNTER_START_ADDR, 0xa00},
	{OP_WR_E1H, XSDM_REG_CMP_COUNTER_START_ADDR, 0x410},
	{OP_WR_E1, XSDM_REG_Q_COUNTER_START_ADDR, 0xa04},
	{OP_WR_E1H, XSDM_REG_Q_COUNTER_START_ADDR, 0x414},
	{OP_WR, XSDM_REG_CMP_COUNTER_MAX0, 0xffff},
	{OP_WR, XSDM_REG_CMP_COUNTER_MAX1, 0xffff},
	{OP_WR, XSDM_REG_CMP_COUNTER_MAX2, 0xffff},
	{OP_WR, XSDM_REG_CMP_COUNTER_MAX3, 0xffff},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_0, 0x20},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_1, 0x20},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_2, 0x34},
	{OP_WR, XSDM_REG_AGG_INT_EVENT_3, 0x35},
	{OP_ZR, XSDM_REG_AGG_INT_EVENT_4, 0x5c},
	{OP_WR, XSDM_REG_AGG_INT_MODE_0, 0x1},
	{OP_ZR, XSDM_REG_AGG_INT_MODE_1, 0x1f},
	{OP_WR, XSDM_REG_ENABLE_IN1, 0x7ffffff},
	{OP_WR, XSDM_REG_ENABLE_IN2, 0x3f},
	{OP_WR, XSDM_REG_ENABLE_OUT1, 0x7ffffff},
	{OP_WR, XSDM_REG_ENABLE_OUT2, 0xf},
	{OP_RD, XSDM_REG_NUM_OF_Q0_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q1_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q3_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q4_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q5_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q6_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q7_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q8_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q9_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q10_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_Q11_CMD, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_PKT_END_MSG, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_PXP_ASYNC_REQ, 0x0},
	{OP_RD, XSDM_REG_NUM_OF_ACK_AFTER_PLACE, 0x0},
	{OP_WR_E1, XSDM_REG_INIT_CREDIT_PXP_CTRL, 0x1},
	{OP_WR_ASIC, XSDM_REG_TIMER_TICK, 0x3e8},
	{OP_WR_EMUL, XSDM_REG_TIMER_TICK, 0x1},
	{OP_WR_FPGA, XSDM_REG_TIMER_TICK, 0xa},
#define XSDM_COMMON_END         1068
#define QM_COMMON_START         1068
	{OP_WR, QM_REG_ACTCTRINITVAL_0, 0x6},
	{OP_WR, QM_REG_ACTCTRINITVAL_1, 0x5},
	{OP_WR, QM_REG_ACTCTRINITVAL_2, 0xa},
	{OP_WR, QM_REG_ACTCTRINITVAL_3, 0x5},
	{OP_WR, QM_REG_PCIREQAT, 0x2},
	{OP_WR, QM_REG_CMINITCRD_0, 0x4},
	{OP_WR, QM_REG_CMINITCRD_1, 0x4},
	{OP_WR, QM_REG_CMINITCRD_2, 0x4},
	{OP_WR, QM_REG_CMINITCRD_3, 0x4},
	{OP_WR, QM_REG_CMINITCRD_4, 0x4},
	{OP_WR, QM_REG_CMINITCRD_5, 0x4},
	{OP_WR, QM_REG_CMINITCRD_6, 0x4},
	{OP_WR, QM_REG_CMINITCRD_7, 0x4},
	{OP_WR, QM_REG_OUTLDREQ, 0x4},
	{OP_WR, QM_REG_CTXREG_0, 0x7c},
	{OP_WR, QM_REG_CTXREG_1, 0x3d},
	{OP_WR, QM_REG_CTXREG_2, 0x3f},
	{OP_WR, QM_REG_CTXREG_3, 0x9c},
	{OP_WR, QM_REG_ENSEC, 0x7},
	{OP_ZR, QM_REG_QVOQIDX_0, 0x5},
	{OP_WR, QM_REG_WRRWEIGHTS_0, 0x1010101},
	{OP_WR, QM_REG_QVOQIDX_5, 0x0},
	{OP_WR, QM_REG_QVOQIDX_6, 0x4},
	{OP_WR, QM_REG_QVOQIDX_7, 0x4},
	{OP_WR, QM_REG_QVOQIDX_8, 0x2},
	{OP_WR, QM_REG_WRRWEIGHTS_1, 0x8012004},
	{OP_WR, QM_REG_QVOQIDX_9, 0x5},
	{OP_WR, QM_REG_QVOQIDX_10, 0x5},
	{OP_WR, QM_REG_QVOQIDX_11, 0x5},
	{OP_WR, QM_REG_QVOQIDX_12, 0x5},
	{OP_WR, QM_REG_WRRWEIGHTS_2, 0x20081001},
	{OP_WR, QM_REG_QVOQIDX_13, 0x8},
	{OP_WR, QM_REG_QVOQIDX_14, 0x6},
	{OP_WR, QM_REG_QVOQIDX_15, 0x7},
	{OP_WR, QM_REG_QVOQIDX_16, 0x0},
	{OP_WR, QM_REG_WRRWEIGHTS_3, 0x1010120},
	{OP_ZR, QM_REG_QVOQIDX_17, 0x4},
	{OP_WR, QM_REG_WRRWEIGHTS_4, 0x1010101},
	{OP_ZR_E1, QM_REG_QVOQIDX_21, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_21, 0x0},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_5, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_22, 0x4},
	{OP_ZR_E1, QM_REG_QVOQIDX_25, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_23, 0x4},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_6, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_24, 0x2},
	{OP_ZR_E1, QM_REG_QVOQIDX_29, 0x3},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_5, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_25, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_26, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_27, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_28, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_6, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_29, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_30, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_31, 0x7},
	{OP_WR, QM_REG_QVOQIDX_32, 0x1},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_7, 0x1010101},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_7, 0x1010120},
	{OP_WR, QM_REG_QVOQIDX_33, 0x1},
	{OP_WR, QM_REG_QVOQIDX_34, 0x1},
	{OP_WR, QM_REG_QVOQIDX_35, 0x1},
	{OP_WR, QM_REG_QVOQIDX_36, 0x1},
	{OP_WR, QM_REG_WRRWEIGHTS_8, 0x1010101},
	{OP_WR, QM_REG_QVOQIDX_37, 0x1},
	{OP_WR, QM_REG_QVOQIDX_38, 0x4},
	{OP_WR, QM_REG_QVOQIDX_39, 0x4},
	{OP_WR, QM_REG_QVOQIDX_40, 0x2},
	{OP_WR, QM_REG_WRRWEIGHTS_9, 0x8012004},
	{OP_WR, QM_REG_QVOQIDX_41, 0x5},
	{OP_WR, QM_REG_QVOQIDX_42, 0x5},
	{OP_WR, QM_REG_QVOQIDX_43, 0x5},
	{OP_WR, QM_REG_QVOQIDX_44, 0x5},
	{OP_WR, QM_REG_WRRWEIGHTS_10, 0x20081001},
	{OP_WR, QM_REG_QVOQIDX_45, 0x8},
	{OP_WR, QM_REG_QVOQIDX_46, 0x6},
	{OP_WR, QM_REG_QVOQIDX_47, 0x7},
	{OP_WR, QM_REG_QVOQIDX_48, 0x1},
	{OP_WR, QM_REG_WRRWEIGHTS_11, 0x1010120},
	{OP_WR, QM_REG_QVOQIDX_49, 0x1},
	{OP_WR, QM_REG_QVOQIDX_50, 0x1},
	{OP_WR, QM_REG_QVOQIDX_51, 0x1},
	{OP_WR, QM_REG_QVOQIDX_52, 0x1},
	{OP_WR, QM_REG_WRRWEIGHTS_12, 0x1010101},
	{OP_WR, QM_REG_QVOQIDX_53, 0x1},
	{OP_WR_E1, QM_REG_QVOQIDX_54, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_54, 0x4},
	{OP_WR_E1, QM_REG_QVOQIDX_55, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_55, 0x4},
	{OP_WR_E1, QM_REG_QVOQIDX_56, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_56, 0x2},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_13, 0x1010101},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_13, 0x8012004},
	{OP_WR_E1, QM_REG_QVOQIDX_57, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_57, 0x5},
	{OP_WR_E1, QM_REG_QVOQIDX_58, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_58, 0x5},
	{OP_WR_E1, QM_REG_QVOQIDX_59, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_59, 0x5},
	{OP_WR_E1, QM_REG_QVOQIDX_60, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_60, 0x5},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_14, 0x1010101},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_14, 0x20081001},
	{OP_WR_E1, QM_REG_QVOQIDX_61, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_61, 0x8},
	{OP_WR_E1, QM_REG_QVOQIDX_62, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_62, 0x6},
	{OP_WR_E1, QM_REG_QVOQIDX_63, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_63, 0x7},
	{OP_WR_E1, QM_REG_WRRWEIGHTS_15, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_64, 0x0},
	{OP_WR_E1, QM_REG_VOQQMASK_0_LSB, 0xffff003f},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_15, 0x1010120},
	{OP_ZR_E1, QM_REG_VOQQMASK_0_MSB, 0x2},
	{OP_ZR_E1H, QM_REG_QVOQIDX_65, 0x4},
	{OP_WR_E1, QM_REG_VOQQMASK_1_MSB, 0xffff003f},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_16, 0x1010101},
	{OP_WR_E1, QM_REG_VOQQMASK_2_LSB, 0x100},
	{OP_WR_E1H, QM_REG_QVOQIDX_69, 0x0},
	{OP_WR_E1, QM_REG_VOQQMASK_2_MSB, 0x100},
	{OP_WR_E1H, QM_REG_QVOQIDX_70, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_71, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_72, 0x2},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_17, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_73, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_74, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_75, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_76, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_18, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_77, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_78, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_79, 0x7},
	{OP_WR_E1H, QM_REG_QVOQIDX_80, 0x0},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_19, 0x1010120},
	{OP_ZR_E1H, QM_REG_QVOQIDX_81, 0x4},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_20, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_85, 0x0},
	{OP_WR_E1H, QM_REG_QVOQIDX_86, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_87, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_88, 0x2},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_21, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_89, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_90, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_91, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_92, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_22, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_93, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_94, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_95, 0x7},
	{OP_WR_E1H, QM_REG_QVOQIDX_96, 0x1},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_23, 0x1010120},
	{OP_WR_E1H, QM_REG_QVOQIDX_97, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_98, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_99, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_100, 0x1},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_24, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_101, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_102, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_103, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_104, 0x2},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_25, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_105, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_106, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_107, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_108, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_26, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_109, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_110, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_111, 0x7},
	{OP_WR_E1H, QM_REG_QVOQIDX_112, 0x1},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_27, 0x1010120},
	{OP_WR_E1H, QM_REG_QVOQIDX_113, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_114, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_115, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_116, 0x1},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_28, 0x1010101},
	{OP_WR_E1H, QM_REG_QVOQIDX_117, 0x1},
	{OP_WR_E1H, QM_REG_QVOQIDX_118, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_119, 0x4},
	{OP_WR_E1H, QM_REG_QVOQIDX_120, 0x2},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_29, 0x8012004},
	{OP_WR_E1H, QM_REG_QVOQIDX_121, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_122, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_123, 0x5},
	{OP_WR_E1H, QM_REG_QVOQIDX_124, 0x5},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_30, 0x20081001},
	{OP_WR_E1H, QM_REG_QVOQIDX_125, 0x8},
	{OP_WR_E1H, QM_REG_QVOQIDX_126, 0x6},
	{OP_WR_E1H, QM_REG_QVOQIDX_127, 0x7},
	{OP_WR_E1H, QM_REG_WRRWEIGHTS_31, 0x1010120},
	{OP_WR_E1H, QM_REG_VOQQMASK_0_LSB, 0x3f003f},
	{OP_WR_E1H, QM_REG_VOQQMASK_0_MSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_0_LSB_EXT_A, 0x3f003f},
	{OP_WR_E1H, QM_REG_VOQQMASK_0_MSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_1_LSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_1_MSB, 0x3f003f},
	{OP_WR_E1H, QM_REG_VOQQMASK_1_LSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_1_MSB_EXT_A, 0x3f003f},
	{OP_WR_E1H, QM_REG_VOQQMASK_2_LSB, 0x1000100},
	{OP_WR_E1H, QM_REG_VOQQMASK_2_MSB, 0x1000100},
	{OP_WR_E1H, QM_REG_VOQQMASK_2_LSB_EXT_A, 0x1000100},
	{OP_WR_E1H, QM_REG_VOQQMASK_2_MSB_EXT_A, 0x1000100},
	{OP_ZR, QM_REG_VOQQMASK_3_LSB, 0x2},
	{OP_WR_E1, QM_REG_VOQQMASK_4_LSB, 0xc0},
	{OP_WR_E1H, QM_REG_VOQQMASK_3_LSB_EXT_A, 0x0},
	{OP_WR_E1, QM_REG_VOQQMASK_4_MSB, 0xc0},
	{OP_WR_E1H, QM_REG_VOQQMASK_3_MSB_EXT_A, 0x0},
	{OP_WR_E1, QM_REG_VOQQMASK_5_LSB, 0x1e00},
	{OP_WR_E1H, QM_REG_VOQQMASK_4_LSB, 0xc000c0},
	{OP_WR_E1, QM_REG_VOQQMASK_5_MSB, 0x1e00},
	{OP_WR_E1H, QM_REG_VOQQMASK_4_MSB, 0xc000c0},
	{OP_WR_E1, QM_REG_VOQQMASK_6_LSB, 0x4000},
	{OP_WR_E1H, QM_REG_VOQQMASK_4_LSB_EXT_A, 0xc000c0},
	{OP_WR_E1, QM_REG_VOQQMASK_6_MSB, 0x4000},
	{OP_WR_E1H, QM_REG_VOQQMASK_4_MSB_EXT_A, 0xc000c0},
	{OP_WR_E1, QM_REG_VOQQMASK_7_LSB, 0x8000},
	{OP_WR_E1H, QM_REG_VOQQMASK_5_LSB, 0x1e001e00},
	{OP_WR_E1, QM_REG_VOQQMASK_7_MSB, 0x8000},
	{OP_WR_E1H, QM_REG_VOQQMASK_5_MSB, 0x1e001e00},
	{OP_WR_E1, QM_REG_VOQQMASK_8_LSB, 0x2000},
	{OP_WR_E1H, QM_REG_VOQQMASK_5_LSB_EXT_A, 0x1e001e00},
	{OP_WR_E1, QM_REG_VOQQMASK_8_MSB, 0x2000},
	{OP_WR_E1H, QM_REG_VOQQMASK_5_MSB_EXT_A, 0x1e001e00},
	{OP_ZR_E1, QM_REG_VOQQMASK_9_LSB, 0x7},
	{OP_WR_E1H, QM_REG_VOQQMASK_6_LSB, 0x40004000},
	{OP_WR_E1H, QM_REG_VOQQMASK_6_MSB, 0x40004000},
	{OP_WR_E1H, QM_REG_VOQQMASK_6_LSB_EXT_A, 0x40004000},
	{OP_WR_E1H, QM_REG_VOQQMASK_6_MSB_EXT_A, 0x40004000},
	{OP_WR_E1H, QM_REG_VOQQMASK_7_LSB, 0x80008000},
	{OP_WR_E1H, QM_REG_VOQQMASK_7_MSB, 0x80008000},
	{OP_WR_E1H, QM_REG_VOQQMASK_7_LSB_EXT_A, 0x80008000},
	{OP_WR_E1H, QM_REG_VOQQMASK_7_MSB_EXT_A, 0x80008000},
	{OP_WR_E1H, QM_REG_VOQQMASK_8_LSB, 0x20002000},
	{OP_WR_E1H, QM_REG_VOQQMASK_8_MSB, 0x20002000},
	{OP_WR_E1H, QM_REG_VOQQMASK_8_LSB_EXT_A, 0x20002000},
	{OP_WR_E1H, QM_REG_VOQQMASK_8_MSB_EXT_A, 0x20002000},
	{OP_ZR_E1H, QM_REG_VOQQMASK_9_LSB, 0x2},
	{OP_WR_E1H, QM_REG_VOQQMASK_9_LSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_9_MSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_10_LSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_10_MSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_10_LSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_10_MSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_11_LSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_11_MSB, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_11_LSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQQMASK_11_MSB_EXT_A, 0x0},
	{OP_WR_E1H, QM_REG_VOQPORT_0, 0x0},
	{OP_WR, QM_REG_VOQPORT_1, 0x1},
	{OP_ZR, QM_REG_VOQPORT_2, 0xa},
	{OP_WR, QM_REG_CMINTVOQMASK_0, 0xc08},
	{OP_WR, QM_REG_CMINTVOQMASK_1, 0x40},
	{OP_WR, QM_REG_CMINTVOQMASK_2, 0x100},
	{OP_WR, QM_REG_CMINTVOQMASK_3, 0x20},
	{OP_WR, QM_REG_CMINTVOQMASK_4, 0x17},
	{OP_WR, QM_REG_CMINTVOQMASK_5, 0x80},
	{OP_WR, QM_REG_CMINTVOQMASK_6, 0x200},
	{OP_WR, QM_REG_CMINTVOQMASK_7, 0x0},
	{OP_WR_E1, QM_REG_HWAEMPTYMASK_LSB, 0xffff01ff},
	{OP_WR_E1H, QM_REG_HWAEMPTYMASK_LSB, 0x1ff01ff},
	{OP_WR_E1, QM_REG_HWAEMPTYMASK_MSB, 0xffff01ff},
	{OP_WR_E1H, QM_REG_HWAEMPTYMASK_MSB, 0x1ff01ff},
	{OP_WR_E1H, QM_REG_HWAEMPTYMASK_LSB_EXT_A, 0x1ff01ff},
	{OP_WR_E1H, QM_REG_HWAEMPTYMASK_MSB_EXT_A, 0x1ff01ff},
	{OP_WR, QM_REG_ENBYPVOQMASK, 0x13},
	{OP_WR, QM_REG_VOQCREDITAFULLTHR, 0x13f},
	{OP_WR, QM_REG_VOQINITCREDIT_0, 0x140},
	{OP_WR, QM_REG_VOQINITCREDIT_1, 0x140},
	{OP_ZR, QM_REG_VOQINITCREDIT_2, 0x2},
	{OP_WR, QM_REG_VOQINITCREDIT_4, 0xc0},
	{OP_ZR, QM_REG_VOQINITCREDIT_5, 0x7},
	{OP_WR, QM_REG_TASKCRDCOST_0, 0x48},
	{OP_WR, QM_REG_TASKCRDCOST_1, 0x48},
	{OP_ZR, QM_REG_TASKCRDCOST_2, 0x2},
	{OP_WR, QM_REG_TASKCRDCOST_4, 0x48},
	{OP_ZR, QM_REG_TASKCRDCOST_5, 0x7},
	{OP_WR, QM_REG_BYTECRDINITVAL, 0x8000},
	{OP_WR, QM_REG_BYTECRDCOST, 0x25e4},
	{OP_WR, QM_REG_BYTECREDITAFULLTHR, 0x7fff},
	{OP_WR_E1, QM_REG_ENBYTECRD_LSB, 0x7},
	{OP_WR_E1H, QM_REG_ENBYTECRD_LSB, 0x70007},
	{OP_WR_E1, QM_REG_ENBYTECRD_MSB, 0x7},
	{OP_WR_E1H, QM_REG_ENBYTECRD_MSB, 0x70007},
	{OP_WR_E1H, QM_REG_ENBYTECRD_LSB_EXT_A, 0x70007},
	{OP_WR_E1H, QM_REG_ENBYTECRD_MSB_EXT_A, 0x70007},
	{OP_WR, QM_REG_BYTECRDPORT_LSB, 0x0},
	{OP_WR, QM_REG_BYTECRDPORT_MSB, 0xffffffff},
	{OP_WR_E1, QM_REG_FUNCNUMSEL_LSB, 0x0},
	{OP_WR_E1H, QM_REG_BYTECRDPORT_LSB_EXT_A, 0x0},
	{OP_WR_E1, QM_REG_FUNCNUMSEL_MSB, 0xffffffff},
	{OP_WR_E1H, QM_REG_BYTECRDPORT_MSB_EXT_A, 0xffffffff},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_0, 0x0},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_1, 0x2},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_2, 0x1},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_3, 0x3},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_4, 0x4},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_5, 0x6},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_6, 0x5},
	{OP_WR_E1H, QM_REG_PQ2PCIFUNC_7, 0x7},
	{OP_WR, QM_REG_CMINTEN, 0xff},
#define QM_COMMON_END           1368
#define PBF_COMMON_START        1368
	{OP_WR, PBF_REG_INIT, 0x1},
	{OP_WR, PBF_REG_INIT_P4, 0x1},
	{OP_WR, PBF_REG_MAC_LB_ENABLE, 0x1},
	{OP_WR, PBF_REG_IF_ENABLE_REG, 0x7fff},
	{OP_WR, PBF_REG_INIT_P4, 0x0},
	{OP_WR, PBF_REG_INIT, 0x0},
	{OP_WR, PBF_REG_DISABLE_NEW_TASK_PROC_P4, 0x0},
#define PBF_COMMON_END          1375
#define PBF_PORT0_START         1375
	{OP_WR, PBF_REG_INIT_P0, 0x1},
	{OP_WR, PBF_REG_MAC_IF0_ENABLE, 0x1},
	{OP_WR, PBF_REG_INIT_P0, 0x0},
	{OP_WR, PBF_REG_DISABLE_NEW_TASK_PROC_P0, 0x0},
#define PBF_PORT0_END           1379
#define PBF_PORT1_START         1379
	{OP_WR, PBF_REG_INIT_P1, 0x1},
	{OP_WR, PBF_REG_MAC_IF1_ENABLE, 0x1},
	{OP_WR, PBF_REG_INIT_P1, 0x0},
	{OP_WR, PBF_REG_DISABLE_NEW_TASK_PROC_P1, 0x0},
#define PBF_PORT1_END           1383
#define XCM_COMMON_START        1383
	{OP_WR, XCM_REG_XX_OVFL_EVNT_ID, 0x32},
	{OP_WR, XCM_REG_XQM_XCM_HDR_P, 0x3150020},
	{OP_WR, XCM_REG_XQM_XCM_HDR_S, 0x3150020},
	{OP_WR, XCM_REG_TM_XCM_HDR, 0x1000030},
	{OP_WR, XCM_REG_ERR_XCM_HDR, 0x8100000},
	{OP_WR, XCM_REG_ERR_EVNT_ID, 0x33},
	{OP_WR, XCM_REG_EXPR_EVNT_ID, 0x30},
	{OP_WR, XCM_REG_STOP_EVNT_ID, 0x31},
	{OP_WR, XCM_REG_STORM_WEIGHT, 0x2},
	{OP_WR, XCM_REG_TSEM_WEIGHT, 0x5},
	{OP_WR, XCM_REG_CSEM_WEIGHT, 0x2},
	{OP_WR, XCM_REG_USEM_WEIGHT, 0x2},
	{OP_WR, XCM_REG_PBF_WEIGHT, 0x7},
	{OP_WR, XCM_REG_NIG1_WEIGHT, 0x1},
	{OP_WR, XCM_REG_CP_WEIGHT, 0x0},
	{OP_WR, XCM_REG_XSDM_WEIGHT, 0x5},
	{OP_WR, XCM_REG_XQM_P_WEIGHT, 0x3},
	{OP_WR, XCM_REG_XCM_XQM_USE_Q, 0x1},
	{OP_WR, XCM_REG_XQM_BYP_ACT_UPD, 0x6},
	{OP_WR, XCM_REG_UNA_GT_NXT_Q, 0x0},
	{OP_WR, XCM_REG_AUX1_Q, 0x2},
	{OP_WR, XCM_REG_AUX_CNT_FLG_Q_19, 0x1},
	{OP_WR, XCM_REG_GR_ARB_TYPE, 0x1},
	{OP_WR, XCM_REG_GR_LD0_PR, 0x1},
	{OP_WR, XCM_REG_GR_LD1_PR, 0x2},
	{OP_WR, XCM_REG_CFC_INIT_CRD, 0x1},
	{OP_WR, XCM_REG_FIC0_INIT_CRD, 0x40},
	{OP_WR, XCM_REG_FIC1_INIT_CRD, 0x40},
	{OP_WR, XCM_REG_TM_INIT_CRD, 0x4},
	{OP_WR, XCM_REG_XQM_INIT_CRD, 0x20},
	{OP_WR, XCM_REG_XX_INIT_CRD, 0x2},
	{OP_WR_E1, XCM_REG_XX_MSG_NUM, 0x1f},
	{OP_WR_E1H, XCM_REG_XX_MSG_NUM, 0x20},
	{OP_ZR, XCM_REG_XX_TABLE, 0x12},
	{OP_SW_E1, XCM_REG_XX_DESCR_TABLE, 0x1f59f7},
	{OP_SW_E1H, XCM_REG_XX_DESCR_TABLE, 0x1f5aef},
	{OP_WR, XCM_REG_N_SM_CTX_LD_0, 0xf},
	{OP_WR, XCM_REG_N_SM_CTX_LD_1, 0x7},
	{OP_WR, XCM_REG_N_SM_CTX_LD_2, 0xb},
	{OP_WR, XCM_REG_N_SM_CTX_LD_3, 0xe},
	{OP_ZR, XCM_REG_N_SM_CTX_LD_4, 0x4},
	{OP_WR, XCM_REG_XCM_REG0_SZ, 0x4},
	{OP_WR, XCM_REG_XCM_STORM0_IFEN, 0x1},
	{OP_WR, XCM_REG_XCM_STORM1_IFEN, 0x1},
	{OP_WR, XCM_REG_XCM_XQM_IFEN, 0x1},
	{OP_WR, XCM_REG_STORM_XCM_IFEN, 0x1},
	{OP_WR, XCM_REG_XQM_XCM_IFEN, 0x1},
	{OP_WR, XCM_REG_XSDM_IFEN, 0x1},
	{OP_WR, XCM_REG_TM_XCM_IFEN, 0x1},
	{OP_WR, XCM_REG_XCM_TM_IFEN, 0x1},
	{OP_WR, XCM_REG_TSEM_IFEN, 0x1},
	{OP_WR, XCM_REG_CSEM_IFEN, 0x1},
	{OP_WR, XCM_REG_USEM_IFEN, 0x1},
	{OP_WR, XCM_REG_DORQ_IFEN, 0x1},
	{OP_WR, XCM_REG_PBF_IFEN, 0x1},
	{OP_WR, XCM_REG_NIG0_IFEN, 0x1},
	{OP_WR, XCM_REG_NIG1_IFEN, 0x1},
	{OP_WR, XCM_REG_CDU_AG_WR_IFEN, 0x1},
	{OP_WR, XCM_REG_CDU_AG_RD_IFEN, 0x1},
	{OP_WR, XCM_REG_CDU_SM_WR_IFEN, 0x1},
	{OP_WR, XCM_REG_CDU_SM_RD_IFEN, 0x1},
	{OP_WR, XCM_REG_XCM_CFC_IFEN, 0x1},
#define XCM_COMMON_END          1445
#define XCM_PORT0_START         1445
	{OP_WR_E1, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
#define XCM_PORT0_END           1453
#define XCM_PORT1_START         1453
	{OP_WR_E1, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
#define XCM_PORT1_END           1461
#define XCM_FUNC0_START         1461
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_0, 0x0},
#define XCM_FUNC0_END           1470
#define XCM_FUNC1_START         1470
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_1, 0x0},
#define XCM_FUNC1_END           1479
#define XCM_FUNC2_START         1479
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_0, 0x0},
#define XCM_FUNC2_END           1488
#define XCM_FUNC3_START         1488
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_1, 0x0},
#define XCM_FUNC3_END           1497
#define XCM_FUNC4_START         1497
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_0, 0x0},
#define XCM_FUNC4_END           1506
#define XCM_FUNC5_START         1506
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_1, 0x0},
#define XCM_FUNC5_END           1515
#define XCM_FUNC6_START         1515
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_0, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_0, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD00, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD10, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD00, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD10, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL00, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL10, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_0, 0x0},
#define XCM_FUNC6_END           1524
#define XCM_FUNC7_START         1524
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_TMR_VAL_1, 0xc8},
	{OP_WR_E1H, XCM_REG_GLB_DEL_ACK_MAX_CNT_1, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD01, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_SET_TMR_CNT_FLG_CMD11, 0x0},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD01, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_CMD11, 0x2},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL01, 0xff},
	{OP_WR_E1H, XCM_REG_WU_DA_CNT_UPD_VAL11, 0xff},
	{OP_WR_E1H, XCM_REG_PHYS_QNUM3_1, 0x0},
#define XCM_FUNC7_END           1533
#define XSEM_COMMON_START       1533
	{OP_RD, XSEM_REG_MSG_NUM_FIC0, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FIC1, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FOC0, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FOC1, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FOC2, 0x0},
	{OP_RD, XSEM_REG_MSG_NUM_FOC3, 0x0},
	{OP_WR, XSEM_REG_ARB_ELEMENT0, 0x1},
	{OP_WR, XSEM_REG_ARB_ELEMENT1, 0x2},
	{OP_WR, XSEM_REG_ARB_ELEMENT2, 0x3},
	{OP_WR, XSEM_REG_ARB_ELEMENT3, 0x0},
	{OP_WR, XSEM_REG_ARB_ELEMENT4, 0x4},
	{OP_WR, XSEM_REG_ARB_CYCLE_SIZE, 0x1},
	{OP_WR, XSEM_REG_TS_0_AS, 0x0},
	{OP_WR, XSEM_REG_TS_1_AS, 0x1},
	{OP_WR, XSEM_REG_TS_2_AS, 0x4},
	{OP_WR, XSEM_REG_TS_3_AS, 0x0},
	{OP_WR, XSEM_REG_TS_4_AS, 0x1},
	{OP_WR, XSEM_REG_TS_5_AS, 0x3},
	{OP_WR, XSEM_REG_TS_6_AS, 0x0},
	{OP_WR, XSEM_REG_TS_7_AS, 0x1},
	{OP_WR, XSEM_REG_TS_8_AS, 0x4},
	{OP_WR, XSEM_REG_TS_9_AS, 0x0},
	{OP_WR, XSEM_REG_TS_10_AS, 0x1},
	{OP_WR, XSEM_REG_TS_11_AS, 0x3},
	{OP_WR, XSEM_REG_TS_12_AS, 0x0},
	{OP_WR, XSEM_REG_TS_13_AS, 0x1},
	{OP_WR, XSEM_REG_TS_14_AS, 0x4},
	{OP_WR, XSEM_REG_TS_15_AS, 0x0},
	{OP_WR, XSEM_REG_TS_16_AS, 0x4},
	{OP_WR, XSEM_REG_TS_17_AS, 0x3},
	{OP_ZR, XSEM_REG_TS_18_AS, 0x2},
	{OP_WR, XSEM_REG_ENABLE_IN, 0x3fff},
	{OP_WR, XSEM_REG_ENABLE_OUT, 0x3ff},
	{OP_WR, XSEM_REG_FIC0_DISABLE, 0x0},
	{OP_WR, XSEM_REG_FIC1_DISABLE, 0x0},
	{OP_WR, XSEM_REG_PAS_DISABLE, 0x0},
	{OP_WR, XSEM_REG_THREADS_LIST, 0xffff},
	{OP_ZR, XSEM_REG_PASSIVE_BUFFER, 0x800},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x18bc0, 0x1},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x18000, 0x0},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x18040, 0x18},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x18080, 0xc},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x180c0, 0x66},
	{OP_WR_ASIC, XSEM_REG_FAST_MEMORY + 0x18300, 0x7a120},
	{OP_WR_EMUL, XSEM_REG_FAST_MEMORY + 0x18300, 0x138},
	{OP_WR_FPGA, XSEM_REG_FAST_MEMORY + 0x18300, 0x1388},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x183c0, 0x1f4},
	{OP_WR_ASIC, XSEM_REG_FAST_MEMORY + 0x18340, 0x1f4},
	{OP_WR_EMUL, XSEM_REG_FAST_MEMORY + 0x18340, 0x0},
	{OP_WR_FPGA, XSEM_REG_FAST_MEMORY + 0x18340, 0x5},
	{OP_WR_EMUL, XSEM_REG_FAST_MEMORY + 0x18380, 0x4c4b4},
	{OP_WR_ASIC, XSEM_REG_FAST_MEMORY + 0x18380, 0x1dcd6500},
	{OP_WR_EMUL_E1H, XSEM_REG_FAST_MEMORY + 0x11480, 0x0},
	{OP_WR_FPGA, XSEM_REG_FAST_MEMORY + 0x18380, 0x4c4b40},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x55c8, 0x2},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x11480, 0x1},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x5000, 0x48},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2808, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1020, 0xc8},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2080, 0x48},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1000, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x9020, 0xc8},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x5128, 0x8e},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x9000, 0x2},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x5368, 0x0},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x21a8, 0x86},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x5370, 0x25a16},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2000, 0x20},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x5418, 0x45a18},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x23c8, 0x0},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1518, 0x1},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x23d0, 0x25b0e},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1830, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2658, 0x45b10},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1838, 0x0},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x28a0, 0x0},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x1820, 0x25a1c},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x2890, 0x0},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4ac0, 0x2},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x3010, 0x1},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4b00, 0x4},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x4040, 0x4},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x1f50, 0x25a1e},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x4000, 0x105b14},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6ac0, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6b00, 0x4},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x83b0, 0x25b24},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x10800, 0x0},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x10c00, 0x105a20},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x10c00, 0x105b26},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x10800, 0x1000000},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x10c40, 0x85a30},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x10c40, 0x85b36},
	{OP_WR, XSEM_REG_FAST_MEMORY + 0x10800, 0x2000000},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x10c60, 0x85a38},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x10c60, 0x85b3e},
	{OP_ZP_E1, XSEM_REG_INT_TABLE, 0xa35a40},
	{OP_ZP_E1H, XSEM_REG_INT_TABLE, 0xa25b46},
	{OP_ZP_E1, XSEM_REG_PRAM, 0x33a45a69},
	{OP_ZP_E1H, XSEM_REG_PRAM, 0x33d45b6f},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x8000, 0x38176752},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x8000, 0x377c6864},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x10000, 0x3d707558},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x10000, 0x3dcb7643},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x18000, 0x1a0384b4},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x18000, 0x1cd085b6},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x20000, 0x598b35},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x20000, 0x5a8cea},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x28000, 0x598b4c},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x28000, 0x5a8d01},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x30000, 0x598b63},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x30000, 0x5a8d18},
	{OP_ZP_E1, XSEM_REG_PRAM + 0x38000, 0x598b7a},
	{OP_ZP_E1H, XSEM_REG_PRAM + 0x38000, 0x5a8d2f},
#define XSEM_COMMON_END         1647
#define XSEM_PORT0_START        1647
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1400, 0xa},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xa000, 0x28},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1450, 0x6},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xa140, 0xc},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x5378, 0xc},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x23d8, 0xc},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x5378 + 0x30, 0x28b91},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x23d8 + 0x30, 0x28d46},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x55d0, 0x78b93},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2810, 0x78d48},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x55f0, 0x7},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2830, 0x7},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1500, 0x0},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x3000, 0x1},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1508, 0x1},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5020, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3020, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5030, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3030, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5000, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3000, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5010, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3010, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5048, 0xc},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x3040, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x5048 + 0x30, 0x28d4f},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3048, 0xc},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x50b8, 0x1},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x3048 + 0x30, 0x28b9a},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x6ac8, 0x28d51},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x30b8, 0x1},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6b10, 0x42},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x4ac8, 0x28b9c},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6d20, 0x4},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4b10, 0x42},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4d20, 0x4},
#define XSEM_PORT0_END          1683
#define XSEM_PORT1_START        1683
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1428, 0xa},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xa0a0, 0x28},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x1468, 0x6},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0xa170, 0xc},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x53b0, 0xc},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2410, 0xc},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x53b0 + 0x30, 0x28b9e},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2410 + 0x30, 0x28d53},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x5610, 0x78ba0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x2850, 0x78d55},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x5630, 0x7},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x2870, 0x7},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x1504, 0x0},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x3004, 0x1},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x150c, 0x1},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5028, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3028, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5038, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3038, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5008, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3008, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5018, 0x2},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3018, 0x2},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x5080, 0xc},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x3044, 0x0},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x5080 + 0x30, 0x28d5c},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x3080, 0xc},
	{OP_WR_E1H, XSEM_REG_FAST_MEMORY + 0x50bc, 0x1},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x3080 + 0x30, 0x28ba7},
	{OP_SW_E1H, XSEM_REG_FAST_MEMORY + 0x6ad0, 0x28d5e},
	{OP_WR_E1, XSEM_REG_FAST_MEMORY + 0x30bc, 0x1},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6c18, 0x42},
	{OP_SW_E1, XSEM_REG_FAST_MEMORY + 0x4ad0, 0x28ba9},
	{OP_ZR_E1H, XSEM_REG_FAST_MEMORY + 0x6d30, 0x4},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4c18, 0x42},
	{OP_ZR_E1, XSEM_REG_FAST_MEMORY + 0x4d30, 0x4},
#define XSEM_PORT1_END          1719
#define CDU_COMMON_START        1719
	{OP_WR, CDU_REG_CDU_CONTROL0, 0x1},
	{OP_WR_E1H, CDU_REG_MF_MODE, 0x1},
	{OP_WR, CDU_REG_CDU_CHK_MASK0, 0x3d000},
	{OP_WR, CDU_REG_CDU_CHK_MASK1, 0x3d},
	{OP_WB_E1, CDU_REG_L1TT, 0x2008bab},
	{OP_WB_E1H, CDU_REG_L1TT, 0x2008d60},
	{OP_WB_E1, CDU_REG_MATT, 0x208dab},
	{OP_WB_E1H, CDU_REG_MATT, 0x208f60},
	{OP_ZR, CDU_REG_MATT + 0x80, 0x20},
#define CDU_COMMON_END          1728
#define DMAE_COMMON_START       1728
	{OP_ZR_E1H, DMAE_REG_CMD_MEM, 0xe0},
	{OP_WR, DMAE_REG_CRC16C_INIT, 0x0},
	{OP_WR, DMAE_REG_CRC16T10_INIT, 0x1},
	{OP_WR, DMAE_REG_PXP_REQ_INIT_CRD, 0x2},
	{OP_WR, DMAE_REG_PCI_IFEN, 0x1},
	{OP_WR, DMAE_REG_GRC_IFEN, 0x1},
#define DMAE_COMMON_END         1734
#define PXP_COMMON_START        1734
	{OP_WB_E1, PXP_REG_HST_INBOUND_INT + 0x400, 0x58dcb},
	{OP_WB_E1H, PXP_REG_HST_INBOUND_INT + 0x400, 0x58f80},
	{OP_WB_E1, PXP_REG_HST_INBOUND_INT + 0x420, 0x58dd0},
	{OP_WB_E1H, PXP_REG_HST_INBOUND_INT, 0x58f85},
	{OP_WB_E1, PXP_REG_HST_INBOUND_INT, 0x58dd5},
#define PXP_COMMON_END          1739
#define CFC_COMMON_START        1739
	{OP_ZR_E1H, CFC_REG_LINK_LIST, 0x100},
	{OP_WR, CFC_REG_CONTROL0, 0x10},
	{OP_WR, CFC_REG_DISABLE_ON_ERROR, 0x3fff},
	{OP_WR, CFC_REG_LCREQ_WEIGHTS, 0x84924a},
#define CFC_COMMON_END          1743
#define HC_COMMON_START         1743
	{OP_ZR_E1, HC_REG_USTORM_ADDR_FOR_COALESCE, 0x4},
#define HC_COMMON_END           1744
#define HC_PORT0_START          1744
	{OP_WR_E1, HC_REG_CONFIG_0, 0x1080},
	{OP_ZR_E1, HC_REG_UC_RAM_ADDR_0, 0x2},
	{OP_WR_E1, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1, HC_REG_LEADING_EDGE_0, 0xffff},
	{OP_WR_E1, HC_REG_TRAILING_EDGE_0, 0xffff},
	{OP_WR_E1, HC_REG_AGG_INT_0, 0x0},
	{OP_WR_E1, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1, HC_REG_INT_MASK, 0x1ffff},
	{OP_WR_E1, HC_REG_CONFIG_0, 0x1a82},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
	{OP_ZR_E1, HC_REG_PBA_COMMAND, 0x2},
#define HC_PORT0_END            1762
#define HC_PORT1_START          1762
	{OP_WR_E1, HC_REG_CONFIG_1, 0x1080},
	{OP_ZR_E1, HC_REG_UC_RAM_ADDR_1, 0x2},
	{OP_WR_E1, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1, HC_REG_LEADING_EDGE_1, 0xffff},
	{OP_WR_E1, HC_REG_TRAILING_EDGE_1, 0xffff},
	{OP_WR_E1, HC_REG_AGG_INT_1, 0x0},
	{OP_WR_E1, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_WR_E1, HC_REG_CONFIG_1, 0x1a82},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
	{OP_ZR_E1, HC_REG_PBA_COMMAND + 0x8, 0x2},
#define HC_PORT1_END            1780
#define HC_FUNC0_START          1780
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P0, 0x0},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1H, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1H, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1a82},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_FUNC0_END            1795
#define HC_FUNC1_START          1795
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P1, 0x1},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1H, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1a82},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_FUNC1_END            1810
#define HC_FUNC2_START          1810
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P0, 0x2},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1H, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1H, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1a82},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_FUNC2_END            1825
#define HC_FUNC3_START          1825
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P1, 0x3},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1H, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1a82},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_FUNC3_END            1840
#define HC_FUNC4_START          1840
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P0, 0x4},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1H, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1H, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1a82},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_FUNC4_END            1855
#define HC_FUNC5_START          1855
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P1, 0x5},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1H, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1a82},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_FUNC5_END            1870
#define HC_FUNC6_START          1870
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P0, 0x6},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P0, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT, 0x2},
	{OP_WR_E1H, HC_REG_VQID_0, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_0, 0x0},
	{OP_ZR_E1H, HC_REG_P0_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_0, 0x1a82},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x120, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x370, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x5c0, 0x4a},
#define HC_FUNC6_END            1885
#define HC_FUNC7_START          1885
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1080},
	{OP_WR_E1H, HC_REG_FUNC_NUM_P1, 0x7},
	{OP_WR_E1H, HC_REG_ATTN_NUM_P1, 0x10},
	{OP_WR_E1H, HC_REG_ATTN_IDX + 0x4, 0x0},
	{OP_ZR_E1H, HC_REG_ATTN_BIT + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_VQID_1, 0x2b5},
	{OP_WR_E1H, HC_REG_PCI_CONFIG_1, 0x0},
	{OP_ZR_E1H, HC_REG_P1_PROD_CONS, 0x4a},
	{OP_WR_E1H, HC_REG_INT_MASK + 0x4, 0x1ffff},
	{OP_ZR_E1H, HC_REG_PBA_COMMAND + 0x8, 0x2},
	{OP_WR_E1H, HC_REG_CONFIG_1, 0x1a82},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x90, 0x24},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x248, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x498, 0x4a},
	{OP_ZR_E1H, HC_REG_STATISTIC_COUNTERS + 0x6e8, 0x4a},
#define HC_FUNC7_END            1900
#define PXP2_COMMON_START       1900
	{OP_WR_E1, PXP2_REG_PGL_CONTROL0, 0xe38324},
	{OP_WR_E1H, PXP2_REG_RQ_DRAM_ALIGN, 0x1},
	{OP_WR, PXP2_REG_PGL_CONTROL1, 0x3c10},
	{OP_WR_E1H, PXP2_REG_RQ_ELT_DISABLE, 0x1},
	{OP_WR_E1H, PXP2_REG_WR_REV_MODE, 0x1},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_0, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_1, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_2, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_3, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_4, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_5, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_6, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_TSDM_7, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_1, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_2, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_3, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_4, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_5, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_6, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_USDM_7, 0xffffffff},
	{OP_WR_E1H, PXP2_REG_PGL_INT_XSDM_1, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_2, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_3, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_4, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_5, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_6, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_XSDM_7, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_0, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_1, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_2, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_3, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_4, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_5, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_6, 0xffffffff},
	{OP_WR, PXP2_REG_PGL_INT_CSDM_7, 0xffffffff},
	{OP_WR_E1, PXP2_REG_PGL_INT_XSDM_0, 0xffff5330},
	{OP_WR_E1H, PXP2_REG_PGL_INT_XSDM_0, 0xff802000},
	{OP_WR_E1, PXP2_REG_PGL_INT_XSDM_1, 0xffff5340},
	{OP_WR_E1H, PXP2_REG_PGL_INT_USDM_0, 0xf0005000},
	{OP_WR_E1, PXP2_REG_PGL_INT_USDM_0, 0xf0003000},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ6, 0x8},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ9, 0x8},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ10, 0x8},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ11, 0x2},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ17, 0x4},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ18, 0x5},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ19, 0x4},
	{OP_WR, PXP2_REG_RD_MAX_BLKS_VQ22, 0x0},
	{OP_WR, PXP2_REG_RD_START_INIT, 0x1},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD0, 0x40},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD1, 0x1808},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD2, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD3, 0x803},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD4, 0x40},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD5, 0x3},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD6, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD7, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD8, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD9, 0x10003},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD10, 0x803},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD11, 0x803},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD12, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD13, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD14, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD15, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD16, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD17, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD18, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD19, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD20, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD22, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD23, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD24, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD25, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD26, 0x3},
	{OP_WR, PXP2_REG_RQ_BW_RD_ADD27, 0x3},
	{OP_WR, PXP2_REG_PSWRQ_BW_ADD28, 0x2403},
	{OP_WR, PXP2_REG_RQ_BW_WR_ADD29, 0x2f},
	{OP_WR, PXP2_REG_RQ_BW_WR_ADD30, 0x9},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND0, 0x19},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB1, 0x184},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB2, 0x183},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB3, 0x306},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND4, 0x19},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND5, 0x6},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB6, 0x306},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB7, 0x306},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB8, 0x306},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB9, 0xc86},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB10, 0x306},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB11, 0x306},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND12, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND13, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND14, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND15, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND16, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND17, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND18, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND19, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND20, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND22, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND23, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND24, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND25, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND26, 0x6},
	{OP_WR, PXP2_REG_RQ_BW_RD_UBOUND27, 0x6},
	{OP_WR, PXP2_REG_PSWRQ_BW_UB28, 0x306},
	{OP_WR, PXP2_REG_RQ_BW_WR_UBOUND29, 0x13},
	{OP_WR, PXP2_REG_RQ_BW_WR_UBOUND30, 0x6},
	{OP_WR, PXP2_REG_PSWRQ_BW_L1, 0x1004},
	{OP_WR, PXP2_REG_PSWRQ_BW_L2, 0x1004},
	{OP_WR, PXP2_REG_PSWRQ_BW_RD, 0x106440},
	{OP_WR, PXP2_REG_PSWRQ_BW_WR, 0x106440},
	{OP_WR_E1H, PXP2_REG_RQ_ILT_MODE, 0x1},
	{OP_WR, PXP2_REG_RQ_RBC_DONE, 0x1},
#define PXP2_COMMON_END         2015
#define MISC_AEU_COMMON_START   2015
	{OP_ZR, MISC_REG_AEU_GENERAL_ATTN_0, 0x16},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_NIG_0, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_NIG_0, 0x55555555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE3_NIG_0, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_NIG_0, 0xf0000000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_PXP_0, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_PXP_0, 0x55555555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE3_PXP_0, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_PXP_0, 0xf0000000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_NIG_1, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_NIG_1, 0x55555555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE3_NIG_1, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_NIG_1, 0xf0000000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_PXP_1, 0x0},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_PXP_1, 0x10000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE3_PXP_1, 0x5014},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_PXP_1, 0x0},
	{OP_WR_E1H, MISC_REG_AEU_CLR_LATCH_SIGNAL, 0x400},
	{OP_WR_E1H, MISC_REG_AEU_GENERAL_MASK, 0x3},
#define MISC_AEU_COMMON_END     2034
#define MISC_AEU_PORT0_START    2034
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_0, 0xbf5c0000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_0, 0xff5c0000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_FUNC_0_OUT_0, 0xfff51fef},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_FUNC_0_OUT_0, 0xfff55fff},
	{OP_WR, MISC_REG_AEU_ENABLE3_FUNC_0_OUT_0, 0xffff},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_0, 0x500003e0},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_0, 0xf00003e0},
	{OP_WR, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_1, 0x0},
	{OP_WR, MISC_REG_AEU_ENABLE2_FUNC_0_OUT_1, 0xa000},
	{OP_ZR, MISC_REG_AEU_ENABLE3_FUNC_0_OUT_1, 0x5},
	{OP_WR, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_2, 0xfe00000},
	{OP_ZR_E1, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_3, 0x14},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_3, 0x7},
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_NIG_0, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_4, 0x400},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_NIG_0, 0x55555555},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_5, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE3_NIG_0, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_5, 0x1000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_NIG_0, 0x0},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_6, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_PXP_0, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_6, 0x4000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_PXP_0, 0x55555555},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_0_OUT_7, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE3_PXP_0, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_0_OUT_7, 0x10000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_PXP_0, 0x0},
	{OP_ZR_E1H, MISC_REG_AEU_INVERTER_1_FUNC_0, 0x4},
	{OP_WR_E1, MISC_REG_AEU_INVERTER_1_FUNC_0, 0x0},
	{OP_ZR_E1, MISC_REG_AEU_INVERTER_2_FUNC_0, 0x3},
	{OP_WR_E1, MISC_REG_AEU_MASK_ATTN_FUNC_0, 0x7},
#define MISC_AEU_PORT0_END      2066
#define MISC_AEU_PORT1_START    2066
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_0, 0xbf5c0000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_0, 0xff5c0000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_FUNC_1_OUT_0, 0xfff51fef},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE2_FUNC_1_OUT_0, 0xfff55fff},
	{OP_WR, MISC_REG_AEU_ENABLE3_FUNC_1_OUT_0, 0xffff},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_0, 0x500003e0},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_0, 0xf00003e0},
	{OP_WR, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_1, 0x0},
	{OP_WR, MISC_REG_AEU_ENABLE2_FUNC_1_OUT_1, 0xa000},
	{OP_ZR, MISC_REG_AEU_ENABLE3_FUNC_1_OUT_1, 0x5},
	{OP_WR, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_2, 0xfe00000},
	{OP_ZR_E1, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_3, 0x14},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_3, 0x7},
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_NIG_1, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_4, 0x800},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_NIG_1, 0x55555555},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_5, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE3_NIG_1, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_5, 0x2000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_NIG_1, 0x0},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_6, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE1_PXP_1, 0x55540000},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_6, 0x8000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE2_PXP_1, 0x55555555},
	{OP_ZR_E1H, MISC_REG_AEU_ENABLE1_FUNC_1_OUT_7, 0x3},
	{OP_WR_E1, MISC_REG_AEU_ENABLE3_PXP_1, 0x5555},
	{OP_WR_E1H, MISC_REG_AEU_ENABLE4_FUNC_1_OUT_7, 0x20000},
	{OP_WR_E1, MISC_REG_AEU_ENABLE4_PXP_1, 0x0},
	{OP_ZR_E1H, MISC_REG_AEU_INVERTER_1_FUNC_1, 0x4},
	{OP_WR_E1, MISC_REG_AEU_INVERTER_1_FUNC_1, 0x0},
	{OP_ZR_E1, MISC_REG_AEU_INVERTER_2_FUNC_1, 0x3},
	{OP_WR_E1, MISC_REG_AEU_MASK_ATTN_FUNC_1, 0x7},
#define MISC_AEU_PORT1_END      2098

};

static const u32 init_data_e1[] = {
	0x00010000, 0x000204c0, 0x00030980, 0x00040e40, 0x00051300, 0x000617c0,
	0x00071c80, 0x00082140, 0x00092600, 0x000a2ac0, 0x000b2f80, 0x000c3440,
	0x000d3900, 0x000e3dc0, 0x000f4280, 0x00104740, 0x00114c00, 0x001250c0,
	0x00135580, 0x00145a40, 0x00155f00, 0x001663c0, 0x00176880, 0x00186d40,
	0x00197200, 0x001a76c0, 0x001b7b80, 0x001c8040, 0x001d8500, 0x001e89c0,
	0x001f8e80, 0x00209340, 0x00002000, 0x00004000, 0x00006000, 0x00008000,
	0x0000a000, 0x0000c000, 0x0000e000, 0x00010000, 0x00012000, 0x00014000,
	0x00016000, 0x00018000, 0x0001a000, 0x0001c000, 0x0001e000, 0x00020000,
	0x00022000, 0x00024000, 0x00026000, 0x00028000, 0x0002a000, 0x0002c000,
	0x0002e000, 0x00030000, 0x00032000, 0x00034000, 0x00036000, 0x00038000,
	0x0003a000, 0x0003c000, 0x0003e000, 0x00040000, 0x00042000, 0x00044000,
	0x00046000, 0x00048000, 0x0004a000, 0x0004c000, 0x0004e000, 0x00050000,
	0x00052000, 0x00054000, 0x00056000, 0x00058000, 0x0005a000, 0x0005c000,
	0x0005e000, 0x00060000, 0x00062000, 0x00064000, 0x00066000, 0x00068000,
	0x0006a000, 0x0006c000, 0x0006e000, 0x00070000, 0x00072000, 0x00074000,
	0x00076000, 0x00078000, 0x0007a000, 0x0007c000, 0x0007e000, 0x00080000,
	0x00082000, 0x00084000, 0x00086000, 0x00088000, 0x0008a000, 0x0008c000,
	0x0008e000, 0x00090000, 0x00092000, 0x00094000, 0x00096000, 0x00098000,
	0x0009a000, 0x0009c000, 0x0009e000, 0x000a0000, 0x000a2000, 0x000a4000,
	0x000a6000, 0x000a8000, 0x000aa000, 0x000ac000, 0x000ae000, 0x000b0000,
	0x000b2000, 0x000b4000, 0x000b6000, 0x000b8000, 0x000ba000, 0x000bc000,
	0x000be000, 0x000c0000, 0x000c2000, 0x000c4000, 0x000c6000, 0x000c8000,
	0x000ca000, 0x000cc000, 0x000ce000, 0x000d0000, 0x000d2000, 0x000d4000,
	0x000d6000, 0x000d8000, 0x000da000, 0x000dc000, 0x000de000, 0x000e0000,
	0x000e2000, 0x000e4000, 0x000e6000, 0x000e8000, 0x000ea000, 0x000ec000,
	0x000ee000, 0x000f0000, 0x000f2000, 0x000f4000, 0x000f6000, 0x000f8000,
	0x000fa000, 0x000fc000, 0x000fe000, 0x00100000, 0x00102000, 0x00104000,
	0x00106000, 0x00108000, 0x0010a000, 0x0010c000, 0x0010e000, 0x00110000,
	0x00112000, 0x00114000, 0x00116000, 0x00118000, 0x0011a000, 0x0011c000,
	0x0011e000, 0x00120000, 0x00122000, 0x00124000, 0x00126000, 0x00128000,
	0x0012a000, 0x0012c000, 0x0012e000, 0x00130000, 0x00132000, 0x00134000,
	0x00136000, 0x00138000, 0x0013a000, 0x0013c000, 0x0013e000, 0x00140000,
	0x00142000, 0x00144000, 0x00146000, 0x00148000, 0x0014a000, 0x0014c000,
	0x0014e000, 0x00150000, 0x00152000, 0x00154000, 0x00156000, 0x00158000,
	0x0015a000, 0x0015c000, 0x0015e000, 0x00160000, 0x00162000, 0x00164000,
	0x00166000, 0x00168000, 0x0016a000, 0x0016c000, 0x0016e000, 0x00170000,
	0x00172000, 0x00174000, 0x00176000, 0x00178000, 0x0017a000, 0x0017c000,
	0x0017e000, 0x00180000, 0x00182000, 0x00184000, 0x00186000, 0x00188000,
	0x0018a000, 0x0018c000, 0x0018e000, 0x00190000, 0x00192000, 0x00194000,
	0x00196000, 0x00198000, 0x0019a000, 0x0019c000, 0x0019e000, 0x001a0000,
	0x001a2000, 0x001a4000, 0x001a6000, 0x001a8000, 0x001aa000, 0x001ac000,
	0x001ae000, 0x001b0000, 0x001b2000, 0x001b4000, 0x001b6000, 0x001b8000,
	0x001ba000, 0x001bc000, 0x001be000, 0x001c0000, 0x001c2000, 0x001c4000,
	0x001c6000, 0x001c8000, 0x001ca000, 0x001cc000, 0x001ce000, 0x001d0000,
	0x001d2000, 0x001d4000, 0x001d6000, 0x001d8000, 0x001da000, 0x001dc000,
	0x001de000, 0x001e0000, 0x001e2000, 0x001e4000, 0x001e6000, 0x001e8000,
	0x001ea000, 0x001ec000, 0x001ee000, 0x001f0000, 0x001f2000, 0x001f4000,
	0x001f6000, 0x001f8000, 0x001fa000, 0x001fc000, 0x001fe000, 0x00200000,
	0x00202000, 0x00204000, 0x00206000, 0x00208000, 0x0020a000, 0x0020c000,
	0x0020e000, 0x00210000, 0x00212000, 0x00214000, 0x00216000, 0x00218000,
	0x0021a000, 0x0021c000, 0x0021e000, 0x00220000, 0x00222000, 0x00224000,
	0x00226000, 0x00228000, 0x0022a000, 0x0022c000, 0x0022e000, 0x00230000,
	0x00232000, 0x00234000, 0x00236000, 0x00238000, 0x0023a000, 0x0023c000,
	0x0023e000, 0x00240000, 0x00242000, 0x00244000, 0x00246000, 0x00248000,
	0x0024a000, 0x0024c000, 0x0024e000, 0x00250000, 0x00252000, 0x00254000,
	0x00256000, 0x00258000, 0x0025a000, 0x0025c000, 0x0025e000, 0x00260000,
	0x00262000, 0x00264000, 0x00266000, 0x00268000, 0x0026a000, 0x0026c000,
	0x0026e000, 0x00270000, 0x00272000, 0x00274000, 0x00276000, 0x00278000,
	0x0027a000, 0x0027c000, 0x0027e000, 0x00280000, 0x00282000, 0x00284000,
	0x00286000, 0x00288000, 0x0028a000, 0x0028c000, 0x0028e000, 0x00290000,
	0x00292000, 0x00294000, 0x00296000, 0x00298000, 0x0029a000, 0x0029c000,
	0x0029e000, 0x002a0000, 0x002a2000, 0x002a4000, 0x002a6000, 0x002a8000,
	0x002aa000, 0x002ac000, 0x002ae000, 0x002b0000, 0x002b2000, 0x002b4000,
	0x002b6000, 0x002b8000, 0x002ba000, 0x002bc000, 0x002be000, 0x002c0000,
	0x002c2000, 0x002c4000, 0x002c6000, 0x002c8000, 0x002ca000, 0x002cc000,
	0x002ce000, 0x002d0000, 0x002d2000, 0x002d4000, 0x002d6000, 0x002d8000,
	0x002da000, 0x002dc000, 0x002de000, 0x002e0000, 0x002e2000, 0x002e4000,
	0x002e6000, 0x002e8000, 0x002ea000, 0x002ec000, 0x002ee000, 0x002f0000,
	0x002f2000, 0x002f4000, 0x002f6000, 0x002f8000, 0x002fa000, 0x002fc000,
	0x002fe000, 0x00300000, 0x00302000, 0x00304000, 0x00306000, 0x00308000,
	0x0030a000, 0x0030c000, 0x0030e000, 0x00310000, 0x00312000, 0x00314000,
	0x00316000, 0x00318000, 0x0031a000, 0x0031c000, 0x0031e000, 0x00320000,
	0x00322000, 0x00324000, 0x00326000, 0x00328000, 0x0032a000, 0x0032c000,
	0x0032e000, 0x00330000, 0x00332000, 0x00334000, 0x00336000, 0x00338000,
	0x0033a000, 0x0033c000, 0x0033e000, 0x00340000, 0x00342000, 0x00344000,
	0x00346000, 0x00348000, 0x0034a000, 0x0034c000, 0x0034e000, 0x00350000,
	0x00352000, 0x00354000, 0x00356000, 0x00358000, 0x0035a000, 0x0035c000,
	0x0035e000, 0x00360000, 0x00362000, 0x00364000, 0x00366000, 0x00368000,
	0x0036a000, 0x0036c000, 0x0036e000, 0x00370000, 0x00372000, 0x00374000,
	0x00376000, 0x00378000, 0x0037a000, 0x0037c000, 0x0037e000, 0x00380000,
	0x00382000, 0x00384000, 0x00386000, 0x00388000, 0x0038a000, 0x0038c000,
	0x0038e000, 0x00390000, 0x00392000, 0x00394000, 0x00396000, 0x00398000,
	0x0039a000, 0x0039c000, 0x0039e000, 0x003a0000, 0x003a2000, 0x003a4000,
	0x003a6000, 0x003a8000, 0x003aa000, 0x003ac000, 0x003ae000, 0x003b0000,
	0x003b2000, 0x003b4000, 0x003b6000, 0x003b8000, 0x003ba000, 0x003bc000,
	0x003be000, 0x003c0000, 0x003c2000, 0x003c4000, 0x003c6000, 0x003c8000,
	0x003ca000, 0x003cc000, 0x003ce000, 0x003d0000, 0x003d2000, 0x003d4000,
	0x003d6000, 0x003d8000, 0x003da000, 0x003dc000, 0x003de000, 0x003e0000,
	0x003e2000, 0x003e4000, 0x003e6000, 0x003e8000, 0x003ea000, 0x003ec000,
	0x003ee000, 0x003f0000, 0x003f2000, 0x003f4000, 0x003f6000, 0x003f8000,
	0x003fa000, 0x003fc000, 0x003fe000, 0x003fe001, 0x00000000, 0x000001ff,
	0x00000200, 0x00000001, 0x00000003, 0x00bebc20, 0x00000003, 0x00bebc20,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0x00088b1f, 0x00000000, 0x51fbff00, 0x03f0c0cf,
	0x19d8d38a, 0x1138b218, 0x9380a1fc, 0x52181998, 0x880d3880, 0x1bf10197,
	0xb7860646, 0x0febc48c, 0x1fb04512, 0xf030310a, 0x3430330a, 0xac303209,
	0xef884611, 0x1091aa04, 0x0db86061, 0xb2054b15, 0xbc0c883f, 0xd781a9df,
	0x758a6148, 0x6bd8204b, 0xe323c8b1, 0xaff26875, 0xebf95025, 0x681fe809,
	0x95114b3c, 0x421e5c7f, 0x67c543ab, 0x809fc9a3, 0xfa839fca, 0x76228e6b,
	0x720fcf73, 0x0030c37f, 0x2bf7e1ca, 0x00000400, 0x00088b1f, 0x00000000,
	0x7dedff00, 0xd554780b, 0x733ef0b5, 0xc9999cce, 0x3c9c999c, 0x33084099,
	0x10a88c49, 0x1f018786, 0xa4024ebd, 0x580d52c1, 0x01d51f14, 0xf2648479,
	0xbc7f5290, 0x1099fef5, 0x7fad1102, 0x22d168b4, 0x5a2d5e1d, 0x180d03b4,
	0x0a03b06c, 0x6f5efe86, 0x4b45aaf0, 0x416b46fd, 0xb5312431, 0xb96afe96,
	0xcfbdad7b, 0x199339cc, 0xd7ef6d40, 0xfbe7efde, 0xb39f6774, 0xaf6bdecf,
	0xed6b5ed7, 0x9248f7b5, 0x086be442, 0x68ff0b39, 0x84226439, 0xef2f1e5c,
	0xe1d8bd77, 0xb0f21371, 0x10a7d699, 0x0e623c12, 0x5908176d, 0xd8fdda3e,
	0x8e5a6ca2, 0xe906f6cf, 0xfd19f27b, 0x99108cba, 0x640f7fb0, 0x4291714f,
	0x2cf67e7c, 0x87816e7d, 0x25d88445, 0x449f4c12, 0xf1131ac8, 0xeeb499a9,
	0x2b5de425, 0xfc2ce6fb, 0x8266982f, 0xf654727e, 0x0a6dc06c, 0xbf69d39a,
	0xa776c6f9, 0x4440af05, 0x499b3a42, 0x2131714e, 0x58ad9b7b, 0x39ab3576,
	0xcf2112c5, 0xecb0bb35, 0xf3e3766e, 0x62c79be7, 0x62f66919, 0x6c1a6999,
	0x8e73ef80, 0xe320cbcc, 0x2c4ff3e2, 0x71d334d7, 0x3ff5e38b, 0xa25048ba,
	0x2251fcf0, 0xefd35477, 0x9c9e5e5a, 0xfae5a51e, 0x1326e23c, 0xc3ff7f86,
	0x9a2ebf95, 0x11909931, 0xcd14f4f7, 0x04eda2c8, 0xc0ac3f32, 0x39849a2c,
	0xaee3d48e, 0x10653737, 0x29eb9b8a, 0x08b86646, 0xbe0db369, 0x21227332,
	0x7df3fbb6, 0xde746c33, 0x2b8bb42d, 0x1499b909, 0xd3578307, 0x111e0ffe,
	0xe47d29d3, 0x036c212e, 0x16de09d2, 0x7c87d281, 0xc3b77893, 0x65b79270,
	0x703f7d14, 0x73af711d, 0x99b9c7c7, 0x10e66250, 0xb0988f32, 0x74605cbc,
	0xa4647326, 0xa5832133, 0xb753e3d5, 0x5fc2f29f, 0x1c78f764, 0xc328c0ef,
	0x473bf478, 0x1c46efea, 0x0ddf62fc, 0x855526bc, 0xf1126f00, 0xf4feda11,
	0xebcddc9c, 0x1cfdac3c, 0x32037c1d, 0xa12709a9, 0x4b8c0d67, 0xcccdb9f9,
	0x0f43f6e8, 0x31851f2b, 0xc02420af, 0x5ed779c7, 0x64942771, 0x3cce653e,
	0xbd395a42, 0xca0d8eca, 0x595c280b, 0x728513dd, 0xee3acf5a, 0xc0281615,
	0x38fdf487, 0xfd8424e8, 0xf548108f, 0x3acf5a6e, 0x602a15e3, 0x95de3e1c,
	0x274507ef, 0xcbb1bb85, 0x66eecbb3, 0x3f4054fd, 0xa1615e7d, 0x8dd387a2,
	0xd17564fd, 0xf79fa071, 0xccb438e8, 0x5e902b5b, 0xa7724718, 0x1f1fe413,
	0xa454b921, 0x109931a6, 0xe034a8c9, 0xc95cfa67, 0x0f93f2a3, 0x86aed27f,
	0x508de214, 0xafbe7a7a, 0x5ba1b178, 0xfdf42b71, 0xf9a72e68, 0xc4d99afe,
	0x8a56c849, 0xe53a3c9e, 0xbbd24dd1, 0x8d9c9d51, 0x02da2db9, 0xa5663fa2,
	0xb89bb9f1, 0x9ecf204d, 0x5179f1a0, 0x20feb1bb, 0xb89f6471, 0x20e1fe8c,
	0x9262b38e, 0x4197bc79, 0xab97de40, 0x6fca5e0c, 0x36df9eb2, 0xa55c9336,
	0x089cb538, 0x6b3c7bcb, 0x13ed0f41, 0xfdfa16bc, 0xe54f6826, 0xdbbfc43e,
	0x41f5ebc2, 0xacf90259, 0xc64a08a7, 0xf949471f, 0x49fbc056, 0xa3658152,
	0x14ab2834, 0xd926c6be, 0xb7865217, 0x11194fdf, 0xf241a4f8, 0xf1d2b41e,
	0x77885b07, 0xb97f1d0b, 0xfa80ad59, 0xa8dc7bf2, 0xa3db0b17, 0x63afc095,
	0xf2baa8ba, 0x00bfbfc4, 0xff40f678, 0x6c3d9e14, 0x904ac19c, 0x02fdc1cb,
	0x7181e2d9, 0xf7cbbf58, 0x93d04879, 0x89c7ce1a, 0xa9c9f919, 0xf2845ff8,
	0x13a41100, 0x68f4e363, 0x3ffc29ad, 0x0d7ab495, 0xd789cfbc, 0x5cab0b5d,
	0x31bbe07e, 0x25af40c4, 0xd002a6d6, 0xe1d5b5eb, 0xc08be04a, 0x50c3defc,
	0x48e73c52, 0x4ad7a8c5, 0xd17bf4f4, 0x180fffe2, 0xde17ab57, 0xf4296f7f,
	0x4545b4fb, 0x77306dfc, 0x01e3d63c, 0x207f94fc, 0xc3a43e51, 0x8133d305,
	0x05d612df, 0xb1ddeffa, 0xe6a62ebc, 0x8b95f387, 0xf0091fa0, 0x0932e549,
	0xf5c0febe, 0x581d2104, 0x52be57ba, 0xafa59c54, 0x3c545cbf, 0x86540399,
	0x84f812f0, 0x9fa0a890, 0xd98e56b7, 0x9523de57, 0xefe786a6, 0x4e8a4f3d,
	0xc52373c4, 0xbd4ff02d, 0xa2ad0e43, 0xc7be9ef8, 0xf286b91c, 0x2166fd4f,
	0xd375a164, 0xdf7c36f3, 0x23d591bf, 0xd9e9990e, 0x554eb46d, 0xf7a5a363,
	0xff80abc1, 0x0b6488f6, 0xae963b74, 0x9cff54d3, 0x2993b0e0, 0x625edd6c,
	0xcdfad563, 0xef876e07, 0xc42cba6b, 0xdfabfb46, 0xabbaf4b7, 0x8f697d68,
	0xfa934099, 0x48f22ded, 0x62165f5a, 0x0540d5eb, 0x57b82f83, 0xeda76d0c,
	0xb9bd9c07, 0x4e7d28f3, 0x9b895b35, 0x8ead151a, 0x516fdcde, 0xed0da9be,
	0x6aef84aa, 0x405e0a77, 0xdb3df4fb, 0xbcc1e70f, 0x5ff2649e, 0xdc4ec3b7,
	0x7fe8fe1a, 0xc8c53a27, 0x72fdf435, 0xfb424f3a, 0x2a3a4a5d, 0x6fd64f41,
	0xeb76487f, 0xcd5399d6, 0x93138e2a, 0x38e927cf, 0x6786bbf4, 0xb14c2f04,
	0x20fc44c1, 0x6cfbfda7, 0x302ab7f3, 0xc4b916bf, 0x2b5af301, 0xa1a5bb43,
	0x6e6d7b05, 0x5cb36f80, 0x6ed7df49, 0xd12f2cdc, 0x8edd75c9, 0x1b5c232c,
	0xcff8468a, 0xa29c7761, 0x24bb8776, 0x3d05af5e, 0x485feb81, 0x6f77afd6,
	0x97c81909, 0xe2443b75, 0xa311f036, 0xfa75f07b, 0x7057c527, 0xaaf103bf,
	0x6fa62dd1, 0x5486dd39, 0xb069474e, 0x3e124e6c, 0x40e8107e, 0x3c00e9e1,
	0x0e01f2d1, 0x526af39f, 0x9dfed12e, 0xb982a23e, 0xecbe3e70, 0x84059330,
	0xf0ab758e, 0xeba24fa4, 0xee4c876e, 0x61e73b02, 0x066fb769, 0x0b576f5d,
	0x9d0279fe, 0xd7f2688f, 0xec2cf5b0, 0x0d607b02, 0x29bf875f, 0x6bbe71b8,
	0x527f28f2, 0x2ccc77bc, 0x1c0a2adb, 0x2fa86cf6, 0x05d809f9, 0x05db9fb4,
	0xa6517f3a, 0xbf9d14fd, 0x9a72b51f, 0xb2b51fa1, 0x2967eb46, 0x617693f6,
	0x5e5474fd, 0xb2a78469, 0x09a7eb56, 0xd85e71fb, 0x5fafd4bc, 0xebe7846d,
	0x6327ec01, 0x15f89786, 0x3f39ef58, 0x489f5e90, 0x333b2bdf, 0x7a23ad26,
	0x17b8a8be, 0x52a0e8f0, 0xf48be7a2, 0x3e066969, 0x1a65f0cc, 0x1527b4ea,
	0x7fae6bd7, 0xca2b4e7c, 0x46523ca5, 0xd23e50bd, 0x3ddcf08a, 0x70bd4152,
	0x8bfe95f7, 0xb1849d61, 0x5bba5ec1, 0x93504ff6, 0x538535f0, 0xa9282e20,
	0xfe1ae0dd, 0xe199ad7e, 0x67d462a1, 0xefd0ef25, 0x25834d1b, 0x6edeb419,
	0xe6147f2a, 0x7a6051b1, 0x4d244d39, 0xc2cd2ed0, 0x9eb5c0ec, 0x1d41adb2,
	0x5347da9e, 0x7ef10bfa, 0x177ecddb, 0xa5a857f0, 0xf8512837, 0x42a68cd6,
	0xcd90923e, 0x48246f42, 0xa3b5abd7, 0x9f00b897, 0xb7ca9916, 0x8e997c7e,
	0xffc70e3f, 0x33bf8c09, 0xc296f8c5, 0xadf18669, 0xf1863505, 0x9f1d32ad,
	0xe5b87bf2, 0x8adf1f18, 0xe12efb76, 0x296f8e18, 0xd7f1c1a8, 0x1faadd82,
	0xfe362d3f, 0x6e9be05e, 0xc3cdd981, 0xa5785fe6, 0xb505fe71, 0x6ccbf9c6,
	0x289691fe, 0xe70d3f1f, 0xb288407f, 0xb2d417f9, 0xbf585bf9, 0x319df1b1,
	0xf9861ffc, 0xfe6a9cbf, 0xe71b5745, 0x9c60263f, 0xdf8d85bf, 0x1f3ef2db,
	0x8ff1c15f, 0xf9b3ef0a, 0xf8e0098f, 0x05efc5b2, 0xa547923e, 0xdec08535,
	0x69daa7c8, 0x1f28ea04, 0xd1336396, 0x285fbf4e, 0x9ddc3c44, 0x93eef8c6,
	0x4a6fca34, 0x1091df5c, 0xcfaa2895, 0xd7cf381a, 0xfd972ced, 0xaa7bf8e3,
	0x507316f7, 0xcc897517, 0x096f59cf, 0xede1445d, 0x508312ef, 0x6bfeb45f,
	0x3bd71121, 0x3353b766, 0xffcf022f, 0x2df8c8f0, 0x962579fa, 0x27cc3b8b,
	0x623906a2, 0xc82b04f0, 0xdf0a26d8, 0xf88a82d5, 0xa827ead3, 0x7f54251e,
	0x28f54bbe, 0xcccd2794, 0xea8f791e, 0xe5eb2259, 0x23d985a6, 0x38daf241,
	0x391baf3a, 0x862427fc, 0x842b13ef, 0x93ffe010, 0x4192ee87, 0xb0ee2d3f,
	0xe1c7a453, 0x1a74e468, 0x6d0967dc, 0x6e9f1011, 0x284dcfc0, 0x8efc848a,
	0x374bfddb, 0xbbbe1964, 0x5cda848d, 0x0f9dfdb4, 0xd2ad182c, 0xdf3adff9,
	0x57ec0932, 0x994611aa, 0x28c98e50, 0xe63df513, 0x1e643e77, 0xcd372b45,
	0xfeec1b37, 0xfac6fd9b, 0x7ac635ad, 0x366439bf, 0x4cb1bd81, 0xbf699b20,
	0xbe326edf, 0x9ab1c6d7, 0xc63db932, 0x9731bbc6, 0x286dfbc1, 0x1563c127,
	0xcabb7ae9, 0x69e0d5be, 0x44999efc, 0xe68cbd70, 0x824f7f80, 0xf9af6839,
	0x44ef3655, 0x5b376f78, 0x9e14d57d, 0x1111efdb, 0x47f0899f, 0x4cfbb79f,
	0x6e8b8ed4, 0xec19a3f8, 0x24f9c4df, 0xcac77fc2, 0x32a8f9c4, 0xc105fbe8,
	0x4f8ce7c4, 0xb1a9f912, 0x3deb3cab, 0xf0fabb5d, 0x74f7acac, 0x63b755fc,
	0x2cbea18e, 0xfda1b374, 0x0c0b0dd2, 0x2c7717ef, 0xb3bfbc33, 0x7d432efd,
	0x431ef041, 0xb6563bfb, 0xbb7fde18, 0xfbc33ee9, 0x321e6b5b, 0x3ff66fd4,
	0xd37f6866, 0xf786cdfc, 0xc6cbf3c2, 0xfaaf5144, 0x5d81e4c7, 0x0085a6f9,
	0xaefc6a3f, 0xcdfbc3c9, 0x354f2c2e, 0x016cb1bb, 0x6ff2a539, 0xc6cac7da,
	0xa8c60b2d, 0xa4fdbb3a, 0xe400a9b9, 0x13ef9129, 0xdfc899f1, 0x64a8dff4,
	0x065690eb, 0x7a0f1fa8, 0xcfaf806e, 0xae01f3da, 0x85590987, 0x9990197c,
	0xe77606dc, 0x1d1f8055, 0x4d252390, 0x988afc49, 0x9c05873c, 0x3a2b0107,
	0xb946e807, 0x22d740d5, 0x077d9c03, 0x01bf1c44, 0xbfea9764, 0x4af549cf,
	0xe443c813, 0xc61b8285, 0x7bbe3c03, 0x574f004c, 0x7dbfae0e, 0xef5955cd,
	0x6abf8049, 0x9e6fdf2c, 0x6689e58f, 0x35ef963f, 0x6ef960d7, 0xd1961373,
	0xbe5895e6, 0xf2c41cdd, 0x963b7378, 0x6077356f, 0x0379ac79, 0x87346f96,
	0xf66fecb0, 0x2bf31961, 0xcd993d34, 0xff6e4aed, 0xeb0215d3, 0x222e7c43,
	0xe517bbfd, 0x7902ebd1, 0x293e521c, 0xe879bb01, 0x4f108598, 0xf2257c6a,
	0x12bc4a43, 0x4b15da1f, 0x4c395442, 0x96defe1e, 0x3364e8c6, 0xf5422a91,
	0xfd177dc6, 0x1c70bbc4, 0x099225d6, 0xc9bc87df, 0x7c0471e2, 0xa7e711da,
	0x960df113, 0x38f4a5ce, 0x65a7f8f1, 0xac00efd0, 0xbe5eb053, 0x497ae220,
	0x40bd5b22, 0x70de1d2f, 0xc3dc19fd, 0xf079f2f5, 0xc3473a77, 0xf8016f5f,
	0x2a4d13e1, 0x69d433f6, 0xb1e01221, 0x10821edb, 0x56cf50d6, 0xcb77ac27,
	0xbdf5265d, 0xcad07824, 0x5547b0fa, 0x9744ebf4, 0x21d43eb1, 0x96b8b154,
	0xe35bfd3b, 0xf554af81, 0xbfa062bd, 0x9fad4b0b, 0x7d592ee5, 0x10e3fd0f,
	0x333bd3d3, 0xdfa94f90, 0xd6feed86, 0x27eaa470, 0xf927470e, 0x7d1efd3d,
	0xee2fa291, 0x63e91337, 0x6e913f8c, 0x9eb027f3, 0x677fe85b, 0xb097bfd1,
	0x18dbf5ae, 0x09968316, 0x61a77cf0, 0x5b9dfa3c, 0x16cf89f3, 0x255f8b9e,
	0xe7e74272, 0xede3c47f, 0xaa6c3b75, 0x1867ef51, 0x795d8dea, 0x801d61aa,
	0x93dca83f, 0xfc0482f9, 0x33dce012, 0x02ed2920, 0x9365ef85, 0x146dfb1b,
	0x6b7abb58, 0x81bbf654, 0xbc6f5a6f, 0x3b2d0dca, 0x8b7164e4, 0x6e3dcd53,
	0x7f0d4a49, 0x7774389d, 0x3f3b1275, 0xd0278c17, 0x4f66268b, 0x09d06b13,
	0x057124fe, 0x081d739d, 0x0fc3129a, 0x1c7441fa, 0x67eb5d5d, 0x983cc859,
	0x33ec9d6c, 0x71393b31, 0x16458bdc, 0xfe1f3dbf, 0xad1e761a, 0xe2277984,
	0x23eba1b1, 0xcbe2cfd9, 0x1a09d812, 0xbefc351e, 0x58beaa6c, 0xeed7fda4,
	0xc9ed0778, 0x92c1cdf7, 0x6f439def, 0x715f870d, 0xe7c7b09d, 0x038f7cb9,
	0x0fe5b7ed, 0x9d04b8b1, 0xbb8c2f5e, 0xc973c790, 0x0e95b467, 0x9932080e,
	0x5e4efd68, 0x0b03e2d3, 0x7e30eb3b, 0x941207fb, 0x40fc29c1, 0x3b0328ec,
	0x59bc36b0, 0x4f3851f6, 0xe0155313, 0xd57934eb, 0xaf475939, 0xf88ca2d9,
	0x68ddb3ba, 0xd63b508f, 0xc1ba5f50, 0xe6425f58, 0x59be82e6, 0x424cdeb2,
	0xf0d3ce02, 0xc5516afe, 0xa692977e, 0xff4eb035, 0x8df273be, 0x9e1d0157,
	0xf00ca27d, 0x1ebe90bb, 0x3c780995, 0xa2fc788a, 0xef832fe3, 0x371f0d27,
	0x7109b7ce, 0xfa878e13, 0xf8d2421d, 0x6f9ccde8, 0x01dafe34, 0xf4ecebf0,
	0xad1f3e4e, 0xf8f22f5e, 0xa04448a9, 0x1ad569e3, 0x7be3a534, 0x7707b38c,
	0x6eadbc5b, 0x77d519d0, 0x7b50bf01, 0xdae894a0, 0xf1f9359d, 0xf2f09f79,
	0x931fdc12, 0x41dfb822, 0xbf4912d7, 0x39a6267f, 0xec3e214b, 0x2cbd7420,
	0x20b3fd82, 0x1c6bfd3a, 0x2949b335, 0x7ca9a7c4, 0xefbefed3, 0x6811ecac,
	0x1274a6dd, 0x32e2cfe8, 0x6e6ddfc6, 0xfe11bd63, 0xb196fd80, 0xf641e304,
	0x3d8252b1, 0x0fa0211a, 0xf3e35e1c, 0x8a7863fb, 0x38425f20, 0xa768ec11,
	0x74888955, 0xea4d327c, 0x853ff98b, 0xf8317fe0, 0xeda7dfd1, 0x7daca857,
	0xaf778f03, 0x4462a478, 0xa4ec39e6, 0x39aa33c6, 0x62375ba4, 0xd933f8f1,
	0x57d650e6, 0xba6e93d0, 0xe4f4ea7a, 0x56ff2673, 0x17a672f1, 0x8e813e01,
	0x45c1d7e3, 0x2f55511d, 0x7e0491b7, 0x6470d2f8, 0x7ebe8313, 0x04efe4d9,
	0xe38448be, 0x1aeff74b, 0x6fe47fd6, 0xb0f17fda, 0xd64e5ffe, 0x4fb3fd7f,
	0x7e520def, 0x23f9fdaa, 0xe4ccca4e, 0xd723a903, 0xd81fe94b, 0xb904e6de,
	0x3a0a5f7c, 0x841fae81, 0x9250aac4, 0x6924c4f5, 0x8453e77c, 0xe41fe432,
	0xdd4f53a3, 0x4fd81d7f, 0xab376c9f, 0xb0efafe8, 0x29942c44, 0x31973a1b,
	0x7961d8f9, 0x7ed7d587, 0xd8d9fc04, 0xb517d465, 0xd7247d3f, 0x9051eb8d,
	0xf411b3fb, 0xfdb61a07, 0xabec12a1, 0xfa883246, 0x183bf12b, 0xae264cff,
	0xf4e40bff, 0x7db5efe1, 0x978e46b9, 0x3ffbcec6, 0xa2585112, 0xb625ffe8,
	0xfd76e1af, 0x4fbe451f, 0x054c9536, 0x41f0d33e, 0x17aecc42, 0x14a27d9f,
	0xdb7d32e2, 0x1853affe, 0xe64fe7a7, 0xef850c87, 0xee73f1fc, 0x4fd4f2d4,
	0x7edea2f5, 0x7735ecd6, 0xba47f717, 0x47301959, 0x0fa7109c, 0x837b366c,
	0xe9e071f4, 0x1c793fad, 0x5a6f24e2, 0xfed117bc, 0xf43e9eeb, 0x5eb495c6,
	0x3d9ccbb7, 0x11434d9b, 0x6974e372, 0x9cadffa4, 0xed43a714, 0x3ee10e2f,
	0x37bf3c2f, 0xba8f4e33, 0x3264075d, 0xa63e387e, 0x51c80f87, 0xc25d0925,
	0xdf8254ef, 0xb9fb3e20, 0xe0ff740c, 0xf08c8179, 0xe6e7c124, 0x02ff6843,
	0x9c8e909e, 0x25ba314e, 0x74a46fb4, 0xd1aafd01, 0xebfdf129, 0xfe803d7c,
	0x9f90e3dc, 0xf60e799f, 0x78b2de35, 0xcf35fe61, 0xf309c77c, 0x31352938,
	0x2da27ebe, 0xadc747d7, 0x55730731, 0x9af3d92c, 0x7e45df4d, 0xbbf47a5b,
	0x208f18b9, 0xae133cbe, 0x983cc1f5, 0xf38de2df, 0x884b7e70, 0xe6aef91f,
	0xd61ab109, 0xa4493fab, 0xb912576a, 0x3b312958, 0xea16e4eb, 0x9df9d048,
	0xe2038584, 0x7c8aaffc, 0x8c2efedf, 0xdb577c77, 0xb1cb219f, 0xa32b27fe,
	0xe692f5d3, 0x4795d2c7, 0xd6dbafcf, 0x4e7d02f6, 0x808df68d, 0x91236e38,
	0xc21f1c82, 0x78afda59, 0x4608e674, 0xca96e21f, 0xdf5477f8, 0xd0e7874f,
	0xb3ecd7be, 0x23be1a95, 0xf1f13d67, 0x29f1f057, 0x9f6069dc, 0xbe4dcc9e,
	0x262dbf5f, 0xd22ed4f7, 0xbe4e97f1, 0xbb6fbc99, 0x26b7c98f, 0x5539a1ef,
	0xd7e3fef0, 0x77c0fc98, 0xb8502f60, 0xfdf02322, 0xa8096f81, 0x92242c0f,
	0x99b7ae4c, 0xdf1b5cb9, 0xe1427c6b, 0x8ddd6096, 0xf6610bf1, 0xbf1e49cc,
	0x7e9eb25d, 0x8d97d3a7, 0x78739e30, 0x2edc9a7f, 0x1dfff2e5, 0x64ff28c9,
	0xd4fb9323, 0xf11043fe, 0x7e873013, 0x2bc838f2, 0x6fd84f95, 0xae6d3c0e,
	0xb87f7986, 0x6e3785f3, 0x61f272a1, 0xa3539358, 0xd3944cfe, 0x9397dd9a,
	0x21fa7264, 0x93240da4, 0xa93cfa53, 0xe4512a9c, 0xfd2effe3, 0x47efe1a9,
	0xf4d3f809, 0x263c2a61, 0x9269c3ea, 0xa899f11b, 0xd7bfe90f, 0xfe70d948,
	0xe34ef8d3, 0xd59fdab7, 0x13bd018f, 0xef8d4be3, 0xf1a97c62, 0x9ff8b0dd,
	0xef897f01, 0x85ac4317, 0xefbd55c2, 0xdfc84af5, 0x7db37409, 0x61ddfa4e,
	0xf93c53a8, 0x71d55b98, 0xe268f218, 0x3d4250f5, 0x97ded09c, 0x684eaf50,
	0x37a84fef, 0x310fb425, 0x05ebaf3f, 0x44a3e599, 0xabcded0c, 0x7101d048,
	0xc622fde7, 0xcc280637, 0x68ff206b, 0xf90427a7, 0x16366d0a, 0x91cc1a37,
	0x1afe80d7, 0x999d0750, 0x78b1b750, 0xa0f540db, 0x87674333, 0xa22dd3bd,
	0x48868dfe, 0x8fff3255, 0x53c45690, 0xcf7aa494, 0x4533e8e2, 0xc42560a5,
	0x2f443a4b, 0xb5166084, 0xfd84e4dc, 0xa2ee81fb, 0xe7d3e7eb, 0xb8888f8b,
	0xf600373d, 0xd9a03a77, 0xfce9e527, 0xf049f7ae, 0x2e21abd1, 0xaefccdde,
	0xf8240f45, 0x190aca47, 0x8ff521f4, 0x07ee35de, 0xe5aebe30, 0x346cd4fd,
	0x0f25afbe, 0xfe693f20, 0xe336ed78, 0xdff73f7b, 0x3e7c68cf, 0xfe644c91,
	0x23716133, 0x8a6757ae, 0x4f9faee3, 0x23d03ef1, 0xa193e012, 0x3ef1116e,
	0x33f353b4, 0x1a5e5073, 0x33ea20c8, 0x207d3f0d, 0x7d6a720f, 0x77e7b7d3,
	0x4da3df65, 0x5b7f7b02, 0xf65a23fa, 0xe4b37ded, 0xf67f5097, 0x25bf0537,
	0x7f4fdbc3, 0x0efb86de, 0x703bcf03, 0xff60709f, 0x0f7c17bf, 0x5e2cfbea,
	0xf9e07380, 0xdf02973f, 0xd4b2ac0c, 0x181abe80, 0x5aa8f2cd, 0x34b9fff7,
	0x6ae3eb8a, 0x999157a4, 0xdd43a9f9, 0xf90dbe9f, 0x74dd436c, 0x3feeb056,
	0x59f8c76f, 0x8c3673e3, 0xffec0d7b, 0x6ede9973, 0x69f3aaff, 0x0381fbe0,
	0xf21f320e, 0xd83206b9, 0x2fe34a3e, 0x02dad8af, 0x079d0cf9, 0xfbe93be4,
	0xbcfabfe9, 0xc0e0f414, 0xf4cf666e, 0x609ba39b, 0x6db4abbf, 0xa5332af5,
	0xc3083f57, 0xdd7e4248, 0xa822a876, 0xe7cbc324, 0x50bbcf18, 0xa7fccc7c,
	0xfb8087c1, 0x476e81d8, 0xbcc02ac8, 0x6ff6f2ff, 0xb79ffe41, 0xf36a5f20,
	0x82dc30fd, 0xe6f9c6f6, 0xdc7fe8bd, 0x85c885bc, 0x1ff5bbcc, 0xb336de7c,
	0x944be11b, 0xbe7ce183, 0x3fac6eff, 0xbc22f0ed, 0x5befc817, 0xff97fe61,
	0x0bffcee3, 0xa5377dd3, 0xf3fcf3bb, 0x4b4ff83e, 0x73b723f7, 0x2f90abba,
	0xcfabf8d2, 0xaa2fbe11, 0x07fddee7, 0xf9aa7ba7, 0x3af9766b, 0x10a3b793,
	0xf5606be2, 0x715a75d3, 0x70876dcc, 0x73b1badf, 0x4513b055, 0x0898bfbe,
	0xfccc965f, 0x7498513a, 0xba710fcc, 0x8bcb0ad1, 0x6e107ee6, 0x25a1d1bd,
	0xa1da0965, 0xd986b292, 0xe282f0c7, 0x3f815d65, 0xeb427904, 0x97e84594,
	0xcac5b211, 0xfe8c9df6, 0xf8816ae0, 0x4a9f6a04, 0x03db5e97, 0xac7989fe,
	0xc5296229, 0x2d281df2, 0x365573da, 0x38ca2df8, 0x36e6dd63, 0x78f2d7d6,
	0xea4c95a4, 0x107c8428, 0x14435245, 0x03bca55e, 0x22e553fd, 0xf2e8e16a,
	0xe32e2c28, 0x4c9003f7, 0x82c78baa, 0x76a11e9d, 0xb73b4bfa, 0xf4e05c62,
	0x075cef53, 0x52fdd4fd, 0xcf3a5624, 0x120e9dfe, 0x4291be01, 0xb51df832,
	0xe30fa29d, 0xeca45226, 0x9e7edd06, 0xfdd61f66, 0x6bddc59c, 0xb3425b77,
	0x7bb5f7e9, 0xeb8a5f7f, 0xb441aaf6, 0x094f835f, 0x68c1df0c, 0x96ade029,
	0xd227f9e7, 0xfcccbc69, 0xf67dbee7, 0x0ba7e0f9, 0x63be583b, 0xb326f86d,
	0x62bf3745, 0xd2dfe599, 0xc147c876, 0x37cc0527, 0x79f4f801, 0xda7d9a76,
	0xe0c0a4f7, 0x208732eb, 0xc776b26f, 0x37887eae, 0x78b31ed4, 0xb8d90c21,
	0x678c23e3, 0xd3f9ff4f, 0x57fa28ce, 0x1cdfc1a2, 0x10ede7e6, 0x9d0dae91,
	0xd2af68f5, 0x21b7d23a, 0x71de3c9c, 0xeea47f3e, 0x06f7fbe7, 0x7eeb0a29,
	0xc42753f1, 0x6ef54e33, 0xb7bfa277, 0x9671dce3, 0xf85d7e61, 0x75fa73be,
	0x6a0fe0a7, 0x2728dd3f, 0xb23bc5f8, 0xf0a57ed0, 0xb7db2595, 0xeea6f8d2,
	0x826d3fe9, 0xeedf63b8, 0xbc01370f, 0x71febf81, 0xe49fd813, 0x1dba9b79,
	0xebd4f2f0, 0xbed1b718, 0xd772e26b, 0x314fe4ff, 0xfd4fd5de, 0x7fade869,
	0xf002c9ff, 0xfd77fa3b, 0xe3fc1725, 0x8e67fb15, 0xd8aef980, 0x49047d33,
	0x095abf22, 0x80ba1b7c, 0xbd225b78, 0x017ce85e, 0x94d3e4ed, 0xc49fe0de,
	0x3d70f4fc, 0xb9b87b8b, 0x7933be7f, 0x3f98735c, 0xf5c379de, 0xa5029b5f,
	0x1726ebd9, 0x46bf97e0, 0x02e138e9, 0x3ef3b7e8, 0xa724afee, 0x83f869df,
	0x04c1e9d2, 0x73a9fdfa, 0x871f8ff1, 0x29599d77, 0x05c8f2fd, 0x9b8b4de0,
	0x1efb2ade, 0x766e4193, 0x20e30cff, 0x74d9b740, 0xff4ffda2, 0xcde200a9,
	0x6f079bef, 0x16f37967, 0xdad0fc15, 0xf941bffd, 0x1473dfe9, 0xc78492e3,
	0xec49fb2f, 0xf1378b1f, 0x6dc6b69c, 0x73cfe60e, 0xefbf83fc, 0xee73e276,
	0xd63e33d7, 0x7e54fdfc, 0xe59951fe, 0xdcf16803, 0xe5bf6dfa, 0x5e9c737e,
	0xd3a034c2, 0x3f8ce73b, 0x0150786b, 0x71f5530f, 0x94f1e4ab, 0xd3937c58,
	0xc5578b4b, 0x9eb452e2, 0x908a710f, 0xebc21bf0, 0x6fc893a3, 0xf71666ff,
	0xf31b37ea, 0x6274e261, 0x1397acf1, 0x617435e5, 0xcdf3ac71, 0xa9e28be3,
	0xf81b765b, 0xdf57c346, 0xf9f5c967, 0x2fff9700, 0x2df21fbd, 0xa43f7121,
	0x90fd865f, 0x766477ce, 0x6b9d803e, 0xf363ed89, 0xa7bebdfc, 0xac878c44,
	0xfa80bf09, 0x686f513c, 0xf08965fb, 0x1f16160a, 0xeb62e86d, 0x476edf45,
	0xf4fda148, 0x7c87dc1d, 0x1df3b0dd, 0xc3cdfc19, 0x33217e3b, 0x11c98abb,
	0x1d2117ac, 0x1ccf7dfc, 0x3af16528, 0x389c4f96, 0xe185ba4e, 0xf93bb1a5,
	0x3f3b8d38, 0x17538c32, 0x1f2ccb0c, 0x9de3dcf3, 0x41377c92, 0xcd7aa77f,
	0x4eedf204, 0x64aac585, 0xb043b3fb, 0xd03da27e, 0xae87e4c1, 0x7d37989b,
	0x984f9d94, 0xe61a6af2, 0x5a38af25, 0x6cf4dbf5, 0x05e12928, 0x7c871f3c,
	0xbe6ff9da, 0xceef4051, 0xb088b7a3, 0xfc05ed5e, 0xb2c3ecea, 0x3ba69ad7,
	0x3b287ea8, 0xd8053d5e, 0x4cef5135, 0xc032663d, 0x0119c74f, 0xda6ac1eb,
	0x80179c0f, 0x4780267c, 0x01565674, 0x526aa23c, 0x44f2496d, 0xe6354acd,
	0x9afd6b6d, 0x365e6355, 0x1bb26cf9, 0x48bfe9fa, 0x4ea9f3cb, 0xa9fd3c07,
	0xb9fa5e77, 0xcfbe27ce, 0xb35f65f5, 0x76644497, 0x8dea025e, 0xa6b74f3c,
	0x373c05fb, 0x88161354, 0x1969e29b, 0xb97940e9, 0x708192d6, 0xed190b2c,
	0xffeeda87, 0x9db5f6c4, 0x091d7dac, 0x57387b63, 0xc5c83111, 0x83bb04e4,
	0xcf00f5f1, 0x299c08cf, 0x38ac9123, 0x3e70b79c, 0x0d566bea, 0xf0003dfa,
	0xaa0e7029, 0x0fa9c717, 0xd1c61967, 0xb99fd5da, 0xfb744492, 0x2f52f5c1,
	0x99fd59f2, 0x6271c17f, 0x42ecd572, 0x7feea43c, 0x78ee0194, 0xf00cd3ff,
	0x1abffbc6, 0x77fad5c7, 0xc17165cd, 0x19581bbc, 0x2cadced4, 0x42b50b49,
	0x5fdd883e, 0x8e76816f, 0x04439ef5, 0xc34d51ce, 0x1615e6fc, 0x24e0379e,
	0xa037964e, 0x9d744d04, 0xf2d95c7d, 0x8700d5d0, 0x72d2bfc9, 0x802f2eb9,
	0xa5dcf044, 0xfbd86ed6, 0x7c81bc84, 0x3caa84f8, 0xc457c391, 0x934606f3,
	0xdd939e28, 0xfce760e8, 0x26d928c6, 0xb72b7ef8, 0x7c73b5d3, 0x25fdcec3,
	0xdf3bf79c, 0xe9ecbf39, 0xf18d77e5, 0xdaeaf212, 0xae70e9fe, 0xf2a6fb23,
	0xea54a35d, 0x1995046f, 0xfd9df790, 0x7989f2d3, 0xf6b5feb4, 0x47ffab20,
	0x5a02c4f9, 0x981ed977, 0x04ebed81, 0x81ff8bcc, 0xe08ce165, 0x87a0afb8,
	0x967ed9ab, 0x18ff0f4e, 0xfaba76f0, 0xdd8b8df8, 0x28309790, 0x96d2fc33,
	0x1a720e70, 0x72be5bc3, 0x69e0177c, 0x02da298c, 0xfbc7e3fa, 0x7a019cff,
	0xc4544ddb, 0xab564a8f, 0x1f44b790, 0x8e7b3b4d, 0xbcc4b67c, 0xfc6f8d2e,
	0x700c3f8a, 0x8b1c2db4, 0xaf1eebe7, 0x3f056499, 0xf9998370, 0xf2c58fbf,
	0xbb39d8fb, 0x5fe61683, 0xd51e78b8, 0xfd278d50, 0xae12f99c, 0x83a49b5e,
	0xc41a406b, 0xcf81f57d, 0xf21db9de, 0x719ea11e, 0xe8d23d0e, 0xa126cd7a,
	0x1df3191c, 0xfc8d9a88, 0x17f388b5, 0xcbaacde0, 0xb22a5fa3, 0x6e2d23bc,
	0x150cc84d, 0x03042fe6, 0xbecbd9e2, 0x8a9c9e38, 0x9f904dff, 0x805e4037,
	0x29cfc3de, 0x4c7809be, 0x63f8a73c, 0xe16ff54b, 0x3392de79, 0xb16f2005,
	0x474285f3, 0xf12fd01e, 0x0691231c, 0x87fcc94d, 0x631cfc2d, 0xb29fb82a,
	0x7c014ffa, 0xef72bf85, 0x3f72a1ee, 0x85ec9161, 0x2b09cd94, 0xec48e4a7,
	0x01da205c, 0x5caf9c8d, 0xc81fa626, 0x65f704dd, 0xcf822c07, 0xefa17107,
	0xe7eeb8a8, 0x7e8d9a2f, 0x13dd80f6, 0x81a1fc86, 0xa373b1ef, 0x40105ed4,
	0xa77747be, 0x944e6c47, 0xe4124fcf, 0x7da313f3, 0xe0771c64, 0x8a2bbbac,
	0x3fbca9fd, 0xc6e7c06a, 0x880efdcf, 0x681f3d6c, 0xa31c2376, 0xd800f049,
	0x9e3a1787, 0x3ced4acd, 0x143e9c7b, 0x4e6b76ff, 0x8e94ff1c, 0x8f4a5699,
	0xf3ca6b74, 0x3ed099a6, 0xe7898e91, 0xf8b45f4b, 0x93bb4047, 0x81af0e4b,
	0x6dfd4b90, 0x8420254d, 0x14897d1a, 0x253c03cc, 0xea51b7d2, 0xa74ccc78,
	0x11fddb98, 0xfd1a29da, 0xe6f4ac26, 0x7a065948, 0x13ff4116, 0x01323fba,
	0x7f1d1adc, 0x73b72428, 0x3ad95bc7, 0xee5e3896, 0x9fc9a8fc, 0xcae97da4,
	0xe28fec32, 0x7e024267, 0x933f00ca, 0xeca7e353, 0x1573f102, 0xfc3e73f4,
	0x1d5bfe68, 0xd83ae397, 0x41bc826f, 0x42dcdcf7, 0xa8a56e3a, 0xdb2e9f20,
	0x96bc622e, 0x979d9fb6, 0x65fb971b, 0x301d3457, 0xf6597e53, 0xb4fc8084,
	0xff1b9f88, 0x491f9f90, 0x325bdbcc, 0x767a883f, 0x285efe58, 0xa10faed1,
	0x61dba8de, 0xce2f3e7c, 0x5798055f, 0x1085efcb, 0xe226ff39, 0x72e1487f,
	0xd0c328bd, 0xa31e912e, 0x3c864c9b, 0xb1e9bcee, 0x779fd07e, 0xc1bfdc99,
	0x9b5fb8fc, 0x7c81c409, 0x0894f652, 0x308a63e0, 0xe72dfa03, 0x37f5a5f2,
	0x8ed1a566, 0xe78d04f3, 0x8dda8aeb, 0xea2eebe7, 0x7f686918, 0xc34286f1,
	0x97424bfb, 0xb65fde1a, 0x3ea19263, 0xa1a57c3e, 0x0aae84fd, 0xe4627d43,
	0xc9fb435a, 0xf50d733d, 0x316f7bcb, 0x6c7a9fb4, 0x15fde1a1, 0xfbc35ad1,
	0x6e5fdeab, 0xf06d7fa8, 0x23ed0d5f, 0x3afe998b, 0x7fcaecd8, 0x7c2f974f,
	0xa4d92ef0, 0x4abbf3c2, 0xfea96a4c, 0x5dcfae79, 0x0f99650a, 0x7a54e8fc,
	0x2f35ba76, 0x97bebf5f, 0xff41b313, 0xeb1ab74c, 0xbf72b23f, 0x0bf280b3,
	0x41287e25, 0x6dbca8ae, 0xd5193905, 0x353b7574, 0x65c8c93f, 0x4f20e9c5,
	0x0bf3c0d7, 0x281db393, 0x35910d67, 0xb3944f50, 0x378ee60d, 0x5df00f65,
	0xa139ef10, 0xfd2f37e6, 0x35228cc8, 0x4894a037, 0xe2c98830, 0x96798bc4,
	0xb6beeb89, 0x63e227de, 0xbf9d95bf, 0x3ae9b8b3, 0x43bbb06f, 0x1d709fcc,
	0x7c3a49b3, 0x50d46a88, 0x8a43b8b7, 0xddf64d64, 0x9fdf450e, 0xed0d86a8,
	0x88af3c5c, 0xcb9d9afc, 0x7b1c2df6, 0xef89e83d, 0xa605111c, 0x5cecdc27,
	0x5cfeca9d, 0x5cdcc8fc, 0xc6fdbefd, 0xf56ba6e6, 0x0a7e69eb, 0x95b8f67f,
	0x9a9bb3f9, 0x045dafab, 0xeec02e67, 0x539f8b2a, 0x3d06882e, 0xa4bd8fb0,
	0x7885eed3, 0x63650932, 0xc39ebb3c, 0x1ff4413a, 0x9c2e3a07, 0xcff98bd0,
	0xf1fe7863, 0xed7e14e8, 0x7dc7ae69, 0x9ca4ad0b, 0x7af1fbf6, 0x973dea33,
	0xf981c74c, 0x1c63b5ee, 0xc7f53178, 0x602f2132, 0x9d88564f, 0x15c23473,
	0xbb5ff66a, 0x2e3e38ba, 0xf034e385, 0xafea3b89, 0x003df184, 0xbfe438c7,
	0x8fbe018f, 0x9aed29ac, 0xec49ad8f, 0x85c1571a, 0xfa20bfdd, 0x18fedc4c,
	0x59c2ff76, 0x8bab5718, 0x2ff709e9, 0x1a8fb0a4, 0x897b6f25, 0x27ebfce7,
	0xaf609bac, 0x9d26eb6b, 0xec0d8667, 0xfe519b38, 0x6196f274, 0x24cf324b,
	0xfd0b96f2, 0x9225bc9c, 0x7b835d74, 0xcf7d6023, 0xcbcb9391, 0x2f2636f5,
	0x304caa8d, 0x1c452b5f, 0xf8c6c2bf, 0xa9fe712e, 0xecf9d2f4, 0xc611c2c3,
	0x827ae87e, 0x22592276, 0xd50d3f23, 0x04afbe6c, 0x429431f2, 0xd54cafcc,
	0xaf95a8cf, 0xf14e3da2, 0x4be01579, 0x04b4dfc3, 0xef035ebc, 0x00afe993,
	0x80c9a7c5, 0x02ed9f4f, 0xed2fa8ec, 0x9e322d77, 0x78e7e89b, 0x0797fea7,
	0xc37d3dc6, 0x0fe065db, 0x04fbcc37, 0x3e5f61e3, 0x3bfd46ce, 0x5f9a38dd,
	0x07c9c747, 0xf0dff53c, 0x8b6f1e57, 0x75a89c62, 0x3f78c5cf, 0xa6857d53,
	0x78ac9b67, 0x10bf2cfe, 0xaf7a73e9, 0x9e7007c5, 0x8b7164ce, 0x1ea77bd3,
	0xc3f9ff06, 0xfd429ee6, 0xcfd397f9, 0xd3332d1c, 0x3eef4efe, 0xe239265a,
	0x5f7b53fa, 0xcb3ff67f, 0xf2d2cfc0, 0x677c63c2, 0x9aefae4d, 0x517e7f39,
	0x149c403c, 0x7912ffe3, 0x18ddd60c, 0xf88c6a5e, 0xbb7f6d3f, 0xf140f00c,
	0xe1788cd2, 0xc87168f0, 0x4e2c6d87, 0x83042ad0, 0x156bcf10, 0xc15e7dd8,
	0xec2f159b, 0xf3c23c8f, 0x4d7272b2, 0x7f1e420f, 0xeb19116e, 0xd23975a1,
	0xc4ade904, 0x388872f6, 0x6bfb3b68, 0x8e942091, 0x133c51e3, 0x691efe90,
	0x0e31ba71, 0x3dd020f2, 0x097fcfa3, 0xb3c3f5c8, 0x220e30ca, 0xb8f6f74d,
	0x966c2f21, 0x0ce5f784, 0xbeb888f5, 0x6eb2cf64, 0xb077dfd1, 0x2dee9bfe,
	0x9cf98fb0, 0xffcb532d, 0x3af9c0f6, 0x10ff9489, 0xcd9b73e6, 0xd99438ff,
	0x1c9fdea6, 0xbd6ceda2, 0x5c40156f, 0xaa8fbb5f, 0x007bdcb3, 0xf706d5f2,
	0x642dee09, 0x39f51c78, 0x5affd31b, 0xfd5088f9, 0x3cede426, 0xc61dfb67,
	0x55b11e23, 0x30153de3, 0xfb45d5b0, 0x256ef9b3, 0x969c7419, 0xe8abab63,
	0xa669d2a2, 0xf6d227ef, 0x7ab9bdf7, 0x677fc535, 0x89946f86, 0xbcb477be,
	0x6be7bab1, 0xcf182750, 0x37beee78, 0x5cfdc356, 0x8b2a6c7b, 0x0f3e2a5f,
	0xaeac65f0, 0x5d78fad2, 0x97509add, 0x579b5d58, 0xc17f0bfd, 0x6e86bc3c,
	0xdc0a6f76, 0x86f30523, 0xee40a2fb, 0xbebe3623, 0x7f5d89d8, 0xc9ace53e,
	0xc58da2ff, 0x7c984a8f, 0x14a5f168, 0xa97c79ef, 0xfc635498, 0xb6bb05c3,
	0x14ca9045, 0xee1f32c6, 0x73022873, 0x2d4b106b, 0xbc48524e, 0x26909658,
	0x0e92c72c, 0x61252f2c, 0x5e91c72c, 0x20c94b2c, 0x8aa25e96, 0xaa9a6650,
	0x3d04cce7, 0xea336bf9, 0x731de2c9, 0xf9848e0e, 0xbf6dd025, 0xf3cdc99d,
	0x76d9f2f6, 0xc70f17ca, 0xe76353ee, 0x3340024c, 0x84bf8837, 0x5c7d7179,
	0x30ec3e96, 0x815f6105, 0x3cf8c954, 0x0659cfc0, 0x0b98391e, 0x7d0f9571,
	0x8706f3c9, 0xdb57d26c, 0xcf1bf017, 0x67ae3449, 0x972a3cf1, 0x06ef8043,
	0x4dd68b80, 0x0f3c5ed6, 0x7e155e65, 0x7dbe0450, 0x55fb8cda, 0x47b39075,
	0x928e75eb, 0x79008b50, 0x1203de93, 0x9f946be3, 0xee708cba, 0x84f20524,
	0xea091c58, 0xbf389513, 0x543d7437, 0x1f9ffb00, 0xf913781c, 0x079a64e7,
	0x79df53e7, 0x703bf654, 0x8106451f, 0x5b4720fe, 0x6f18bcb7, 0xc3a4e3a6,
	0x7fc18039, 0x68fdf767, 0xea427bf8, 0x3c3aa9b5, 0x0aa66e1d, 0xbfd41a8e,
	0x1f11766e, 0x6e5f15b5, 0xa7bd6376, 0x4bfac559, 0x9303c8e6, 0x629cde00,
	0x50fde015, 0x4c7978ed, 0x1715e436, 0xad3e61ba, 0x932a2fd9, 0x158cef41,
	0x22d4d4bd, 0x29c2c766, 0xead1ef90, 0xfa044b9a, 0xc932ad7e, 0x4f0a07fa,
	0xe6b5e4ab, 0x288f71d0, 0xd1172b0f, 0x53e7d672, 0x8f6fa0ad, 0xdc57af64,
	0xc97d9cb4, 0xda4a153c, 0xd80df65f, 0x37f7999f, 0xefed0ac9, 0x78947e83,
	0x7d78073f, 0x6ce1e396, 0x3362ff78, 0xe567b841, 0x7e86cfac, 0x9ccf150e,
	0x1d9b700d, 0xdaf7a4a6, 0x4d933acc, 0xaf39947c, 0xe580533d, 0x4bea8af6,
	0xeb7dfe41, 0xa959b546, 0xd53c907e, 0x661fa0b5, 0xfac62bad, 0xa3f0a643,
	0x9f58bd13, 0xe1425ca9, 0x2f304198, 0xdb8b0490, 0x73393ee0, 0x05f5099e,
	0x5ef1813c, 0x9fbf88ca, 0x1fdf3571, 0xef4ff5a6, 0xb04ccefb, 0xbaec56b7,
	0x4d39005c, 0x9cd43f65, 0xa4e78919, 0x34c9fab4, 0x1ad1ea37, 0xed718829,
	0x7805339a, 0xfdfceabe, 0xb0e70cb8, 0x8f93f786, 0xd12e1ce3, 0xfa1f57d6,
	0xb1762bd1, 0xcc47f27d, 0x0f979b44, 0x1e4b4bce, 0x333a2f3e, 0x97d5ea89,
	0x0d3ead64, 0x8e5db9e7, 0x69920fb5, 0xed69df68, 0xbca7e07d, 0xc5e1a694,
	0x3f2336d7, 0x84b4fb49, 0x7d5a85f6, 0x089ff616, 0x78b623cf, 0x4bdb4add,
	0xdfe25b9f, 0xf16e80bb, 0xa65fd8f7, 0x1c1cfe36, 0xe44f2ebf, 0xe4396fef,
	0x5d74f493, 0xf7f706d8, 0xa7eba2a5, 0xd5b6bab6, 0x6c97fbf4, 0xa75c72de,
	0x9d7049be, 0xeaf2f902, 0x7ca7ddf4, 0x7339aa7d, 0x33d3d129, 0x6252ff8e,
	0x3f950fa0, 0xd2d6fefd, 0x7cc1df9d, 0x72e14ffc, 0x0487e82a, 0x8d92f9d9,
	0xad7d8645, 0x97c70fff, 0x0297c385, 0xcdff198e, 0x8c358c70, 0x9c638717,
	0x3fbfbe01, 0xe029151c, 0x051ffca8, 0xa25da247, 0x5db84795, 0xaeaa6d92,
	0xf33d80f2, 0x67b426af, 0x19243206, 0x328847f2, 0x1774ed0d, 0xfdc3fd89,
	0x30153014, 0x596dd1ce, 0x81748600, 0x4ca5da44, 0x2b4157d0, 0xeb05d1e4,
	0xd397684d, 0x24d23de7, 0x58661fea, 0xb8288ed1, 0xdb0ebaad, 0xc7a92f57,
	0x1eba6d52, 0x2fcc1bee, 0x7a089dee, 0xc7cac7fd, 0x0db9b497, 0xeb882f7a,
	0x016730bb, 0xfbd6b3d8, 0xdec0db5b, 0x7eab49cd, 0x215dec0c, 0x93d6dad8,
	0xd33dec97, 0xeafb165b, 0xbfdfb099, 0x097a22a9, 0x6c9b39f8, 0xa041f0a1,
	0x6829bfc7, 0x3fb98c8f, 0xeb485ed4, 0xdbc98b52, 0x32913f42, 0x40b63b42,
	0xdbc4adbd, 0x026fdf42, 0xdbed07fd, 0xb2173c24, 0x0f9dd9a6, 0x76b444f7,
	0x74283b30, 0xd6156cef, 0x9d06737f, 0x5737bc3d, 0xcd700cdf, 0xb3696fb0,
	0xb7b21c02, 0xeacbcb3d, 0xf6e70a2e, 0x9ac7a8c2, 0x75d3dfc1, 0x344b5376,
	0x0bd5d54f, 0x6c8abf84, 0x7cda5bde, 0xcf9eb0f9, 0xfbec25ad, 0xd9171043,
	0x85e1a99e, 0xd5d02fbd, 0x8b524881, 0x696c7eb6, 0xbbe7419b, 0xefa609f9,
	0xc1fed2c7, 0x09f3a7ae, 0x836bfdc2, 0x207ce9e3, 0x0d8e93df, 0x27dabcf7,
	0x68bc6216, 0x07d58d93, 0x6af9b227, 0x78eb7671, 0xec9bc613, 0x4f761f1c,
	0x58c3ee21, 0x91cec9bf, 0xb614f35b, 0x66f9236f, 0x83927e40, 0xc71687f3,
	0x5a1c7997, 0x87dc6299, 0x61f7bb4d, 0x1b4cfbcc, 0x2d6e7c67, 0x442dd636,
	0xb776085d, 0x3e7c6f9c, 0xa8e3cedb, 0xe20f2499, 0xdf931eee, 0x8bcb7104,
	0x4bcb1049, 0xcbcb0848, 0xf7ed0448, 0xf58a24f1, 0x2cdd1009, 0x6e296382,
	0x78868076, 0x9c2ff045, 0x3b06ff8a, 0x3b6aa395, 0xd1e45b8f, 0x55ee217e,
	0x933e9c55, 0x06e2fc60, 0xfead1790, 0x8c4aacf0, 0xaf92a45f, 0xef933b2e,
	0xe7c5799c, 0xfcb13fbc, 0x75b8978c, 0x7d259ff2, 0xe36e7684, 0x00f7826c,
	0x7f337634, 0x64df7b49, 0xc6a07167, 0x2a42f114, 0xe7004dd7, 0x187a2413,
	0x7436268e, 0x7e059d1d, 0x130afd6a, 0x3eb9ff01, 0x27de26f2, 0xa7576899,
	0x6a59dfca, 0x31bbfb67, 0x2bfb85ff, 0x9d0053e8, 0xc8b29fb9, 0x78ddd1a6,
	0x3f3b5e8e, 0x66e5c03f, 0xcf1976e0, 0x608e3681, 0x3f6cd665, 0xc25ebf9e,
	0x4364b3e7, 0x01f82e79, 0x8cdc0e8b, 0x3f5e2e70, 0x878ff647, 0x300b4a73,
	0xebc34e1f, 0xe03f04a2, 0xcf931d8f, 0xecd30f19, 0xd00fcd66, 0x7f44feec,
	0x55f7d520, 0x8748cdee, 0xf707aa19, 0x4f6666cf, 0x937d4134, 0xa4fa3289,
	0x97b139f8, 0xb98ee4cc, 0x76646fa0, 0xf90fcf7f, 0x9f704df3, 0xc3d9950f,
	0xbe13312e, 0xbbf51caf, 0x623ca04b, 0x6f4050ed, 0xe8ecf91f, 0x4827e875,
	0x7fec0a1d, 0x9f98969f, 0x3909d5a7, 0x459e0223, 0x8e59f78e, 0xb7409d57,
	0xc3bf7959, 0x8ef5ba73, 0xef3cf157, 0xe6334ee9, 0x75b2cd27, 0xe8ea6764,
	0x89ef2b39, 0xe7e573ec, 0x4bc27e68, 0x23c3de1c, 0xe3f02c3f, 0x9c9f7cb8,
	0x22f840fc, 0x2c93e4fb, 0x3c82f715, 0xd5f9cbdd, 0x097ff8af, 0x6d76d97c,
	0xe64fca09, 0xd65629ac, 0x7f1f71bf, 0xf97dfc36, 0xf8d23e70, 0x31f7fcef,
	0x89fc1a64, 0xb90c7df8, 0xf3f41fe8, 0xae2bc238, 0x3cabfae8, 0xb5796f70,
	0xf83ff719, 0x02ad163d, 0xb85e8331, 0xbdc25a7e, 0xe57f3c28, 0xbe18be3a,
	0x4e29790e, 0xe43d5ef8, 0x81bc53a3, 0x579fb1b8, 0x9417bdf8, 0xfbfaccdb,
	0xf692b5c1, 0x7363d06b, 0x0dfac67c, 0x8bfb0955, 0x61efc9d5, 0xe6acd83b,
	0xaa37efeb, 0x3e0fa148, 0xa5fbf2e6, 0x618102e3, 0x9c6027f7, 0x35f21eae,
	0x38b27f51, 0x1b2b74dd, 0xb1b117df, 0xbc8a0873, 0xd01c4c19, 0xf8ff705f,
	0x17e98574, 0x3dc10388, 0xed25d3e1, 0x7690d05e, 0x4b9e1e6f, 0x6d72aac9,
	0xe779875e, 0xc7de175e, 0x386695d3, 0x0fc5a837, 0xe9dd8a86, 0x03e0e719,
	0x2a1306cb, 0x56bead67, 0x1f02b26a, 0xf967cdac, 0x0dbe712c, 0x96a3e219,
	0x7bd2720d, 0x50fd62b9, 0x71e7023d, 0xacbf7c6d, 0xfaa9f25d, 0x5cc58338,
	0x8a3ec2ad, 0xebd151d9, 0xf65bbca6, 0xf04ab8c0, 0x8f215b25, 0x23c7ae92,
	0x4135ec95, 0xcd5b7eba, 0x8f581ede, 0x1b930ead, 0xc516dfd6, 0x756b7884,
	0x5dbd7159, 0xbd540423, 0x4a8d6bbf, 0xa5219f38, 0x76799cf0, 0xc22719f2,
	0xcf8f789f, 0x053c6fdf, 0x478e25db, 0xe302b85e, 0x09b736a7, 0x62e44ef3,
	0xd29fef05, 0x1fb12bf8, 0x692906eb, 0x9ff0a93f, 0x28e6ee92, 0x2bf513e6,
	0x74f7a4a6, 0x62be57cc, 0x84fcecfe, 0x1bc675f8, 0x5ef81125, 0x1ce13a88,
	0xf98f950d, 0x46cbc40a, 0xee52bd0f, 0x65c8f946, 0x6e4c0d79, 0x5655955b,
	0xbc695f96, 0x3f152a5f, 0x8549786a, 0x0fc8e907, 0x7edebdf8, 0xb34fdfa2,
	0x98d54d0a, 0x225a33cf, 0x79e493db, 0xd0f1c33e, 0x7f91792a, 0x6355afc5,
	0xbb25aa9c, 0xbdf90ac2, 0x1d3b926d, 0x23c182fc, 0x797b0122, 0x1b946ab5,
	0xf7075cad, 0x56385222, 0xf7a4a629, 0xd8a5a643, 0x61527e27, 0x03bac2eb,
	0xcefaf457, 0x6f1427c1, 0x42b48f38, 0x20bd0549, 0x76bc199a, 0xaa75cf7e,
	0xc7f1537e, 0xfdd807fd, 0x5671b6e1, 0x3892b73c, 0xdbc96ade, 0xab4f790b,
	0xd7603c29, 0xe3a7ceae, 0x525d4367, 0x9b1e6ed1, 0xbe3aac46, 0xe0a63290,
	0x1b2521fb, 0xd5914ace, 0xc34ef829, 0x2f9577d3, 0xe3129fb7, 0xfa8cdbbf,
	0x5bce74f8, 0xf1d70718, 0xfc648edf, 0xb9e05df7, 0xfebf061c, 0x8329403e,
	0xc225d7ed, 0x5b31e5ab, 0xf6864df3, 0x6097d465, 0xc3a2c77e, 0x47359415,
	0xc194eac4, 0xa09d78e9, 0x2a5c58e7, 0xdbc6b562, 0x551653ef, 0x8eb096ae,
	0x77e89ee7, 0xb60acdbe, 0xea437bc7, 0xc08939f9, 0xe9510a4d, 0x2d4f3cfa,
	0xa3cc15ff, 0x3b20f7ac, 0x8399d07f, 0xeff00ff3, 0xcb7de113, 0x96fee8c1,
	0xfd32c543, 0x7067ef98, 0x6f677c6f, 0xb3e21b9a, 0xefc9999d, 0xbfc89fd1,
	0x476de78b, 0x6721bf71, 0x068f5b3a, 0x1fd1d9f7, 0x169f8e1a, 0x8240af76,
	0x6fbb11bd, 0xdda08a40, 0xc776e011, 0xe4efc6f9, 0x4a1e3ef7, 0x49d6ed23,
	0x80301304, 0xe5ffaeaf, 0xaf9f7865, 0xeb416e76, 0xe236eca7, 0xff6ba2db,
	0xe3cda2a1, 0x9a4fbe61, 0xeb833df8, 0xa0de5d10, 0xb4666e7d, 0x0afa2854,
	0x188db87c, 0xb7aaa7ee, 0x9fc04b46, 0x3fe4ce7b, 0x727f80a3, 0xf50b9a2c,
	0xa14f57ce, 0xf8a1791d, 0xd9ac5cf4, 0x273c11f5, 0xf95762b7, 0x052fcf39,
	0xc3a27e20, 0x95ef1c7f, 0xd6495718, 0x07c5e41f, 0xc1248cce, 0x80add273,
	0x3c332704, 0xd17a73b3, 0x9017b852, 0xb98ee3ce, 0x43b17eb4, 0x7fe9e830,
	0xb3b3f854, 0x2d9f3d98, 0x88651791, 0x05bd4819, 0xa7e87f70, 0xe53eef9c,
	0xfff9d2f2, 0xe8037fa6, 0x49aaf9d3, 0x885ddf85, 0x091a4bf1, 0xd777e95a,
	0x80cfa25b, 0xb5d5a3bd, 0x085bd7f7, 0x6afc0699, 0xc9a37265, 0xe4b6e06b,
	0x38a3da72, 0x1ccfefd9, 0xff61388b, 0x94d875e2, 0xbfc3f185, 0x3a9cfbc7,
	0x570244bb, 0xcdb88fcc, 0x3895fa2f, 0xc3f787fe, 0xef26a8f4, 0xccbc7cd4,
	0xf81de5c1, 0xf992bedd, 0xd15e9acf, 0xa1d1bbbe, 0xd87b357c, 0xccfcec3d,
	0x91cb8e8d, 0x32c30fff, 0xdd92b05c, 0xdda7d627, 0x7f32a72b, 0xa84fbb59,
	0x11fbdf8f, 0x1fd6fbe0, 0x5f30fb17, 0xd523603a, 0xac7d9eb0, 0xbf99d2fa,
	0xb47ff467, 0xa7ff34ef, 0x67df85ad, 0xb2f8cf9b, 0x98ee104d, 0x38b27a03,
	0xe6bbf78a, 0x51f5b2e6, 0x15c41bd3, 0xd21fdfc5, 0x38f814f8, 0x87ba3e99,
	0x8ce045f3, 0x715fc0c9, 0xaf9192be, 0xd2efe7b4, 0xb3a82d75, 0x5fbe16c7,
	0xee18e78c, 0x478c5e24, 0x276ed9de, 0x3b1e1d41, 0x76e3651f, 0xbf8e32ae,
	0xdbd3cb8a, 0x4ed7464e, 0xa7715f7e, 0x1f83b3e4, 0x4a3de9ab, 0x57cc3b67,
	0xeba5fcfa, 0x366efe70, 0x385f18ff, 0xcbf21d99, 0x5efc8abf, 0x476f3a74,
	0x1c9bbe7c, 0xcbe53b46, 0x10cfadcb, 0x67e38db7, 0x6a73ca06, 0x23cf55b9,
	0x5f88d9b7, 0x613a7cba, 0xcc2a7edd, 0xaa7a87ee, 0x25b554c7, 0xc2bc1c89,
	0x1cd2e0e5, 0xba53ef09, 0xd5d6c22c, 0x3372ed54, 0x1ca77df9, 0xc878892f,
	0x7f9e4a2e, 0x35e38074, 0x6beec150, 0x21a3fb85, 0x02cb4d9e, 0x857bf02f,
	0xffe7c412, 0xf61b7912, 0x2dbb0385, 0x7d23d06e, 0x20356dbb, 0x2dbb7d87,
	0xe1945b35, 0x9bfde8f4, 0xbdefe3d1, 0xff26f80e, 0x75dbe43b, 0x5cbf7889,
	0x3b97f8e2, 0x4c5df81c, 0x53b0a5ff, 0xc30a2976, 0xd9e19db3, 0x93d6c85c,
	0xef118b6c, 0xcc39701f, 0x3a88e116, 0xa67eb1d5, 0x7c704ecf, 0x7b7c3c81,
	0xc315d41c, 0xdb8c743a, 0x7cde9a01, 0xf905656c, 0xb4df9d3d, 0xeefd1068,
	0x0522b7ce, 0x395f4e30, 0xe113a3f3, 0x84f9ce3b, 0x399da310, 0x805b8675,
	0x16120cfd, 0xd6afd854, 0xb30d4fda, 0x1d4b4afb, 0xf4fd98f6, 0xbe77f46d,
	0xc4e3906f, 0x5c1dd271, 0x01af41ce, 0x6968945d, 0x9ae673b2, 0xa3e6d6fe,
	0xbb5a67ad, 0xf797ce5c, 0x95a732f0, 0xacff478d, 0x75b264b2, 0xcbe7dd89,
	0x1e7d20f4, 0x457ac0b4, 0x4a78e2fc, 0xf83b86cf, 0x38f0826f, 0xafd53cc6,
	0x08fc753a, 0x71ea28f6, 0xf2767f6e, 0x8ecd533c, 0x4934fd01, 0x641dc3d1,
	0xd3028870, 0x3f519257, 0x79d07069, 0x703bdff0, 0x75f13f60, 0xe5a7ad96,
	0xe66e0f5c, 0x990ed4e7, 0x775c6ac8, 0xf9349e39, 0xe7fce699, 0xfccd9f90,
	0x1e80eef7, 0xea8ef4c9, 0xd9407664, 0x8144df31, 0xd545d9f2, 0xa9fc178a,
	0x07b9deb2, 0xd25eb4cd, 0x114c3f0d, 0xce12af97, 0x6ddfd077, 0xe2dc7c3a,
	0xd853fc74, 0x48c72565, 0xeb6ffe0c, 0x2772e1f4, 0x891cde63, 0xff7f90f8,
	0x3eafe161, 0x022ce708, 0xa2202e94, 0xc33afd1a, 0xc0d9560b, 0xbc463b0e,
	0x87f5c760, 0x53c69817, 0x606ff5fa, 0x3f4c4c76, 0xa7f367ae, 0xfa0c2dfa,
	0x3e63a2ed, 0x6f5a38fb, 0x7ed1fa05, 0xb08dba2e, 0x8ec253fb, 0x9a6ff810,
	0x2b7ce65c, 0xb7cf1d3a, 0x6c5a9bdb, 0xf6b1e7ba, 0x27bdb45d, 0x9001df2e,
	0xd4ee3a6f, 0x749ef62a, 0x79174259, 0x4c1ff992, 0x37b2a55f, 0xfd32751f,
	0xe81afa06, 0xac4ed334, 0x21f70a36, 0xc4bdfb0f, 0x26791743, 0x87ca7dc1,
	0x96e3fcd3, 0x7973efd3, 0xe797227c, 0xb1a6e6fd, 0xdb9394f2, 0x7cace957,
	0xceb99796, 0xa38cf1e4, 0x8990fdfc, 0xf2baf9c9, 0x2ef3ebe4, 0x6b8c57e7,
	0xb8860b15, 0x776bb516, 0xf7e72f39, 0xfae29ae4, 0x13d3e351, 0x3944bbfc,
	0x20867a5b, 0x3bfb68ff, 0xd7c1a54b, 0x59f8a26f, 0x3c622dda, 0xdfc59265,
	0x1276c4ed, 0x2980d1f2, 0x300f7b7a, 0xc5eefc10, 0x59f9a915, 0x9c9dabd3,
	0x40b0c1ae, 0xc0399f60, 0xb3d060fd, 0xcaf41ab7, 0x2ecf08fd, 0xa939fdd0,
	0x2f2fdded, 0xb0a6975f, 0x26ff4aff, 0x87c69ff6, 0x8b44bc5a, 0x4a7c684b,
	0xaf3803c8, 0x1c9833a9, 0x2763f5d1, 0xfd74f5f8, 0xf50d3718, 0x5f988fc6,
	0xd1786564, 0xb9b91be2, 0xfbf006d1, 0x77e03ca9, 0x7875efda, 0x798abd4e,
	0x99d26377, 0x7d54e67f, 0x0f572003, 0xa9dbfcf0, 0xadd91155, 0xeff8e75f,
	0x8e603c78, 0xe6065efd, 0xb00c8d51, 0x07c3f37e, 0xa7c74904, 0x98f0caca,
	0xf9de7445, 0xe93e7c35, 0x369e8366, 0xdd29baf3, 0x4d7e658d, 0xfe862844,
	0x24136e36, 0xf848dfda, 0xbf2a123d, 0x48489b23, 0x231c3bff, 0xc53c6cbd,
	0x1cee121b, 0xbb4f9f17, 0x9538ce69, 0xae7b49f2, 0x9f4adbdd, 0x7b7eaad5,
	0x78f9e03a, 0x98e80224, 0x0257bc7a, 0xd55eed3f, 0xc4e7a4a7, 0xd516e3e7,
	0xbffbf891, 0x1d9c19c7, 0x5a23bf31, 0xf7b8e2c0, 0xe16ffc73, 0xc1e93ceb,
	0x9850e5df, 0x6abb905d, 0x97f7e1ac, 0xb69b7b34, 0x27e8276b, 0xbb943d33,
	0x86f304aa, 0x2ccffa35, 0xcf06deaa, 0x64b88e67, 0x2ecf9c12, 0xc122207a,
	0xb73eadef, 0xbef494d1, 0x99d24b81, 0x8bf853bc, 0x4f9ff0f5, 0xe676b47e,
	0x83cb73b4, 0xf0c7f39d, 0xfbe20ff7, 0x6fb227f2, 0x56c47bc1, 0x0ff604cb,
	0xabdfbc34, 0x78054f56, 0x0b378646, 0xde3e1388, 0x0d7f7cbb, 0xbc1c839e,
	0x6ff6c72b, 0x7f6b9c47, 0xf772b021, 0x397a4598, 0x5d232d5b, 0x7efc2736,
	0xcd5766ae, 0xd3766749, 0x2aead4cf, 0xd74377a0, 0x2f8fe843, 0x0f7ec6db,
	0x2e7e2521, 0xde747f10, 0x823bf02d, 0x860ed475, 0xb084d2fb, 0x605c7680,
	0x0947db3e, 0x4a7c64ec, 0x7f78cb56, 0x2bbc2052, 0x47efa262, 0xc2f3ebdd,
	0xcedd48b6, 0x1d62c25d, 0x4205475e, 0xb17cafb8, 0xa6239343, 0x1786462f,
	0x5ddf9004, 0x3bf02f76, 0xc520edc4, 0xd98db0fc, 0xcce57d89, 0x0733eadf,
	0xbb69bac7, 0x179a4f3e, 0xda5e32f2, 0x97dc75f5, 0x44b6ec74, 0xbf9c6704,
	0xcbb8b5d6, 0x3375ce01, 0x45fc0a89, 0x50e5afd7, 0xc0aad99f, 0x1f4c679e,
	0xbd4d7068, 0x0ffff197, 0xffa03eb9, 0xffff0126, 0x3eb674ef, 0xed0df5d3,
	0x0666c3d4, 0xe8c26ecf, 0xfd59ca7f, 0x99ef00bf, 0x7f808452, 0x46155198,
	0x327a41bd, 0x1b75bf11, 0xa37e713b, 0xadfb3276, 0x9466e76e, 0x013f4d5b,
	0x28f7e03e, 0xb477c2a7, 0xa2fae3ac, 0xc26d89fc, 0xadf075ef, 0x1c59174b,
	0x03b6e367, 0xa49b3bf0, 0x97e0a886, 0x660776d1, 0x1277e365, 0xd3144bdc,
	0x38de3013, 0x9d62de36, 0x4fe0d09e, 0x821e2fa2, 0x7bc72879, 0x22fa645f,
	0x83777ec2, 0x8f4689f3, 0xe55f41c7, 0x5872e9c4, 0xfda0f4a6, 0xc34c2e1c,
	0x05f9347e, 0xf5cb9b79, 0xfb894999, 0x1a1c1a7f, 0x62b54e9c, 0xd4cfc813,
	0x7f9c5eaa, 0xe10946fd, 0x1757299e, 0xdfe3a5df, 0x1ecce99d, 0xdbd37838,
	0xfac99f78, 0x5e228f67, 0xb6043beb, 0x5471daaf, 0x45eb079e, 0x1bcc49f0,
	0xd75f06f8, 0x09f7e51f, 0xe193a37d, 0x9773bebf, 0x69c4f704, 0x7539e4fc,
	0xaa21ef10, 0xd8085b0f, 0xfeaaf757, 0x618780dd, 0xa0f1c57c, 0xf254c5e9,
	0xaeecd762, 0x17768ca0, 0xe03ccbb5, 0xf57a690f, 0x885ff714, 0xc2bf9ec2,
	0x4fae37e5, 0xf8c02ffc, 0x07bcd333, 0x271fa0ad, 0x1256de09, 0xa7b2af5f,
	0x0e9838f3, 0x0bbf649e, 0x657b8b1a, 0x2b2fcd11, 0x1f3bab98, 0xfccfd313,
	0xae9ca3fb, 0x3d8479f4, 0xfeb08527, 0xd227706a, 0x8fae73ed, 0x5bd1f093,
	0x0d1dd6c9, 0x7e3f8d7e, 0xe83251ba, 0xd9d20ff9, 0xa41f8abd, 0x47febcb3,
	0x1d743e81, 0xd6ccd47e, 0xac5b4799, 0xd2f58798, 0x0c7eeccd, 0x04722dc7,
	0x85a643ca, 0x687f7801, 0xddbf1b24, 0x6f394264, 0x9ce4c55f, 0x00a717ae,
	0x3937839e, 0xf9812e91, 0xd732f7ec, 0xade982ff, 0xfbc15040, 0x6ffe030a,
	0x94f3c22d, 0xfe2f36d9, 0x45ffab1e, 0x38639e79, 0x1f77b93f, 0x6f9d3cc0,
	0x697c9984, 0x0f7aa074, 0x675b4af9, 0xf1c6bc34, 0x295ef0c9, 0x332da093,
	0x4e538f4e, 0xfd73c795, 0x9ade761e, 0x05ffb3d9, 0x3165a956, 0x00008000,
	0x00088b1f, 0x00000000, 0x7dd5ff00, 0x45547c09, 0x7ebd789a, 0x8774857d,
	0x0849d1ce, 0x42043a39, 0x42742480, 0x9d202082, 0x61ca0084, 0x04024387,
	0xb900ee68, 0xc78ff450, 0xc8831a6c, 0x744eceb0, 0x9d4703c6, 0xaf1af106,
	0x068341a0, 0x1c19046d, 0x2030cd71, 0x8cd38238, 0x7a48670c, 0xcbb8b1e3,
	0x57df5b2c, 0x2f7ee955, 0xb32e1cdd, 0xcfe2dfff, 0xbd5ea55f, 0x7df557aa,
	0x55777d5f, 0x65c84213, 0x53757ffa, 0x91a4e5b4, 0xd7a83fe0, 0x9cb1f4b6,
	0x57d40acc, 0xe87d1fc1, 0x22621eff, 0x62a909c3, 0x8d3de44d, 0x4852d22b,
	0xfb7d1bfb, 0x86423674, 0x5debf51f, 0xfe07da26, 0x84940d8d, 0xd2b109b8,
	0x21fed671, 0x4230e4f3, 0xc7ee2656, 0x2c922e32, 0xa2136670, 0xa0cb47eb,
	0x8916897e, 0xe5ee3a10, 0x4bf612de, 0xff58d8b3, 0xa13d2682, 0x593aafef,
	0xd2d1b7a7, 0x3c389134, 0xa5a31e50, 0xbf7bf829, 0x3c84fec0, 0x234afd82,
	0x71cbc69b, 0x64adfcb4, 0xe73d2069, 0x12e5ca27, 0xf1d13671, 0x27b33f4e,
	0x8f1d216a, 0xe32cba5c, 0x7ad8237a, 0x8e0d16ed, 0x4cb2fedb, 0xadaed0bc,
	0xeb1093d3, 0x88f1d6bd, 0xe24490f7, 0xec387ae9, 0x192b5fdb, 0x0a02b7f9,
	0xdb7b97ad, 0x9f25d007, 0xbdfa6d7f, 0x6ef3a37f, 0x2ed636df, 0x06b8f6d3,
	0xeb4212e7, 0x7d846b7e, 0xcbad3a6b, 0x4f94a264, 0x3da6bac8, 0xbf68a351,
	0xcd0eafb3, 0x137ed037, 0xbdcf3cf8, 0xb805af2d, 0x9bd2f83c, 0x2afb40b7,
	0x806b148f, 0xdbfcbcef, 0xe3a24aff, 0x05ab6e54, 0x57869348, 0xe8fbd43f,
	0x16cf1a7b, 0xdee5fcf6, 0xecef7816, 0x02de8ff3, 0x6a686ef0, 0xcf73f6c0,
	0x47fac16f, 0xc1f9bd2f, 0xaaf7d07f, 0x7876519c, 0xbbdbdcef, 0x2e552f11,
	0x4bd603ad, 0x33f57b5c, 0x57f680cd, 0x24df5864, 0xb627dcbe, 0x72dbd6ef,
	0x7e89bd68, 0xe527f695, 0xba00cf7a, 0xeda6aa8e, 0x1f00c5da, 0xef30604a,
	0x182d2fb3, 0x5a447409, 0x557748ac, 0x825933b2, 0xf60c13f7, 0x8fd76817,
	0x8c6dc4f5, 0xd10465a1, 0xbf43e446, 0xf2cf0c2d, 0xc03addea, 0x6f648673,
	0x4b1e10e0, 0x8d8fb7eb, 0x7e89b2dc, 0xe8c91ac7, 0x6233f68c, 0x7b3fad3f,
	0xb3679d1a, 0x24973f9e, 0x31e3ff7c, 0x4836b643, 0x7c08f981, 0x25952c7e,
	0x3c0eceaf, 0xb1e7c8df, 0x112117b1, 0x645f3cb4, 0x29bd4b72, 0x1b4d8b9c,
	0x7aff3ca1, 0xbfc03944, 0x8ccbef46, 0x3364f806, 0xf80e5d3a, 0x57bac2b1,
	0xd84c6aeb, 0x42f9c71f, 0x39940847, 0xa29cbf74, 0xb5be8ffb, 0xf830f2ed,
	0x3ef81bde, 0xcc046f7d, 0x09c5567b, 0x9913e009, 0x855ba75d, 0xb5957b70,
	0xb7042c53, 0xf6c35f0f, 0xd72e9a87, 0xbef84c59, 0xcd4997d8, 0x8036c965,
	0x0ec19c6f, 0x4beb10f8, 0x983574aa, 0xd6dbf3e9, 0xa532ecb8, 0x1ccef7ab,
	0xd697df1c, 0x8692ca5f, 0x12ca3d21, 0xb71adfee, 0xbd53bf09, 0x437c98b6,
	0xf7c8dbe7, 0x6885bc6f, 0x8fc60e6f, 0x0c4d6896, 0x9465a9ee, 0xb637aa0e,
	0xdeae3ee1, 0x8c49e6c6, 0x66e9d4fe, 0x39ba67ec, 0xda0f3026, 0xbac264cf,
	0xda0ef53f, 0xbba2722f, 0x267a509c, 0xf7ce3d36, 0xc44fe09c, 0x272f3b9d,
	0x35e3ffb0, 0x18f405c4, 0xc225a7af, 0x465e95c9, 0x52d57fc7, 0x1ac5a2f4,
	0xb17be328, 0x7c9c3576, 0xb457bdbc, 0x73e045e3, 0x4258e5e4, 0xefdf8646,
	0x1c359e02, 0xbe484fff, 0xeee74065, 0xa016119d, 0x7c5b9adb, 0xee7cc199,
	0xb7f18598, 0x1d374e0e, 0x7cbd193b, 0x61b8d1ac, 0x1d6f1f7d, 0x30e805b2,
	0x5c3afe30, 0xe367c0d7, 0xb8e969d6, 0x05922d49, 0xccf492f0, 0x8afe0534,
	0x4eb6dd9e, 0x59d5eb4f, 0x07e070d2, 0x3feacb52, 0x1af5a20c, 0xd7a8378a,
	0x412d9734, 0xd845c5f8, 0x5abcc007, 0x9e619aca, 0xd8a6e37d, 0xa3ffda65,
	0xef8f5f59, 0xaa6bdb4b, 0xefec2148, 0x3b1c5227, 0x243ae2fb, 0xffed02f2,
	0x6893ce84, 0x0c4feda4, 0xa1bbb4ca, 0x15496bbf, 0x48c4e7ee, 0xb5c49fdc,
	0xfd06cb3e, 0x9bec736d, 0x607c10a4, 0xbc2774a7, 0x4486e94f, 0x6a4defd0,
	0xdfd81c91, 0xa0fc8913, 0x08bd25a6, 0x9c6937e6, 0xfed322dd, 0x447c0417,
	0x0f9b6ba9, 0x30ec77ef, 0x3ed07710, 0x09cefdfd, 0x425ca5fb, 0xbc18efcc,
	0x77af9e50, 0x84b46f90, 0x11f9076c, 0xbd578fb4, 0xfd81ae96, 0xc3b78171,
	0x973c5b3f, 0xead5f473, 0xcba45e25, 0xdc24d7aa, 0x470671af, 0x78415dde,
	0x72612b8b, 0x701d07ab, 0xecf81fba, 0x1247c40c, 0x33c007c5, 0x1ccd19e9,
	0x4f5b9f5c, 0x55b77d60, 0x9d2d6f12, 0x68cf6ddf, 0x696963bc, 0x3fca558d,
	0x8cd1ca51, 0x3ac6944f, 0x95ff80f3, 0x83d932ce, 0x2f6952f9, 0xc2822687,
	0xf05f34a9, 0x8681673b, 0xde2677be, 0x15ef708c, 0x95a6e4cd, 0xfb822b8a,
	0xe673f490, 0x70cff504, 0x9738036e, 0x1bd84426, 0x3726bce8, 0x3f4973ba,
	0x57aebada, 0xca47ec39, 0xe8464d67, 0xe9fda167, 0x475bf17b, 0xf909bf3d,
	0xfb8e0343, 0xc6c2c5bd, 0xd4167589, 0x70c94b01, 0xc9f261ae, 0xf52adf6c,
	0x9cabcf5c, 0x6b347def, 0xe8069e7e, 0x6ec98663, 0xfafdefa0, 0x8c11697d,
	0x82a6e35f, 0xcd69e910, 0x5e015bc1, 0xf40ec495, 0x50335c46, 0xcdc4d5ee,
	0x7bf7e3b6, 0x2609d3d0, 0xbe185a57, 0x3c985a6a, 0xf8c89c89, 0xe005f02d,
	0x247dea37, 0x67f029f6, 0xbe80767b, 0xd6bd3ec4, 0x73a1d8fd, 0xa0e9fee2,
	0xec7a06eb, 0x18f7c3a6, 0x675a6e1d, 0x4df6822b, 0x10d2c4a5, 0xe9f75fc4,
	0x274059dd, 0x42f5fafb, 0xb360dabc, 0xf9edbad1, 0x238c0f48, 0x8b4adaf8,
	0x9868a6f3, 0x364fd6ef, 0x3e72b920, 0xcfdef354, 0x6fa4af33, 0x3c6cb519,
	0xc157dd23, 0x60a46374, 0xe963e736, 0xb91c7e06, 0x893fa956, 0xc99a2cb2,
	0x472f5589, 0x6bc3f428, 0x926d17d6, 0xf424f016, 0x571a03c5, 0x17d73459,
	0xd4902529, 0x8c5f4cb5, 0xfc0ede07, 0xe7a46b68, 0xf89f0a05, 0x2b7ae278,
	0x47467cc4, 0xf0297e33, 0xf6c318da, 0x7b147c4d, 0x17ef8abf, 0xeeef7f17,
	0x81eb8968, 0x1f62dd6c, 0x13ae34d8, 0xf7cf0e44, 0x2f3a3f45, 0x36fda76c,
	0xb231fee2, 0x983fc679, 0x105375b9, 0x68fb031e, 0x37e03e50, 0x76af11e3,
	0xbe302991, 0xba6a3b90, 0x7c837981, 0x65947582, 0x71af7f87, 0x6a37e337,
	0xef927e3a, 0x826882a7, 0xae317be5, 0x8adf00c3, 0x4b11c4de, 0xa1f15ef1,
	0x6488e901, 0x749d33f9, 0xe25a55dc, 0x3e00c436, 0x105f1e75, 0xfe018afe,
	0xd9a75fb4, 0xfd2996e8, 0x3d71881f, 0x8bb8e30c, 0xfa0bdd89, 0x3f947de8,
	0xde243ec0, 0xb51fe042, 0xf00517c4, 0xfd766f1b, 0xdca5d233, 0x2a750a96,
	0x3be17331, 0x2146464f, 0xc89ffc9c, 0x1e14819e, 0xbfdf465d, 0xe9f3a28c,
	0x7761935a, 0xbf8e71d3, 0xaf8ed5f7, 0x7617dbe8, 0x05714e9c, 0xa31ad1f1,
	0x0d8da8c6, 0x52243bd4, 0xcf8214de, 0x37e38efe, 0x6d21207d, 0x1fad1700,
	0xbb35cff5, 0xa4ae128a, 0x2c5ed78f, 0xf1a09e26, 0x503f696b, 0x8e2f6a85,
	0xa1619e27, 0x503903c7, 0xb889317b, 0x894dfa83, 0xd0357c61, 0x69b8953f,
	0x521ae3ff, 0xffbe6a19, 0xf1f4cd19, 0x86264266, 0x6c31276a, 0xd8fdcd3d,
	0x966ff57e, 0x2fdfa03c, 0xcaf6635b, 0xe8cb9414, 0x9687d063, 0x4d5edc59,
	0xca1bf014, 0xfa2286b7, 0x3da91866, 0x2dcb90b1, 0x34769efa, 0x82dba9d0,
	0xf7c5cefb, 0xdf96c2dd, 0x38c128ff, 0x4d1c625a, 0xb46459c7, 0x9f4bebef,
	0x2e34cdff, 0x92c1c40a, 0x83c7a7bb, 0x515099b2, 0x9d2177a7, 0xfe80b38d,
	0xf2d19129, 0xe92bc8e5, 0x53d45a3b, 0xfe288e91, 0x9f9c62cb, 0xfc03fa09,
	0xf8c5dc57, 0x9fff7898, 0xd354fef8, 0xf061d7df, 0xf14c62fc, 0xd7a0d17d,
	0x408f3946, 0x05d77159, 0x90ebbf05, 0x06fe2f7c, 0xd9b573e8, 0xd9e902fe,
	0x7b8714ff, 0x9e9b5e67, 0xf572d064, 0xdf5153df, 0x51fdfd6c, 0x46d5cbe0,
	0x25a65793, 0xfbb5d669, 0x0e283ac4, 0x4e3944b6, 0x0fdcf7c2, 0x353e8e8f,
	0xa04c3e84, 0xae3e71cf, 0xe81cf073, 0x4c1711db, 0x31deb6df, 0x6efa2740,
	0xf18d38bc, 0x6490bc01, 0xad1f12b3, 0x163e209f, 0x807a1d19, 0x138762fb,
	0xdbd157e7, 0xc051685b, 0x3cbe5b3f, 0x7fe1dae4, 0xe3ed9a3c, 0x874a7ae3,
	0x0c42e4a1, 0xbe14ff83, 0x31278fdf, 0x4a9e3d7a, 0x3282df2a, 0xdfb49693,
	0x1ebc7ef1, 0x7367a4af, 0x838be30c, 0x5f5c1862, 0xc444718c, 0x8e63be30,
	0x46f77861, 0x029df307, 0x812877ca, 0xf8521675, 0x2a6df9d3, 0x011ea7f2,
	0x60cbb0be, 0x3abb6ad9, 0xbef9d21e, 0xa7f2c9f8, 0xc33f953f, 0x1d27f215,
	0x0fe54be6, 0x44ce9dc2, 0xfea1f4cf, 0xb3c46f08, 0x5ef0ed7c, 0x2ef8c115,
	0x3121fba5, 0x73794f68, 0xd9fc419c, 0xf824e1c1, 0x4a5ef1c2, 0xf391fcbc,
	0x5ef102b1, 0x65d985b4, 0x8c2a7f76, 0x34263c73, 0x77470f1e, 0x7c247fc3,
	0x9fe0c2b7, 0xe7e94b1f, 0xf5ef2a0e, 0xe38f88f9, 0xec3da740, 0xf7ef6cc8,
	0xef6b2fb0, 0x5f901334, 0x26163125, 0xf7e80b1f, 0x522728cc, 0xf4da3c19,
	0x7e1abf50, 0xf7e9d1d6, 0xc924b4a1, 0x534043f4, 0xe386c459, 0xdc16d190,
	0x7cdd1137, 0xc298f6e1, 0xdfd47c00, 0x35f1c63d, 0x9ed2463b, 0x89dabc02,
	0xffcdfa1d, 0x79e6b7e3, 0x582e4e94, 0x950d6e8c, 0xae35974b, 0xfb4e3079,
	0x9ea09fbd, 0xcdef4c7a, 0x6885346c, 0x7b9f7bd7, 0x2fb40a52, 0xeb764578,
	0x6e6cbee9, 0x167c7f6b, 0x4dabbf5d, 0x74bec3b6, 0x67fdf03d, 0xd1de8137,
	0x200fb3a6, 0xd11f1f28, 0x98ea3ac2, 0xa34c757e, 0x7bf9ff84, 0x7dff7a94,
	0x2f546f1c, 0xfb133a40, 0x544458fb, 0x59f3a12e, 0x8003bc4e, 0x435217ee,
	0xeadf4a15, 0xdd0993e5, 0x334d8bf7, 0xdf4efe90, 0xe07eeb79, 0x0b884b03,
	0xb742fff7, 0x7cc1afee, 0x6546f171, 0xb2a3697d, 0x6529fcbe, 0xd60be85d,
	0xc4f6d092, 0x9eff7cb3, 0x7f6e87d7, 0xbf5fb794, 0xf28c1d5c, 0xcd5ca7b3,
	0x1eab7945, 0x4618f1ef, 0x9af901e7, 0x972d0ba8, 0xee307593, 0xe7a165f9,
	0x1fce5bfb, 0x145a2f6a, 0x3fd039f2, 0xd532e50e, 0x39bad8a0, 0xf0f7e8fe,
	0x3d0ba8b9, 0x38bbe82e, 0x96dc651e, 0xfd819153, 0xe6c5ebae, 0x84f5e821,
	0xd07d8c44, 0xfb947aae, 0xd3b92c53, 0x009f7d28, 0xeaf14cf9, 0xf03e409a,
	0xbc2e29d1, 0xb6a64fbf, 0xd59e805f, 0x3f78a0eb, 0x5fe20be7, 0x71cc623b,
	0x64a1ddf8, 0xd0577c28, 0x4b7bfce3, 0xfe7c837b, 0x092503cb, 0xb7537ac1,
	0xeccf41df, 0x0a4c4219, 0xf2544379, 0x950b6168, 0x07a8b93f, 0x7e1d0264,
	0xd2366bb3, 0x8f6212e3, 0xdced3a07, 0xff454865, 0x43944fdb, 0xddd33e62,
	0x2f4c750b, 0xee8142a4, 0xfbfc698f, 0x3e995bd3, 0x743a31a2, 0x88386fa8,
	0xa68f12cd, 0x5497931f, 0x7d696878, 0xd103a88c, 0xbe68fad0, 0xd3fa0918,
	0x25e18ff9, 0x844ae459, 0xef8063fd, 0x3c76c0ca, 0x8c365089, 0x1ca0dbb4,
	0x6cb5392b, 0xe3cf0c1e, 0xbc325d49, 0x64fa31af, 0x19d0efa6, 0xf17f43c4,
	0xf337563d, 0x5d19fafa, 0x73c297f3, 0xb9f71993, 0x07e3cf9e, 0xc48cafc1,
	0x9836eb08, 0x5d6167bc, 0x8bba5e66, 0xba37686d, 0xcfb411fb, 0x0226917b,
	0x2e9935df, 0x16b161b8, 0x1ea09162, 0xdef2e961, 0x998f804f, 0xc8a19adc,
	0xf803fec7, 0x6074bb7a, 0xca39f019, 0x6f817337, 0x7ad76d86, 0x7c16ef51,
	0xafcf8628, 0x3ea1f381, 0x9621c184, 0x8f7bf038, 0x1f219799, 0x48d69ab2,
	0xd4737fd0, 0xf143e444, 0x1eda7800, 0xe0ab513b, 0xb2a7562b, 0xacae509e,
	0xeb2971f7, 0xf90c7246, 0x2675e4bf, 0x3b458e5e, 0x03fc0b22, 0xf9b17ab3,
	0xe8bcc074, 0x7b708e3a, 0x6744c67b, 0xf7c296a9, 0x99f26c8e, 0x56e99683,
	0x5d2c7c57, 0x75fdecdf, 0x5eb455d5, 0x78e4807e, 0xd6379969, 0x0a35eab2,
	0xccf30dcf, 0x7d6907f6, 0x96919983, 0xa0f06adb, 0x1fe409df, 0x49a2df6d,
	0xa3ff80f4, 0xf491fc16, 0x4e401bfb, 0x10061e03, 0xdca92fb4, 0xfda460df,
	0x58b26cb6, 0x9fc0d936, 0xfe0f1fe3, 0x6252ff32, 0xd0424ad9, 0xe74a25e3,
	0x43cfae14, 0xe251c29d, 0xb7cf15f8, 0x560cf3c1, 0xec1c3b1f, 0xa32ff623,
	0xf0083295, 0x3de96463, 0x6dab67e0, 0x6959d22d, 0x1d9c633d, 0x5f62a9fd,
	0xfba2a4de, 0xc43a0151, 0xef5e3cf6, 0x6968fadf, 0x076e1c7c, 0xba0a5794,
	0xe85ac985, 0x4ccce183, 0x3737de0d, 0x183fc093, 0x3e3024af, 0xbc7189f2,
	0x1379e3ed, 0xd26e0e90, 0xbec3777a, 0x3ccbc51a, 0x9670ce5e, 0x31df81e5,
	0x0ec98675, 0x5c7b397e, 0x777c034e, 0x1924c558, 0xb890a8e8, 0x1c2947e4,
	0x651b1846, 0x8c7f1d2b, 0x0df6c5e4, 0x8ca37d92, 0xf6dfeffb, 0xfe515f81,
	0x70061915, 0xb909d0ef, 0xf20de8e0, 0xe4b94665, 0xe3c83bfe, 0xebc23271,
	0xbd2571bb, 0xd67728af, 0x60fac86a, 0xaf5ebfbe, 0x133f77f0, 0x0f17fccb,
	0x105f8ec6, 0x95d9fc8b, 0x6968fb0e, 0xc0b7dd2c, 0x1648b2af, 0x7da0dbec,
	0xf41622b5, 0xc34fa287, 0x3b653bed, 0x1d3377df, 0x4fa874c3, 0xf827fdf2,
	0xa317b39c, 0xa484d9f3, 0x20ccdd00, 0x0f0fc875, 0xfdc0ad16, 0xeb710777,
	0x2cbe6e80, 0xf3177066, 0x29513e9e, 0x953a67d7, 0x6ae559f5, 0x1ebf4fb9,
	0x6ceef81f, 0x9a7db297, 0x2a26dfd0, 0xff8ab7f5, 0xe51a2977, 0xd58bc24c,
	0x6fc0d397, 0x0567433c, 0x64ab5c3f, 0xab71bf41, 0xdad97e84, 0xfc07a372,
	0x122db574, 0x17acd3f3, 0x21f0bcf4, 0x0fbee7a0, 0x553e3038, 0x5a5db2d3,
	0xbeaf841a, 0xf8091e55, 0xa30a40eb, 0x5c279036, 0x79d11ffe, 0x1c1d0376,
	0x9e494159, 0x9e8f677e, 0x46f64fc5, 0x1bf83710, 0xe79a1d05, 0x5ed9ff33,
	0xf7d193f0, 0x2c9f82f7, 0x1252efc8, 0x25d0fcc9, 0x7cf8f443, 0x5fa09686,
	0x426dda39, 0x819674dd, 0xcdff71d4, 0x268a645e, 0x70f15fe6, 0xac41737b,
	0xeb42fc24, 0xdaa3bfd1, 0x8258d6bf, 0x373adbfc, 0xe567fd0b, 0xe00579ad,
	0x0072a4b7, 0x620becfd, 0xdcbfd86d, 0x9ffe8795, 0x71b34cdb, 0x6eb6d45f,
	0x05312ed1, 0x58ede6e8, 0x4922272e, 0xb75bd024, 0x032de55f, 0x6b2e55fa,
	0x5d02ef9c, 0xb9bde955, 0xf88f4944, 0x5f9f1c3c, 0x2badf1ce, 0x4a5ece76,
	0x99f9ddd7, 0x15760ede, 0xa788e415, 0x234677b7, 0x234ed41f, 0x17d777c8,
	0x9d97e411, 0xe17f985b, 0x64e57474, 0x4bd642da, 0x767fa88d, 0xb8478cc4,
	0x45ed34af, 0x19f2a07d, 0x7a41474a, 0xca6dcac9, 0xecc22afa, 0x7ad7aaba,
	0x25f223d0, 0x9a6ab7c1, 0x7f48fd95, 0x1ced4726, 0x9f9c79ce, 0xd3ed3be6,
	0xe5ea614b, 0x9f660cf6, 0xf3f00711, 0xee7a03c2, 0x9cb0ab6f, 0xf756008a,
	0x7d2574a2, 0x467cd3a4, 0xf197fb66, 0x1dfe42cf, 0xe42f5f35, 0x5a2dc87a,
	0x80fc9dfa, 0x5848515e, 0x55a6af7d, 0xe604d44e, 0x09fbc05b, 0x55f0467d,
	0x11a2af81, 0x3a51f794, 0x4bf824bb, 0xf00fd23f, 0xfa47c74d, 0x10022096,
	0xc1bbe383, 0xbfc518ce, 0x0dc1e947, 0x18d6e574, 0x1bc7403d, 0x27943aa4,
	0x695bd046, 0x217249b9, 0xd2b77d1f, 0x47bc032d, 0x93e9ba92, 0x8da37be9,
	0x2700916d, 0xce24274a, 0x069fa01a, 0x2edd4de2, 0xdb08e829, 0x0d3fa3db,
	0xff824749, 0xf264bf7b, 0x315d1279, 0x5c4a538c, 0x95ed37a8, 0x4c9d2396,
	0x0b5afd30, 0x30d53ffd, 0xf12265bb, 0xa57e6168, 0x27fe2516, 0xb7eb2a24,
	0x07d07ada, 0x1c1dc1c6, 0x94b2939e, 0xafc10eed, 0x401fca88, 0xf2bb312e,
	0x06eefbe7, 0x2d72367b, 0x447902c9, 0x638c2b35, 0x5060e9a9, 0x5ff70ddc,
	0xe10b8a0f, 0x71d4eebf, 0x5f455bbd, 0xcdcefb35, 0xe804847f, 0x9b87ec50,
	0x489c9d49, 0xc87d26e1, 0x033704e2, 0xdc80c5fd, 0xd03a16a4, 0x17f30157,
	0xe821fd89, 0xddaf386d, 0x2be9c71a, 0x7d01a48d, 0x4089698d, 0x40cde13f,
	0xf36e9467, 0x8e42b8f8, 0x61b8fd0b, 0x4aba0f44, 0x6f996897, 0x80adfb64,
	0x3e786538, 0xe6ffb24c, 0x8fd074fe, 0x071fa8dd, 0xa414d1d1, 0x11d28923,
	0xf21ecfee, 0xa2aed951, 0x43ef8133, 0x222bff5c, 0x335f4875, 0xbd2c3634,
	0x2e3ecc65, 0x4e4e5131, 0x1a7efffb, 0x4071b3a3, 0xbef01987, 0x8c4a4e92,
	0x0e9abaca, 0xc13517e9, 0x65d355df, 0x034b3a38, 0x3172133a, 0x7674eaf6,
	0xb3a78dcf, 0xce87ae7b, 0x1edadf04, 0x81312961, 0x5094aebc, 0xacfb0c0e,
	0x07d4037f, 0xbea3a756, 0xbeda3db9, 0x58ebdb07, 0x439b417b, 0xc67ef886,
	0xee9ede1a, 0xed7a812c, 0x874eda5a, 0xe2c43c2e, 0x601ffdff, 0xd60f79ed,
	0xff8331ed, 0xbffacdc8, 0x1c837677, 0x1b3ddb45, 0xc6a2ff78, 0x6ed7a812,
	0x434ffd64, 0xe428613c, 0xe01a7905, 0xd247a0f9, 0x643ccced, 0xbe58ee7a,
	0x5bd2edde, 0x235fb07b, 0x9f7cb7eb, 0x3b4117b1, 0xb7afe996, 0x7d8e75f0,
	0xee33ad86, 0xda26db9b, 0xf52c5d28, 0x3aef51bb, 0x8e1aa9a5, 0x1d8c2d7c,
	0x26352458, 0xb2813943, 0x461d285d, 0x63f68faa, 0xf4ada471, 0x98e3db13,
	0x61c4411f, 0x165bbe20, 0x8f6cc7a4, 0xf1537e63, 0x610c7c5e, 0xcda7eaf1,
	0x9f787768, 0x77c81224, 0x1fbc1b58, 0x21345e2e, 0x84f50ea3, 0x4e226909,
	0xa22ed3e4, 0xfcbbcbdf, 0xfe50f8ed, 0xbdfe168d, 0x2d4e3c33, 0x587a579e,
	0x103b7afc, 0x67001247, 0x0eb01ff1, 0x94265ffe, 0xe00464dc, 0xc5f7d593,
	0x31b4d82d, 0x5355c299, 0x108375a7, 0x4e30954b, 0x79fe953f, 0xfce7bf31,
	0x57896827, 0x6c1a798f, 0xa81acbfe, 0x636245fc, 0xc7266c7c, 0x003d191b,
	0x8e0cf5f7, 0xbe093f9f, 0x030c8c34, 0xe39334be, 0xd5230eeb, 0x371e517b,
	0xe2fc54ea, 0xcd8bf208, 0x656df561, 0x549f8abb, 0xe32eeff2, 0xe20af67a,
	0x94e47d47, 0xccf2c1e4, 0xaf67a666, 0x7d421d32, 0xa669f3a6, 0x1f115657,
	0x3c2b3bea, 0xeab07e4a, 0xbabd6565, 0x6daf5949, 0x733bd651, 0xce9df8dc,
	0xc1c3d5cd, 0xd4f9558f, 0xad2fe867, 0xa3c57c14, 0x3c842be4, 0x93caf8c0,
	0xa29fd183, 0xdda987b6, 0xd7ac03fb, 0x5b996c5d, 0xfcc0fa05, 0x97d71648,
	0xffb8394d, 0x83b446cd, 0xb57fedc3, 0x0df4235d, 0xbef43832, 0x08c612a0,
	0x77820cf0, 0xf6caf584, 0x855db28f, 0xcc7f610f, 0x4e98f8e1, 0xf9df0df1,
	0x3b40e4b3, 0x860ae0e7, 0x35a6998f, 0xae5f0f48, 0x7610f864, 0x3ddbf5d0,
	0xd8a7f90e, 0xb4ff6a3d, 0x291d57d8, 0xa1b51ec2, 0x000b59dd, 0xfab9fca6,
	0x81cf23bd, 0x3bde2a5e, 0xdaac4f58, 0xb078fda0, 0x9c9fe948, 0x70f8e936,
	0x88abf7c8, 0x82b1ce28, 0x456ad9dd, 0x82755dff, 0xf8d883b0, 0x527e78b3,
	0xef7a6557, 0xb9d92b98, 0xda116d89, 0xa76aff20, 0x7e051fd6, 0x124bceca,
	0xd1ea177e, 0xba51f2a1, 0x808a1ffb, 0xefcf6ab8, 0x15f3ddb7, 0x22e7b1f0,
	0x55d67e31, 0x11f8bd19, 0xcf5d774a, 0xed38c20c, 0x08d1ab69, 0xe3cf3c78,
	0xcb1e028d, 0xf1c41ed6, 0x807e45ce, 0x0b95c371, 0xe23f47de, 0x0a6b835e,
	0xb08ab7ac, 0x5d69db78, 0x76636a5d, 0xfde1fd60, 0x73e46e87, 0x9c988ffa,
	0x30bd4bf5, 0xcf3e91bf, 0x4ca78e0c, 0x3cf1e78f, 0x730f072e, 0x774356ff,
	0xfcc7d629, 0x1c620709, 0x873e60f3, 0x27e0de61, 0xf90ea3fa, 0x47089af5,
	0xa8ebc402, 0x637d25d4, 0xe207ce7a, 0x21aedbd0, 0xcad2bd0e, 0x01e7c7ec,
	0xa2fff4c7, 0xf82ac768, 0x7f1e19de, 0x3de3c33b, 0xfc58a267, 0xe32b6ee7,
	0x7ef3cfe7, 0x4cf2f30f, 0x78b1b898, 0xd1bd64ef, 0xf5ce9eb8, 0xb8c4f5af,
	0xf5253fbe, 0x98750d27, 0xd6c152d7, 0x1a33b9d5, 0xbf451bf3, 0xcf45acc7,
	0x5a363cc3, 0xfb04ff9c, 0x09e34975, 0xb8bfb07d, 0xfa83d613, 0x67575b04,
	0xf7c52b04, 0x3d96b31e, 0x673afd0f, 0x75bf90fb, 0xba8a47d7, 0x1cefc713,
	0xe128f8c3, 0xbe6a87fe, 0x8bc5c30f, 0x522716ae, 0xf1e74fc7, 0xb4fc44f1,
	0xe6450d82, 0x7ce9f8f1, 0x97d0d923, 0x4d682fb6, 0x946af660, 0x3f11533b,
	0x575e4775, 0x61d05afc, 0x5e204a67, 0xc475f4f9, 0xf0e5df2b, 0xcaf181bb,
	0x3d85ad77, 0xb8ea95e3, 0x1fa03bf4, 0xe1e00ff4, 0x5b830b4e, 0x02555ca9,
	0x25aecd7e, 0xf379f304, 0x4727bf48, 0x5fb59e83, 0xe4363c47, 0x5f1fa89f,
	0xa7566f0d, 0xfe14d886, 0x16c45edf, 0xae3eff34, 0x351d4518, 0xba7ca0ee,
	0x8a4995be, 0xfd7529fe, 0xada7ef14, 0x4f68ac1d, 0xea2be777, 0x566f1b19,
	0xb1a03fbc, 0xf81f5158, 0xf78a6dd4, 0x29a67907, 0x07f05dea, 0xe3d935f2,
	0xc864fba6, 0xfd1473cb, 0x2c327f97, 0xccdbe011, 0x3b7130e5, 0x3387b2da,
	0x3fcc0a37, 0x629169a7, 0xbc95e23c, 0xca5f6d12, 0x6a3e74f1, 0x4b5bda3c,
	0x7d5f98da, 0xc54acb68, 0x2ae4abf8, 0x7e3a9fc4, 0xe8fc4f97, 0x48f1ad0f,
	0x19e92f76, 0xb2d15bcf, 0x4d5dfb05, 0xf5fe114f, 0x371e564b, 0x8c49224a,
	0x60f4d59e, 0x218386ea, 0xf321e81d, 0x0a05d1c9, 0x8de0507a, 0x54fd0dc2,
	0x5199af5d, 0x64ff2c1e, 0x90c7ce31, 0x0887a4a8, 0x221e929b, 0x60f494b3,
	0xdff12bb6, 0xff12847b, 0x3b47786a, 0x7c40f494, 0xc02bbff4, 0x92a2763b,
	0x7051fe5e, 0xc2578ace, 0x475ed877, 0xc6e10983, 0x7d8470f2, 0x3476e06f,
	0xb9fa5389, 0x22351e84, 0xf903fb9e, 0xbebfc238, 0x5da37241, 0x1abf1dde,
	0xa6f54de1, 0x475e7d83, 0x39c79f98, 0x9fb43e3a, 0xf3879f10, 0xceb80a13,
	0x2ae6fae0, 0xf47f40e2, 0xd33b8852, 0x0ad964f2, 0x372ceff4, 0xfd0f5afd,
	0x7a634fcf, 0x20f12559, 0xdc5abf7f, 0xd0370d59, 0x1f90494f, 0xa9470d55,
	0x819af255, 0x903970cf, 0x1c855a44, 0x777cb170, 0x4084bfa5, 0x4f882adc,
	0x8c57fd09, 0xf827e02f, 0x00df1897, 0x07d8167e, 0xb2467e2a, 0xfb517894,
	0x181b6057, 0x4dc70787, 0xce38246c, 0x04abf6a2, 0xce2c29fc, 0x37a5a721,
	0x61b78a10, 0xebfa0716, 0x5cdb490a, 0x29fc2e78, 0x44185fe8, 0x610bfdba,
	0xe255d3e5, 0x92ddd3a2, 0x3de937ef, 0xbe22a1e3, 0xcdf0c14a, 0x68f3b457,
	0x9ef886c9, 0x2b40def6, 0xff4f51d0, 0xfbe8fda2, 0xe3591c74, 0xfbf60d8f,
	0x4b55e775, 0x1dcf5c3e, 0x0910f1c4, 0x486a33d2, 0xe9b9f8d3, 0x72a5dfe0,
	0xe64a0a31, 0x6a2d2287, 0xfe8b5b7d, 0x095d0d5f, 0xa090cde6, 0xa07a6178,
	0xcf72eb1d, 0x99e6b5fa, 0x3c2c12e8, 0x1df2cf0e, 0xc27fe709, 0x976f0c4e,
	0xd8b7e729, 0xa25d24b4, 0xcf0717cf, 0x29e61ae3, 0xd63e0cf2, 0xfb52d853,
	0x6dfa0bf9, 0x6de2f3d4, 0x3af75658, 0x5e0385f6, 0x0d4b682b, 0xf56b6bd6,
	0xbb0190d4, 0x8b031dfc, 0xf529364f, 0xccf1dde5, 0x0e1e10ff, 0x65497f3c,
	0xdf4d5ccf, 0x0f4bf911, 0xf3145bc7, 0xfce518db, 0xca49f818, 0x4929df51,
	0x2a5fe813, 0x5dbe63b7, 0xe78c8b57, 0xb8c66a7e, 0xecd43f91, 0x750b7194,
	0x123c1ab4, 0xcb65639d, 0xda93d41e, 0xa20329eb, 0x7ab9c97a, 0x15ed65fa,
	0x6f5aafe0, 0xe440fb38, 0xe78f1cf9, 0xc92e6e76, 0xa213ce0d, 0x8284f07c,
	0xafdb760f, 0x2741f9dd, 0x52c9f142, 0x2fb7bb39, 0x441f283b, 0x169d4feb,
	0x3af51f84, 0xf8f8e75e, 0x073ceb54, 0x4b689de3, 0x2bc6027e, 0x25f75b95,
	0x48d67c01, 0x8d9f8876, 0xf83706a5, 0x6af20dfd, 0x7d905d7b, 0xd96ef037,
	0xe3ca7109, 0x598aee6b, 0x77181d9c, 0xf3c1a4a0, 0xf5bc8462, 0x10057df5,
	0x6fb0ab37, 0x0679b5a2, 0xdfa65f66, 0xa0cde913, 0x3d43ebfb, 0xe97d0231,
	0x9e61d5fa, 0x465a3fbc, 0x4c9c5c7f, 0x885d01c6, 0x75f38af9, 0xb3d179e2,
	0xc73824db, 0x6d8f9e25, 0x93bb0ff0, 0x7d387b96, 0x2d8df98a, 0x33ab0ff1,
	0x61dee005, 0x58837264, 0xd69fb8b4, 0xea7ed918, 0x35acf9e0, 0xd006fd56,
	0xefebbe9b, 0x26b63b40, 0xbec13882, 0xe8e2cef8, 0xb1eb8d1d, 0xc6b99ea1,
	0xe6b7eca2, 0x7804e2f1, 0x92be5c3f, 0xd3e9812d, 0x8a351755, 0xad2a9efc,
	0xaa74f317, 0x8f31ea2e, 0x2bff3c47, 0x333bb75d, 0xa6745f50, 0x03b078ff,
	0x06fb1317, 0xc6f17f78, 0xd20ee248, 0xae3e443b, 0x1c4ddf1a, 0x5ad135bf,
	0xaaeba5a2, 0xc2f8e7e1, 0x7ffef7bd, 0x83cf21c9, 0xed604b8c, 0x0f987d74,
	0x8c08ed4b, 0x6bdfa9bb, 0xf954978a, 0x573c3ecc, 0x516766b8, 0x5d82b902,
	0xa1d1735f, 0xa1ae67c8, 0x359d60fd, 0xf2a9c717, 0xd9e30399, 0x80a2ddb0,
	0xdfe0135b, 0x8e3fdc1a, 0xa2f93fe7, 0xaefcff60, 0xf6089e45, 0x6bf6efe6,
	0x310d6e26, 0x9d7c159f, 0xa45aad83, 0xe25e21eb, 0x9f0212d8, 0x57913de2,
	0xa981ce2f, 0xec5cd0e1, 0x70f40f9b, 0x9fe638d3, 0x91538f55, 0xf313dec0,
	0xf0618e6e, 0xc280f9ad, 0xfc40f317, 0x6de71099, 0xc32df18e, 0xe2516cfd,
	0x47ee19ed, 0x97cdbe68, 0x6e3ce78a, 0x386ff665, 0xb8b4cefc, 0x6bbd435e,
	0xb2720996, 0x9d6d70c8, 0x1fda0964, 0x9adf8ad7, 0xcf3a318b, 0x8f1ee115,
	0x5c627079, 0x7d9fafa1, 0xfbf8c64a, 0x1f7c83d9, 0x0a498712, 0x4b3efbca,
	0x6cfe5f98, 0xfa7a84a3, 0x6b211722, 0xb8587f29, 0x75ea156d, 0x86185ecb,
	0xfcf032a9, 0x1607ca01, 0x0b721226, 0x57ad172d, 0x3c9765c6, 0x46bfc3d2,
	0x52e7e582, 0x7efc8752, 0xfd95afd9, 0xff23c92a, 0x1d5f7206, 0x25df462f,
	0x997f6bb5, 0xe1e6f5c0, 0xebf03864, 0x56f85f3b, 0x4f0b651f, 0x3f2867d7,
	0xbe05afec, 0xbdb2c468, 0xf3e582de, 0x13278e09, 0x27b61e28, 0xb2869eb8,
	0x1e0c8ff3, 0x8c5d555d, 0xc121c39f, 0x256fc091, 0xb9864794, 0x30fa9e2c,
	0x17101365, 0x5c981833, 0x303f7b96, 0xd2ce2a6d, 0x93707483, 0x1a3f32cf,
	0x113d85e5, 0xd5ee3de8, 0x3f311309, 0x0748d5ea, 0x91536fc0, 0x03f045e7,
	0x0bd75a6c, 0x0346b1fd, 0xbc66e78b, 0x3c81a456, 0xd2cd41fa, 0xd443f06e,
	0xb2cbaeb6, 0x6c9aefd0, 0xa00f30bd, 0x74c2eb77, 0x77d88726, 0xdb9c1ae2,
	0x70719f01, 0x6bce8b8e, 0x9127ba53, 0xa7a659f1, 0x77d870d4, 0xc25fb64a,
	0x27f75d79, 0xebb79e32, 0xf2fcb2d2, 0x55e184c1, 0xb7c11de4, 0x76b1f583,
	0x4e48370a, 0x4dc1f513, 0xd7475792, 0x1dbcdd51, 0x0f5505e3, 0x82e7e37a,
	0x8b4578bc, 0x79ee9671, 0x18a7d87d, 0x4e4229e2, 0xcc2c95cc, 0xcdf5c3af,
	0x63fc44d9, 0x4e7298f1, 0x9eb9b30f, 0xc1923739, 0xa7b11177, 0x4639bf42,
	0x5ba1a512, 0x53496e67, 0x956fae21, 0xb5e41a2e, 0x97842f88, 0x31fda1f3,
	0xd99a2f35, 0x9fc93fb9, 0xd39c8309, 0xfda57211, 0x87f39a76, 0x5fe64c9a,
	0x0389fd25, 0x1f3558e2, 0x7102dc0c, 0x162f430c, 0xc87ca527, 0xf51f2238,
	0xbb9c2335, 0x847ef15d, 0x38baf317, 0x91c5885c, 0x6ae9e707, 0x63e725a7,
	0xca51c1fe, 0xb790cc1f, 0xfdc54be4, 0x448bf94a, 0xf8949a65, 0x70b4931f,
	0xea892b1e, 0x343eb44b, 0xeb1938d1, 0x34cb7cfd, 0xd89e5eb4, 0xee96b26f,
	0xbec19a83, 0x945f5053, 0xf9eac398, 0xad3265be, 0x14712cff, 0x91c183ab,
	0xb122e944, 0xf41bb278, 0x8fae6882, 0xde787dd8, 0x81bde6b1, 0xdf3f609a,
	0x8f8c893d, 0xef608b9d, 0x0b274b9d, 0xb3bc01a6, 0x273fbf42, 0xe3f5c351,
	0xd627ec46, 0xc493fa2b, 0xfc2cfdd0, 0xb9f82b3b, 0x6491b1c7, 0x4d3f3b23,
	0x979051dc, 0xe3103ad3, 0xc425df5b, 0x742df1b0, 0x38c0829c, 0xe2d473ea,
	0xa6252bbb, 0x98e87427, 0xa7b4523f, 0xd1fc3224, 0xefc7acef, 0xf3b077f4,
	0xf392d382, 0x6f147f00, 0x2d378e5a, 0x2f9c4de0, 0x73a37186, 0x030fdf91,
	0x4bdef23f, 0xc0f4fdf4, 0x3274d5bc, 0x17e99138, 0x3c581a2b, 0x819d1fcf,
	0x923634f4, 0x40a46de9, 0x719f8eb9, 0x1893ddf8, 0x05f4f3cd, 0xfc2412bc,
	0x6387034e, 0x5a732fb2, 0x7baff5ce, 0xdd683ff4, 0xc072f841, 0x5b7b083d,
	0xeb656d06, 0x17e7e189, 0xa831a97d, 0x18aa3da7, 0x553adcef, 0x437411ff,
	0x32637ac2, 0xe2c3ffb0, 0xdad93d1c, 0x973d2fdd, 0x57a08fe9, 0xc4e0f38a,
	0xf6090b7d, 0xfb9f766b, 0x35e7626e, 0x5c9ceb03, 0xe169d7c0, 0x75b0b4eb,
	0x4af4147a, 0x6753f90e, 0x71d27b98, 0xc7bbfc37, 0xe3e7cecb, 0xa879f629,
	0x875f60f1, 0x8ded4bc3, 0xa7988bc6, 0x70dd9e0a, 0xc04fcd56, 0xf637f613,
	0xa5d256cb, 0xbe22e798, 0xefec7b4f, 0xbdf89ff4, 0xfaafd622, 0x4b47965e,
	0xaeba4a6c, 0x40d74e6e, 0x3bf45afc, 0x6b6a3e00, 0x58f52fc0, 0x92d3b722,
	0xbc987249, 0xad1227b7, 0xf859fd21, 0x75a76d5c, 0xcb09eb46, 0xebda576f,
	0x1b7b569d, 0x5f72c79c, 0x4785e760, 0x100bfca9, 0x14cb78e7, 0x2f9017e8,
	0xbe49faca, 0x47fa7bbf, 0xb1be78fc, 0xb6fc50c0, 0xb6f54ecd, 0xefe472c4,
	0xef8bbd05, 0x77f5a74a, 0xeac39a9e, 0x4dbf8b7d, 0xe5bcfca7, 0x3eacb9a9,
	0x7edbf8a4, 0x60ac4f50, 0xb78eb1f5, 0x0d53df81, 0x3eb8f276, 0x67623d01,
	0x29e10da2, 0xd0086897, 0xf2feb751, 0x17f501a1, 0x6570d701, 0x17534181,
	0x51f47e2a, 0x3f303d37, 0xd3f808ff, 0xdc467906, 0x1569f70e, 0x14677876,
	0xb9d9ff3b, 0x9e31dfeb, 0xeba259f7, 0x7fb489f7, 0xfcfb646d, 0x307f5a74,
	0x238c6bf2, 0x87aa0e49, 0x66c21f80, 0xbe741521, 0x2726fb52, 0xa5644be8,
	0xb845a8dd, 0x5d0cbf72, 0xbf0a65e3, 0xe5783ff7, 0x33ecbefe, 0x48c7984e,
	0x3f6a07ce, 0x8807f1f8, 0x339ed63f, 0x1c3d41d9, 0x2ef9bad9, 0xb646b7d0,
	0x9323fa7e, 0x831cecc3, 0xf048f798, 0x23e7d1bb, 0xff380c5a, 0x9683ad91,
	0xfea3fbc2, 0x74019ad4, 0xb798e632, 0xe742d801, 0x2afb77ae, 0xbe9e31cf,
	0xd860be62, 0xc7809038, 0xd552a8df, 0x9671e11b, 0xe612e3c1, 0x0f587537,
	0x73a1f06e, 0x844e794e, 0xc718edea, 0xecbd22ec, 0xe71767e0, 0xbcfed56a,
	0x7d7465a3, 0x3f18f9f4, 0xde90419d, 0xb522f63c, 0xf0f483df, 0xa8ad1222,
	0x28fb1897, 0xa4b52fde, 0x2427da2b, 0xdfb4520e, 0xd453cb6a, 0x548d6527,
	0x5ec53fbc, 0x3edfa8a4, 0xfbc556e2, 0x45328e65, 0xa4dbcf3d, 0xfed87f78,
	0x21fb6516, 0xf21e0322, 0x40f7da8f, 0x81d27859, 0x67e1c16e, 0x3940f6ea,
	0x0e063bf2, 0xe6f33fb5, 0xe07b4d8b, 0xaa67f0b9, 0xff087dcf, 0xe4d92ce6,
	0x63f687d1, 0x79696a26, 0x3f21f241, 0xdcec3591, 0xcbb378c7, 0x7030a7d6,
	0xf82c63ee, 0x4a122933, 0xe7605c17, 0x3f982b92, 0x062028eb, 0x336cd3f8,
	0xea8ee1fa, 0x8aff5eea, 0x8053a1c5, 0x97f18def, 0xf63dd62b, 0xeeb14ba2,
	0x8542b222, 0x7a8ad5a7, 0xc55ee5a9, 0xd71213fb, 0xb56fda29, 0xa7855cfd,
	0x29f51547, 0x3c2acdf6, 0xe9e1516d, 0xa0bb4515, 0x5fee56ef, 0x42fc00fa,
	0x6bed1cb4, 0xdc3c012b, 0xf88fc672, 0x58d6d118, 0xf9ba7802, 0xabe21368,
	0x012cebc0, 0x7f7c3976, 0xbd281edd, 0x7e82fed4, 0x6227d51f, 0x86deb7b9,
	0xf57da5fe, 0xafee5859, 0x3ff3e3b7, 0xf2c08fd4, 0xcb03bd40, 0x889fad7f,
	0x13bd5b65, 0x26faa6cb, 0xfaadff7c, 0x8a9fe616, 0x9ed73eed, 0x0e807e02,
	0xce06af8d, 0xe7d1dc30, 0x1d97e475, 0x501d7cbd, 0x2afdd07f, 0xc872cbf2,
	0xfc78a275, 0x26d72f35, 0xa1f74e39, 0xc42974fb, 0xbc81ad4e, 0x238d2680,
	0xd5f0f40f, 0xd11e5b9b, 0xd0f210a6, 0x25a2673a, 0xb48dd59a, 0x3186c88e,
	0x388f2ddc, 0x1d790992, 0x58cdc944, 0xcef50c9f, 0x74bed608, 0xb764cb73,
	0xcf107fe9, 0xe788f7b5, 0x2213eeae, 0x19fafb9e, 0x32fc199b, 0x340d2f07,
	0x720e3c03, 0xe48394bf, 0xb2d216e9, 0x03a79b48, 0xa5547b39, 0x4bb28897,
	0x8c1f7453, 0xcfb1a4db, 0xdbe23cc4, 0x77e80474, 0x5decc49a, 0x24acdef1,
	0xa73adf26, 0x3a9ed018, 0xc52c71a4, 0xffc925fc, 0xf379c01c, 0xf70803e6,
	0x153fb34e, 0xe6e4f7e0, 0xeadd594f, 0x07b24e7f, 0x3e0c75d5, 0x07fcdf3f,
	0x206e53b4, 0x050f1e7c, 0x58fba79f, 0x3af31c98, 0x100f4052, 0x8e6543f5,
	0x87cfd86a, 0xce781c8a, 0xc0d3a0f2, 0x8cd3aff6, 0xd68813e7, 0xc8333851,
	0xa49f139f, 0xe0337ec3, 0xdbf81700, 0xcfb8c8e7, 0x482cf0d5, 0xd21efa62,
	0xb399d809, 0x382ed123, 0xa3e761a4, 0x4f4fefd5, 0x7cf67262, 0xcc7ed0af,
	0xc5ee1c19, 0xdf5fabd3, 0x5cebc741, 0x77438113, 0x3ea2073a, 0xe12759d6,
	0x33ced479, 0xbb581775, 0x8241cec1, 0xf0b9c571, 0xbd7f6d17, 0x0fefaef5,
	0x5ebff7d3, 0x19476913, 0xf28c1962, 0x797f0e71, 0xf511ac5e, 0x52d379a7,
	0xce2e418a, 0xf9aa71e5, 0x863c6d66, 0x7ad1b4ab, 0x89670ab8, 0x85036f29,
	0x57165920, 0x622b87a6, 0x6f57932a, 0xff657280, 0xb570f547, 0xf6f65541,
	0x56c6a00d, 0x885c2dd3, 0x59f7cffc, 0x82d79d3d, 0xd98db2b5, 0x3aae5c73,
	0x7e575d56, 0x43dfa085, 0x0285df3c, 0x99d5ed01, 0x4ec29249, 0xf9e1c99a,
	0x4e3c3ee7, 0xd872439a, 0x3f6e9d39, 0x2740d7fe, 0xcb3ef3ed, 0x57e7e30c,
	0xf1fd73b6, 0xaefb3d0b, 0xf101fefa, 0x3cf83bdd, 0x0389e90e, 0xcf71dbee,
	0xb7207261, 0x0b07dbfc, 0x5b73fae9, 0xa38c1a2d, 0x01dea82f, 0xe16ae878,
	0x1691d478, 0xddd34fd8, 0x5cc6bf0b, 0xc779d523, 0x7b4bc9ab, 0x5824a59b,
	0x9cf8165e, 0x72f2c125, 0x04b1bf84, 0x8f90a2e4, 0xade7be22, 0xb97ce4af,
	0xdee9f90e, 0xdf58b5fa, 0x72c6ef57, 0xce46fd7f, 0xfdb11b97, 0x9c53fd40,
	0x5f387b2f, 0xb79f197e, 0xf96397d6, 0xcb0bbd41, 0x5d4e518d, 0xa313ec12,
	0x3ef4f30b, 0x10206cde, 0x356aea9f, 0xdd00de60, 0x26fdcf11, 0x0c61f20e,
	0x9d4e7e78, 0xf3e6a317, 0xf3d0f4dd, 0xf868859e, 0x0b3e774e, 0xe1698be8,
	0xb120e9e9, 0x0d2f8199, 0x029e8a4a, 0x368392fe, 0xe9f4199b, 0x3ad34fc1,
	0x1d074be5, 0xd68eb336, 0xb0c52487, 0x3666cbba, 0xd3f67ad0, 0x99b6eebc,
	0x273d6823, 0xf7f59629, 0xe6f20c10, 0x014e2527, 0xa444563e, 0x4a3fb0bd,
	0x20e3e98c, 0x52d4b695, 0xc5f617b4, 0xe385c484, 0xb6fc5f60, 0xe3e90d8f,
	0xbdbadb56, 0xb5949f50, 0x80470b45, 0xf5bca61c, 0xae38afd0, 0xc6fd0b4c,
	0x0f5eaf25, 0x7ff7c6fd, 0x6fdc1b54, 0xf5f6f662, 0xdf6c9f50, 0xf4fd05a2,
	0x898f9cb7, 0xb45d4471, 0xf22d3e0b, 0x3ab686b4, 0xb6e41e51, 0x081e5138,
	0x28cf14b8, 0x8efc087b, 0x45922db5, 0x90cc7982, 0x90d783ba, 0xf70356e3,
	0x5d7e520e, 0x79a674f4, 0xb56fdd1d, 0xeb19bf50, 0x637758bf, 0xa494f7f9,
	0x08fbfc10, 0xef20efdf, 0x88faaf21, 0xb12fdd9e, 0xc562e00d, 0xbc666473,
	0xccb8911f, 0x8efd67a0, 0xa037f3cb, 0xcd7de3a4, 0x7af0dfeb, 0x2b31c697,
	0x27e7d689, 0x8b0fe585, 0x7fee9da0, 0x308539d5, 0x2c3f9ced, 0xbf30b249,
	0xa097bf0e, 0x5173b09a, 0x52fbcb57, 0xf3ab23e7, 0xa6925621, 0x9ef48e7d,
	0x4f221079, 0x5c679d52, 0x19cc7903, 0xbb8df33d, 0x8c5eaaed, 0xaf03969f,
	0x1f5d74a1, 0x570d0e1e, 0x28434381, 0x0f58f438, 0x3dd4f961, 0x5e7863f2,
	0xc45d7ab5, 0x36f76565, 0xf56b3cf2, 0xf45d04fa, 0x93235f5c, 0x7f065af3,
	0x0e3ddfaa, 0x605d2bf3, 0x0ab7e026, 0xaf873fe6, 0xfcd47fc0, 0xc9f146ec,
	0xd9aa0b59, 0x7c9ef8b9, 0xf8a177ec, 0x52cbc898, 0x854f4297, 0x9f905f73,
	0x0220fee7, 0xf135fced, 0xdeb01dae, 0x0fff62ce, 0xe343b01a, 0xa287087c,
	0x3c0b5768, 0xfe2cf497, 0xcf62f22f, 0x806fdc68, 0xd271f6de, 0x1d6fe462,
	0x3ee82c20, 0xe075a56f, 0xce2d1b67, 0x245e600f, 0x79f787cb, 0x2e117e08,
	0x971f73ff, 0xa24b3d7f, 0xdcec8bc8, 0xdd35e3f2, 0x1e0e13a3, 0x1f68f2a5,
	0x1ae8439c, 0xb3f28911, 0xb85e225d, 0x28bdb4c7, 0xf696f51e, 0xca16bd14,
	0xb7176d1b, 0xf8e264a7, 0xbdb8fb6a, 0xfb2308cf, 0x5089f8ee, 0x4f5de8b6,
	0xf07f042d, 0x49c60348, 0x8179e73e, 0x297aff53, 0x54e1e40e, 0x2b9f1bd9,
	0xdbabb4f5, 0xb628a93f, 0xafb4f6e5, 0xc1c6fae9, 0x6766aefa, 0x316d8d3b,
	0xbdb54600, 0x07f6b55d, 0xa3d6f902, 0x90225ed6, 0xb73ffe07, 0x5152dbbf,
	0x7e4aba2f, 0xa7bf08d1, 0xb18df401, 0xb6964897, 0x2c6afc00, 0xf88d25ae,
	0xf11be594, 0xcfa76d52, 0xbcfb50d7, 0xbcbb4f5f, 0xc70df642, 0xda84a673,
	0xf64119e7, 0x0dcbb739, 0x5153e584, 0xafbe3d7b, 0x06f8ed15, 0x2c7f3936,
	0xf7dc69e6, 0x91fbfce5, 0x7e60440f, 0xdf2debc5, 0x7fae6158, 0xfe3eb369,
	0x5fc82dbe, 0x0481f96b, 0xad57cbe7, 0xdbd452ed, 0x51bb5fb9, 0x54fbcec7,
	0x728c97fd, 0x8db1ca89, 0xf22aa780, 0x20cefe91, 0xfe9a4af9, 0x43de1bad,
	0x832bbf29, 0x3d7ca139, 0xdf41c534, 0x10f6e32b, 0x62a7b321, 0xc48fdb9d,
	0x41c53cdd, 0x8ab32dc7, 0x62a7b3f7, 0x9fbc453d, 0x23efdec3, 0x01ff79da,
	0xc39eeebc, 0xe3174fde, 0x66eacfdd, 0x37f23ed6, 0x7d854eb7, 0xd8f9f82e,
	0x73fbcabe, 0xe92f7f28, 0x7cc5785b, 0xe73b6518, 0x9cbee2ff, 0x8d6efbd2,
	0x69f60cfc, 0x6fb98493, 0xd0e80f55, 0xa63e7f5f, 0x3ef83729, 0xe337914c,
	0x1e63312c, 0x033bf553, 0xc89d02b7, 0xa0f143e6, 0xe3cc3ca7, 0x09b2a5ed,
	0x8f5d2ce3, 0x4e1e3e30, 0xf6b65bcf, 0x7abe053d, 0x677bf3b4, 0xbf491031,
	0x0917e177, 0xfa4eff98, 0x7fdc61b7, 0xdc495f61, 0x71e787df, 0x5c563e45,
	0x7d807106, 0x046ef71c, 0x64f10fbb, 0x65d7f21b, 0x75ff32ef, 0x283de6f5,
	0x36c916cf, 0x2cfd1ff4, 0xe81cb5dd, 0x96dcc3b0, 0xb5ef7189, 0x1c3ee01f,
	0x71e16690, 0x30767f2e, 0xc27b6b3c, 0xc0abaeff, 0x4dffaeff, 0xbd5337f8,
	0x3b5ce301, 0x4d9ed022, 0x76f4fad0, 0x651e6388, 0xd13e29f7, 0xc3bdd997,
	0xe78afedb, 0x70e25ff4, 0xe2c2ddec, 0x4a4f2234, 0xbea5f77c, 0x79af2666,
	0xda7aa43c, 0x0f10d181, 0x1b1bf811, 0xbfc09a49, 0xe760f14d, 0x1e03b078,
	0x7103bc04, 0x3d2fda11, 0xc29b5c78, 0x0f70141e, 0xf4d58fb7, 0x8eade621,
	0xed34ac13, 0x2af3c42d, 0x67d799d7, 0xbd70b14b, 0x7b7987c4, 0xd608d203,
	0xe8df1e05, 0x011ce3cb, 0xd7d5bfbc, 0x2bbc457a, 0x78c1ffdb, 0x5d4dc357,
	0x97b8f156, 0x5f5b79fa, 0x8e143fcd, 0xa9fcd7ff, 0x2b76eaf3, 0xfdac17da,
	0xadfc9ae4, 0xbffa0fc2, 0xfe1577e5, 0x2f6fa9d6, 0x465c40d7, 0x4c6f8f6d,
	0xa64e0e71, 0xbdfdb878, 0x811f67bf, 0x626657c9, 0x7c5dc9fe, 0xfceb9f2d,
	0x759c835f, 0xb9e036af, 0x47bb63b0, 0x767c0ede, 0x8a5901fe, 0x9edf02b8,
	0x1c435177, 0x6f367441, 0x20751fed, 0x4d51e6af, 0x6a7c5423, 0x8bf33268,
	0xe5093e61, 0xa246e50b, 0x2ddfa38b, 0x19f7672f, 0x26204397, 0x8baf4b06,
	0x12d54fb6, 0x5a5fdc2f, 0x0d7ad266, 0x9e521f18, 0xfbf03547, 0xa9a1a94d,
	0x3b2a9738, 0x9a77cc64, 0x95c58239, 0xf09a98e6, 0xfdece1bc, 0x9fb85e0f,
	0xeef593b6, 0x2b479642, 0x59fd0dce, 0xa2f13d73, 0x9d84c9a1, 0x1c78934b,
	0xe30eb572, 0x127eea90, 0x5954ef5f, 0x3b06f962, 0xd89abe59, 0xfb7d749f,
	0xaf2cf90d, 0x2cfbee1d, 0x0779d3ab, 0xb23e82e6, 0xda91f51b, 0x0172eb11,
	0xa4e3b59f, 0x80dc8613, 0xf6bb585e, 0xe6afec3b, 0x5af2eacf, 0xd75f50fd,
	0x11fa47ef, 0x7ab1e3fa, 0x7ed5d62f, 0xffb18aa9, 0x919c718c, 0x713d31df,
	0x91c725d4, 0xdd3f6c9b, 0x967612de, 0x76d4bbb0, 0xe21fe09c, 0xc9b9b41e,
	0x8d872616, 0x17f7647f, 0x30b9596a, 0x05872959, 0x777ca59f, 0x33f23269,
	0xe20e3f25, 0xbffed8cb, 0x740397c5, 0xff07675f, 0xbb32794d, 0xf74d5bdf,
	0x9e4c8955, 0x2e5de9aa, 0x51bf5191, 0xf3a0bbd3, 0xd05b1c3b, 0xb101577f,
	0x8a8f3a7b, 0x3fcf095a, 0xe1e77d1d, 0x0a748dbb, 0xd2bf4ded, 0xbb79ee29,
	0x29efba4e, 0x5da24e17, 0x02e593f1, 0xcec5eb69, 0x6c7c3323, 0x5721ee4e,
	0xb2be4d9f, 0xffb6555c, 0x6217f183, 0x9a7ff3fd, 0x0f3c245c, 0xf0f226df,
	0xf61acbe7, 0xe589973d, 0x5a1e4281, 0xdb9d87a7, 0xc46f4caa, 0x81a997fb,
	0x647c0516, 0x6c992ec5, 0x6d0ef162, 0x817ba09f, 0x8bf789da, 0xf2f9f451,
	0x8d5eecd1, 0x98f9f71e, 0x8fbcf19a, 0x911f5efa, 0xc7c359f7, 0x53efdf51,
	0xc53df3c3, 0xfbeaa13d, 0x364b3e7d, 0x9fdda1c7, 0x3c59f24f, 0xa97ccafc,
	0x9065e403, 0x52e3b89f, 0x873bda3d, 0x5fffb99f, 0xf803a3dc, 0x3d27aafd,
	0xf42ae5fc, 0x9fff97f0, 0xb79b20f4, 0xd71dbde1, 0xd3db0f4b, 0x1f01df1c,
	0x7ba2fb12, 0xc06fbeff, 0xd3ee2bfd, 0x3afd5ced, 0xf9d1abde, 0xd078c123,
	0x6331fcd5, 0x9cf1d9db, 0x0d3d2731, 0x51d78a66, 0x27e8dcc7, 0x85c87918,
	0x3a6ed8e7, 0x638c80e0, 0x29d7b792, 0xbe85bcc3, 0x0087f420, 0x4de7e01f,
	0xb5c77e78, 0x8deb8bf2, 0xe2a3fc73, 0x4bdce21b, 0x785bce87, 0xcef5e404,
	0x47f79088, 0x5cd1490f, 0x8dcb1ef1, 0x2921ae51, 0xadf9ced0, 0x54b2cfb8,
	0x76ccf766, 0xa7e8c9b5, 0x3fb3f358, 0x5b1bf1bd, 0x7ad5f1cf, 0x2ba5ad59,
	0xca239da4, 0x9bcb0d5a, 0x61b12fcf, 0x3fd8167e, 0x7e10b7e0, 0xa7ef1e8c,
	0x41498f15, 0x9b747bbb, 0x14f3e603, 0x7c384f9b, 0x93f5aed5, 0xc3d7fbe0,
	0x5776bf7d, 0xd05165a1, 0x14a7f8fe, 0x6a95e789, 0x018ca72d, 0x5d2b5f7c,
	0x03b35ffc, 0x2dc4caa6, 0x239bb951, 0x491e9879, 0x41593e98, 0x4f9cb0da,
	0x08ba58fc, 0x445ea3cb, 0x212e58ec, 0x8bef9eec, 0x533baea9, 0x8fc15f30,
	0x785eadf7, 0xf1b33fe7, 0x465ba59e, 0xd46e4235, 0xab5ff28d, 0x3ccea9f5,
	0xc059e1ff, 0x67fc763f, 0xfee50daa, 0xbcf3ddb5, 0x21b1ca25, 0xfb7f8425,
	0x76648b5f, 0x3ae5e26e, 0x166517dc, 0x638c87d6, 0xe387fffe, 0x022e91d3,
	0x8b61337c, 0xc7109be0, 0x61a139ca, 0x1215f871, 0x8b4beefe, 0x2c5b834f,
	0x07ba6967, 0xa5a5377e, 0x54e7b599, 0x5a247b47, 0xc11919cf, 0x7b4757da,
	0x1e7def20, 0x5cbee1f1, 0x72ef5900, 0xc5e59ee0, 0x25efc1c4, 0x6893f7f0,
	0x46ada5ff, 0x7c4dbf96, 0xb9bd61fd, 0xb0848f60, 0xfdf04f77, 0xe31fb43e,
	0x958b43f7, 0x539785fe, 0xa6b79f18, 0xb4a9cb15, 0x5e3aa734, 0x8d0cb801,
	0xabf4db69, 0x68abf002, 0x3ac39c08, 0x8c5ef23d, 0x637e88a7, 0x00df8ad2,
	0xb129bf7c, 0x2ef7633c, 0x3487b883, 0x7f2fd83e, 0x19a4b531, 0xf41f7bc6,
	0x70f0c281, 0x0a41df85, 0xd8183f3e, 0x7f366e57, 0xbfd109d0, 0xa01ef048,
	0x3f562537, 0xa65fecf0, 0x0fa137ae, 0xe77a0dd3, 0xc7d73498, 0x213d7f38,
	0xb3ff9826, 0xa90cfcfc, 0xf7f8854b, 0x1a0ce7f2, 0xa4be2bd0, 0x15ce18e2,
	0x59ed457c, 0xbb538f28, 0x50bfca14, 0x13ca14bb, 0xf2852ed4, 0x42976a1b,
	0x1da2f4b9, 0xcb259b2e, 0x61c71d53, 0x5067117c, 0x6e8bf7cf, 0x9e10ba78,
	0xa5d8f3dd, 0x19bc79c7, 0xafd8f6dd, 0xdcde3ce8, 0xe7035fd1, 0xa3c1c25a,
	0xa7bfd773, 0x5077e95e, 0xdd43bc44, 0x7eff19fe, 0xe516b36e, 0x2f8b6e7e,
	0xdcb0596a, 0x7b63d14f, 0x51938ece, 0xa5877e30, 0x890eae1b, 0x86aa752e,
	0x7ca7cfd5, 0xa6b5708f, 0x2b54e439, 0x584eefee, 0x9fcb6e77, 0x1c73831e,
	0xcb8c7c74, 0x27fe4a76, 0xaf531f40, 0xb16ebd43, 0x4dfeba2e, 0x1dcdffd0,
	0x942560fd, 0x5fb610df, 0x6efbb176, 0x1d77ae7b, 0x8376f7ce, 0x27ce00bf,
	0x0e597edc, 0x4d6a1799, 0xff78422b, 0x8899d056, 0x12ba71bb, 0xfba9faf8,
	0x111e3d5a, 0x0f0010f7, 0xba3c81b5, 0x60fa0514, 0xb65f8f19, 0x1cfff734,
	0x97ecbbcf, 0xddeefc09, 0xbee518d0, 0xf6ca9e1b, 0x767328a5, 0xaf809de9,
	0xea9d7737, 0x526cf70f, 0x4a5ff4fc, 0x1d4ccfdf, 0xe61bf0a0, 0x69f1fc8c,
	0x3efa1fa0, 0x6cddcefe, 0xe214a5b2, 0xbb8d73f4, 0xcd25863f, 0x85289cb3,
	0x4482fd38, 0x0b941f69, 0x21e3e96d, 0x9bf22f3e, 0xed156717, 0xd934ad83,
	0x5c7a865e, 0x20973011, 0x8c6250b9, 0x0aed97e4, 0xa8ab1439, 0xabec484f,
	0x5b56ff78, 0x527da286, 0x7b4510d6, 0xfb13b9f7, 0x7ef3c0b0, 0x3f7f0f00,
	0x75d19b88, 0x7bcddfb0, 0x9b8fdd81, 0x6dd0e3b3, 0xea7d6843, 0x5ef1338b,
	0xfb7937b5, 0x3c4ab7d4, 0x0a4e8f80, 0xa4553d4f, 0xf9f88cce, 0xc182bf13,
	0xd541f654, 0xc1f7e7ae, 0xed61cb7d, 0x05d8ab83, 0x14ffeee1, 0x2eda81f6,
	0x31f27ca0, 0xdf4393e0, 0xfc816199, 0xfe4737ef, 0x68720498, 0x5ed2aa7a,
	0xdd2f4708, 0x7db242fb, 0x4a3e7c1e, 0x3c842f4d, 0x958fe9c8, 0x73b20f53,
	0xc7cbd740, 0x0c7c06fe, 0x09376eed, 0x9ebcbdfe, 0x5fc632fe, 0xf1dad5be,
	0x3d50ebbc, 0xe7e46bcf, 0x4bc196b4, 0xc9de8072, 0xf50f2d92, 0x6ee7c389,
	0xb86b83d0, 0xa997ecdf, 0xb55d6fdc, 0x053ea1fb, 0xe6b27681, 0xf27de284,
	0x5141b480, 0xacae9f5f, 0x21b4523f, 0x3d387fb8, 0x0b53d96c, 0x381caef5,
	0xfc8527cf, 0xf9eec09d, 0xb0be71c4, 0xd9f2396b, 0xe857bb53, 0xef9ee66d,
	0xc0f1d0d7, 0x8c2cb7df, 0x69fc157c, 0xe5eeccb6, 0x2b3fb755, 0xb1bf67be,
	0xc292fbdf, 0xdeb9f31e, 0xcbf77265, 0x42bd2ede, 0x5eeff3ae, 0xcfe8fcd8,
	0xd278807e, 0x5d4f664e, 0xcd786688, 0xd1ad3e6d, 0xc5ecdc80, 0xf16b9af0,
	0x4cbce069, 0x1ba46567, 0x576bb7f2, 0x6eef3198, 0x17ff3f68, 0xd7aa3cc6,
	0xa5ffcea7, 0xcff9e291, 0x482e0870, 0xce82770e, 0xe7f9f105, 0xf20edde6,
	0x3cb36482, 0xceb51b87, 0xe4c254d6, 0x17e3317f, 0xb8fe81f3, 0x559422bc,
	0xba443ed5, 0x21f017e5, 0x7fd40b80, 0xf9f85d48, 0xffaf41af, 0xf00bf184,
	0x3d45cc1b, 0xfa5261c0, 0xbf709a13, 0xc16dbfd3, 0xf96121f9, 0x3d46dec7,
	0x9a3795d8, 0xca997c8f, 0xe78693cf, 0x51270717, 0x64eed63c, 0xad5ddd79,
	0x20937a03, 0x5f86a1fe, 0xdc1a53ed, 0xd1dea2e7, 0xfd844f2a, 0x2c9f3ea0,
	0x992c4ce0, 0x3e757b8a, 0x61a7f9d7, 0x2d2ee9de, 0xa9dedde6, 0x5f4425b3,
	0x351b7be9, 0xbdf416c4, 0x280cbba1, 0x3a3ac4cf, 0x43ad6c2d, 0x531f7d77,
	0x75cacd94, 0xd52ae421, 0xa0717407, 0x6849940f, 0x95de1ebf, 0x38780c50,
	0x2daf112c, 0xfcc0871f, 0x386ce9d1, 0x7bc26e78, 0xb4b31223, 0x09e6f7c1,
	0xaee675fb, 0x6f400399, 0xd179a2fd, 0x62218a61, 0x7a40cb4e, 0xf3f7059a,
	0x33bbf0c9, 0x8bf014ce, 0xd7f1e54c, 0x76fed1c3, 0x8f0fafd0, 0x6fc09489,
	0x0f5fc749, 0x1d758be3, 0xea5339d6, 0x8e8bfd82, 0x3ee93fc1, 0x2a5ed12e,
	0x0934503f, 0x0415c7e2, 0x5dbf27ef, 0xf934fa66, 0xc16bed90, 0xb6a56b5f,
	0xc5ef9818, 0x34b669d4, 0xb584af0a, 0xad7682ff, 0x5ae8bf3a, 0xfb6ee9f5,
	0xdd8965f9, 0xf467617b, 0xfcfa335a, 0xf7e8b3e3, 0x0f9da86b, 0xcb755dfa,
	0x4507bc6e, 0xdb77d76d, 0xe17f6a55, 0xd22fdef5, 0xde732ec3, 0xff05669c,
	0x6787b7c2, 0x59f69e91, 0xe2656e40, 0xbd009ff9, 0xf8137d52, 0xf7ec0be1,
	0x35d4eef6, 0x802aac76, 0x2d7dd973, 0x313d786e, 0xc35f7153, 0xec9e63e7,
	0x57b697b8, 0x016914bd, 0x3a4d6ab3, 0x59bc8371, 0xfa2065b3, 0x6dea86a3,
	0x32efc2af, 0xe1d15ff8, 0x8167143d, 0xecfd68c6, 0x77f0835b, 0x6c6b96a0,
	0xc77b84bf, 0xd2328bc8, 0x0d67e9e9, 0x38aca7a8, 0x0a7a8192, 0xc51b3fec,
	0x8faa69cf, 0x15bf685a, 0x71c5f76f, 0xeccc97e5, 0xf01337bd, 0xefc0bbfc,
	0xf0236799, 0x6e65765c, 0x3e97a653, 0x9aef527b, 0x97387007, 0x0fb179e2,
	0x4bc95385, 0xd057ff7f, 0x69bc560f, 0xf0057c45, 0xe8af5a1c, 0xfc60cd6a,
	0x27ebc381, 0xe8ce43e7, 0x62ef8f71, 0xc26abfa0, 0x7913cdee, 0xff10f96f,
	0x22fd7801, 0xfbe5f9f4, 0x56dc78d3, 0x89627bf8, 0xb3f61131, 0xfefbb08b,
	0xef10317e, 0x5a55fd63, 0x377df74c, 0xa09e5cec, 0xef3563d7, 0xc0c7bfa3,
	0x4222abf2, 0x4e1fc9c7, 0x97f7c68b, 0xf853bf19, 0x5ed66a7d, 0xd9b3d654,
	0x37e6f3ef, 0xefc186d8, 0xf1c5df1f, 0xb9c13870, 0xb2bee009, 0x0e77d1e9,
	0xb99f3c20, 0xddf0cfe7, 0x33f426fd, 0x3edc0391, 0xcb5fd953, 0xcf1e7e8c,
	0xdfd8a2d8, 0xc91f36a7, 0xa9c83f05, 0xf7f0431d, 0x6dc9169d, 0xa37ee0a7,
	0xd7db730e, 0x5bf51f70, 0x3fa20ffb, 0x1edf3d5c, 0xe3120179, 0x8eb0554f,
	0xe1c79061, 0xe13cc0f4, 0xefc02bfc, 0x10729baf, 0xdd2fc27e, 0x7db43679,
	0xc629e628, 0xe313f317, 0x48def78b, 0x05c97663, 0xe82e5b7d, 0x6c526305,
	0x42e43b0a, 0xfc2e5b54, 0xee18e694, 0x4310bdcf, 0x76f441eb, 0x70cff1ad,
	0xf170a071, 0x2fdc399f, 0xeeb35475, 0x8dc6636e, 0xf9b0f788, 0x713e3c8a,
	0x34f3f35e, 0x214f97ee, 0x79ce6129, 0x1fe009fe, 0x3e279ce2, 0xb3ce770f,
	0xf7e75cfb, 0xd56077fc, 0xb9f93ee7, 0xf3aa31ce, 0x9a25059e, 0xef396bba,
	0xf6c6c2b9, 0xe86c4159, 0x6f3293f3, 0x324d206f, 0x9e4cbfdb, 0x859f7e06,
	0xf42b3fdd, 0xe7ce1a98, 0x51c1b9c5, 0x4e3f2cad, 0xdd0a8efc, 0xf26e78f5,
	0xe365e266, 0x02c9eea9, 0xf2815219, 0xf8368879, 0x9e7a5b77, 0xfbc36b73,
	0x7e216ee5, 0x82c41d2c, 0xb053a3f7, 0x388e3963, 0xf70f1cb1, 0x3dc067ab,
	0xde588dfd, 0x9cb09a46, 0xfcb0da4c, 0x589b6b6f, 0x008000cc, 0x00000000,
	0x00088b1f, 0x00000000, 0x98edff00, 0xd7146c6b, 0xcccf8015, 0x6d78cbec,
	0x03f1b1af, 0xa9b5983f, 0x3c4b09b3, 0x6d8eabf1, 0x88c6c194, 0x042ed422,
	0x3d4294b5, 0x1081026d, 0x556c1bc7, 0xb8c56d28, 0xa8897956, 0x44949fee,
	0x0d44b4a9, 0x2c542a8a, 0x316ad40a, 0x701a8a75, 0xa147511b, 0x9a16a50a,
	0xe545c438, 0x111b8eb1, 0xe7a25521, 0x776599dc, 0x5f8fa06c, 0xf08c71fd,
	0xebee6737, 0x77b9eebc, 0x0e8d8f0c, 0xe7f01840, 0x6ca9a17b, 0x939e97c4,
	0xbe1b22ef, 0x20a1f106, 0x79fa5dc0, 0x551acd2a, 0x30005806, 0x280a4300,
	0x07d60e34, 0xe95a009a, 0xa65fa549, 0xe8bf2804, 0x82062fc8, 0x00e3caa3,
	0xa980dcc9, 0xd3bf61e4, 0xa123bc7f, 0x7d19eadc, 0x00e92887, 0xb403e6bb,
	0x6f98a8c0, 0x50251825, 0xbd87638d, 0x9888ac37, 0x6156ee1f, 0x136b9c3f,
	0x88f283f6, 0xb16fe687, 0x260fc09b, 0x482cb8d0, 0x81971094, 0x5541e625,
	0x72cf343d, 0x77243d50, 0x4ee42e80, 0x82ae0b88, 0x30d5c141, 0xc606b824,
	0x47f1c105, 0x8c7865b3, 0xd2fc7de8, 0xa287c721, 0xeb52fd73, 0xe457e5f8,
	0x291ee403, 0x975f340e, 0x011a2f8a, 0x64283002, 0x4b633d40, 0xf7a9edd3,
	0x24a82407, 0xdbb21b3d, 0x7086a1ff, 0xe63cb539, 0xfae51279, 0x946adef6,
	0x98d1aa37, 0xd6e514a7, 0x06af7af6, 0x34bfdfd0, 0x03db02b6, 0xfd1db47e,
	0xd02b54a2, 0x72b2348c, 0xf45a871f, 0x1692f28b, 0x300c920f, 0xa078764e,
	0x0d865008, 0x413e3235, 0xcf8ec85f, 0xa1d19f15, 0x81dd7ea2, 0xfd155cd1,
	0x59dfd7dc, 0xaf7fd80c, 0xa3f79ecf, 0xdf92ea05, 0xb8fc3fa0, 0x6d2ea04e,
	0x599bb60f, 0xda925b28, 0x5e9c2bbb, 0x6f583ff7, 0xebd6c3ed, 0xaabe362b,
	0x5020ffa2, 0xb2e71403, 0xf8ee3d80, 0x934d56f1, 0x5890fd69, 0xe9a9cadf,
	0x674d85dd, 0xd45d638b, 0xe763993f, 0xffe39757, 0xfaa80f14, 0xdcc17566,
	0xcffec9f7, 0x73e28d4f, 0x185c13f2, 0xc6aaf5c7, 0x8f57a4b3, 0x63d6556c,
	0x8d907e1c, 0xf9d3469a, 0x9bbae129, 0x1d01ded0, 0xf7913e12, 0x25a9a16d,
	0xddc98c08, 0x277e74ea, 0xe87ce0b7, 0xac588687, 0x4dcd8bc3, 0x8967e21b,
	0x0760c6cd, 0x2f3ad0b6, 0xca3d3e91, 0xf78a56f4, 0x7c0ffcad, 0x57fd889f,
	0xe519e76e, 0x391fbe3b, 0x32ddf633, 0xc6418c5b, 0x7339eafe, 0x0b5ff6e7,
	0x8d413391, 0x7e9eb7ba, 0xd37217ad, 0x48200afb, 0x3fb7bf9e, 0x65acfb52,
	0x88aa3fd8, 0xa16e8f7e, 0x983ecbfe, 0xfff406a8, 0x40d61353, 0x8e4bf60e,
	0xe766587c, 0x54d08afb, 0x5cfeec84, 0x6e64bbba, 0x0148a79e, 0xf5a48a9e,
	0x6887da05, 0x4182a757, 0x79d8006f, 0xd1f84952, 0xdc129dae, 0xff944d93,
	0xc93cc016, 0xb07afea3, 0xe6daed14, 0xf63dd5d8, 0x62c81f7b, 0xddec931a,
	0xedbfe8ee, 0x00d6678d, 0xe13dbfea, 0xce02b49d, 0xc77ff87a, 0xe90f6244,
	0xf76de3bd, 0xc8179c7b, 0xfc671efe, 0x68f9600b, 0xb90f757f, 0xc1c0f5fb,
	0xf52ea94f, 0xffdfbb0c, 0x1429cd4c, 0x0a80ad71, 0xf9102edb, 0x87d39cfb,
	0x3d920bec, 0x1f84be23, 0xd3f9db6d, 0x72442d5e, 0x75135045, 0xe45fafb4,
	0xbc3faa6d, 0x24722051, 0xefb73fb5, 0x320b7343, 0xbf11c6ea, 0x3da8f14e,
	0x9d93ac52, 0x8ae83eb5, 0x44243889, 0x4fa2d79e, 0x63bbcc24, 0x3255d3f9,
	0x246c73ae, 0x858561a2, 0xe1d6ef5f, 0xfd69c5e3, 0xabfb3a76, 0xe1da3953,
	0x7998fcc3, 0xca7e4216, 0xa4fc883f, 0x9e35c70d, 0xdb0242f7, 0xc78ec067,
	0x413935cc, 0xd58cb4f3, 0x281e5097, 0x51ba9cf3, 0xe19a8322, 0x1e752c8f,
	0x9cb491a8, 0x89dfaff2, 0xbe64765b, 0x5b473dab, 0xd79f1ae8, 0x6f1ee55c,
	0x26d1e3ea, 0xf8f6d3aa, 0x5731fd7c, 0x1ff0b07f, 0xee39b7b6, 0xf2bb9bdb,
	0xb2efe53c, 0xe435b6e0, 0x755582a7, 0xe57efeae, 0xb7fa42b4, 0xc571e67d,
	0xeb108bf1, 0x9b3b41c8, 0xfb46822f, 0xbb86e5bc, 0x8132cb3d, 0xc45d65c6,
	0xf9fa19f7, 0x953cb755, 0x287287ca, 0xb487cccf, 0xfcf783bf, 0x04d0f949,
	0x9efe5d8b, 0xfe7bafed, 0x7ec4fa0f, 0x15eb1968, 0xb9882dfa, 0xc1bc5efd,
	0xc352f7ed, 0x6db2e7ed, 0xc4573f6e, 0xb45e7edd, 0xb0d7edcb, 0xf55bf6e9,
	0xff5716be, 0xbbb60c2f, 0xad0e47e4, 0x347ff576, 0x2f25ceb1, 0xaba37b79,
	0x6fa1d2ff, 0x876bdabb, 0xa7b5779f, 0xfc766bf2, 0x39dd189f, 0x9064bf2b,
	0xfaff121f, 0xd6bb2ff3, 0x80771d99, 0x6dfe42b8, 0x0f5e00b5, 0xe37b8dcf,
	0x55c841c5, 0x0a9dc6e7, 0x6e672c4f, 0x18c26bfc, 0x4eb42a7f, 0x4c5097fc,
	0xc85dceb1, 0xb69076bd, 0xedb397e9, 0xb4a9d67a, 0xd714eb8d, 0xb146af36,
	0xd05a93fe, 0xc0f54391, 0xce62c739, 0x0ffa0639, 0xcb64396d, 0x9676b8da,
	0xa5dd58ea, 0xd5e90758, 0xa2cfc560, 0x6d74d099, 0xf44f23b0, 0xf9843507,
	0xfafe3923, 0x1e04b34a, 0xb9427ed7, 0xa7cfed28, 0x0f257ecd, 0x33feb73b,
	0x2cca2031, 0xd6f58a14, 0xb352ed39, 0xd5ac4e7d, 0xe193c0b3, 0xa9cd6597,
	0xf22a23f3, 0xa7ffe535, 0x642a3de9, 0xd0f803b6, 0x240e533e, 0xbbf7c206,
	0x148768bf, 0xc432bf71, 0x649ceb7d, 0x03eb8978, 0xd75495e3, 0x62322f5f,
	0x2ddbf461, 0xfdc55359, 0xc806b24c, 0x461924a8, 0x34799587, 0x4a56e3a6,
	0x42f3e3e6, 0xf3fca3f4, 0xea151998, 0xdfd42c87, 0x14d9f470, 0xc61ebe36,
	0x852938ba, 0xd8e3d4f6, 0x2bd72d0b, 0x9c3adce9, 0xf9a46fab, 0xf96dbdcd,
	0xa316bf62, 0x2d5f585d, 0x05c93559, 0xf692cbe6, 0x9d7fda16, 0x63327926,
	0x8af3eedf, 0x44280a73, 0xc766f768, 0x2058504f, 0x9c9b99ee, 0x8a712775,
	0x37bf586d, 0xfe139f0f, 0x037251d8, 0xdf22053c, 0xffce10b4, 0xeeb0794c,
	0xd7a2d900, 0xd296eb6b, 0x351ce77b, 0xe6ff94cb, 0xa254ed1c, 0xee7dd679,
	0x28ee2997, 0xfa9e06b9, 0xed47f18c, 0xf3c1e5f3, 0xd35f229b, 0x4ff3db76,
	0xe716cfee, 0x8afee4ce, 0xfe7a6276, 0xcdfe625b, 0xf95df7f1, 0x2febb5d1,
	0x96fbbcae, 0xddab91f9, 0x96f69c2a, 0xa9d6fda1, 0x40df95d2, 0xe93cddff,
	0x2282326f, 0xb8a23f5e, 0x5eb7e6a4, 0xad056479, 0xfcedeff7, 0xc4eff0bb,
	0x2cf071ee, 0x6579db4e, 0x5b2125f7, 0xd9c12dbb, 0x469e6276, 0xa29bdee8,
	0xf11077ef, 0xa5a67c60, 0xe19bda79, 0xaa84ebb9, 0x4ece7164, 0xa76a2f2c,
	0xc2a277f3, 0x6359b1e7, 0x01cda5cb, 0x8ab95e5b, 0xf706f498, 0x26b1b849,
	0xcc25d024, 0xb785c987, 0x8a70f88f, 0x28e322be, 0x9f6c99d9, 0x39d32dbe,
	0x52556851, 0x6f9e593d, 0x957ca31c, 0x3a57f2f0, 0x4359e85f, 0xb26bfff7,
	0x1ac00bf9, 0xa7f0f970, 0x2b7f9ee2, 0x5ffbced7, 0xf229be1e, 0x76285f7e,
	0x6e81c692, 0x4a7fa8f9, 0x1b2fdc5f, 0xe92cbbe8, 0x64bf6245, 0xb091cd96,
	0x333fec24, 0x76c2178b, 0x6c4ebabd, 0xac1fbf24, 0x707ee891, 0xf7940fc8,
	0xd3a2b293, 0xe33cc2bd, 0x7d45bc4f, 0x1909fd2c, 0x2dae6fdb, 0x8b9f28d7,
	0xb7ba6750, 0xdc4cede0, 0xeb7eebff, 0xb13aa51f, 0x8899f035, 0xe4d8f74f,
	0x1fdfda15, 0xda26d57b, 0x1b0fdfd7, 0xeeef4957, 0xf67c77dc, 0x54e80ef7,
	0xf94f2637, 0xa6103cdf, 0xe8565afb, 0x74de466a, 0xe4bbe50f, 0xd0d2e19e,
	0xdb3c8cd5, 0x77180f41, 0x7b892f58, 0x7ece0bed, 0x2e364f7c, 0x9602758b,
	0x69846f7d, 0xd907a7e1, 0xf8cb7379, 0xade451ab, 0xa49bed1c, 0xd6eca4e7,
	0x8e3d9ef7, 0x1e79e9de, 0x035ba79e, 0x38fdaed3, 0x1adedaf5, 0x9bf47bca,
	0x53aa7141, 0xf775aea4, 0x92afef19, 0x2e7ffcc4, 0xfad0cd8e, 0x7c7fc7cf,
	0x33353dea, 0xb9df83ce, 0x2c6b754c, 0x83d6ea28, 0xb3b6cfc6, 0xf098ccfb,
	0x84ec7dc7, 0x6f3b0caa, 0x6af87c8e, 0xeddffd54, 0xfb8c564b, 0xe1e4de68,
	0x8e2a953b, 0xee7d3eef, 0xb745e512, 0x270fbdf3, 0xfeefdfdc, 0x38bdf879,
	0x533ea33f, 0x9a245acd, 0x91fbcca5, 0xdcbe353f, 0x178f1ee3, 0xc357da62,
	0x1ee8ffb4, 0xd522e781, 0x78b9d4e7, 0x90aef9c2, 0x7d4577ac, 0x5f28f5a6,
	0x38a648f7, 0x1f7f529f, 0xfcf09018, 0x7a34bca1, 0x1656dd45, 0xcbca3505,
	0xe3839813, 0xd1eabdf4, 0x9c08e9b3, 0xec5addfd, 0xb8552237, 0x6fdefa8f,
	0xdaefa62f, 0xed587fe3, 0xe7d92f7c, 0x9793a346, 0xe93eb48d, 0xe713cd1f,
	0x5fa38347, 0xee2e2053, 0xa9824fa9, 0xf9c2fbd8, 0x77fec2bb, 0x3359df5d,
	0x4c779db2, 0x64c99326, 0x264c9932, 0x3264c993, 0x93264c99, 0x993264c9,
	0xc993264c, 0x4c993264, 0x64c99326, 0x264c9932, 0x3264c993, 0x93264c99,
	0x993264c9, 0xc993264c, 0x4c993264, 0x64c99326, 0x264c9932, 0x3264c993,
	0x93264c99, 0x993264c9, 0xc993264c, 0x4c993264, 0x64c99326, 0x264c9932,
	0xfffcc993, 0xc300bfe2, 0x00deea6a, 0x0000deea, 0x00088b1f, 0x00000000,
	0xc5edff00, 0x30001131, 0x3fb10008, 0x27bfd53c, 0xc9a42014, 0xd5ea9d92,
	0xdb6db6da, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xfdb6db6d,
	0x555707f1, 0x800043f8, 0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00,
	0x30001131, 0x3fb10008, 0x27bfd53c, 0xc9a42014, 0xd5ea9d92, 0xdb6db6da,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xfdb6db6d, 0x555707f1,
	0x800043f8, 0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30001131,
	0x3fb10008, 0x27bfd53c, 0xc9a42014, 0xd5ea9d92, 0xdb6db6da, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xfdb6db6d, 0x555707f1, 0x800043f8,
	0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30001131, 0x3fb10008,
	0x27bfd53c, 0xc9a42014, 0xd5ea9d92, 0xdb6db6da, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0xfdb6db6d, 0x555707f1, 0x800043f8, 0x00008000,
	0x00088b1f, 0x00000000, 0xc5edff00, 0x30001131, 0x3fb10008, 0x27bfd53c,
	0xc9a42014, 0xd5ea9d92, 0xdb6db6da, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0xfdb6db6d, 0x555707f1, 0x800043f8, 0x00008000, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0x00000003, 0x00bebc20, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0x00000003, 0x00bebc20, 0x00002000,
	0x000040c0, 0x00006180, 0x00008240, 0x0000a300, 0x0000c3c0, 0x0000e480,
	0x00010540, 0x00012600, 0x000146c0, 0x00016780, 0x00018840, 0x0001a900,
	0x0001c9c0, 0x0001ea80, 0x00020b40, 0x00022c00, 0x00024cc0, 0x00026d80,
	0x00028e40, 0x0002af00, 0x0002cfc0, 0x0002f080, 0x00031140, 0x00033200,
	0x000352c0, 0x00037380, 0x00039440, 0x0003b500, 0x0003d5c0, 0x0003f680,
	0x00041740, 0x00043800, 0x000458c0, 0x00047980, 0x00049a40, 0x00008000,
	0x00010380, 0x00018700, 0x00020a80, 0x00028e00, 0x00031180, 0x00039500,
	0x00041880, 0x00049c00, 0x00051f80, 0x0005a300, 0x00062680, 0x0006aa00,
	0x00072d80, 0x0007b100, 0x00083480, 0x0008b800, 0x00093b80, 0x0009bf00,
	0x000a4280, 0x000ac600, 0x000b4980, 0x000bcd00, 0x000c5080, 0x000cd400,
	0x000d5780, 0x000ddb00, 0x00100000, 0x00000000, 0x00000000, 0xffffffff,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x00088b1f, 0x00000000, 0x51fbff00, 0x03f0c0cf,
	0x33a8578a, 0x32eaf830, 0x31ebc830, 0x21ebf430, 0x1b8969c4, 0xcfd328b9,
	0xc0c0c2c8, 0x40acc40c, 0xafc40ecc, 0x5e181918, 0xffaf1233, 0x9d823093,
	0xf0c0c02b, 0x0077c819, 0x1905cfd2, 0xd9006e18, 0x19b8805f, 0xc40f9fc8,
	0x06d881ab, 0xa4083fc8, 0x09f100ef, 0x8c2afe20, 0x046ffcdf, 0xa109b7e4,
	0xf1a11ff2, 0xd7e2082f, 0x7cc0492f, 0xd8f20279, 0xf21174f0, 0x050ee3e3,
	0x1f02077a, 0x0be54350, 0x14c302a8, 0x0ea59628, 0x92441fe1, 0x098a01af,
	0xefd842aa, 0x581818e4, 0x6a43fc80, 0x0f7dcdd8, 0xca056794, 0xbc0fa877,
	0x0061f11f, 0xd3ef8030, 0x00000400, 0x00088b1f, 0x00000000, 0x7dedff00,
	0xd5547c09, 0x73b9f8b9, 0x3264ee67, 0x0909264b, 0x04936c21, 0x21c43511,
	0xeb1a0840, 0x44a1e364, 0x8a0a8a8d, 0x21091138, 0x71fcb8bb, 0x961b9be9,
	0xc6dfca88, 0x87d47d4a, 0x5368683a, 0x80843a8a, 0x183a06b1, 0x43416a40,
	0xd5ab40ab, 0x484d9161, 0xd2db5c42, 0x77df3be7, 0xf7b99dce, 0xfb512266,
	0xefafaf7f, 0x9dfcfe3f, 0x6ff67b9c, 0xcef9df3f, 0x11b468c1, 0x5f212572,
	0x4fa68fc3, 0xa490848a, 0x4053da48, 0xc88449d3, 0x75fe317d, 0x6dc12102,
	0x86463d7f, 0xeda67210, 0x8d399726, 0x4c5f4f10, 0x7e5a4af0, 0x37ef9fc6,
	0xcdc2f2d3, 0x348c39ef, 0x3459b35f, 0x9b61b942, 0xaf77db05, 0xaf90fc11,
	0x713d7733, 0x6ef7cd39, 0xb40bc916, 0x3362d26b, 0x8e421c90, 0x33f610c5,
	0x99240dda, 0xcb0b7290, 0x3eddacd6, 0x68abc617, 0x6d0b1337, 0xf44dac7f,
	0x3ad17e40, 0x78e84fc1, 0x223daf35, 0x16fed2a5, 0xc58085f8, 0x9eebf345,
	0x42765c94, 0xdf7b6c96, 0x3b4ba211, 0x2e218be5, 0x1151d709, 0xd2a424c8,
	0x2a5a71bf, 0x41b95f6d, 0xff681b70, 0x76ce6b95, 0xdb2afcc3, 0xb488174c,
	0x2b16aabf, 0x63638d71, 0xbc604d7f, 0xde3823ce, 0x1818d366, 0x3ddce2af,
	0x9d611112, 0xabb40f26, 0x7580f3a1, 0xf29ee32b, 0xd8d71135, 0x7e6b3c08,
	0xf5a3c741, 0xdc165f6a, 0x035ac4b0, 0xba3cc2f1, 0x7accb35f, 0x6beb06d1,
	0xd5dac690, 0x02db28eb, 0xaff4a8eb, 0x60d9a695, 0xf2a56b7e, 0x557f48cc,
	0x57114f2d, 0xab7e6a8c, 0x557a8633, 0x94f4fae5, 0x53e6688f, 0xb0165149,
	0xd2fd9c01, 0xdf23e3f5, 0x88f10a0f, 0x5116aaef, 0x3cc53fd3, 0xa3df977e,
	0xc838527f, 0x75feed5b, 0x2dbc1169, 0x5dbfd272, 0x39f5bc11, 0xe6f63c15,
	0xd257fba8, 0x741f0027, 0x273e4d3e, 0xa5f63fa6, 0xe7caba60, 0xed3d3c42,
	0x6ae9871b, 0x3fbf1b9f, 0x74c5cbe3, 0xe983cf8d, 0x98e9be73, 0x58a57dfa,
	0x2cdf05ef, 0x5e7d9b4c, 0x5f33fefc, 0xbe2da605, 0xdebefc7a, 0x0dd318b7,
	0xbfbf193e, 0x69815bec, 0xd5a9e380, 0x36d31ab7, 0x6deb1f9f, 0xda60b5f1,
	0xf7e00bee, 0x8e7e1c95, 0xa46f923c, 0x887877eb, 0x249ba293, 0x4df27894,
	0xca509f34, 0xe473c9f2, 0x93e6897c, 0xe14f34bd, 0xcc1d5a91, 0x6a7cd337,
	0xf51f2b3d, 0xa1882930, 0x2b3251f9, 0x29e95f4f, 0x7a7cd0b0, 0xbb1f2b13,
	0xa5882e46, 0x567eb1f9, 0x6086f17e, 0x2fe69581, 0xacf2b00e, 0xa368520e,
	0xcb20acf9, 0x14f1ef67, 0xbb3e69da, 0x3e73e58b, 0x341d0b90, 0xed62139f,
	0x980f70f5, 0x71423cc8, 0xdd3c8cf3, 0xf3461c63, 0xb887b912, 0xebe45c29,
	0x14a9c63d, 0x9617260e, 0xc56f936f, 0x85c956f2, 0x3cf25de5, 0x79336f2c,
	0x5cb0fcb0, 0x926de58d, 0x933fcb07, 0x16fcc3ef, 0xa5cb1793, 0xfac57f86,
	0x962f245b, 0x823c34a7, 0x8c9376f9, 0x343717e5, 0x4976fd61, 0x2f1ff2c6,
	0x88a7a9fb, 0xef04fb96, 0xa5b3a02a, 0x6482b782, 0x5204fd00, 0x34fd294a,
	0xd016640a, 0x6440c3eb, 0x987e6993, 0xd8177c84, 0xf022f399, 0x4086fe2b,
	0x8f67fcbe, 0xcf3f61a5, 0xda263f62, 0x7efe788f, 0x3572bbdc, 0x5577b8fd,
	0x0cfcfd28, 0x0cb52dea, 0xaec09fae, 0xd9f3b4cb, 0xf3f4a955, 0x1f63f60a,
	0x6fdcbadc, 0xf3e769e6, 0x4fd2b566, 0x3f13f63b, 0xeeb4f9b8, 0x75a7c2d5,
	0xdb3e186f, 0x83493e11, 0xdbf64f9b, 0xbf64f85a, 0x5bcf861d, 0x83619f38,
	0x6df5a7eb, 0xdf5a7c2d, 0xf7e7c30e, 0x83919f38, 0x3bf6575b, 0xbf64f85a,
	0x07cf8613, 0xe0da4fd8, 0x4f7b69fa, 0xf7b69f0b, 0x18f9f0c2, 0x7060b9fb,
	0x5fb49aeb, 0xfb499f0b, 0x46e9f0c3, 0xb8345cf8, 0x6bf6da7e, 0x3fb6d3e1,
	0x712f9f0c, 0xb707e33e, 0xb40749ae, 0x207499f0, 0x40221f0c, 0x3706133f,
	0xd27f2d9f, 0x9fcb67c2, 0x60b1f0c2, 0x3707933f, 0xb50f9c9f, 0x30f9c9f0,
	0xec049f0c, 0xfae0ea67, 0x16a1f2d9, 0x0c3e5b3e, 0xf63867c3, 0xd6e0c573,
	0x1691f395, 0x851f393e, 0xfb0633e1, 0x21f3e7c9, 0xc0fb1fb4, 0xac7fb4fd,
	0xc7fb4f85, 0xc78cf861, 0x7cf98a7e, 0xee4fd3ce, 0x727c2d31, 0x93e1858f,
	0x355cfd83, 0x8fda7eb8, 0x7ed3e169, 0x2b9f0c2c, 0x066b9fb1, 0xe3dcaeb7,
	0x1ee4f85a, 0xb099f067, 0xf413b4a7, 0x6e81d50d, 0x7a993691, 0x6811e3d4,
	0xf2c9d17d, 0xc04dd3a2, 0xfb15110e, 0x44797482, 0x21b6df5a, 0xa231fb3e,
	0xae0a33b6, 0xa9d8f983, 0x33b6a5f5, 0x356372e2, 0x27bc5776, 0x9c4f9341,
	0x9fa9aa9e, 0x29ae9a54, 0x62eb3a1f, 0x6f30f94d, 0xbc3f26b6, 0xfd4d32e2,
	0x9a05f591, 0x57c5e8fc, 0xc9a7ea6b, 0x19f26837, 0xd4d56e2b, 0x4ee9a0bf,
	0xab85f94d, 0x17e5352b, 0xf26917f9, 0xa83cb497, 0xb03e3fa9, 0x697e5344,
	0xf29a63fb, 0x6b1fc109, 0x3f7713f2, 0xb93fa9a3, 0xf94d05eb, 0x35eb8394,
	0xad4353e5, 0x84c53c9a, 0x3c25d8f3, 0x139d022f, 0x930fd766, 0xda0b9ed0,
	0xa94bcc25, 0x83d3b436, 0x51d772f6, 0xe0c9478a, 0x29a10d75, 0xbd5090e0,
	0x715a9f9d, 0xf9e28861, 0x17bccbfe, 0xfbf7e93a, 0xcea5ef25, 0xc527f628,
	0x205240bf, 0xd5201975, 0x62623f97, 0xfc3057f4, 0xb443d8dc, 0x77a19d7d,
	0xf7cd3c6c, 0x0957f218, 0x119f1e94, 0xb197480c, 0x7a87a922, 0x768266b1,
	0x396923ff, 0xfa2aca2f, 0xf292315c, 0x77e9109d, 0x029bc985, 0x0d73c576,
	0x6760c8ef, 0xeba48e34, 0x79e4254a, 0x3ca09de1, 0x591fb686, 0xfda5e29e,
	0x876a2599, 0xe897c7ab, 0x7e3899f8, 0x7ebf8c33, 0xe9cdf180, 0x63f19ab9,
	0xc6685546, 0xf8e8918f, 0x36676a4e, 0x53e3e01c, 0xc8465d24, 0x1c01c22b,
	0x02aa3cdf, 0xa2447fc7, 0xf8f511fb, 0xdbf1e1b1, 0x057e3f80, 0x594527e3,
	0xda65fa7f, 0xd4aa8ff5, 0xeb625fae, 0x11f0d6df, 0xd7163f1f, 0x23e16bff,
	0x9551feb6, 0xd666fd6c, 0x477c786f, 0x603bfe18, 0xb40d6ffd, 0xed3c8cfe,
	0x6b5747fa, 0xe3666fd7, 0x9c70ddbf, 0xf1c36f8f, 0xb38e11df, 0xc6ae8ff5,
	0xd7b325f1, 0x0d23f40d, 0xd3f7ad8f, 0x2a08c9f1, 0xb9028688, 0x1d2071d0,
	0x98894097, 0x74854790, 0xb1fdc79c, 0x88bede8c, 0xf286f4a5, 0x10f84645,
	0x7464953f, 0x79cb521f, 0xbe436aa1, 0xcb087204, 0x3e647ee9, 0xed5dea9f,
	0x5937d222, 0x405ff665, 0x2edddbe7, 0x6bbf90ca, 0x907e15d5, 0x72667577,
	0x33b42947, 0xff7c2092, 0x5fe327f8, 0x9f4baf50, 0x1d326fce, 0x8bf8690b,
	0x202e47cd, 0xfce9eae3, 0x2608818a, 0xe8c7f247, 0x7dd0877e, 0x9fba61c4,
	0x89b8f480, 0x1fbf478e, 0x2221fba5, 0x01a6f9a9, 0xf3d911db, 0xff3a18de,
	0xf3f2899b, 0x476f3ae0, 0x19fda296, 0xd18ffc19, 0x63e0357d, 0x0295937e,
	0xba1f323f, 0x6f6f5c1e, 0x417fe099, 0xeda570e0, 0x09ede16f, 0x3ff68fcc,
	0xfcdac9d7, 0x187ba289, 0xd582f905, 0x667e9a89, 0x14f2ff13, 0x95b6feda,
	0xd6844ddb, 0x8d942fd9, 0xf2f4045c, 0x71048990, 0x224a191f, 0x68189c99,
	0xeb275eff, 0xa65996ff, 0x3f5521a3, 0x9e314d73, 0xb99f3a52, 0xdf38880f,
	0x796d5ed9, 0x63d59b68, 0xeae9a2c8, 0xa2844d4f, 0x6d0ab6fc, 0xdaf5edf9,
	0xb58b1dfc, 0x091eba79, 0xac995af4, 0x43974eff, 0x786779d7, 0x34e174dd,
	0xcd978f3f, 0x3592615b, 0x686d8478, 0x074f2f0e, 0x138413b0, 0x5fe8cfb6,
	0x2681d29f, 0xaeb560bf, 0xff174e3f, 0xbbffff1f, 0x9ed75ff1, 0x3554789f,
	0x55c09aaf, 0xf5554789, 0xd7ae5aaa, 0x67fa17e4, 0x582fea6b, 0x9f29a65d,
	0x5350b4df, 0xddc56f3e, 0xfc997c9a, 0x1dfea680, 0xe5341b8b, 0xaa3fd7b7,
	0xe2adbf29, 0xb67e4d49, 0xfa9aa7f7, 0xab5accb7, 0x2db61729, 0xbd421d1c,
	0x0c3d1de9, 0x307f81fc, 0x8533a013, 0x3f7a159e, 0xf4c14be1, 0x6985cf94,
	0x2a61c803, 0xb1af0ddf, 0xb285eeb4, 0x15cf20d1, 0xaa6e3ffa, 0x52f2051f,
	0xf97acf4f, 0xfa53a7ab, 0xcecd1e1b, 0x816ad250, 0xeb1e8294, 0xf2af76e1,
	0x73d70cfd, 0xb4c12c84, 0x597c625a, 0x80ac3add, 0x1c1f2038, 0xb81b6f5b,
	0x7010125f, 0x99bc041d, 0xe1b78049, 0xf1a97754, 0xe799a19a, 0x8e22ede9,
	0x393c0b5f, 0x694dd415, 0x0fc601ab, 0x71ba8e76, 0xb3c7cc3c, 0x49edf309,
	0xf69d6f68, 0x6a3c4f4d, 0x6295f804, 0x0b37c27a, 0x2f3e63d3, 0x157d47a6,
	0xd5f61e98, 0x2df21a63, 0x9f43f4c6, 0xbe07e98c, 0xd1fe9815, 0x41e984d7,
	0xf74c6adf, 0x7698fcfb, 0x2a983cfb, 0x82cffa74, 0xff86f1d7, 0x519ebc76,
	0xc1bc75e3, 0xf1c3e6c9, 0x37cc38fa, 0x0a9cdd8a, 0x9564c8c6, 0xa2b1e23d,
	0xf711755f, 0x8c4b5387, 0xd8f959f9, 0x5d77694b, 0xc7f8b768, 0x1bee1c81,
	0xe0b197f7, 0x483bee47, 0xc0da4015, 0x6fe3d3eb, 0x0f103840, 0x7ee5efda,
	0xf6261caa, 0x32c4b72f, 0x640c5ab8, 0xf6a6c93a, 0x733f05da, 0x798999df,
	0xf6804923, 0xf6f5f77e, 0x5b52fd28, 0x3e7be010, 0x7fb52eb8, 0x1dfd0591,
	0x39afe67b, 0xa4378e90, 0x53b8bb33, 0x0494bb44, 0x7c03745f, 0xecd672c3,
	0x6d3f014e, 0x139205ef, 0xee2adef5, 0x27e056a7, 0xbf02bcb3, 0x6bf0c347,
	0x8df8414a, 0x0a9fe2f9, 0x9bd3c47e, 0x08f8c375, 0xdf08cefc, 0x9ce53f0c,
	0x75de3f44, 0xd15bf1a2, 0x02b24f65, 0x8451aed7, 0xd006f38e, 0xafbfed3f,
	0x8038c2ed, 0xd93ed873, 0x060ff66c, 0x4f00674f, 0x357f48b6, 0x76fafeba,
	0xbb00e8bf, 0xc18a517f, 0x9c0a3479, 0x9026b495, 0xeda9b4e6, 0xbe6d76a4,
	0x1e9849af, 0x15c67b40, 0xc83c7337, 0xe8f3a75f, 0x29939018, 0x2cfd2a98,
	0x479c914a, 0x8c3f1113, 0x23c437af, 0xc5f29fdf, 0xf7bfbd60, 0x27ea063c,
	0x72368f32, 0x5007b684, 0x70319d7e, 0xd4e901fd, 0x7e0499f8, 0xfa61d233,
	0x1897ec02, 0x70d7fffa, 0x988c4640, 0x0badfa57, 0x52f9b288, 0x3341bef8,
	0x52e76d1e, 0x4ebef0ce, 0x307e26ff, 0xbd0a6392, 0x04d15552, 0x40c9a93e,
	0xd6a716b7, 0xe4d78a3e, 0x3987daeb, 0xfc12f635, 0x9928e541, 0xee811825,
	0xf4d939aa, 0x042b6d18, 0x702abf3a, 0x0abd014a, 0x4c4d5eac, 0x80baf248,
	0x7cde965e, 0x366a0bb9, 0xf3f57ae1, 0xdebbf8a3, 0xfe781c68, 0xfddf6255,
	0x63f851a5, 0xd5db9733, 0x2057e606, 0xce03b231, 0xec8a48bf, 0x538ec1b8,
	0x83e185b3, 0x8e3a387e, 0xb3f4af2a, 0xd5ea6fd0, 0xd232afda, 0xf30369f9,
	0xddc7e817, 0x9d26e305, 0x1bb57e1f, 0x75834df6, 0xdb58e1eb, 0x22f2567e,
	0x72ffd15f, 0xe0547022, 0xee96255b, 0x95ff6912, 0x5f70872d, 0x8f24c27d,
	0xe41be87d, 0xdbf9ff62, 0x23598e52, 0xd9b45ceb, 0x45855b8e, 0x907e0a4f,
	0x5d7974af, 0xb99dee30, 0xb473e07c, 0xd41e6a96, 0x9c8620a2, 0x9caebd88,
	0x56d9de67, 0xfc7a0255, 0x79e32263, 0x29b149ec, 0xcaf3ec07, 0x03c95ac0,
	0xa6188e72, 0x90cebc03, 0xaa2639df, 0x2889f5f0, 0x1da89e21, 0x4f3d587f,
	0xf26bc76a, 0xe4d78ed4, 0xc90dc9cb, 0xbe5dae70, 0x02fc44ca, 0xfe5353ae,
	0x3c44e8be, 0x8df5202c, 0x691cf760, 0xe5f3789b, 0x9f578780, 0xdef801cd,
	0x27878b49, 0x21f71c00, 0xf8edbf1c, 0x767da10b, 0x742371ff, 0xe5e73bab,
	0x1169a870, 0x7428fe3c, 0x57a715f3, 0x462cbe85, 0x915fc6a7, 0xfc6a7464,
	0xf2ba6919, 0x77fcbaf1, 0x4421dfe6, 0xa255bfc3, 0xc498c937, 0x6bf615f8,
	0xe917b182, 0x9ff73bf3, 0x34ffafd2, 0x63bfe4e3, 0x7c7423ff, 0xffc77a23,
	0xd31ffb5d, 0xa353fe6f, 0xeaf35ff5, 0x2a645b4b, 0xf95f2a6f, 0x16508389,
	0x4a6c693b, 0x57fc5376, 0x00ee5baf, 0x9461383a, 0x2797401d, 0x7f74e2fd,
	0x6755f914, 0x63c1e854, 0x069fc013, 0x4ffed27f, 0x5afc7fad, 0xac5fd3d0,
	0x4fd13933, 0x9a0e62d6, 0xb6d5df29, 0x59212c2d, 0xf2c43f98, 0x21159c8f,
	0xcfa5aedf, 0x24ff9fca, 0x4ff285d9, 0x7f406e1e, 0xf9ed1070, 0xa78fe6da,
	0x23af1e81, 0xfa2fc8bd, 0x57fe3076, 0xca6fa809, 0xe5feb8a4, 0x864f31b8,
	0xd757ecf6, 0xd159f8f6, 0xd0857f01, 0x5fafa00f, 0xaf72edc1, 0xe5043ed1,
	0x053214d1, 0x0f0291e4, 0xb97667e2, 0x59b3eaf8, 0xdd3d0fe0, 0xa0875bfc,
	0x8fb29382, 0x7bcc0be8, 0x81ae57fe, 0xe5375fe5, 0xa83db543, 0x76ae07d8,
	0x60e89fbe, 0xe829b569, 0xc1ca9cb8, 0xb726b5ea, 0xbf573f4c, 0x9ecfe2f4,
	0x1fe4ff01, 0x680beecc, 0xed2f55ff, 0xcd197fdc, 0x0d346d57, 0xb0cb6129,
	0xbc11c909, 0x17ffd1d4, 0x50f04767, 0xe4a769b9, 0x3fbecf1a, 0x47c1109c,
	0x12edc6d5, 0x1e1fdf19, 0x52ed8185, 0x2f0516c8, 0xc0d34381, 0xfd5f129e,
	0x3f78049b, 0x43204db9, 0x73c0a2d3, 0xb7b44eed, 0x47884e00, 0xde30a78e,
	0x28ebf574, 0x2b3e405e, 0x1797d278, 0xfd027970, 0x9e9132b9, 0xc415fe5f,
	0xecd1fcfd, 0xbc57f586, 0xd6038f7c, 0xcf58dc71, 0xe5d9fae8, 0x6e3a1ec9,
	0x764e4985, 0x57beca62, 0xd21f773c, 0xf77d82db, 0x94bf3325, 0x75019867,
	0xd60c3c8b, 0x4dcd7f37, 0xe272beb8, 0x78abba45, 0xf9052c56, 0x4c91b9f8,
	0x2f8518df, 0xfd32363e, 0x6a05fc7a, 0x1df5d2b0, 0xe303eaa7, 0x62277e60,
	0x7721143c, 0x3eebdfa3, 0xd9aa16be, 0x0c79ff30, 0x918753c3, 0x5809f1f9,
	0x6d7a6ae5, 0xf00ba47e, 0x67a46a73, 0xd49f9c28, 0xe1cca311, 0xfb4d7c21,
	0x0f15f715, 0x2e21f865, 0x476f0e63, 0xf842aaed, 0x4cbbf50e, 0xa6964b1e,
	0x2d3af91d, 0x7cbdfe32, 0x58ef3a7c, 0x278e87b0, 0xe3ebb747, 0xbf32824d,
	0x2fa2a22e, 0x7e337f15, 0xf1947e6f, 0xfeefc2b7, 0xf943a7eb, 0xfe32ef67,
	0x9fa07681, 0x4382bce8, 0x4cfb7cb1, 0x9981e501, 0x75f1a304, 0xb5f389b3,
	0x13a15cb6, 0x10a36f3a, 0xc217a2a7, 0x7e71e7f4, 0x8abe526e, 0xcbc953b6,
	0xd1cf183a, 0x6f853fbf, 0x0ffe7017, 0x125fff01, 0x86b27fe1, 0xf6c0fdf1,
	0xa9f08caa, 0xf67ff936, 0xe52bf00c, 0xfc05d94f, 0x75852a6a, 0x73a1b27f,
	0x4f94adff, 0x7c28093e, 0x7a9f95aa, 0xbd68ad3e, 0xea7d008f, 0x1193f4f9,
	0x9f2a24f5, 0xf951efd2, 0xbfe84474, 0xf02a7e54, 0xe569318b, 0x070f22a7,
	0x1e5ea382, 0xa2ba33ae, 0x7bfa43ca, 0xa7f4e497, 0x14ee853f, 0x65fcab7a,
	0x3b9068cd, 0xe854ba61, 0x0a974c2e, 0xabd7e9dd, 0xfcbe9f85, 0xa303e077,
	0xed7d284b, 0x29c369bd, 0x043bab3e, 0xed85d9b7, 0xc29e4176, 0xf8ccc3c9,
	0x87c35da6, 0x5d7ef3a8, 0xefaba03e, 0x754be5d1, 0x7cbabdf5, 0x9fbeaebd,
	0x3bda2bed, 0x10748225, 0x2d37d4d4, 0xcb9c3221, 0x71156ef7, 0xe743dd1f,
	0xf7db48dc, 0xcbf3486c, 0xb72c1e54, 0x6f7afdb0, 0xf208d492, 0xebd9c7ab,
	0x85bc8048, 0x4a7acbf9, 0x2af11d7b, 0x8750f0fb, 0xe437f288, 0xeda3d327,
	0x8a590837, 0x81910a70, 0x45f9d9ca, 0xb51b68b1, 0x4d28fc18, 0xfab61ba2,
	0xe2dc3577, 0x9e83f380, 0x66eb8c8e, 0x7ff3efd1, 0x42386223, 0x0b23ac4f,
	0x8f6445e6, 0xceca9871, 0xa7e4413f, 0xe67ae8f3, 0xff3b3075, 0x7b3a95ae,
	0x04af76dc, 0xe3da90f2, 0x76feb587, 0xbc95d746, 0xda358a9f, 0x12b24af2,
	0xffd949e9, 0xcb6b3655, 0x38bf7cbd, 0xc4e5c4df, 0xed813204, 0x77f308d7,
	0x2c5ab970, 0x8b375e66, 0xb767bdc2, 0xfa4e8048, 0x7b84443a, 0x5f6506df,
	0x52fc8493, 0x9e517a4b, 0x0d39f029, 0x2c0d20fc, 0xfe6f4e6f, 0xb443ce53,
	0xf796f54a, 0xa69dfeb3, 0x61fcb7a7, 0x7f90ebec, 0xf7a8c0f5, 0x85faff49,
	0x2e782cdb, 0x8ecdb3db, 0x5b3da871, 0x087a8ef7, 0xdd99aff2, 0x6d9ecf30,
	0xdd01665f, 0x57312cf4, 0x19eabc80, 0x4b8efcc9, 0x15997eb7, 0x0cb8fd42,
	0x6264d5f1, 0x8ebea2fb, 0x0c287ebf, 0x0aae9481, 0x2b36fef4, 0x7eea69fa,
	0xdb78c165, 0xe25fad9e, 0xb5efe67e, 0x0e7e5a9e, 0xb32763df, 0xf17e615a,
	0xeeb99cec, 0x362fa9f5, 0xda6bf1d0, 0x68f34bb6, 0xffafe179, 0xb0720596,
	0x33d995a7, 0x73d0a6dd, 0xeffcce70, 0x9897d7a6, 0x81babe28, 0x58a95219,
	0xc815ce92, 0xf97068b6, 0x068dfa1b, 0xffd68f0b, 0x3010f031, 0xc3baa76e,
	0x60118fee, 0xf0fe7fdd, 0x6dffe07d, 0x654ba466, 0x1a049fbd, 0xdf38ded0,
	0xd3fdf7ba, 0x0e085bad, 0xffbddd66, 0xdfbeebe0, 0xe9f9c2e4, 0x9d3fa0f9,
	0xf31fbd6f, 0x38ddd92f, 0xbbd241df, 0x3f989253, 0xfd741ff5, 0xadef1adf,
	0xf38eef14, 0x7fd2fbaf, 0x8c0f75f0, 0xe5ccdff7, 0xbde27778, 0x0dff5f8a,
	0xe56df7e7, 0x43ff75dc, 0xe5d8afd7, 0x57694366, 0x2cdf9d3e, 0x830764d2,
	0xdf527662, 0x336d081e, 0x086cfc8f, 0xcfc4d7cc, 0x93f3f507, 0x30efe625,
	0xbd07d909, 0x93725c74, 0x85cebddd, 0x41f71e7a, 0xe1fb72d7, 0x68e511da,
	0x61eb5e87, 0x3b013a76, 0x7cc5c291, 0xe21f9973, 0x4549cc83, 0x3700af18,
	0x83446e21, 0x7c1fbb4d, 0x811e205b, 0x8ed7e1da, 0xec1bbe9a, 0x1846ebd2,
	0x1e966683, 0xe526f482, 0xdf76ae7b, 0xcdabdb32, 0x9b4b32df, 0xdac1cf7f,
	0xe86e4cdd, 0xbff3a7ca, 0xe9d18879, 0xf5f97687, 0xecdf9826, 0xa4d205db,
	0x54ded3f2, 0x073f6daa, 0xff2ab1f6, 0xef18c2df, 0x8847380c, 0xfee02719,
	0x2295baf6, 0x4c9893ca, 0x9a5bd701, 0xc0b8c26b, 0x39a50d8f, 0x8992e700,
	0x641f6a53, 0xbd61b9dd, 0xcabc390b, 0x3bda3d49, 0x5fd7dce4, 0x15efd1e7,
	0x75c291f0, 0x6b9087a1, 0x9e5e9da8, 0x29630427, 0x12302e5f, 0xfc1b2e39,
	0xac39029c, 0xb5fa73f6, 0x20fdf879, 0xf9cfd239, 0x8f440fea, 0x23f4ef7f,
	0xc787ff4a, 0x52197b50, 0x7e673f3c, 0x753f653a, 0x63830747, 0x4fe0b55d,
	0xd0413f47, 0xf86f3ea4, 0x47dfd38c, 0xbe444f0f, 0xf8d1ffca, 0x1bcfb638,
	0x1d667683, 0x64fb33b7, 0x35f81c57, 0xf8323afa, 0xc3a15739, 0xf79e851b,
	0xefd67df1, 0xa69e9ce1, 0x9342453d, 0xe93ef608, 0x5c9dff45, 0xa2eb2164,
	0x2bbdb3c4, 0x7a89fe29, 0x4fc1f7dc, 0xb23c01cc, 0x34da02df, 0xb785412e,
	0x349cd795, 0x03c7f566, 0xceab0efc, 0x7c2fbe75, 0x70075f61, 0x4d0967dd,
	0xdeb28d2b, 0x257e1c63, 0xef19fc6f, 0x91d0dd5d, 0xdcb80266, 0xce6a2450,
	0xb8943f3f, 0x4c913f1d, 0xbc957984, 0x2a639571, 0xe8b765e0, 0x75567b86,
	0x6f25671d, 0x3d207394, 0xf07fa13c, 0xb9311ea3, 0x479e01cb, 0xc085affe,
	0x3f2f6afe, 0xb884c997, 0xc2dc4ce7, 0xd48fc07b, 0x83f8b123, 0xd313b322,
	0x4df24b1b, 0xccdc7449, 0x3804e736, 0xf5e54a9a, 0x4d69408b, 0xd6072086,
	0x5a97a94e, 0x921deacd, 0xd6d1b59c, 0x5b0c50ff, 0xbee202ff, 0xc7f8573f,
	0x8ffe5bc3, 0xd002c1ec, 0x7eec4527, 0x26ba7f5c, 0xd37d1fc8, 0x7bc83f05,
	0xbe613fd8, 0xdbebdd84, 0xf2e5606b, 0xd9fa020d, 0xc3d7ba14, 0xd1998479,
	0x9e7e32af, 0xcd3dc199, 0xc0a3e0cc, 0x7eaf8159, 0x2a7d4abe, 0xfb54aeaf,
	0x9f6bae1f, 0xc3e832f0, 0x69c10eda, 0x1ad55da0, 0x61f01243, 0x2693fb5d,
	0x76cfaff0, 0xb1897eb1, 0x3e7d4b34, 0xe766645b, 0x97d99de4, 0xf93a05cf,
	0x4bb52574, 0x5dcf7b68, 0x77a01d67, 0xefdc1af7, 0xf947fdc0, 0xfbac916d,
	0xbef57906, 0x917579cf, 0x1a6fdd51, 0xeac6f3ae, 0x4bb8137c, 0x6edeab6e,
	0xa7a2aa1a, 0x96027322, 0xab53df2b, 0x9df0d95d, 0x90f3878e, 0x8813309f,
	0x740ccef3, 0xdbb2bde1, 0x1d19e3ea, 0x4bb60456, 0xfac34f98, 0x38ca78ca,
	0x599a7e7a, 0x99df8da2, 0x011a1857, 0x07312970, 0xa14775ef, 0xe566e3d3,
	0xea5be15c, 0xdba50f09, 0x7a45ffac, 0x4f455ee2, 0xaaa54c84, 0xcc578f78,
	0xd0c4f4fd, 0x51627a68, 0xe0286b83, 0x8cd6d161, 0x8b24c0a1, 0x1c9c537e,
	0xe7bc4f4d, 0x0784e763, 0x9ecc3df8, 0x5c4f5499, 0x3313d2aa, 0xfa27482d,
	0xf8553f76, 0x427a7ce4, 0xb17fdbc1, 0xf40f79bc, 0xdefe1444, 0x89ead660,
	0x50ca3b9b, 0x533cdc4f, 0x788fdcd4, 0x9afdccd1, 0xfc89ea03, 0x3798d9e4,
	0xe851adb9, 0x0f6e3de7, 0x7271e01f, 0x8be80e30, 0xebfe5cc3, 0x7240c6f5,
	0xcac191fd, 0x3826fff5, 0xd17d722b, 0x773eec4d, 0xec243a7f, 0x95367f7c,
	0x23d002eb, 0x6e8beb93, 0x9d317ee7, 0x39052d9c, 0x672d493b, 0x2f5afb59,
	0xed750bd3, 0x8736ff69, 0x64dadf96, 0xfad0c772, 0x6ee446b7, 0x1eee5a8e,
	0x56ee481e, 0x69fbb930, 0x9fb444c7, 0x9fdf5a06, 0xf2a5bcb8, 0x0a3b8c6c,
	0x639acc7d, 0x39b7dcd5, 0xcccde132, 0x7b2fc04d, 0xfbaf3c45, 0x7b01db98,
	0x0939bc26, 0xc657d3fc, 0x6358f9b0, 0xb74af9d8, 0x445d5c8f, 0x5de140e5,
	0xd9ae9ecc, 0x6afc2220, 0xd7ff18db, 0xbbf5898e, 0xf65a7e68, 0x57c8259f,
	0x6ee7656d, 0xf9250574, 0xed57fc2a, 0xff82350d, 0x80ad6ab7, 0xaf1086e7,
	0xc05cf00c, 0xaeee59e1, 0x3e8afdc2, 0x8bf1407e, 0x0b7af0d6, 0xffa2d63b,
	0x504f1f54, 0x93eae633, 0x3128afb0, 0x6c943c33, 0xd36bfc12, 0x575afce0,
	0x9e28fdcf, 0xb404d417, 0x7af933df, 0xccc18be7, 0x7aafb04d, 0xd3477447,
	0xb87a9973, 0xb84f7c54, 0x9970a3ec, 0x2e1efff4, 0xda81c103, 0xd64fe8f7,
	0x862b23c3, 0x326c95cb, 0x63f0f809, 0x8ae50783, 0xfb8896fc, 0xbc9ebbcd,
	0x3f7f7340, 0x5efff38f, 0xe211b783, 0x015ae56f, 0xb3582deb, 0xcd326771,
	0x099009cf, 0xb05e8ee0, 0xc387ab5a, 0x85cdbf7a, 0xfd4e7d7a, 0xfde20146,
	0x3bfbf3e6, 0xf127fe15, 0x17db83dd, 0xeb4f3d53, 0x7b36cbcf, 0x9f73dce1,
	0xa6e517a5, 0x4055b742, 0x641fb8b7, 0xda9238f3, 0xa9fa845b, 0x3f22705d,
	0x5f4c2d06, 0x7bc13c51, 0xbf539d0c, 0xc2f1c69c, 0x0ced10fc, 0x6f14758f,
	0x3ad3cfc0, 0xd985be78, 0xf929b781, 0x0977e080, 0x9bb75720, 0x020efbd8,
	0x12381449, 0xce11fa54, 0x5593f2d3, 0x887ade78, 0xc13affd1, 0xf4fc1f8d,
	0xe782efbf, 0xd99ee901, 0x77a58331, 0x31554e05, 0xf1c19f7c, 0x55d2cfbc,
	0x65cf1132, 0x73be3704, 0xe78f11d1, 0xd89b470a, 0x700f0d7b, 0x05f3d7fa,
	0x2a5c3bec, 0x30f5cabf, 0x9d038871, 0x3b78c16e, 0xd99d371c, 0x7dfbda65,
	0xc9c7df32, 0xd3078a83, 0x91d49bc7, 0x22c7b42e, 0xafde5f71, 0xb9f7d024,
	0xba3af8da, 0xbff3a422, 0xcc9bff43, 0x4ff70349, 0xff189c52, 0xf9538f79,
	0x30f764ee, 0x6473be78, 0x143981ce, 0x10ae9fbe, 0x16ee9cf1, 0x1e7f6b83,
	0x4cc79bc8, 0xd3e5f804, 0xd30f263d, 0x3bd45603, 0xe08f7b65, 0x163295fd,
	0x7eca4473, 0x11cbf4c8, 0x523f9f3e, 0x9f01edbd, 0x864c0908, 0xee99bdb8,
	0x4a2ec5ed, 0xda4d3707, 0xc3ce1cb7, 0xee742c6e, 0x7cf80fdf, 0x725bbd94,
	0xee214578, 0x5bb9eed3, 0x483b7e40, 0x6fed06f1, 0x7fb6999a, 0xf6f71d3f,
	0xbe784915, 0x7493c735, 0xcd779c33, 0x5dba23d9, 0xebbcdeb4, 0xef3836ec,
	0x244e319a, 0x6e7c155e, 0xe1cb5d27, 0xfd4e771c, 0xbcc137dd, 0x143ea82b,
	0x57dd20d3, 0x6bf2143c, 0x275f6c04, 0x94a1a57b, 0x9f56ba74, 0xf1d12695,
	0x003d69cb, 0x561add7b, 0x7059aeaf, 0x796d0843, 0x2f2893c7, 0x7c059bcb,
	0xda8ba220, 0x5fac31bf, 0xb7ed0c7f, 0x4f6d0d6b, 0x3da00bf3, 0x7f1cdbf4,
	0xd5679c33, 0xfb6279d1, 0x873c06dc, 0x68eda72c, 0xbe6ae931, 0xb85bfb1b,
	0x1f702046, 0xed3722a8, 0x6fe85c89, 0xe50dc98f, 0x14ffb607, 0xd2e645e3,
	0xfed186f1, 0x62a189e7, 0x121e4fa8, 0x9d98eb9c, 0x1eb17e80, 0xec1a13f8,
	0x2e7c674e, 0x8e5ee510, 0x907f1d51, 0xca716168, 0x1a1b8be5, 0x39215d61,
	0x7480cd29, 0x3d025675, 0xdbc2947e, 0x23d7ed4b, 0xe86b8b12, 0x21488f94,
	0x5b751c95, 0x5dfdb032, 0x4e78f9ed, 0xe2949f3e, 0x81b7b939, 0x968723d9,
	0xd802fc5b, 0x28e72661, 0xdcb9def8, 0x5fbbdf8c, 0x7ba7fa62, 0xa1fd0864,
	0x0898d7c7, 0xba5a57dc, 0xc069e326, 0x260df1e3, 0x59f137a4, 0x05b1ca13,
	0x593f312f, 0xefd61ae7, 0xf6257bf1, 0xd3940e0e, 0x285f82fc, 0x1cad5ffb,
	0xa255772b, 0xa5cbd29c, 0xab7f717e, 0xd920241a, 0xdeeaf27e, 0x2aaf2869,
	0x4201dea9, 0x46af27eb, 0x52bfa234, 0x88eaaf2f, 0xd947d14d, 0x56522f10,
	0x6aee7233, 0x59dbe3a0, 0xf05775e0, 0x027fcfb5, 0x4edab77a, 0xd1ad4be0,
	0xe8c0b4f9, 0xccbf0082, 0x39f8d8e9, 0x1cc541f0, 0x739fbe0b, 0x7c00f00c,
	0xcf1132b3, 0x65fdcb3b, 0x0e256f08, 0x2d6ac172, 0xd9e72b9d, 0xf122bdb3,
	0x8557f5a8, 0xf5547895, 0xd290fc0e, 0x8ee71d2b, 0x116fc176, 0xd7687f20,
	0xef30937d, 0xe62d79c4, 0x3b4ac1f6, 0x0781f3d2, 0x7a072ece, 0x40b0fb9d,
	0xb2275ec0, 0x61f411b7, 0xf5c16aed, 0x61f5c018, 0x6d017ed6, 0xf03ef30f,
	0x94574653, 0xff405dbe, 0xdc9e6bb5, 0x059bf585, 0x607ff417, 0x13da196d,
	0xb048b215, 0xee10f9bc, 0xc29ea81f, 0x594ea2b8, 0xaffa064c, 0x8276665d,
	0x91d0a4a9, 0xf8879742, 0xe31266fd, 0xf0bf02ce, 0xe4c9d087, 0xce28f4fe,
	0x14fac212, 0x664ea4e8, 0x25e87674, 0xe6c81b93, 0xeec974fc, 0xfae71eb5,
	0xa6f67c55, 0x9d60c369, 0x42fc58eb, 0x09429ae7, 0x7ee388ec, 0xfbe1cf01,
	0xa9b125d3, 0x2e8528ed, 0xbc98159f, 0x3a8f47ee, 0x7747ec3a, 0xfa152e9c,
	0xfb8d44a3, 0x263deaca, 0x3d72fe02, 0x814d7a3d, 0xa04e219b, 0x1eba65ec,
	0xc6c2df3a, 0x575ed007, 0xc9f348e0, 0xf2372f90, 0x0fce57f8, 0x0f164635,
	0xa7e7adf4, 0xc2589f1b, 0xf41b3b7a, 0x4947b536, 0xe6fb8e90, 0x3e311786,
	0x43faccee, 0xf37da2d7, 0x8003a53a, 0x093b06ff, 0x8fc3fee2, 0x4db2a872,
	0xa0fc60f4, 0xa3739831, 0xc4aedf6a, 0xc2bd5449, 0x5b2b9de2, 0xda12fecd,
	0x91cb72be, 0x5ebf3c2c, 0x1c718bd2, 0xed017af2, 0xb2872263, 0xa5461ee0,
	0xe86bc591, 0x2c8782ed, 0xfa75cfcc, 0xb02ceb35, 0xf61684db, 0xe065562e,
	0xe5599316, 0x31645dd7, 0xd7ba38b1, 0x229e78ac, 0x7dc33c53, 0xfa9f9867,
	0x4e25263d, 0x182ff4e3, 0x9bb655fd, 0x6cab9ed0, 0x710dd8d9, 0xcd079577,
	0x6badcfb8, 0xc4718b39, 0x84bcaf85, 0xb5d569ef, 0xabb89a8b, 0x2d4ef17e,
	0xd46f9e22, 0xdc60d5b6, 0x39e3cd06, 0x7a206d47, 0xe2f9dfdc, 0xd95eaa72,
	0x20a645ba, 0x73f4daac, 0xd5afbe07, 0xf781ceb5, 0x39be5a47, 0x7c5fb0de,
	0x6fd1e053, 0x053a6f8c, 0x6ac2507f, 0x9be368b6, 0x6b930b48, 0xd1397e74,
	0xed840bee, 0x7f3e97ad, 0x4f6fe20e, 0x1cf27eb7, 0x3ffab7cc, 0xe20e7d3e,
	0x8b36c830, 0xba91ec13, 0xfc61eff5, 0x9b6ed2a2, 0x7e7fef85, 0xfb8c73f1,
	0xd983feec, 0x6f75bd0d, 0xec0a3e3d, 0x7f8dee8d, 0xce78864e, 0xa316b77b,
	0xcddee73f, 0x14494385, 0x0292817f, 0x1107fadd, 0x57c7aa77, 0xc6275b67,
	0xf8a19c8b, 0x8e10f906, 0xb0d40b57, 0x8f173ff8, 0x3d10db53, 0x5c5fb7be,
	0xd78ddb5a, 0xb172015d, 0xe705d98d, 0x977b4f8d, 0x41d2f1e2, 0xa3c36fe0,
	0xc7449e5c, 0x83f819df, 0x1d03e9e2, 0x9b6f3efe, 0x5033fcff, 0x603896d6,
	0x10705a7c, 0x87e25370, 0x1cf1617f, 0xb61f00b7, 0x01e312fe, 0x2e256f01,
	0x8f9fcf90, 0x09f0bf02, 0x1ffa2f53, 0xf19ab77a, 0xd6e559fe, 0xdd3fc803,
	0x7c61f79b, 0xbc71e12e, 0x63fc24dd, 0xd7dc9771, 0x676cd753, 0xfe1c6d71,
	0x72e6f710, 0xdf1e77e0, 0x8958e8c6, 0xde281b7b, 0x3a6c746d, 0xc5811f7f,
	0xbf34d5e5, 0x22c7e3cf, 0x017212f8, 0x31be874f, 0x8381508e, 0x4530e013,
	0x3d19bf1d, 0xe71c30ae, 0xf805f1cb, 0x8e1d3903, 0x11f9a4cf, 0x17e7af10,
	0x1f9e100e, 0xbb7f8519, 0xcff8b2d7, 0x5ef6936e, 0x2c4f0467, 0x563533ae,
	0xc1feafc7, 0x6f9e73c5, 0x4e16df1d, 0xec2eb1b1, 0xd3af0f57, 0xf3cba2e7,
	0xef85622b, 0xa669ef77, 0x9017bfa0, 0x26f70b17, 0x04490eda, 0x7df16def,
	0x887f7294, 0xaf4ed5fb, 0xb02e3117, 0xf289d031, 0x6a372f5c, 0x7e8979f9,
	0xf9f1d7be, 0x7d33b6d6, 0xeed5ba71, 0x4e7ed1b7, 0xd21af1bf, 0x4386ed75,
	0xed5dc412, 0xb124d96a, 0x47c602f8, 0xaafc2fa0, 0x797e9ff9, 0x6fca167b,
	0x7e904efe, 0x38f9db9c, 0xc7d11d75, 0x5670dba9, 0x1c954e33, 0xf3b69c90,
	0xe8ca778f, 0x3bfa05b9, 0xa6ecc5d5, 0x7a710153, 0x9e317bb4, 0x47df1358,
	0x377f3137, 0x5ef89bd5, 0x8fbd9d92, 0xd1623a24, 0x9ed7bb0e, 0x086e307b,
	0x4bc612a4, 0xf1e06d2c, 0xa7743f15, 0xda97be00, 0xdf3026af, 0xd55f00e5,
	0xf4e4de7e, 0x4cdfb012, 0xd493a529, 0xfcca2de7, 0xe20621a5, 0x5effe157,
	0xb0a1f4fb, 0x7946250f, 0xdae3cc04, 0xa08d2ff4, 0xcc7cbb07, 0x1dce4f8f,
	0xbbdf0319, 0x899dce8c, 0x22aedfb4, 0xd82e0dc1, 0xfacf74fe, 0x3c15fb0f,
	0x211e77da, 0xd7d61e96, 0x5da036e7, 0x9d043768, 0x5bb10ab4, 0x237052ba,
	0x632e22eb, 0x63c08632, 0xbe63fa1c, 0x4f709998, 0x99a841ce, 0x46dcf50a,
	0x7107bbcd, 0x3bdd46b9, 0x31dde408, 0x38d8ef54, 0x39fe2abd, 0xf69bfb3b,
	0x15f7c21b, 0x034933e2, 0xbb4aef90, 0xa787ed17, 0xf414bbf8, 0x5fee0e37,
	0xb7589025, 0x3a165dfa, 0x07bde6ae, 0x1f26ae3a, 0x13e6d1ef, 0x468f1ba7,
	0x7c8933d3, 0x1b44d31e, 0xd8be21c2, 0x4adbeca0, 0xcc8e482e, 0xb8893e3b,
	0x8d7e5083, 0x29c0e30d, 0x75eac97b, 0x79da6cd8, 0xe469f9d3, 0x48665c44,
	0x6a79b036, 0x4b893bbe, 0xb47bf5c0, 0x357ce9df, 0x6e58f6f9, 0x11891aaf,
	0xa62d9de4, 0xf7f8708b, 0xccbde069, 0x1938bce8, 0xfef843f0, 0x8f70265a,
	0x83af8e20, 0xefa9af8e, 0x1b012f04, 0x190fdb5f, 0xdfdf54e1, 0xc1eb94bb,
	0x6fe96b06, 0x8ce4de40, 0xde40c7ae, 0x899214bc, 0x863b50f7, 0x5f4a7ca0,
	0xd08e405c, 0xe8c4d0bc, 0x824acc6a, 0xd7a6337c, 0x59e1dec0, 0xa9768b16,
	0x96c88639, 0x44c7b86c, 0x8c365364, 0x4ce7e7e2, 0xda0625ae, 0xa5057195,
	0xa3aeda35, 0x9f30c0b7, 0x45002122, 0xb15dffb4, 0x7e30839e, 0x14def5e3,
	0x78f804c3, 0x231df2cf, 0x022f6b90, 0x5841a0cf, 0x15f773b4, 0xfdf04228,
	0xef196a25, 0x14dc3d04, 0xdc2093ce, 0x0d8a6e9b, 0x54313de7, 0xb3a537de,
	0x45d8b1fc, 0x51e457cb, 0xf4ae285b, 0x62438c18, 0xb9e3179c, 0xd7013057,
	0xa2fd3e7f, 0x735c73cc, 0x24ec5a68, 0x77853fe6, 0x87b02f39, 0x3ea345ef,
	0xf253675e, 0x944fdc41, 0xb943edb6, 0x87d81356, 0xd3c806e5, 0x68627474,
	0x2a78f0da, 0x525f1e37, 0xc411729c, 0x18a597eb, 0x8f1d3ae8, 0xf709d92f,
	0x787022c1, 0xbc8ef964, 0x868c1c08, 0x8f773be5, 0xf961c354, 0xc1f5e04e,
	0x5d61c1c2, 0xec18708e, 0xd85d29ba, 0x919d34ad, 0x9477c06f, 0xa1b41ca6,
	0x2cfe859f, 0x3f788fa8, 0xcfb8076b, 0x684becaa, 0x1556493f, 0x14ed297d,
	0x6e881aba, 0x62f38832, 0x969e5ef6, 0x3d59a67e, 0x7cb4aca3, 0xa6f3d5b4,
	0x1fae326d, 0xf0cf57ef, 0x1345dd7a, 0x6c4d7423, 0x5f7089de, 0xe77ac1b7,
	0x7f955685, 0x22fe4676, 0x77ce9d31, 0x5242f01c, 0x8b493d64, 0xba58cb65,
	0x018f24ce, 0xac1bade3, 0x8e30f1de, 0x906f5663, 0x026a126a, 0x620a2778,
	0xf1942f84, 0x7db2b71a, 0xc199637b, 0xfb9d84bf, 0x845fd00a, 0xfa3a423e,
	0xd1f465e8, 0xa3e9087e, 0xa310e3b6, 0x0286f68f, 0x3f382fa0, 0x137efd83,
	0x78009de9, 0x6d7c7c2f, 0xac2471b1, 0x3871b7b7, 0x79130ba5, 0x82c4b8be,
	0xf987cd70, 0x9f0fc3f5, 0x81aeb29f, 0x3bb4dbf0, 0xd84cf1fd, 0xe031ee57,
	0x370297b9, 0x95855ea5, 0xda26d1c5, 0xfc02d7bd, 0xbb4372ea, 0xbbadf960,
	0x1bf1877f, 0x6c373d8e, 0x998ef687, 0xc8ae4314, 0x967b4db8, 0x4db7fbe0,
	0x65d01d74, 0x4195e91c, 0x0f0c0faf, 0x78613fc6, 0x0993dd80, 0xfc8438f0,
	0x13df9eb2, 0xf7877ca2, 0xd95b475f, 0x56650b3b, 0xcfbe8fb6, 0xef3ce22a,
	0x587db2b3, 0x093e9ed2, 0xcb755df6, 0x093f580c, 0xfaf54cd2, 0x46faf197,
	0xc15d9f8d, 0x544f42a7, 0xbde15a92, 0xbde30b86, 0x6ac9d6b5, 0xa6b049fa,
	0xda53faab, 0xee23e13d, 0x3c50c6bb, 0x1ef3b8ec, 0x7e94abd0, 0x8dda6866,
	0x6e005937, 0xcfa07d4a, 0xeda1f868, 0x977c661e, 0x617b0560, 0x22458ee3,
	0x160c339c, 0x1ef039af, 0x639fad1c, 0xb4adf525, 0x4d1c4e7d, 0xf3c89f21,
	0x387e7943, 0x703e334b, 0x7dfa041b, 0xaebff72d, 0x542570e2, 0x137bc0ed,
	0xf35c38ab, 0x2f516252, 0x360b7c28, 0x1b5f9c03, 0x7a7639f9, 0xf001ba6f,
	0xb1b1f0a6, 0x53b410d7, 0x746e95a5, 0xe19e2019, 0xb75d1f2d, 0x73b96071,
	0xfeec45f5, 0x0b7bfe9e, 0xb677cf9f, 0xbbf74faf, 0xf002dbd7, 0x3d0989ad,
	0xd7cd0371, 0x9e29f45e, 0xd6b12e13, 0xbf3eae5e, 0xf9faa7d3, 0xb8ee75bf,
	0xeec3ec03, 0xa3d3ccaf, 0xe47fd9d9, 0x9beddb70, 0xbb14ed85, 0x7185510b,
	0x827baaa6, 0xaed14c66, 0x3c8a01fa, 0x4c6ca3c0, 0x656afd00, 0x752ba57e,
	0x107f03f7, 0x62bdfe64, 0xe40e34d2, 0x5fd58e64, 0x92e1ca82, 0x240f8c0c,
	0x28fb315f, 0xe707fe86, 0x5cfcc54c, 0xb9d073cc, 0x4e5fd403, 0x0251535c,
	0xc34b8fd4, 0xf689f3fe, 0x449cadbd, 0x977208d9, 0x7f61a464, 0xf2ba3185,
	0x68ed04a1, 0x18c5e172, 0x544c55d7, 0x5f9d18f6, 0xb7a3064e, 0xdccae319,
	0xa7fbfc45, 0x1b3ebc40, 0xe445c671, 0xd9ae55fc, 0x9d8d22ee, 0xb906e4d2,
	0x89bfdbfd, 0xab8b4477, 0xfb636098, 0x52bedd8a, 0xeb379c37, 0x12e05ae1,
	0xfd5dd996, 0x9f87abe1, 0x3c0ade1e, 0xffcb70f5, 0xe0945dc0, 0x3d1f0fea,
	0x283c143c, 0xe3c3d670, 0xc29bf82d, 0x334cadeb, 0x96f69bbe, 0x2df7c191,
	0x77b22e6a, 0xbf683d18, 0x50f9f316, 0xd3ed15fb, 0x9bbb24c2, 0xa4a78791,
	0x5f323938, 0x70f55c3d, 0xb2efe1cc, 0xdf113890, 0xf005dd05, 0x085874a2,
	0xdc741407, 0xee12adc2, 0x4af0491f, 0xa0e38ea2, 0xe5f7c0d3, 0xa2fce4ae,
	0x5ac725c0, 0xfa1e23bf, 0x39e1a733, 0x695f95f6, 0x8ee2d9ed, 0x2fc12769,
	0x5de71390, 0x2250fe06, 0x574e11a6, 0xc574b587, 0xf34d65e7, 0xac3aba73,
	0xe4662ba3, 0x62f2b224, 0x833caea7, 0xa1543fa0, 0x15bafd3b, 0x3e057afa,
	0x270fed4c, 0xd9c6be85, 0x4a9dfdb8, 0x9c3d8046, 0x38a4daf5, 0x23a4cf90,
	0x61dfaa21, 0x70d2c1ca, 0x914e9c3f, 0x0de2050e, 0x7c66777f, 0x83b5390f,
	0x1f95416a, 0xbde8b660, 0x4e4516c2, 0x05727429, 0x4415d7c7, 0xa47e0ede,
	0xb3f1882b, 0x169fbdb0, 0x8db17f59, 0x938655fb, 0x5fceb0e1, 0x2ecc5d58,
	0xaf0cebe7, 0x808f9a9b, 0x7e3e3cf7, 0xef0d8c5e, 0xe35e905d, 0xd3fc30e9,
	0x59189df1, 0xc3cc884a, 0x5193ebc4, 0x6bd984f5, 0x5a7df073, 0xb5f2170a,
	0x5b8f3235, 0xdf11826d, 0x38f3e14d, 0x432312d3, 0xa273dabc, 0x71d82e77,
	0x593d85a7, 0x70633eb8, 0x7d37e82c, 0x3beda7f9, 0xd69ca16a, 0x7c7ac72b,
	0xf32255fe, 0x356ef42f, 0x1b485ffb, 0xeca50ed8, 0xe1407a8c, 0xafb83c9f,
	0x5bf02978, 0xfbcc3870, 0x3465504a, 0x02b676dd, 0xedf97df7, 0x671846d9,
	0x8c34df67, 0x1e202fcf, 0x7aafd823, 0xb7d3d7ba, 0xf4f59e9e, 0xf447f11b,
	0xc87d828e, 0xc517a5b7, 0xcdd30b4e, 0x2a374a1e, 0x0bd0a6fd, 0x40e59fa5,
	0x3e933d3f, 0xeacc1a7e, 0x4d3e93bd, 0xd8a6fd06, 0xc37b11e1, 0x3be002b3,
	0xd8ae3d90, 0x79b13fe1, 0x19fd047f, 0x685cef49, 0x65ce3e9f, 0x9deefb80,
	0x7c134f36, 0xf393ec57, 0x0ec82bed, 0x74a5e1ba, 0x21e39733, 0x7ef82060,
	0x4048bcab, 0xe93b7539, 0xb778c135, 0xfb349bd7, 0xde96b9d7, 0x73821f0f,
	0x310b86c1, 0xd10bc82e, 0x67b6226a, 0x2c8dc5f1, 0xeb8c98be, 0xbd700b1d,
	0x3db6b163, 0x13991e3e, 0x43f32779, 0xe7ebed81, 0x7049425a, 0xd64cb68f,
	0xaf8fd7d6, 0xafdf43ac, 0x7f1d5dbe, 0x21de0837, 0x82ecab76, 0xc766368d,
	0x16fbe784, 0xc280777f, 0x9afe00db, 0x8ffc8b8e, 0x255fa145, 0x6424c6f5,
	0xf923131a, 0xacf356d0, 0x287fef68, 0x9ef028e3, 0x7814ba43, 0x7bda25fe,
	0xb65e7944, 0x0aac37df, 0x95ddce6a, 0x116f4c74, 0x026375da, 0xd5d1da02,
	0x3cc37c81, 0xf6cf3d8d, 0x79ecfdbb, 0xea029778, 0xf6676db7, 0xf701a07c,
	0x6c6dd505, 0xce16b37f, 0x44f9539a, 0x0fced132, 0x1e215bef, 0xedde06aa,
	0xb841e563, 0xc4d19e6a, 0xbb6e7fea, 0x0c747a4f, 0x29bd3bec, 0xafcd3726,
	0x8631b07c, 0xd31a8fee, 0x804c8588, 0xa7079138, 0x6f7d84ad, 0xf1204782,
	0x0db46f98, 0xf93efc1b, 0x340f95f3, 0xfb8118ae, 0x17c0d3ab, 0xc40cbf0a,
	0x5cda1f1f, 0xf681c708, 0x4ae38bab, 0xfca1b73f, 0x3d077e61, 0x5c62fbfe,
	0x8f7f4071, 0xd5f47df2, 0xfdc4ef8b, 0x73c2e581, 0x2bee20a3, 0xb05de38f,
	0xceb27b33, 0x1759eeca, 0x4ec15e88, 0xe379edfb, 0x13f058dc, 0x08ee35bf,
	0xf83acbee, 0x7c7b89fb, 0x291f6815, 0x59d9b478, 0x17d5efdc, 0x5f603a75,
	0xdfe4cd71, 0x33f0fde3, 0xd93ef646, 0x63495ce9, 0x1b1ffec7, 0x23931cd5,
	0x089b0529, 0xd26f3972, 0xe7a0838e, 0x110fd207, 0x4011eff9, 0xfb7393fe,
	0xa79cf192, 0xfc03a76d, 0x7df9a715, 0x9d6d33f3, 0xb4d277c9, 0x1defe366,
	0x691a9fb0, 0x19dd7667, 0x6fbe1763, 0xc459bd53, 0xb8e81977, 0xff81b7c9,
	0xce5e6db8, 0x18986c63, 0xfc23feb5, 0xfec50d5d, 0xf64622bb, 0xf8a87d73,
	0x8e1df12d, 0x8f44db2b, 0x0edfd1c5, 0xfd3bb33c, 0x07c012a9, 0x802fb931,
	0x03b2468f, 0x8e7e42ed, 0xe03b7f43, 0x3c6ddefd, 0x4fb6ebf3, 0x891cbc6f,
	0x12ecb9c8, 0xef23ec01, 0x639ce610, 0xdfb15872, 0xeb4afcae, 0x8fdbd49f,
	0x96131d05, 0x0f08270d, 0xaf7b7ef6, 0x67668fe4, 0x8b4ef717, 0xf2124f6a,
	0xf643d224, 0xf0198ce6, 0x6ff64cfe, 0xb78c4e0c, 0xac7a33b1, 0xdf14fb6b,
	0xc125a947, 0xb6bca19b, 0xc906744d, 0x65e7c937, 0xff7f85bf, 0xe4c3a7a9,
	0xe9edba02, 0x059319d8, 0xfd1176f9, 0xf37b755d, 0xeb3a012e, 0x3be130ee,
	0x3f5b7521, 0x501c8076, 0x07777bf4, 0xa7a43f7b, 0x577e08e3, 0x4f6eedfa,
	0xcef404bc, 0x5fdb0346, 0x17f5d8ee, 0x5f85c82b, 0xc44beb9f, 0x9fa2ad7d,
	0x08bfdbfb, 0x18bb4297, 0xedaadff6, 0xbde6225f, 0xc550710b, 0x0a222671,
	0x9fb53b11, 0x2c80fe7e, 0x7afe93b3, 0xbef400ba, 0x735f4518, 0x8cf1d378,
	0xfd7aef40, 0xf6e7675d, 0x0d9248d4, 0x9fb5e5ef, 0xfbc2ac4b, 0xe7561d9b,
	0x30bff412, 0xc767a4bb, 0x80cf1fa9, 0x76447bef, 0x889cff7f, 0xb6c6ff74,
	0x9b21d1aa, 0x888dee1a, 0x9d862faf, 0xd69d7eed, 0x2c6762ff, 0xdd1b47f3,
	0x0fefa897, 0x39fbea44, 0xeca982bc, 0x854e4b5c, 0xb3be7177, 0xdfb479dd,
	0xed2b54bb, 0x4ef67768, 0x763bf103, 0xe40921cd, 0xf4bda245, 0x95ea3b09,
	0x22e01580, 0x84e18293, 0x4b115b8e, 0x7abe800a, 0xe213881b, 0x36ef36e9,
	0x932f0018, 0xdc61a5d6, 0xee7e7acb, 0x24d030b7, 0xcbe4a9a5, 0x746e7e42,
	0x4a8f24c2, 0xe21f7d50, 0xc4e07260, 0x51e7cace, 0x4cc1fe4e, 0x17a2882e,
	0x3d33b33f, 0x679249b7, 0x877a806c, 0xd8dfb80d, 0xbb57ebb1, 0x85cfdde0,
	0x40135d07, 0xf9cdbccf, 0xfacf7da1, 0x6d9b8846, 0x77a080ff, 0x4cb9a735,
	0x5f71d034, 0x07e62e27, 0xfb80d77b, 0x90ffb0e0, 0x9d611278, 0xf772e5bf,
	0xcd06ddf5, 0xfcebd339, 0x3b0ecfbd, 0xb568d38b, 0x75af588b, 0xc8224177,
	0x77bb44ed, 0xbacdc833, 0x8746a1a3, 0x5337e22b, 0xefa9a4ec, 0x4f18ceb6,
	0xda7a9cff, 0xbb7404e0, 0x84417dde, 0x104ebaf5, 0x7e902f12, 0xefed1376,
	0x5efeead7, 0xa3facd3f, 0xf80378f3, 0xd53f8154, 0xd2678fbc, 0xc65debfc,
	0x52978804, 0x43acafe0, 0x2015df19, 0x6436b59e, 0x37eb4f25, 0x78956ff8,
	0xa24e89cd, 0x748e37bc, 0xbcf76c59, 0x8c82f4c3, 0x9d89ec76, 0x6c8f68b1,
	0xa48c7ae2, 0xf8068d94, 0xe5ea7829, 0xcf9947fa, 0xc27fe340, 0x7e9280f5,
	0x6f5eba5b, 0x3748c972, 0xb5bc599b, 0x64c60e4b, 0x7b565c40, 0x26fbfe06,
	0x4fd5b8aa, 0xad21fe70, 0x643da87f, 0xaabdc030, 0x3c42adda, 0x4832173e,
	0x674c36bb, 0x5fd200c6, 0x7c8241fb, 0x3772d95c, 0x7951dff3, 0xc2afdfc3,
	0x1fe068f3, 0x4c3d2e7e, 0x8ed4e9a0, 0x23874bb5, 0xe00e837c, 0x289c08ab,
	0xdf5a40df, 0x2ebd0124, 0x0ba597bc, 0xc2eef9f8, 0xcfe45ed5, 0x5e2c35f2,
	0xc348e4cf, 0xf4e19c79, 0xa9b10c4a, 0x7321cf10, 0x5ef3283c, 0x64f6e9c9,
	0x309d53db, 0xab2fa52e, 0x6b2fe683, 0x9869f27f, 0x27af42ae, 0x4fd84d9b,
	0xfcf6ac45, 0xfd60e9db, 0xd1977e6d, 0x5366d4fb, 0x349fbc01, 0xf04e2655,
	0xbcdebf07, 0xfdf9044e, 0x1a73d03a, 0xebd073e3, 0x663e7627, 0xddf4107d,
	0xbf010321, 0x548926f3, 0xc5f1546c, 0x6aafb58e, 0xa5b2b7f8, 0xb7fa0661,
	0xc8020943, 0x156f8579, 0xdc926fb8, 0x5fff2157, 0x22ffe3ab, 0x839a7ed6,
	0xce29e5e1, 0xa74d4fff, 0xc53f4ffc, 0xd00bc737, 0xfa2926cf, 0x1c535a7b,
	0x3bf3f7c2, 0x5727ec1e, 0x7ed838a7, 0xc74191de, 0x0fa6bdaf, 0xf9e1f3f7,
	0xaa79ba71, 0x349ba148, 0x44dfe001, 0xe0063831, 0xf40ae145, 0xc82b768c,
	0x7c74fcdb, 0x3d3fa827, 0xddce512e, 0x911b7c34, 0x7aff0a6b, 0xe77c02af,
	0x052fd514, 0x44b13afb, 0x293d3a46, 0x50274778, 0xf81276bd, 0xb85c8a39,
	0x2fe7cb90, 0xbbcd5e4c, 0x41e7fde0, 0x2bae8152, 0xd60d4ee8, 0x4e08d645,
	0xee528fc0, 0x13f6c35a, 0xe53fbce5, 0xceff92bb, 0x0fd13f70, 0x4eb0e5ee,
	0x0824cfaa, 0x67eb1cdd, 0x05088cfa, 0x70c417c8, 0xdbf02a75, 0x6ec7aa42,
	0x93b1e955, 0x57a426a6, 0x9cf50e05, 0x6788bfde, 0xe9cd1eeb, 0xfdb05ae3,
	0x7448e754, 0x18146063, 0xe3028b5f, 0x3ffa1177, 0xabb2f3b9, 0x89afee90,
	0x1b55f74e, 0xc67d22d6, 0xbde2774f, 0x6e8ca790, 0x34667c4b, 0x74c7ec79,
	0xc37fbac7, 0x31d015fd, 0x7c40fdf0, 0x407c0150, 0x9fbfd0a2, 0x7f0abfd2,
	0xba501d0a, 0xe150e958, 0xca174f43, 0x97029df9, 0xbff3ba4d, 0x3538723f,
	0x4035d4f3, 0x9eb28a1c, 0x50e78cef, 0x8bfebf3f, 0xfe11cf0c, 0x722b7c02,
	0xd9f00562, 0xccf981e4, 0x97cac71a, 0x5e0f79a7, 0x7cb4e141, 0x4a5ae498,
	0x8a72d6e5, 0xe4766766, 0xc7c0285c, 0x2af1d657, 0xce81d7a7, 0xdeac1a75,
	0xf9dd0e2d, 0x42332ba3, 0xcedcc52f, 0x8cceb45d, 0x091beae7, 0x47796fe3,
	0x7f7d5fac, 0x06a469d3, 0x2efd0529, 0xb09ddf2e, 0xd779a62f, 0xa18c8962,
	0xd22fc3fb, 0x7c4076ca, 0xc974bfcd, 0x52e9e325, 0xccf24a36, 0xe09f706b,
	0xbffa0abe, 0x84e0c4aa, 0x8f788b78, 0x04bf0053, 0xe5f02c92, 0xc4ce361e,
	0xb825f70c, 0x27b9757f, 0xe7d87c82, 0xc15afa60, 0xd17040f7, 0xf081c1eb,
	0x70638d6d, 0x7ae5e24a, 0xf9c2d2f9, 0xf9e9e649, 0x022c8be5, 0x7788399f,
	0xc8eb0889, 0x2c31f263, 0x9e08f25f, 0xfef1f5ff, 0xdf7def94, 0x97f7ae57,
	0xae4c7d2f, 0x1b92f973, 0xe85f2a8a, 0x485caa2f, 0x768f9e6a, 0xdd18392e,
	0xfdd035ce, 0x826b9e0d, 0x92f5a57e, 0x84eff664, 0x4cf4e3ee, 0x14e31329,
	0x18cd9a9b, 0x27c8ad97, 0x14d2ccc7, 0x86392bf0, 0x77b86e48, 0xae499ae7,
	0xcbbcd132, 0x9cfdc063, 0x3fc6bf82, 0xc7f1853d, 0x04cceb8d, 0x9c712ff6,
	0x1266e2fe, 0x2a88507f, 0x37f808b7, 0x608e3fe4, 0x03b179fe, 0x315169f9,
	0x63bb7d41, 0xb7a414dd, 0x0174928a, 0x25b2b9e8, 0x84f2805e, 0xe401a722,
	0x2ebf585a, 0x13319036, 0xe3523f91, 0x8a66f254, 0xfc022f5c, 0x537a2746,
	0x5c84f14c, 0xff55a3f4, 0x8ceff6a2, 0x7fb579a5, 0xf91fe687, 0x8b9dfe36,
	0x047a9ee2, 0x3b973bfc, 0x25c6173c, 0x22e79fa1, 0x68673f18, 0xf25448bd,
	0xdef67ced, 0x3a9fa577, 0xbb2247ee, 0x2a7efeb5, 0xb8b6e6b7, 0x079b6fd0,
	0x3d4da9f3, 0x877434f6, 0xb5445aef, 0x863cd9cf, 0x0f917c70, 0x4863e208,
	0x7e08bd69, 0x4d1e4515, 0xb659c387, 0xdce016bf, 0x903fe143, 0xc73e7867,
	0xafc021e3, 0xbebf4765, 0x3e43eb1f, 0xa7223b2e, 0xa2189656, 0x373c37be,
	0xf8fdf6ce, 0x49c72749, 0x3cb75fc7, 0x85e3c398, 0xb9afe445, 0xfeb92a71,
	0x64e1c954, 0xdec15e76, 0x8f87bbf1, 0xf712fcf1, 0x890e173b, 0xc130c7bc,
	0x7710c92c, 0xe5c43c4a, 0x0b1fc554, 0x0ed0421d, 0x817facf1, 0x97dd1e1d,
	0xe980c5ff, 0x3a5afff3, 0xfeec0d3d, 0x5a9b8376, 0x81871050, 0x9a3dd1f2,
	0x0094bde0, 0xbf30df7f, 0x3e01e6d3, 0xf86211ea, 0xf68f69bd, 0x77b7241c,
	0xbe5a06d4, 0xff8cc3b4, 0xbe4f5ed6, 0xb81deff2, 0x02b2def1, 0x4fbdacdf,
	0x4ef8c38d, 0xe41b9363, 0xd6160bed, 0xa5160bff, 0xf40e2bbe, 0xede740fa,
	0x99538b79, 0x21fb905f, 0x22837af3, 0xd7bd25c0, 0x6e416065, 0x2f631c6c,
	0xe72af5c1, 0xf70e01f0, 0x455bbb4d, 0x4539f7d0, 0x5f614b4d, 0xf7bb73f4,
	0x65f38071, 0x707b5a79, 0xff8f5092, 0x8ab9245e, 0x389577b0, 0xc886247f,
	0xe27d3076, 0x203c860f, 0xe13b2e8a, 0xcefb0ed9, 0x402252b8, 0x9ff8aa7f,
	0xc8cf81a7, 0xcd708f10, 0x3a77f810, 0xc841bff9, 0xbbb4d9fb, 0x1f7e0040,
	0xb82455d2, 0xf7d3fb32, 0x4f9fd86a, 0x802a7162, 0x38df6557, 0x171797fa,
	0xa94ddf81, 0x97eb99bf, 0x42debdcb, 0xf5d32570, 0x4cf583ac, 0x84efe59d,
	0x54a6a7a7, 0x4b929dc8, 0x04859eb5, 0x921e1bfb, 0x0ec31d71, 0x7d21f37a,
	0xe38f16d3, 0x8822765e, 0xeb432df1, 0x8cfd8609, 0xed177aec, 0x5df591ac,
	0xd371e002, 0xbe7037ee, 0xb076ba23, 0x2b55f394, 0x799413b7, 0x7a6369bd,
	0x6e7e4df4, 0x1e6678dd, 0x16be95c6, 0x25f8c5e7, 0xf98d1d65, 0xda7a94de,
	0xcb886aff, 0x5c703499, 0x4938eece, 0x076c07f1, 0x0acdd6b8, 0xd3da02ed,
	0xf79217fb, 0x247c461c, 0xf6db662f, 0x09167bd5, 0xcf562720, 0x505fee89,
	0xee6ac5e4, 0xbfc5559f, 0xb6a71dbc, 0xac12ca5f, 0xa4792ae9, 0x123a7bb4,
	0xc789b2ff, 0xb4d36cbf, 0x02dcbf1b, 0xcda374f4, 0xa2f01fb3, 0xeb3f3bfc,
	0xa39fbff9, 0x781577ec, 0x9e993865, 0xfaee2d7e, 0x097ce137, 0x74a4e4e0,
	0x3d12debc, 0x93a87c8e, 0x7a7173b5, 0x5e8c5d21, 0x7b6a1d60, 0x9d0aafec,
	0x4685bc78, 0x60a72746, 0xfd73539e, 0x53b7409d, 0x409dcba6, 0xa70923ff,
	0x4e8ce993, 0x756ef4f4, 0xd97ab932, 0x70025e89, 0x93ef049f, 0xff8f9145,
	0x35e6c711, 0xe900aba4, 0x97c3f287, 0xd7866fa8, 0xba3c268b, 0xbd00ce74,
	0x205e0093, 0xae627dfa, 0xcde813a7, 0x7e4529e9, 0x3275691e, 0x3d2b49ba,
	0x31b77a08, 0x152f7249, 0xa9c11fb0, 0x04ffabe2, 0x0791c4f1, 0x00008000,
	0x00088b1f, 0x00000000, 0x7dedff00, 0x55547809, 0xf57df096, 0x7b2a555e,
	0xad93b2a5, 0x84a20212, 0x51616458, 0x31612b6c, 0xb2d6c5ec, 0x00f62804,
	0x6d022a49, 0x43fe33d3, 0xc80c6241, 0xa1d141d8, 0x1c2eda5b, 0xdb1b41ed,
	0xb686b4a0, 0xa26c2a60, 0xd8285a8d, 0x104cd8e8, 0x61211114, 0xe8768769,
	0xf739ce76, 0x4bdeaa3e, 0xfec46c45, 0x3ffe7fbe, 0xfb97d9fd, 0x9df77dde,
	0xbee5f67b, 0x93fe035b, 0xb18c75b1, 0x25cb071d, 0x4963015b, 0x65bc6181,
	0xc312d1cc, 0x558c4bd8, 0x6bff40b4, 0xb19bbbfc, 0x181bc53f, 0x6acc664b,
	0x652b1891, 0x42da2b2c, 0xf3ae636d, 0x6a1e0198, 0xebd9364c, 0x68ead6e1,
	0x14a5bc57, 0x243833e7, 0x58f03eb8, 0xf5c1978c, 0x64ea2b81, 0x07f38316,
	0x3cc32624, 0x13329655, 0xdaa33fbc, 0x3de0b92e, 0x14aed139, 0xe0f9984b,
	0x8fd9d22f, 0x8e716db1, 0xfde063d7, 0x5a46b74b, 0x3ae9994e, 0xabfe1afb,
	0xf4d04969, 0x96e9addd, 0xfd827d53, 0x748ff8a5, 0xccc7cff8, 0xd563006c,
	0x2a5b16fc, 0x605a7abb, 0xfb731abe, 0x5fa07323, 0x2697dcfb, 0xe1b44b06,
	0x979e01fa, 0xcf45160e, 0x7fae098d, 0x9df75888, 0x0550d70e, 0xac5bffc6,
	0x3f3e2fab, 0xaf779078, 0xac0d0f0c, 0xa055ecf0, 0xf6ea912d, 0x6cfc02c6,
	0x0b3fb324, 0xd676c4fd, 0x84dd0716, 0x388eed63, 0x931ebfe8, 0xe3bc7840,
	0x415b4733, 0x4ef16309, 0x80f3e126, 0x3f5c52b7, 0xe315724b, 0x2b02937a,
	0xbc700664, 0xb989f48c, 0x8f5e7d3e, 0xaf7c1031, 0xe96148c7, 0x71da2232,
	0x33ee85b7, 0x9ca7bf7a, 0x7f83a9f5, 0xa8631faf, 0xa3cc86f0, 0x312c93b6,
	0xf186ee34, 0x5094cedd, 0x7fdf337c, 0xd00ff2bf, 0x65bfe377, 0x8424ffc2,
	0xd71ff007, 0xd8ffd613, 0x5c538f98, 0xb9834af0, 0xf0090df3, 0x6d93e352,
	0x37ddc032, 0x4a9c158d, 0x01feac64, 0xf5c183ab, 0xf648b65f, 0x1ccf1808,
	0x614966cc, 0xfa04588c, 0x5f1b7fe7, 0x16876ec8, 0x9c61582e, 0x7de4dd27,
	0xedee1736, 0x1c2195bb, 0x470104ee, 0xb9e1f403, 0x980a8b0e, 0x7646fa83,
	0xc122cfed, 0x17fc08f8, 0xb4b525cc, 0xc04049b5, 0x65cc41fa, 0xfaf7b804,
	0x8e10ffe0, 0x046f28c6, 0x6debffcc, 0x0198df17, 0x0c07fcfd, 0x1bf82cb8,
	0x1a34f963, 0x5f48751f, 0x99c72b43, 0xdf7028fb, 0x65d9472e, 0x1512df18,
	0x19e2c857, 0xc24bdb2b, 0xc17beac0, 0xfa9ef03c, 0x5f5a28b6, 0x97902f7d,
	0x9587e25c, 0xb17d9f88, 0xd70e9626, 0xe11c812f, 0xfdac81b8, 0x41b921dd,
	0xbd6a5d3a, 0xac0f6b3c, 0xe7cd1ddf, 0xb573d8ed, 0x7ab1f237, 0xb9cad47f,
	0x8cc561f6, 0xd5aecb95, 0xf5eaafc8, 0x8c9cfb37, 0x96337c43, 0xfd12f049,
	0xd77c20e4, 0xf8e166f0, 0x5a156395, 0xb28b0747, 0x4c5bbae3, 0xf274860e,
	0xae7ce71c, 0xf056b5e2, 0xf4af8746, 0xf7d60b98, 0x769963cb, 0xf5a3be7c,
	0xde01a452, 0xf5de2b37, 0x6721c228, 0x0b39c675, 0x6e979f10, 0xf5c02f6d,
	0xf5e2373a, 0x5a4e874b, 0xb437055d, 0xbe205fbe, 0xb73eb7ae, 0xc524d312,
	0x3d1fe577, 0xb6be481f, 0x24854b3f, 0x98f50c27, 0xeb799b27, 0xfd8ddd61,
	0x48c937fa, 0x86ccc9e8, 0xa558ca72, 0x41bed3e5, 0x77898f7a, 0x910960be,
	0x9de3bbaf, 0xdf1f622f, 0xeb445193, 0x16708edc, 0xd8af35be, 0x75a1b868,
	0x3afc2efe, 0x1aaf44fd, 0x731a9eb1, 0xf8065f8c, 0x17e30ed9, 0xe67caaed,
	0xe8178575, 0xf3e71fb1, 0xb98fdb94, 0xc61f9e90, 0x1f11ebd8, 0x8ce2c04a,
	0x275ff825, 0x4e6834bd, 0x7577ae1a, 0x314fe3b4, 0x357e7fd0, 0x4520fce3,
	0xc5869fd9, 0x8d67df6d, 0x26397d42, 0xae36f5de, 0xc5c336f7, 0x97e84e59,
	0xbc069c04, 0x587cfc0e, 0x4292fbac, 0x38c9d470, 0xffac0dff, 0xefebf0c3,
	0x7ce38742, 0x2a0e9c5d, 0xfa08867e, 0xa0fc410e, 0xbe54ee62, 0xf1073768,
	0xcf728123, 0x0f9d76b0, 0xc2365a14, 0x74f3b6db, 0xaf9876ef, 0x59e9f776,
	0xbfb5bf28, 0x0ee2208b, 0xf1adddfb, 0xcbe7c7c8, 0x9896d4d8, 0x8bf4faae,
	0x25767555, 0x96d3b19f, 0xd5abd23c, 0x3d62602c, 0x67de9f51, 0x29f44257,
	0x0ff74c40, 0x70630319, 0x32a543fe, 0x777c0d5b, 0x95303ec9, 0x6ad3d185,
	0x662af6fb, 0x3fb00f9f, 0xf10e7a81, 0x9e24b3bc, 0x92b3e2f0, 0x3f8fd63e,
	0x3ecaaab4, 0xf9fbbf2c, 0x9c8ff50e, 0x4a7a45ea, 0x676a19cc, 0x822412d2,
	0x6e04f6ef, 0x3a514067, 0xaf73ce10, 0x703d7ac4, 0xd1d15ce9, 0x3a780638,
	0x62bde3b7, 0x39cbf00f, 0x1afe5816, 0x18e5cfca, 0xc76a2cf6, 0x578b47fe,
	0xede506c7, 0xed7c41ae, 0x56fabd77, 0x8fc60d9c, 0xc937bed9, 0xbbbf8213,
	0x1af97298, 0x7be2e6ff, 0x299fbd19, 0x1e91bded, 0x2933b5ec, 0xecc76836,
	0xf9c49fdc, 0x7480c520, 0xd6f4215e, 0x7069788b, 0x2b31be70, 0xd48f896b,
	0x3315cd7e, 0xf48626f3, 0x4d098095, 0x1895cd5f, 0x577185e6, 0xa449b12d,
	0x1eb07a3f, 0x2dbe3fa8, 0x55d7f4de, 0x7fea1dbc, 0xf8ed1b26, 0x7cf0c8f9,
	0xebc0a772, 0x54e0fb25, 0x98c697f4, 0x3096f9fc, 0xd2f318e3, 0xdebafd38,
	0x0fb2e55c, 0x6f87ba53, 0x5ab989b4, 0xc951f0c2, 0x3246f7b5, 0xf2f5c80f,
	0x43b2462d, 0xc3fd5d6f, 0xdfa062e4, 0xcb46cde9, 0xd567c01a, 0x3e66f62f,
	0xfaabf706, 0xe8245847, 0xf3f9b69f, 0xfd178f91, 0xbae27642, 0x9e5e6f4f,
	0xb3da0f32, 0x00d58fc0, 0x462da2c7, 0xe5b55eba, 0x8cfd7447, 0xbf45d3e0,
	0x7a8bee48, 0xeb7dadfe, 0x559d7052, 0x87e8797f, 0x9bb62fa8, 0x43fb7d2c,
	0xb24dbd5b, 0x8b910b0f, 0x6a44cf25, 0xac0ddbfa, 0xaea1d70a, 0x6bae499b,
	0xcf006df7, 0x77c304e2, 0xc15a5ff3, 0xf8d1497f, 0xb8138b8b, 0x126e38bf,
	0xf4b6bbac, 0x7b8bf912, 0x1d91440f, 0x9918f7ff, 0xff7f01fc, 0xedfdfaff,
	0x17fa1fd0, 0x843e4ec5, 0x42e1f3e0, 0x9027032f, 0xe6685a1e, 0x153ba1fd,
	0xc68627f2, 0x186f84ca, 0xee1c331f, 0xf78c40ff, 0x7e40de83, 0x8d90f263,
	0xf0dc6183, 0x7f432378, 0x25fe07f1, 0xf7e81863, 0x1f28afbb, 0xa7ac87b7,
	0x41f7359c, 0x198ca447, 0x0a1dd775, 0xd66a1f5e, 0x3f9e1f5e, 0xb9da0cea,
	0x75ed16e1, 0x4a1e6e55, 0x1beffe00, 0x07bdffe4, 0x34747f3e, 0x21e16fac,
	0xd761fb99, 0x236f2fd1, 0xf9d20afc, 0xf06dcacd, 0x2b025bdc, 0xdd3d5d6f,
	0x357c8e90, 0xa06b6248, 0x446afa7f, 0xb8793845, 0xc372e16c, 0x4fb7d018,
	0xed63be90, 0x51f5af8b, 0xba0fc61c, 0xe11f5aef, 0xee7af6ff, 0x6871e59b,
	0xafde8982, 0xb97a83d7, 0xe0f4bef9, 0xb3fbfe98, 0xfed4b13d, 0xb62fdb0a,
	0xd7a2fd73, 0xa7bd7a8b, 0xb787a5c2, 0xa3418ae6, 0x6c124aef, 0xf7a82e34,
	0x6ef7a44c, 0x48159c62, 0x671aed28, 0x7c265d81, 0x5e280679, 0x6fc04f8c,
	0x0ae38a38, 0x65896c62, 0x25835200, 0xf9f51a2f, 0x31d718a4, 0xebf39ebc,
	0xb03186db, 0x35b77dd7, 0x746f501b, 0xcf5e9c48, 0xfd8b451b, 0xf41c6082,
	0xfbfd629f, 0xe21f7812, 0x6fd1d79f, 0xce595bc9, 0x23fac24e, 0x5913cccc,
	0x63def644, 0xbfce0a2c, 0xe345de33, 0xc918cb1a, 0xf7026365, 0xd8faf2fb,
	0x9f98160c, 0x203349f5, 0x5c0b96bd, 0x52cab43c, 0x7bf80a70, 0x6a34aaed,
	0xe7c45fd1, 0x68a27b3c, 0xce489f5d, 0x87bb9442, 0x7a7a7c04, 0xfe5559e4,
	0x5b3d9276, 0x3f5e1e50, 0x5a1559c7, 0xd313d947, 0xf8cfd1b2, 0x367a6da4,
	0x004fcdea, 0x3dda00ce, 0xfe8f1ec5, 0xb39302c1, 0xf17b3877, 0x0f872153,
	0xcff0fb0b, 0x45e22e42, 0xe36c093c, 0xeb831ed8, 0xb5fdd271, 0xbb52a6ab,
	0x1a4ad561, 0x81212977, 0xf8371fde, 0xd01e40a5, 0x997ad4ed, 0xb329fff4,
	0x93d0e281, 0x3b153175, 0xe1670e08, 0x2ebf5094, 0x75f5a141, 0xeb3caeb7,
	0x1ae9e98d, 0x76871ed6, 0x05df1ae7, 0xfa211b00, 0xcaec9a7a, 0xbc6326b1,
	0xe3829ed2, 0xf7a052dc, 0x3bf67236, 0x558fd1b3, 0x8c78ffdf, 0xb5c70f23,
	0xc45f5898, 0xb7144b5b, 0x6f387a2b, 0x7a7e72b3, 0xd04d9568, 0xe7b50fbb,
	0x09f5bf85, 0x7830a3da, 0xb73c5dbf, 0xbb71c637, 0x8b04f515, 0xd692bf21,
	0x67717c01, 0xaf08a39c, 0x82505c43, 0x3ad480ed, 0x1f2128d9, 0x015eb85b,
	0xddfb93ff, 0x2708c1ce, 0x6348724b, 0x4403ff01, 0xfcbba6fe, 0x238e1e80,
	0xbcfacf02, 0x79aada81, 0xbe566183, 0x1609e39e, 0x23cfaf1a, 0x23985ad8,
	0x69e0be5c, 0x6993d72b, 0x6d1c870e, 0x4ace5eeb, 0x647b1f5c, 0x654c8fcc,
	0xa4d05ef6, 0xc369690e, 0x30fa49bc, 0xabcc6aef, 0xe5e82634, 0xf98913ce,
	0x21973c94, 0x52e303c5, 0x1332ae02, 0xf8c9efac, 0x95338214, 0xba46add5,
	0xb40cb895, 0x517d92f8, 0xea0d495e, 0xd0b14860, 0x91912087, 0x63c35f28,
	0x8f11735d, 0xd5d7e603, 0x7f986c9b, 0x4fa8c8f2, 0x2fc048ce, 0xf66727c0,
	0xdff58547, 0x323a0b96, 0x9a07bca9, 0x8c6792f0, 0x67928784, 0xf0859f1e,
	0x8f733c96, 0xe5c48522, 0x091ab53f, 0x2ff6671f, 0xf938a1c9, 0x2bd60883,
	0x0fbcebb7, 0x845ff909, 0x65f68778, 0xabfe7853, 0x61bfef17, 0x8bac7cbd,
	0x0d6f533f, 0xd6d4bfc9, 0x3cbd245c, 0x38236adb, 0x0e5a549e, 0x3e7c00f4,
	0x11d99f39, 0x6eb64bef, 0xcbdd3ca1, 0xdb9196a6, 0x06b53d70, 0xbeff7186,
	0xd03bbf03, 0xf9c1fd03, 0x0fe8feb6, 0xd0fe7b5c, 0xfd788df3, 0x1fd62ac9,
	0xddee9ff1, 0xfffc6120, 0xe1336465, 0x2367cbeb, 0xd2586ad8, 0x232dc3e2,
	0x9bfa01ff, 0xf50c0daa, 0xf0dd7e89, 0x0d21a326, 0x30d1bf5b, 0xf51fd388,
	0x60774a9e, 0x43d2132c, 0x0fe21ba5, 0x67bed8f5, 0x55f8255f, 0xb78c9eb8,
	0x6c96fe11, 0xf9123edd, 0x55b547a4, 0x0a8c7cc2, 0x0bb577d7, 0xbe5ed137,
	0xf676fd62, 0x63e435f2, 0xdbd4bdbd, 0x8e3149c9, 0xaf07a4dd, 0x11ef2f63,
	0xd0bcf87c, 0x7b663613, 0xec93f318, 0x3bf28190, 0x130cba7a, 0xa1f243e3,
	0x206f596f, 0x6ac03a1f, 0xf3ebf7a5, 0xb89bcfa1, 0xb2b66d3e, 0xc8c213d9,
	0x0f217f43, 0x269d8d86, 0x3e4987b4, 0x7a5eac29, 0x25eb863d, 0xa4ed9fd0,
	0xebc2335f, 0x3df830d7, 0x75b9eb8d, 0x8e0f7f9b, 0x8fc84a2a, 0xf00b3746,
	0x9f0699f9, 0x5e2a8f02, 0x183e7c55, 0xf2fc465f, 0x9f2bf0bc, 0x63fad78c,
	0xcf1c89b1, 0x2e3bc60f, 0xdd597ce2, 0x04afede8, 0x3ffe019e, 0x15a4b8e3,
	0x5757934c, 0x7549e9f3, 0x8254c91e, 0xbe5181e6, 0xb5d1272d, 0x3ae308da,
	0xd3fb3307, 0xb4af8fd0, 0xb3bea194, 0x30dbd956, 0x8e78deef, 0xef1b31e7,
	0x3435de63, 0xe7ffe30f, 0x29bca3ca, 0xd319dde2, 0xeba83ed5, 0x9915bb03,
	0x7456edc8, 0x76f77262, 0x45ca26eb, 0x7c98627a, 0x65ba187d, 0xba7a5c23,
	0x6a678d1d, 0x3e3f5bde, 0xa078dc3f, 0x6fc4af73, 0x881fe741, 0xfc6764f8,
	0xa04faa04, 0x830a59fc, 0x33d3d774, 0xea3bfa2b, 0x1978aef1, 0x5f461892,
	0xe8631fac, 0x593ae0a3, 0xdd9c3d94, 0xf3189f19, 0x7eb8e0dd, 0xa0bc7f7e,
	0x0fbf2697, 0xf9ff1a7f, 0xefec6b97, 0xbe7082dc, 0xf45c532d, 0x376a7fcb,
	0xcd585e61, 0xbaf0ab43, 0x028e02bf, 0x95f1dcfd, 0x7af55a81, 0xc62a4fad,
	0xef6cab38, 0x3b8bf255, 0xbf22beda, 0x17e743b8, 0x065defab, 0x31f289ec,
	0xfe218e5c, 0xc799b8bf, 0xfdb332ed, 0xc38010cb, 0xbcc8d07d, 0xf25fe236,
	0xd0bd681f, 0x8e2d88bf, 0xf8a26adf, 0x2f1bd16e, 0xa5c3f00f, 0x660641f8,
	0x8257c10b, 0x42d98a23, 0x615895f0, 0x9d93f4d5, 0x53e3343d, 0xee69e6a7,
	0xd36ebba7, 0x2aa8cfdc, 0xeab3f4d2, 0xcf8cd0ee, 0xda15bb01, 0xd28cf5cf,
	0x34d9ef8c, 0xd5efd351, 0x9e335d3c, 0x7c811c79, 0xb17ce758, 0xcd365bce,
	0x7e678cd5, 0x90f58fc9, 0x67cc8205, 0x10711f9f, 0x45f321eb, 0xef56e1fe,
	0x0b7ccd12, 0x0479b59a, 0x6de023c2, 0x7ec4ab61, 0xa4db788e, 0xdbe55fbd,
	0xed0198d0, 0xfaf6af62, 0x4873ac12, 0xebda9fc8, 0x973835bf, 0xf3ff3fa3,
	0xee5e6d44, 0xdcf5f4ba, 0xdafa3d72, 0x5b7e38fd, 0x8b3bf92c, 0x724798de,
	0xa5a69114, 0xea2da46f, 0xdd17f11b, 0x0fbbaac7, 0xfc06fbff, 0xfcb5dac5,
	0xc29fc7a0, 0x00640f3a, 0xc95eb55c, 0xf15d67ee, 0x0b75b8b7, 0x9fc7a9c1,
	0x1d7e6f1e, 0xbb4756be, 0xb8dea2f6, 0x6642bad4, 0xe0af8f98, 0xad4bc775,
	0xd90f0b97, 0xbdf0f242, 0xffc3cdba, 0x1e4c313e, 0x2beb03be, 0x516fb3b7,
	0x67fbd95f, 0x580443c4, 0x93d0231c, 0xaf9bb20d, 0x832253d5, 0xdebd7779,
	0xdbd05b52, 0x3e92251f, 0xeaa1d60f, 0xf101e9e1, 0x5e113bef, 0xda314eb5,
	0x6f7822e5, 0xc3064047, 0x9d7c317f, 0x87803cea, 0xd18eb853, 0x8c68d665,
	0x5befb6a3, 0xf300f146, 0x273d7125, 0xfc61cfea, 0x2dfbd252, 0xb274cff8,
	0x3d856787, 0x1218973c, 0x95bf31c7, 0xc3d857bf, 0xeb51e6ee, 0xd2b5dd14,
	0x2dea991e, 0x096f589d, 0x9223cfa3, 0xd15da3be, 0xdfd073e9, 0xf1a14911,
	0x1d2e8fc1, 0x780ebd40, 0x78024a8f, 0x5ec16363, 0xf97b414a, 0x2471d12f,
	0xc86f9d6f, 0xc2e05bde, 0xde2db345, 0xa7ac105a, 0x621de1e8, 0x212816b6,
	0x6927dc7a, 0x116365ed, 0x93523ff7, 0x88ad7db8, 0xa152fee1, 0xfe75bbe8,
	0xc789bbba, 0x550d20a5, 0xb03f10be, 0xc6962930, 0x56551fbf, 0x116f7088,
	0xae637df1, 0x946bef44, 0x85ebb224, 0xb885e5f1, 0x96263fde, 0xbd71c3f5,
	0xd10b3e05, 0x39b68227, 0x1363c38f, 0xf9d403fb, 0x52f8e0cf, 0x2da9cb6c,
	0x7c88b24c, 0xa436e58e, 0x072881f7, 0xcb24d7bd, 0x6d4a7f1a, 0xbaf8938b,
	0xd530c78e, 0x8be4d26f, 0x863d0847, 0x1208e1f9, 0xe198c726, 0x30fcc129,
	0x311c8793, 0xb0bc8925, 0x903b8f44, 0x3a0b778e, 0x76279776, 0x83ecb1f4,
	0x13c98737, 0xe6c2d3fb, 0x2823ed89, 0x2a4f0c4f, 0xbe7d2eb8, 0x6d10e918,
	0xb8c3ca0d, 0xe3796ba4, 0x8d37d44c, 0x8e8fedb9, 0x4b78fe46, 0xa08d3fb6,
	0x4689e47f, 0x06ecdadc, 0x78323e3b, 0x09135b33, 0x1b1e45fd, 0x108c95e5,
	0x0516c57f, 0x293ab7e5, 0xefd3f097, 0x085cdf98, 0xe47e07f7, 0x71fcc36c,
	0x8accc9ef, 0x3599bfea, 0x3f438d0f, 0x1b0b3362, 0xf4122caf, 0x47b65d1c,
	0xee4f3946, 0x43097e04, 0xdc49458f, 0x5e3903af, 0xd81b7488, 0xfa84bae9,
	0xa403d544, 0xda2e30ca, 0x593f2067, 0xb8b6fcff, 0x07c8d5a1, 0xf3e1bcfd,
	0x3863c724, 0x728d9eff, 0x3b71a32e, 0x6fa84dda, 0x737aa916, 0x402981be,
	0x7e8249df, 0x3af33693, 0xf5fabb34, 0x5feab2d7, 0xa19f9a31, 0x3934583e,
	0x87798bd6, 0x0f5cbe45, 0x2894e5c1, 0x1df6e2af, 0x517f6276, 0xe3058949,
	0x4c87c75c, 0xb90fb4fa, 0x1deb8c66, 0xeaaa7d85, 0x499fb201, 0x28989754,
	0x8c78eaf8, 0xfd04e08d, 0xe81a3ebc, 0xeaf368b0, 0xe10fb83d, 0xaa32bfe8,
	0x3b931c3f, 0x5364e007, 0x8b2b3900, 0x655855b0, 0xebcc3e11, 0x3cc5931b,
	0xbde0af9e, 0xa77be0e6, 0xf5a0def8, 0x8f32331c, 0x63a5f819, 0x8536bdd7,
	0x3b664bf2, 0x6ba8aff1, 0x0f5d971d, 0x3a50f192, 0x69b4116b, 0x3acb68be,
	0x89bd4758, 0x10d6bf71, 0x8ffc4765, 0x8857698d, 0x153a925f, 0x827be3c4,
	0x0877b4ce, 0xa23325c7, 0xe0619c93, 0xf1b1cb74, 0xdaf9217d, 0x90ab603c,
	0x331af043, 0xe8d8faf1, 0x80d85777, 0x74937f33, 0xf40528ef, 0x77f8d8f7,
	0x7f42e457, 0x51d4d27b, 0xd8f7f00a, 0xe72f778c, 0x9cbfa882, 0xfbf78d34,
	0x0f397bbe, 0x9a4dbffa, 0x1277fbce, 0x9357b3ef, 0x14f28c66, 0xcd16fce0,
	0x21114bfc, 0xcade37c9, 0x70ba8611, 0x589b45f1, 0xf119fc3f, 0xebdf4e3d,
	0x3aced0c7, 0xc3b77ad5, 0x2377a9a8, 0xdf8198c7, 0x62be0b46, 0x07647149,
	0x8dfa0946, 0xffb4fc56, 0x13f660c5, 0x0d616f7e, 0xc01be416, 0x8bafc6d6,
	0x683fbebb, 0x25fcb4d7, 0x095b1839, 0x166c96f4, 0x95fa93e2, 0x768915cc,
	0x3767583f, 0x733b3af0, 0x7855fbe2, 0x8177f7d4, 0x58ab480b, 0x4cdae143,
	0x7570a8f3, 0xa0f08ff4, 0x53f6a93c, 0xea43ab85, 0xdd930a7c, 0x3ebfa48f,
	0x11dae906, 0x412d99db, 0x3f1f9fff, 0x48ee7440, 0xb24a7cee, 0x9c8df487,
	0x5693a78e, 0xcc7ac28c, 0x1a71d906, 0xc4c236e5, 0x613491f7, 0x79ef029c,
	0xc1e5d938, 0x9df01dfa, 0x977c8fdd, 0x343d2265, 0x979b44ac, 0xcbf420b8,
	0xbf39928f, 0xae688f0d, 0xe97c0c3b, 0xd5b121de, 0xf57dde30, 0xc4ed0992,
	0x9309df58, 0x1ddada03, 0xafa84c27, 0xf30fb16a, 0x85366ed4, 0x93ab5bd5,
	0x5a5fc165, 0x567f783f, 0x709307ef, 0x897cc29f, 0x76cb6f2a, 0xfec70c26,
	0x4ab839b2, 0xd90fa6c6, 0x9b1f1c3e, 0x107b6ce9, 0x7dacd9db, 0x34d0b23f,
	0x4bf1ac97, 0x6b455467, 0x7599dafc, 0xecfe9a89, 0xc80ea066, 0x1995ecf5,
	0x4181f8da, 0x4cf00abc, 0xd43fc163, 0x1d05536f, 0x0fada5a7, 0x69953ee0,
	0x3da7a32e, 0xbeb1be64, 0xe1158ad5, 0xa4ec93ae, 0x86cc3d7e, 0x2be0cdcf,
	0x84f15684, 0xb786bfd6, 0xed4624f2, 0xfbf93354, 0xbc07d895, 0x5ecb5656,
	0x3078849b, 0xab777dd1, 0xe2ddf744, 0x524abbbe, 0x7764aeeb, 0x67180b67,
	0x9c3c3aec, 0xff0881b6, 0xf677855e, 0xc4338ad4, 0x57afc28f, 0x06d535d7,
	0x3fae1676, 0x11bef594, 0x63fd9de7, 0xd2e62589, 0x6bb54eba, 0xcfeda8f0,
	0xc1f6d3ac, 0x9e623311, 0xed4af67a, 0xc2c941f5, 0x7d65f69e, 0x4aee9e51,
	0xabd41496, 0xac8bff6a, 0x03f6dff7, 0x4ec94f7c, 0xb2103247, 0xbaa7e4da,
	0x8bb253d3, 0xb87deafa, 0xee48cb5e, 0x39201fc0, 0xeb3e4896, 0x194b0e8d,
	0x1235d1fa, 0x160cedf1, 0x06e42fe2, 0xee5f53c7, 0xcc9e5fda, 0xa47d5aed,
	0xbfd50573, 0x67964976, 0xc530d2e1, 0x581fa0a1, 0x87cf852f, 0xf2e648ac,
	0xe88336f0, 0x8deae01d, 0x7d768a4c, 0x03d7bc52, 0xeffdedef, 0xdfe83c73,
	0x3e062ef7, 0x73dca1b0, 0xd85a337b, 0x5fe0719b, 0x5bd7ffa2, 0xfa4a996e,
	0x859376fd, 0x43b0bbf4, 0x3c70beaa, 0xa343b5a7, 0xfc520f33, 0xfad36e31,
	0xf317a80b, 0x368a3a7b, 0x470f7c00, 0xbc3ff7f2, 0xbee2f253, 0x0382da9b,
	0x81533fa4, 0xb5bdf03d, 0xb68f4269, 0xa555f76a, 0x86435ea2, 0xef405319,
	0xdcab374d, 0x283d20ee, 0x5f0dcbf9, 0xc552fd03, 0x6d33337b, 0x2594af84,
	0x3bae122d, 0xa356798b, 0x42879f1d, 0x6f6c1c98, 0x912f9fd8, 0x0bfef9f4,
	0xb5a7cfe4, 0x63de289b, 0x94efa69d, 0xff3aeb9f, 0x1f9b877f, 0xe9754f96,
	0x357e5c60, 0xcb34f30e, 0xc6fcf576, 0x59b24cfd, 0x2d1b771b, 0x747bb8da,
	0x19fead1f, 0x9dead76b, 0x6a7a83f1, 0xf4704fee, 0x549fdcd5, 0x4fe9ac51,
	0x19a9de71, 0xa1d4ef7f, 0xda447e9a, 0x401e5d28, 0xee89579b, 0xc4abcda3,
	0x9479b5da, 0x3b7e3788, 0x98bc0255, 0x17769ecc, 0x6409a1e0, 0x68359063,
	0x99c6fa47, 0x551b18a9, 0x6d83191c, 0x3f08ff53, 0x0f5349f2, 0xbc47871e,
	0x3f34a3f1, 0xdf8e63cc, 0xc412c666, 0x796f25af, 0x6801cc22, 0x6deabaa2,
	0xcdfd680f, 0x5cb9d23b, 0xb25b6da9, 0x6d02902b, 0x065b56c1, 0x140367f7,
	0x18a3989f, 0x315e8bf7, 0xc6a45f93, 0xd93ceac9, 0x92076599, 0x1c07b9f1,
	0xad613754, 0xc4f982cc, 0x8f224da7, 0x67df0afa, 0x6edad05b, 0xf7c88470,
	0x0fae14e4, 0x8f96771e, 0x7d6bf9c4, 0x9e516560, 0xc26c7d36, 0xafad653a,
	0x59ed0e2d, 0x1363f3a1, 0xd782ebe6, 0x3a539d85, 0xf2aeb0a3, 0x761c8b62,
	0x6292b27f, 0x101d75a2, 0x8fe67d7a, 0xd951f182, 0x9ebea080, 0x6faf9db9,
	0xe91314e6, 0x846c2c13, 0xa7a0dbd3, 0x42ade6bb, 0xef10c1ed, 0x403ba883,
	0xcdc66b7f, 0xa2e3cc9e, 0x28dbd04a, 0xb5cfa0c7, 0x491b33f7, 0xd73e80bf,
	0xd418bf5c, 0xc35f05e7, 0xe19cc773, 0x488f61f7, 0x63f3f5e7, 0xff84a1ae,
	0xe88f01c7, 0x05de3f27, 0xd79f1c6f, 0x480bd7c3, 0xe9ba10fb, 0xe74c4dc7,
	0x1ba17b74, 0x853d3d7d, 0x4b4f97fb, 0xa6542281, 0xf114676e, 0x6bb30ced,
	0xa462a9f4, 0x588d97c7, 0x5bf9989f, 0xfd9da189, 0x6837b68f, 0xfb699e7f,
	0x37dc14fe, 0x9fd96ee9, 0xaaef80c2, 0xe8d5b68d, 0xd85f03c7, 0x6da9efd1,
	0x35fc13f5, 0x786dc52d, 0xb255a6bd, 0xef762aa3, 0xd68230b8, 0xb11bdac9,
	0x3774f7de, 0xb852d970, 0xc537d53f, 0x5db9f046, 0xf7b44ef0, 0x5ebc223b,
	0xf400f909, 0x53b5c212, 0x7fd0cd62, 0x6c39ad7a, 0xc096779d, 0x26b5bef7,
	0xe1aaaf8a, 0x81c75c79, 0x332603ac, 0x5876d1f2, 0x38eb8497, 0xe71a253c,
	0xe864615f, 0x9df0a85f, 0xc71c0acb, 0x1f307ff5, 0x5eb81c02, 0x7c265f3f,
	0xe442b07f, 0xa9181721, 0x89b16d3f, 0xfcef75f8, 0xdf988d93, 0xef9aa0fb,
	0xe0ba1f6b, 0x9bef944f, 0xf75258b6, 0x59f8698f, 0x7f3d57e5, 0x0bb7f9ea,
	0x18dd569f, 0x2293de9f, 0x597d86f2, 0xa079da21, 0xe454f0fb, 0x9c409f9f,
	0x7573f28d, 0xe01531af, 0xd8b46bcd, 0x3f571f71, 0x0a60fbd9, 0xfcbd89ea,
	0x2deaff7e, 0xb637d712, 0x198728e9, 0x4eb6264d, 0x7ae23e42, 0x97a0ba69,
	0xd14a758d, 0xf205ef14, 0xaae52f50, 0xd91839df, 0x8f98edd4, 0xe9beb853,
	0x96da6af7, 0x1b7c2175, 0xd551f829, 0xcc4d7d83, 0xfef29db5, 0xc0263d2d,
	0x79182f3c, 0xcc5b26dd, 0xe767abd7, 0xfed00988, 0x7cff78a3, 0xff6a37c1,
	0x6cffc17e, 0xefc234eb, 0xfbc73358, 0x4afe95a8, 0x5c9a2bca, 0xfee0524b,
	0xabf7ec98, 0xe535ced1, 0xf94059bd, 0x3b236642, 0x7be7c6a7, 0xbcde9f07,
	0x791bd61c, 0x31d1146b, 0x0b06d772, 0xaf6471f2, 0x18575492, 0xf75b53be,
	0x81731b15, 0xc95ed51c, 0x4fed56a3, 0x44c673d8, 0x177d8efb, 0x5c9c9046,
	0xeaeba349, 0x39d24b73, 0xfd89fa1e, 0x12fe6a9d, 0xa832b4f4, 0x0b9f4428,
	0x75dc303c, 0x3cf08a57, 0x7e5af443, 0xd3cfeb1f, 0xfd681be8, 0x4b0faa33,
	0x7b9e6073, 0x0c630e8d, 0xf8fdfbe0, 0xe54fa3a9, 0xc652fee3, 0x5f71bd5c,
	0x4cb9999d, 0x42cfbfb8, 0x34aac0fd, 0xcabbbfea, 0x6663ed46, 0x6f6823e7,
	0xebabeca6, 0xb324fb45, 0xc396709e, 0x190e3a7b, 0x085b5f05, 0xe81d6a5f,
	0x66664f92, 0x87697fb8, 0x154d7544, 0x7a5759fe, 0x63225730, 0xe0fbe21f,
	0xdf2b353d, 0xaf677d23, 0xe30230ba, 0x27d5fea2, 0x5eefb11a, 0xe811a7f9,
	0xfb071c4f, 0xf83d7e41, 0xea1269f7, 0xdc26c391, 0xc579574f, 0x60bcf34a,
	0xf2811ce8, 0x512dd9e5, 0xeb78e9bd, 0xb72a5305, 0xd9410c4f, 0x0073eb0c,
	0x24a4effc, 0xafa33cf0, 0x37d381bf, 0x8255c79f, 0xfb6eda1f, 0x61e90e2a,
	0xe77b695e, 0xa0fe7c4e, 0xd77e50cc, 0x59c67795, 0x63dfe8c2, 0xcdeb2f30,
	0xfead81d7, 0xa79354fe, 0x9b9e1d97, 0x4fbf086a, 0xd729f7ea, 0x1f1413f2,
	0x82949fe0, 0x66ffccf2, 0xade292c2, 0xa3f8f714, 0xfa678e40, 0xb0519e86,
	0xc7d893ad, 0x7d8c78da, 0x77b7e21c, 0xb6df87c7, 0x94f9c5ad, 0x46e31f60,
	0x6107e216, 0xef34c8dc, 0x52bcf0f7, 0x2baa7e56, 0xc9af3acc, 0x660f7b41,
	0x36d57a03, 0x918bba01, 0xf6a36fdf, 0x6c87cefc, 0xa8e63f28, 0x4ed027ce,
	0x8a06deb0, 0x5a3c6a33, 0x1a7767ff, 0x69dde397, 0x53276f1c, 0xc412f1b4,
	0xf0a69f45, 0x0b0e28b8, 0x92f121bf, 0x4bc53afe, 0x782b9466, 0xcfa05f6f,
	0x7ee0614b, 0x2cfcad33, 0x9acd973e, 0xf019cf89, 0x7e97f239, 0x7d0a5f9d,
	0x34f5caa5, 0xdfe46b94, 0xfad72e56, 0x95a68f79, 0xb472897d, 0x856df716,
	0x4fbf1bd1, 0x6cd5f3e3, 0xf72f8462, 0xe9e12b26, 0x2ce4db1c, 0x073cbe07,
	0xbffd6070, 0x4e8ce9c3, 0xcb8cfac0, 0x098d6d19, 0x4dda81ea, 0xdadcf451,
	0x738989fc, 0xca9d1fa0, 0xeb7cfef9, 0x79e23350, 0x7f2e26d6, 0xfb8efbea,
	0x3ca225a7, 0x4d3b1a95, 0xe99fb876, 0x7e87113b, 0x49cee95f, 0xdd872889,
	0x54d7f9c1, 0x65cae701, 0x2e7bf1a3, 0xa67cc3fc, 0xaf737f5a, 0x6ea89bf1,
	0xff1192bc, 0x1ff2bdb6, 0xe7c728b5, 0xb416d17d, 0x4576e79b, 0x77ff507b,
	0x1af08eec, 0x3c3b8a24, 0xced7a0f1, 0x91c7db19, 0xb653b97f, 0xdee77fa0,
	0x9409f67d, 0x112bf747, 0xa5b1e9e8, 0xa02e87be, 0x8df6abdd, 0xd214a33c,
	0xabbff2be, 0xbcacd43c, 0xb522fc9f, 0xd995767f, 0xbcf47a89, 0xd2c4f5c2,
	0xdfc997d6, 0x52f57a5d, 0xcfbdd621, 0x01effaed, 0xffdcd7a8, 0xea00697e,
	0x976bf733, 0xf77de006, 0xe175d1ab, 0xe93595fc, 0xdaa3ef3c, 0x8a23dccb,
	0x85f43f26, 0x86dc8fe0, 0xb7dc0ae6, 0xb2787a59, 0xeab7f31d, 0x065ed2fd,
	0x7a5f9fda, 0x82e25874, 0x021ae790, 0x2f5e054a, 0x7a2c3c39, 0x9e5f087e,
	0xf9aa3348, 0xebca1bc5, 0x40655de0, 0x60271e48, 0xb8c24470, 0xef8501b5,
	0xbc92ad9b, 0xff805f18, 0xfc8e7fa2, 0x89c58ea6, 0x27e475de, 0x2bf74738,
	0xfb2f7ec1, 0x15aa1b3a, 0x10fcfef3, 0xc05a693f, 0x3e008fe0, 0xf08bea9a,
	0x501f7f93, 0xf85f504e, 0x9c2eb34f, 0xc295cd8e, 0xbcfa67e4, 0xb8f51c3b,
	0x7f034f3e, 0xeab708b1, 0xb9d6556f, 0x7d7e10b2, 0xd4f666fe, 0xa43f287b,
	0x06e4dfcf, 0x12d8c314, 0x9af3cfac, 0x46c0dae8, 0xea8bca33, 0x76fd2287,
	0x2fff9184, 0x531eb953, 0x6021aae5, 0x0434ba20, 0x28f9cdca, 0x76ae42cf,
	0xefc53980, 0x937c1a36, 0x423cc59e, 0xa37bd5c3, 0x1abe01fb, 0xf8644c8e,
	0xa58746dd, 0x9f0bdcdc, 0x798f7abb, 0x5f90414a, 0x9ddbeff4, 0xd065f5ca,
	0xf76f084f, 0xfd70145e, 0xafdfecbd, 0xef820d53, 0x7fb6effe, 0x94bf8710,
	0x19f0e3ca, 0xe3c24f3c, 0x50ddbd70, 0xef3ab1f5, 0xaee74149, 0xf90cf8fa,
	0x932f1037, 0x6a993e3e, 0xbe9971a3, 0x47148909, 0x689c991f, 0x7f3ae98b,
	0xb06ec54f, 0x5f9d7416, 0x1edce3f5, 0xc6337ec7, 0x4fbe0e39, 0xa2593dcc,
	0xdfaab57d, 0xe44a76e7, 0x8d2bbb8f, 0xc2a71c5e, 0xf3cc9815, 0x461c53aa,
	0xf414a46f, 0xf1ff550f, 0x44bb7dda, 0x527f55f7, 0x4e031bf5, 0x5c9dc79e,
	0x663fefc2, 0xf8887d76, 0xa48fee3a, 0xf983a5eb, 0xfb9cc675, 0xef7fa033,
	0xf246250f, 0x9549fc2f, 0xe6fef54f, 0xf8cf5f45, 0x6d37ca6f, 0xcaa9fc16,
	0x3e4eb659, 0x2d15fb54, 0xdfb45ada, 0xffbf6889, 0xf5cbf1ac, 0x3efd82f3,
	0xcf8c9a9f, 0x92979231, 0x5c338aa3, 0xf311ee7c, 0x5fa555fe, 0xc2195f60,
	0xb402c59b, 0xbb3bb5cf, 0xcb8d217a, 0xa3f77745, 0x4f5cdc85, 0x76156f9e,
	0xcf25efe2, 0x77fed2bd, 0xbf35f3c8, 0xeaef9bb0, 0x2b2b4cde, 0x4675834c,
	0x328175c9, 0x1bdfbf94, 0xffa7d6c3, 0x710ff022, 0xf78f86ae, 0x180c9967,
	0x78abb917, 0xc129a07e, 0x2fc50ef6, 0xffb4c86f, 0x81c4297a, 0xb92dbfe8,
	0x1ab6a162, 0x676864fd, 0x446c3d6c, 0x4aa332fd, 0xe5137f0b, 0xfbf9e16e,
	0x37e8bd72, 0x28c364cf, 0x97d334af, 0xccfdc160, 0x072dc94d, 0xcf3cae50,
	0x4367b6ca, 0x4dbdafc7, 0x7cf3378c, 0x5782555b, 0xf1a0cf9c, 0xe9d66603,
	0x5fad7dfd, 0x13c8a770, 0xbc1fe775, 0xf5c916d6, 0xe49941ca, 0x4bf316bc,
	0xf26633b7, 0x5ee0bd71, 0x13794919, 0xae10d78c, 0x5e4a56cf, 0x235dc033,
	0x04a67dc6, 0xf544ff28, 0xc6721834, 0xe50521b7, 0xf5b43992, 0x8e679aa3,
	0xd7d4de92, 0x443bac91, 0xdd5ae85d, 0xfd848068, 0x5327881a, 0xd9b4bfd1,
	0x01fe23c6, 0x323ecd3e, 0x78b82fd5, 0x9fc524f0, 0xfaf27633, 0x51fa974f,
	0x3f5e28d3, 0xf434fb12, 0x39d9c879, 0xd867f607, 0xaa375fae, 0xc46c3d6d,
	0xff8ba2b8, 0x563bf3a1, 0xdfcb5da5, 0x47319e50, 0x1cdc79e1, 0xfcc1649f,
	0xe3c08e54, 0xe451b5c0, 0xe3f88f57, 0x07d444fc, 0x4fce9d2a, 0xff3d78e0,
	0xda32e5c1, 0xc547f022, 0x7aeb0912, 0xef1583ed, 0xcdbef065, 0x56e7c36c,
	0xcff7d344, 0x8d165c7f, 0x5a0d7d78, 0xeaf997dc, 0x3e6c2531, 0xfdce90d2,
	0x1b87b00c, 0xbf3192d3, 0x0ad2f22c, 0x60d8c3d8, 0x5cff473e, 0x3767c8ae,
	0x79429841, 0xbebc9dcc, 0x1aee94df, 0xe59ffd45, 0x3fc967b1, 0xf9de5074,
	0xcc6be065, 0xc585f517, 0x37f9fd62, 0xeb01ac51, 0xaec94d45, 0x7e8e4937,
	0x1ca1b066, 0x6754f3c1, 0x91b76cf2, 0x2cd4c47d, 0xc10a73d6, 0x5f699926,
	0x711fdf03, 0x3a63a09b, 0x4f18b1c4, 0xb1933402, 0xd457dcde, 0x98a30a75,
	0x6c3ff382, 0x15bbad74, 0x8a6d48eb, 0x8109357d, 0x6c42713d, 0xe492fad7,
	0xb57175e0, 0xc7d6a4ce, 0x4933abbb, 0x0fbe1ef8, 0xc495d787, 0x9eb5393e,
	0xa4e87ec4, 0xa0fd5722, 0x6b71863a, 0xd9bb265a, 0x29e3a475, 0x673cea61,
	0x4fc89853, 0xeb8aeb68, 0x7c44bcfa, 0x13d6b7fa, 0xd9bb4d6f, 0xfc78db70,
	0x24bb83a9, 0xc50a62e1, 0xaff97f5b, 0xbeb3b238, 0x3b0f644b, 0x8058233a,
	0x3ced8ef2, 0xdfe3eecf, 0xdc4074fb, 0x67621c96, 0xde39522b, 0x1286f8f7,
	0x0c08efff, 0xf7f1c68b, 0x8f6beb89, 0xdf849e4c, 0x0a02796b, 0x8c61cbed,
	0x023b61c7, 0x2dfa294a, 0x5f2e9137, 0x5fa19fa1, 0xdb8a399f, 0xbd1cbd27,
	0x2f22f228, 0x2f019e22, 0xf1e03f43, 0xaf057b97, 0x5e8458a3, 0x48985770,
	0x4ac81e0f, 0x79fcd491, 0xcb3ab86a, 0x1bb24ece, 0xb44b1733, 0xeb86f67f,
	0xc26dad2c, 0xd3f2e96e, 0x6f482315, 0x0eb79776, 0xee6b9ba9, 0x3a8ba4e7,
	0xbf9e3f4b, 0xa16690de, 0xfaeb5af5, 0xa64ba197, 0xd226ffae, 0x30f4ede1,
	0xf389b874, 0x7ef8f677, 0x93bbb8eb, 0xbff9dfbf, 0x57e79efc, 0xfc5fbe52,
	0x7fd387e7, 0x7ffe7137, 0x9fe79efc, 0xe7e33dff, 0xe87a708e, 0x007dd5ff,
	0x7ebf3afa, 0xdebe805f, 0x02c6f11f, 0x487bde0f, 0x87e9df5a, 0xcaf71cd6,
	0xb5540954, 0x198cf092, 0xc198e8ed, 0x76b60ebc, 0x45bbd998, 0x500fee0a,
	0x0671f5f1, 0x0a58cbcf, 0x0112782e, 0xc08ed9cf, 0x93cc44b0, 0x0714660d,
	0x7af24477, 0xe92c5318, 0xbdbf6813, 0xe8227d25, 0xbe6ea6cd, 0x219f5a57,
	0xec6ec2e2, 0xd9667648, 0xfca5e99b, 0xdfb0f1fb, 0x94ba8b77, 0xb7ef95a5,
	0x7d2d8a65, 0x96d7bd22, 0xfc50fe8e, 0xce3d7e3e, 0x085b1ccf, 0x44ee5b2e,
	0xb96d078a, 0xa2a3df08, 0xd51d6bde, 0xd1f3173b, 0xb10bf056, 0xeb01b81e,
	0x5acf1482, 0xbefa9c68, 0x7dfc1eca, 0x84991a8f, 0xadcf5bf5, 0xdb133f7c,
	0x37fc88b8, 0xc8779eb5, 0x47353fe8, 0x27de7aa2, 0x065bff08, 0xb9d3c17f,
	0xbf018982, 0x542c3b05, 0xf07b7c67, 0xdfe1f5bf, 0xdefaf12d, 0xb21f0b72,
	0x8066e317, 0x62aef963, 0x7b19dfe2, 0x12a1ff06, 0x7e7c8ee3, 0xb89747ee,
	0x8e0be452, 0x9a877c89, 0x5aeb502f, 0xc93c891f, 0x40bfcc71, 0x10f98edb,
	0x0c3d0d68, 0x337fdb37, 0x9f2308f4, 0x3f3c4a8f, 0xe78b79e4, 0xf64d8a87,
	0x26fba19e, 0xe75e05e3, 0x42dd79f8, 0x2f3cf7cd, 0x13fc53d6, 0x7e011fd9,
	0x3f637169, 0xe2f9da13, 0x6c28acc6, 0x035e1d0b, 0xcda77896, 0xe9506edf,
	0xd28f8e17, 0x1ed73ac5, 0xdebaa4ec, 0x7f3abacb, 0x1dfe0f65, 0x8fc151e7,
	0xf5183d95, 0xea52f797, 0x1f8c7dd1, 0xd5c39162, 0x5c426693, 0x69ce708c,
	0xf8ab70e2, 0x0db7e99e, 0xd89cf7c5, 0x6d88d9df, 0x50ee5551, 0x5f57b7ca,
	0xcdff4468, 0x81d2f57d, 0x665f29bb, 0x313c61b2, 0x779b5dab, 0xf3c19cbb,
	0xfc4b2fee, 0x48cf4c7b, 0xe2e3e285, 0x8ff10a91, 0xc5246675, 0x932356af,
	0x813fb063, 0x154545fb, 0xcfb14349, 0x3f902726, 0x96d07458, 0x9820a0b0,
	0x5c8eb307, 0xba788c91, 0xcd557d5e, 0x76663da7, 0xfcf481dc, 0x35abeb5b,
	0xbed08e87, 0x2a5d7552, 0x693ad45e, 0x7555f577, 0xe2bb839f, 0x865f66b2,
	0x811ce95b, 0x5de2c7f9, 0x9f624c27, 0x372d25a5, 0xde2d7f58, 0xaeea8179,
	0x5dd59d6a, 0x6afc8177, 0x1dce8e78, 0xa7f20629, 0xb1dc9e83, 0x5f5fd78a,
	0x6db07801, 0x003bf585, 0xfac1dfae, 0xfac1f5b1, 0x55eefaf1, 0xaff5a87d,
	0x67bb53b2, 0xdd6a20d5, 0xaf540bbe, 0xcba3d39d, 0xe7aa48fe, 0xe73b253d,
	0x8feed0f7, 0xdebebea4, 0x7cf14727, 0x91a0fb8d, 0x1f7057be, 0x2efe9332,
	0xc1c9cdf3, 0xc3cbe0f8, 0xbb841cae, 0x216deb16, 0x61de717c, 0x38c04c8f,
	0xc48f69d8, 0xdb715b3a, 0x7fee1319, 0x260255a9, 0xc40187cc, 0xd135b819,
	0xdf02e3bd, 0x8b2bebdf, 0xb75efc44, 0xfffad62e, 0x4b7f62eb, 0x5e658c5d,
	0x23d24f93, 0x63834e45, 0x1d07b60b, 0xf4420b91, 0xaf275ac4, 0xcfcdaca7,
	0xe8dc3923, 0x1f984bcc, 0x05435f32, 0x47585fcf, 0x5e8647e6, 0xe469949f,
	0xb9e2a1e7, 0xbfde6140, 0xedebe6f3, 0xf6f4e19d, 0xf4ccb7f9, 0xcedb48dd,
	0xc4ed3945, 0xdc7cda5f, 0x39f98ada, 0xe7bdfdf8, 0xc5eb0458, 0x7c9a75f3,
	0xe3d5d31c, 0xcdcbcbba, 0x223830a8, 0xcceace29, 0xcfadbb46, 0x33a5319b,
	0x4775db9b, 0xc1af3f06, 0xb106c193, 0x0fb9752e, 0x3e68f799, 0x61569f8c,
	0xd6a17b20, 0x142a8ae7, 0xb3f80ab6, 0x4bd1a568, 0xe50ab975, 0x7117dd04,
	0x28a58363, 0xf8fcf903, 0xdc259321, 0xc57b6abe, 0xf0794d33, 0xb25abdbc,
	0x57aeb2e3, 0xdad99bbf, 0xd6833c36, 0x4e51916f, 0xfa300e52, 0x3d6bb53e,
	0x2ef7ef8f, 0xc34dcd62, 0x37cb1c60, 0xea3ed058, 0x67c86cf3, 0xf3e897e8,
	0x783d9df0, 0xd853aabe, 0x6da442cf, 0xfdc7ce32, 0x3d39f525, 0x76170cff,
	0x7ebcbbae, 0x1af3f0a9, 0xe6d68a2a, 0x18c77d23, 0x8693da18, 0x7e73728a,
	0x06727cc8, 0x28f6cfdf, 0x429307d6, 0x0ebc83eb, 0xaa0bafa8, 0xedb8ae7a,
	0xdf1023cf, 0xa35f411b, 0xf1a7731d, 0xeef141fa, 0x37a883b2, 0xf5f27082,
	0xf6bb4c6d, 0xe30275bd, 0x5fb862eb, 0xa24bb3ce, 0x98d15cfc, 0x11a27bcb,
	0x7bb04e7f, 0xe50ed7a8, 0x3ea0c7d7, 0xe294a31a, 0xa76e3bf7, 0x84cead74,
	0xef49a4f5, 0xefc28d54, 0xf4a78a09, 0x9f788c3f, 0xfda46952, 0x99de9380,
	0xabaf023a, 0xca78aff6, 0x78513596, 0x8f648fbf, 0x8afde1b4, 0x7a3fbc72,
	0xe9331f9b, 0x1eae2c6c, 0xd0e079f4, 0xe6e50529, 0x67abb331, 0x3c5bc006,
	0x2a99d441, 0xe29e9db9, 0xdc64609b, 0xcdd8d49f, 0x525f59bd, 0xaf92e83e,
	0x8947ea98, 0x20a1efb8, 0x778aaf68, 0x0d8b1d81, 0x6aefb1da, 0x586786bf,
	0x83b79f08, 0xac78431d, 0x5e7d7813, 0xd0597f4f, 0xd4bb3bbf, 0xfb461e9d,
	0xa0a8e783, 0x5d694a7c, 0xf30db8ed, 0x5fd1033e, 0x9590f097, 0x996ff96e,
	0x6e84ebe0, 0x05fbb9fc, 0x6fbb76ff, 0x53eff5aa, 0xf1965a67, 0x94df63bf,
	0xf5a97f1a, 0x7b5e3526, 0xda81f047, 0xbfde0406, 0x680c77f3, 0xc77ec35c,
	0x1dff0d60, 0x3a16acc3, 0x8efd4487, 0x9589bf61, 0xfdc24f6d, 0x26bbe2b3,
	0xa4fc93af, 0xb0ff3ffd, 0xfc24b9f1, 0x93c249ae, 0x1e1ec033, 0x9eaf3b26,
	0x3beb573f, 0x2dadf3cb, 0x4d781f7c, 0x5d73f86b, 0x1f7d8462, 0xfaa1eb06,
	0x3b5fd88c, 0x13a88762, 0x5b5e4c39, 0xef2de62e, 0x96f34257, 0x59205b6e,
	0xa5ebb7dd, 0xc79b4f78, 0x596f2eec, 0x5f877eab, 0x3bf1d925, 0x63ce1b9a,
	0xdc3ef83a, 0xd98f35bf, 0x2fdda19a, 0xeb9d207e, 0x892ea989, 0x1b3265ce,
	0x3fb4d59c, 0x0964b77f, 0x6dfbafb7, 0x8b47a7a1, 0x4cafc83a, 0x757e3f9c,
	0xe2fb4487, 0xa43b7bf1, 0xf376affb, 0x557e6def, 0x51b7bfc4, 0x77ea1eeb,
	0xeb06b734, 0x9d9df41e, 0xfa8dfdfa, 0xfdfa8d3d, 0x514d84e6, 0xc3f0fe74,
	0xee3496c6, 0x5e887af7, 0x0f61e00f, 0xb04546d0, 0xfaf270ba, 0x07b28cbb,
	0x203f3f50, 0xfe89bde0, 0x308c89d3, 0x889a53fe, 0x74674f23, 0x8e7c2f1b,
	0x0bc484f0, 0x0bc7d7d4, 0xf1eeab37, 0xcdcfc463, 0xe1adf75d, 0x389bc6fc,
	0xe7be2fff, 0x8e167ff9, 0xe191f56e, 0x959c53cf, 0xaf7d0929, 0x759bf73d,
	0xdb922ef9, 0xf6c926f5, 0x9ea93b87, 0xba7aa46e, 0x629b57aa, 0x32fdfcf9,
	0xdb553eb9, 0x1936d10a, 0x26cbe7c3, 0x641bfb89, 0xb4264147, 0xf36ab77d,
	0xb45afd97, 0x5bdbcbf9, 0xf485e7b5, 0x03cf6bf7, 0x3da83e29, 0xa034a61f,
	0xe0661f3d, 0x30f9ed31, 0xe7b5db83, 0x99f9dcc3, 0xbb987cf6, 0xcbf9b53a,
	0xd44cafbb, 0xe5e9af7d, 0xe7024ce7, 0xd4373e86, 0x2e774f3c, 0x2e77418d,
	0x5cee944d, 0x2839dd1a, 0x4f5cde62, 0x34f9dd0f, 0xb159f5da, 0xe370571e,
	0x7ae7b8f5, 0x7b3de8d8, 0xf1233d7c, 0xf22b47b9, 0x536fd123, 0x4ffe9bbf,
	0x996d67c1, 0xd09979ae, 0x5919ad77, 0xbed57c8b, 0xf31b223a, 0xe935ae2e,
	0x83f01272, 0xbe8911eb, 0x935f2f9b, 0xe67bfb4e, 0x3f27f435, 0xc83988a9,
	0xc8999a4f, 0xf0e79ec2, 0x5bd72670, 0xcc8ceb73, 0xb32f8f14, 0xc4fcf099,
	0x5b124d73, 0xcc4dedc7, 0x2ac3e058, 0x66b0f9c6, 0xaa38e1ed, 0xb3bb0b7b,
	0x5582a398, 0x73a22dd5, 0xbae7f41b, 0x5316b354, 0x64b3cc3a, 0x83c91b7d,
	0xd5179cfe, 0x3cc5b90e, 0xfbda2d35, 0x02feb66e, 0xdacf0b9d, 0xdc67684d,
	0x0ffbdaad, 0x633b0a66, 0x1b947667, 0x66b1fdd7, 0x05cb2ff4, 0x97ace65e,
	0x9c1f582c, 0x7c96d0d7, 0x1de7f42f, 0x52de2994, 0x9cbac2f1, 0xe74053c3,
	0xd83c5fa2, 0x8be7fc8b, 0x8e2a5b36, 0x78f1c573, 0x035c5241, 0x44ccfaf1,
	0xbf3c40d7, 0x5883f3ac, 0x9d87c6fc, 0x7f2062b8, 0x42a07c01, 0xac2cdbf2,
	0x3bcf3430, 0xc14968c7, 0x2d878b3c, 0x5338a34b, 0xbaeabdc4, 0x638866dd,
	0x710fb0e3, 0xf49f5f2a, 0x237444b5, 0x7e09d693, 0xfc07be11, 0xcd638a1f,
	0xfd1abccc, 0xe6b6339f, 0x9d7d7414, 0xafc91a0f, 0x812dbb98, 0x0db98afc,
	0xfe784d43, 0x091ddcc1, 0x79967fb4, 0xae30471c, 0xa278e955, 0x1a40f8a1,
	0x25b73bcc, 0xe96b2ed7, 0x971389a7, 0xe9509d34, 0x743aea76, 0x6e8e153b,
	0xf5cd2f40, 0xfec532d7, 0xf62f410e, 0xbf7d2240, 0xfedf7957, 0xbbef985e,
	0xbf491758, 0x0e35d13b, 0x993d70f0, 0x7789a499, 0x8b5c7a2a, 0xee5ce8e3,
	0x894beb4b, 0x557a7a6e, 0x40de75fc, 0x7d8abefc, 0xdfd0cb18, 0xcd93d998,
	0x67d7089e, 0x66be5c4b, 0x40ac8fd6, 0xd088e73f, 0xb888ef87, 0x45c630e8,
	0x87bfc7e0, 0x8ff41171, 0x0fe8b88a, 0xfb411718, 0xd045c601, 0xffe7129e,
	0x0c0672a9, 0x61fafc40, 0x3fe7f726, 0x57e7a6bc, 0xad3e61a4, 0x95efafe2,
	0xa9782c1a, 0xbbf0dc76, 0xd0ef1b18, 0x2753d3fa, 0x76e9fd6b, 0x1a4465a3,
	0xf5e26bed, 0x3bceb981, 0x6299e335, 0x839e6133, 0x5e0e29f5, 0x3363fb27,
	0xda639e61, 0xf8cd4498, 0x6865361f, 0x5f8517fa, 0xa7a2a13c, 0xcaf4fae6,
	0x9cfe9abe, 0x7804802b, 0x3be247c5, 0xf2b66625, 0xbc459c73, 0x94f31944,
	0xb2e1dd60, 0xf917bf62, 0x64a1f2f2, 0x3d36fd09, 0xcefa545d, 0x3ca064df,
	0xb04dbcee, 0x54ff9846, 0xaf923cf3, 0xe962c7b3, 0x6dc6989c, 0x820f6fc5,
	0x466d89fe, 0xa27657da, 0x3c11f121, 0xb6c4faa7, 0x3efc38e4, 0x3328d5cf,
	0x0b5be93f, 0xde755be9, 0xe9ab0da1, 0x78e60f77, 0x07a8ec23, 0x3cf3ece6,
	0x9f71f6a5, 0x41956d00, 0x7b223939, 0xd1d112fd, 0x3e7e7841, 0x9fe3f292,
	0x02c79919, 0x76bce67e, 0x1267d70e, 0x99fec06b, 0xff7a8fc8, 0x3738e018,
	0x01a179b6, 0x50f929fd, 0x97cde932, 0x5bfc8664, 0x7e919f79, 0x51f1651f,
	0x99f60b79, 0xe9c19454, 0x73efd32e, 0x6823e7b0, 0x9c09d67e, 0x3c56e302,
	0x3af4f117, 0xfea2ef91, 0xd779fb6f, 0x7e453e09, 0x39812cfa, 0x9e580812,
	0x70fcf877, 0x827bd532, 0xe216f4f8, 0x9c531fba, 0x1d0164b7, 0x2de85f3f,
	0x40f6fd24, 0x1e97c932, 0x5c4ca7ef, 0x1e50797f, 0x0cdea0a4, 0xdeff1bca,
	0x9ed19e6a, 0x55bd2762, 0xeb7a8e92, 0xe5237ad4, 0x88e29917, 0x97b8f5e3,
	0xf7d59f88, 0x236c529c, 0x4d53be10, 0xe13df4b9, 0xd932f5dc, 0x3e43e43d,
	0xece3cbde, 0xe30bb20d, 0xe4934f76, 0xcf5db8c2, 0x2d7f2a37, 0x5153da37,
	0xdc42ce6f, 0x17aaee0c, 0x3af3a7ce, 0xb25fda84, 0xcfeb9f8b, 0xc995da4a,
	0xd3d742fd, 0xc69bdfc0, 0x3b9ea3df, 0xfaf79d5e, 0xe9aa3c71, 0xf19ec1e2,
	0x99ce7df8, 0xdbf13223, 0x01e6bc99, 0x2fd74069, 0xfc067b0c, 0xc767fa18,
	0xa0553e7a, 0x6ba449ff, 0xa977e20a, 0x7e367d61, 0x3be1dd1f, 0xf09dc8f9,
	0x182fe7dc, 0x2bf624ed, 0x2c9f4993, 0xce717e79, 0xc42f7d37, 0xcf07bf98,
	0x25d23a3b, 0x5b52ebc0, 0x27cc08cb, 0x614e602c, 0x6c9e3897, 0xc35e78db,
	0x39e791b2, 0xaec6964e, 0xf36dfdc3, 0x938c7974, 0x59555f02, 0x7ea97f5c,
	0x3fa20bc3, 0x1cf9c0cf, 0x77ce2de2, 0xed42eaa0, 0x7dfc52c1, 0xb7a8390f,
	0x0d507b55, 0x85e31776, 0xe3cac87f, 0xe6b303e7, 0x04b71c14, 0xeb86a04f,
	0x7e3c2d0b, 0xe11adead, 0x06d4f8a5, 0x2fc42f96, 0xeb8b2d78, 0x17a62595,
	0x5df6409e, 0x7d7c02c4, 0x1b9f71ba, 0xb9030bbd, 0x42cfed5d, 0x2b0696cb,
	0xe3b46fcd, 0x4245c5fe, 0x259a6b5e, 0x3fd79faf, 0x102e8ec9, 0x76102cf3,
	0xbaaf6f54, 0x5d9d27d8, 0xbbb3a05a, 0x676b59ac, 0xaf3a5e01, 0x0f57855b,
	0x963a33a7, 0x99a4b0f0, 0xd0b1d79f, 0x8e303de5, 0x40ec96e0, 0x2cf02ec9,
	0x0961ce62, 0x3cad8eb8, 0xa7c3d73e, 0x7817575f, 0x70f53ac5, 0xf05fb42f,
	0xf7fc25cb, 0xa7bf6828, 0x3d2a1d6e, 0x4a9bfef4, 0x8e1e8597, 0x893e85df,
	0x35c9f9e8, 0xbed190bf, 0x585f9550, 0xf34ffc0b, 0xea1c73bc, 0x411b45b5,
	0xf906e70f, 0x897996a7, 0x7f32ce4f, 0x6e81fa23, 0xca1c7379, 0xdfc7d2db,
	0xc36e903b, 0xcbdfde18, 0xf3a80090, 0xe2a47f1c, 0xeb3f20ae, 0x7a3d7bf1,
	0x98be28de, 0x73d027a8, 0xcf059f80, 0x4f7df4c8, 0x071138c8, 0x556f087b,
	0xeb098f1e, 0x3f0a55cc, 0x707aee27, 0x3bfe15ba, 0xb785d74a, 0xbbe97f1b,
	0xab267dc2, 0x57ab7f3b, 0xa4fd387c, 0xed46f3ae, 0x7a7a777b, 0x0bebb0a1,
	0xfb43ced0, 0xe997a6e9, 0x364fc5fc, 0xace74cbe, 0x40585e9a, 0xdd3e13fb,
	0xfc11ef34, 0xb74f88dd, 0xbebb23cd, 0x5daae7e8, 0xfd429977, 0xe69ba185,
	0x20fff2fc, 0xa48d6e9f, 0x7dc2f1fa, 0x80ef112e, 0xb67184fe, 0xb25f5c4d,
	0x2e7f5c8d, 0x4057fb42, 0x1c16eff6, 0xd742ff77, 0x21efc82d, 0xde2ec9d7,
	0xe2f5cf3f, 0xfef7982e, 0x3ddb475f, 0x9f8b64b4, 0x7e2d9fe7, 0xcb357fb4,
	0x7e9c70fe, 0x743e4a0f, 0xbdaa27f4, 0xae2b25c7, 0x2b946cd4, 0xe46be761,
	0xf416d92d, 0xf83d840b, 0x2e7be37b, 0x29fc9be2, 0x9b8fef8e, 0xae4f9e38,
	0xdc6f78e7, 0xd4e293d6, 0x927a9b8f, 0xb6f1f51f, 0xf9ef845e, 0xe4df00eb,
	0x7eb4db4f, 0x1be01354, 0x37c405e3, 0x9f7735c0, 0xcedbe04d, 0xf1c4ddf1,
	0x76f3d6cc, 0x7abc177e, 0xfbf51ce8, 0x8ec235ff, 0x9167c17e, 0x3e97f27e,
	0xd9d32edb, 0xa59faa67, 0x627f39fa, 0x3fa14fcd, 0x717be2a6, 0xea2140ef,
	0xaf0dca95, 0x17de21c7, 0x9249e76f, 0x8e66f82e, 0x83bbf454, 0x17e6bfef,
	0x0d2eca8d, 0x25be8bf1, 0x93996a5d, 0xe2d725f6, 0x218564b9, 0xdfd59ffb,
	0x77efd32b, 0x64bcf1b6, 0xcd9bb304, 0xfea64f08, 0x0c5cd777, 0xd97f3ff7,
	0x65acc2eb, 0xbd9dc724, 0x6c577f43, 0xf11bf31c, 0x22d602bc, 0x9a96bed1,
	0x95c5f715, 0xb4873c31, 0x9758e08e, 0x4779edcd, 0xf9366764, 0x3822bb65,
	0x69254fde, 0xc2fe29ce, 0x3c60aed8, 0xd13589e5, 0x1497c6f7, 0x51fa3c7b,
	0x75e01ee3, 0xfa8371bc, 0xa10c2da7, 0xfc2b82ef, 0x5785e29c, 0xf8c58300,
	0x69237efb, 0xe682c41f, 0x5ff75409, 0xd0d0ed08, 0x8f7cddf1, 0xe79b2eb7,
	0xdae38e13, 0x269cf08a, 0xe275fbf1, 0xdbaa349c, 0x478e8e02, 0xbd1ce93a,
	0xfe66c9e3, 0xf14999bb, 0x2e9b4794, 0x988ce1f4, 0x1c6fb403, 0x2b30f1e6,
	0x9eff639e, 0xd2ad0511, 0x8602fedc, 0x4ed3b3c4, 0xc06cc8fe, 0x160dfead,
	0xf1dddf91, 0x78576275, 0x9ed4f482, 0x0a8ee6ef, 0x2c790f9f, 0x9269c79b,
	0x877541c3, 0x0a3b9808, 0xb644ffde, 0xfb175f8d, 0xa066d9dd, 0x73d76c6b,
	0xccebd4e2, 0xad87cfc3, 0xdf7f872e, 0xa14338c1, 0x9a0d90fe, 0xdf89b57e,
	0x71a9e17f, 0x610e37e3, 0x58065dec, 0x297e89ef, 0x9cff71e3, 0xf3ee2f78,
	0x48e78f1a, 0x8855b159, 0xcc2a26bf, 0x536de063, 0xc43fd60c, 0x04e351f9,
	0x620ca6fe, 0x019078fe, 0x73da1bff, 0x1bf5ef14, 0x5e00b7fc, 0x7539e3c7,
	0x9d1e7885, 0xf78168cd, 0x22a42b38, 0xd7aa538c, 0xfd783b7c, 0xbf1b4d4f,
	0x06fa1331, 0x27f38703, 0x03313f3c, 0x8780f5f3, 0x27db0a59, 0x237a7117,
	0x1b56dc5e, 0xbce8fbed, 0x29fda24f, 0xa55e9e6a, 0x9e60ff77, 0x4338e89e,
	0x34f307c0, 0xa6f3e1c5, 0x943af4f0, 0x2dd5c6ad, 0x152f6f14, 0x9554ba72,
	0xf95a6dcf, 0x08e902fc, 0x147b89fc, 0x8866af91, 0xf349d616, 0xa8f78b57,
	0x119fa8e7, 0xf04676f2, 0xc6fe1ff5, 0x7e18b1f7, 0xa72aa36e, 0x7e7c1135,
	0x45e3fdf5, 0x4adb3a7b, 0xe8f0abf3, 0x37a7f3f3, 0x9bb9d3d7, 0x7e637f55,
	0x50ef443e, 0x75324c1d, 0x4bd447ce, 0xb924883f, 0xe96a619b, 0x75d31755,
	0x610e7a9c, 0x79180b25, 0xea6980bd, 0x18e5c3a2, 0x52b2d73a, 0xd9afbfe2,
	0x31eb1651, 0xc6fe63c4, 0xfcada448, 0xeea73f09, 0xdfbe48a3, 0xfdfc6673,
	0xac1fd0e3, 0x7429338c, 0xc40b1eee, 0xf506e6e6, 0x4c99636f, 0x068216e7,
	0xb4758f19, 0xf207ac7a, 0x991d4ffe, 0xfd126d94, 0xfa83be9f, 0xa055f268,
	0xc79bf53f, 0x8efe603b, 0xa7bee2fd, 0x78ef9e99, 0xc7e3e550, 0x8ef8e3c7,
	0x3ffbd5c7, 0xaad7f7e3, 0xfde29ff7, 0x17e7567f, 0xfbba0dfd, 0x7ff775ab,
	0x39e9fbc6, 0x40f78d4f, 0xb39cb2bf, 0x121de574, 0x74c6cefd, 0xd72a2fa1,
	0x95bf09f8, 0x2dbc3d86, 0xc9437e67, 0xcf0dc7f5, 0x7b474e71, 0x8a9ec725,
	0x293d7b45, 0xfd1d31d7, 0xae59218b, 0xa78c1cfc, 0x131e4826, 0x88ec81c4,
	0xb8c7ec97, 0xf4f1f46e, 0x1a7f9e6c, 0xf3d27366, 0x9e61be2a, 0xcf32377e,
	0xe65d39bb, 0xf3237019, 0xebe36d3c, 0xeee7990b, 0x2227991b, 0xea8f0b57,
	0x73cd6d0f, 0xf4f9c74c, 0xb3f55176, 0xf4b87b54, 0xbd1c789f, 0x764b4d74,
	0xd9bfb631, 0x00b0bd99, 0xc81abff7, 0x3d85ba0e, 0x01f6db3c, 0xa3b717df,
	0x00a234cd, 0x91b5c3f7, 0x88fd543d, 0x9ce06eea, 0xfb10639d, 0xfdf0360a,
	0xa339bf55, 0x1a973d20, 0x39fd3e5a, 0xa43bf9da, 0xde57dfb0, 0xde3b9e23,
	0x2d1fefcd, 0xf37511c8, 0x5c7cc77c, 0xc61c88e7, 0x0fa98bbf, 0x6ff36e7f,
	0x2abe3872, 0x379bdd85, 0x036cd620, 0x711e973c, 0xab7ee3d5, 0x8b739b85,
	0x273c4f30, 0xe736bcab, 0x9dacf31b, 0xe3eacf3c, 0x6b4ad679, 0x6f280560,
	0x772fdcf6, 0xc59cd4fd, 0x517fe8d8, 0x164404e5, 0x5088ad9e, 0xf8c8eee5,
	0xfe784361, 0x73ebfb0b, 0xca29fede, 0x078441cd, 0xfb03e9f3, 0x685ea145,
	0x58368dcf, 0x3cbeb1e2, 0x638439e7, 0x68bbc0e6, 0x44594cff, 0xa439ef6c,
	0xc5f118a7, 0x43674cec, 0x8f1f294e, 0xc99710f9, 0xac2f7c9f, 0x4ca6f5c3,
	0x855d56fb, 0x7570aed1, 0xaf0235f8, 0xa858e5cf, 0x4664083d, 0x4385453f,
	0xfbf83f7d, 0xdf30022b, 0xfde935a9, 0xb6a7bbf1, 0x39adb2cc, 0xb7f7c1a5,
	0x471eba65, 0x9ff7d4f8, 0x18deb032, 0x385b7c72, 0xd8f4151e, 0x1ce6e82a,
	0x48473322, 0x587137dc, 0x793fa6b4, 0x8473224c, 0x67276fe6, 0x2b53fa68,
	0x4fc66a7b, 0x7357df9f, 0xa0446c7f, 0x5f842ea4, 0x3c93f7bb, 0x6c4e9f7c,
	0xd3ee146c, 0x4fefa3fb, 0x45efe3ef, 0xdb233c77, 0xbc5db7d1, 0xf1f7d9eb,
	0xf88be0a8, 0x8f9416f3, 0xecde51b4, 0xe33283f3, 0x94385ce7, 0x39d17ad0,
	0x7f027816, 0xfabba117, 0x3ecb52d0, 0x9b803dfa, 0x983a175d, 0x4542ea23,
	0xe0ed08ac, 0x94a3bac5, 0xe18dabaf, 0x93b73aeb, 0xe78b539f, 0x7c0d7f54,
	0x883e0f7e, 0x0f15e17e, 0xb687b7e5, 0xda3aa09e, 0xff1b1ce2, 0x3ef33e7e,
	0x3761fd05, 0x47ffa8b4, 0x078a9e80, 0xb1b4093e, 0xcfd03b7e, 0xfee58dce,
	0x8c8995fa, 0xf13f2225, 0x94c1cefc, 0xe27dfa04, 0x74154da5, 0x144af6bd,
	0x1c8effcd, 0x9e6afda0, 0x47aa2557, 0xb998cd8c, 0x1c6df706, 0x2c14f28c,
	0x7d8ef787, 0xca0a9ef1, 0xfbe0ec9f, 0xefcac649, 0x6d07dc96, 0x3d057375,
	0x0766563f, 0x4613f025, 0x7776e50f, 0x2b7ada2c, 0x5d8dc5ee, 0x3656f687,
	0x893f7bf9, 0x4b14c5fa, 0xcafe25fa, 0xfbbf7a74, 0xbf9e998a, 0x18fdc390,
	0x6b873b63, 0x5d2715f8, 0xbfe0f957, 0xbf34f272, 0x7e4c63ff, 0x45dfc146,
	0x1a33b636, 0x6dcaea3f, 0x7debaad4, 0xd2bfcfb3, 0x931ad9ef, 0xe9bed32f,
	0x0b249337, 0xd1d71fb9, 0xa1f1ddbf, 0x1123c451, 0xfda17fa8, 0x059e8a1f,
	0x00800097, 0x00000000, 0x00088b1f, 0x00000000, 0x7dc5ff00, 0xd554780b,
	0x399ef0b5, 0xce491e67, 0x5e424e4c, 0x27938840, 0x09380409, 0x32c3c30f,
	0xd3c30121, 0x0360cf09, 0x4c67ef0e, 0xa5696c44, 0x8f081cdf, 0x4a86a348,
	0x43bd1501, 0xb5ea58ae, 0x8d62d1fe, 0xd0f0c7d6, 0x838bd41b, 0xaadb5bda,
	0x5045a037, 0x5fb608d4, 0xfcadfdee, 0x4fbdad6b, 0x80926732, 0x3fdedef4,
	0x676f97df, 0x7ecfbd9d, 0x6b5ed7ac, 0xa44fb5ed, 0x93dbaf2c, 0xcdacd8cc,
	0x8933b2ed, 0xd538a631, 0x97009943, 0x16567914, 0x7f057632, 0x1d263226,
	0x0cf7685b, 0xe7b6cc63, 0x30abddb4, 0x2cb280e6, 0x3186bea2, 0x6c044b6f,
	0x2b1e4994, 0x5fa1a363, 0x59ca85b6, 0x67de0ed8, 0xd8c47fab, 0xab16c618,
	0x826cff8c, 0xcc67f449, 0xbb93ed82, 0xa05b0fdf, 0x3fa5e60e, 0x821e08eb,
	0xfcb3d3bf, 0x70df3879, 0x067aab29, 0x19c391fb, 0xdc7fae95, 0xe75e87fc,
	0xf98bfbfc, 0x4db125bf, 0x135bdfd8, 0x30bd8627, 0x8f77a3af, 0xba79291c,
	0xb1e09dfb, 0x76a63b53, 0x3146c37c, 0x9c72fb56, 0x6fac1767, 0x06783f66,
	0x8e4bc770, 0x3d267360, 0x2c249667, 0xa816cd1d, 0xe47775af, 0xb2fc60f9,
	0x6c426257, 0x4afbf438, 0x9c60cc8c, 0x13fc7397, 0xaf652f10, 0xb8b72e0c,
	0x3a2f9261, 0x26ed0664, 0x09bde0df, 0xdf35f79f, 0x251af5e8, 0x37e69c60,
	0xc7a2d2a5, 0x71f803c7, 0x30a59592, 0xbf93a776, 0x3673a4be, 0xa5d73063,
	0x8d8cb19d, 0xc3665804, 0x6f3cc08e, 0x1d34b8f3, 0xb374b9d6, 0xf2c1d685,
	0x585cc12d, 0x8b81ccc7, 0xd79832b6, 0x51ede94c, 0xfd7cc077, 0xdef4150d,
	0x59b5894c, 0xdf7b1912, 0x5f10aac6, 0xfcfe26fe, 0x27c5acb2, 0xe918bc00,
	0xe9b1963f, 0x0add2e65, 0xa9df58f3, 0xa74d7d52, 0xbdbfc687, 0xdae09133,
	0x4b95274e, 0xf3d0873b, 0x5737f599, 0x4e8e78e0, 0xf3c2f32b, 0x13809de5,
	0xe59d5e78, 0x1d00f1ab, 0x8ffb5bfd, 0x7c912bf2, 0xbf915763, 0x56d26f80,
	0xa878dd2a, 0x7990ba3f, 0x491cbf80, 0xe59be23e, 0xd4459650, 0x10fc10af,
	0xd70dbf8d, 0xd17e37c9, 0xca12a97e, 0x6cde02b5, 0x56da3175, 0x24a5cf98,
	0xe3c414cf, 0x00007b86, 0xf9b06e3c, 0xdf305cca, 0x345a0f0d, 0x365b10a0,
	0x8064e5c6, 0xd5ef3197, 0xfc11fdd9, 0x3873b0bb, 0xe7bac0f3, 0xb950e674,
	0x475f9064, 0x39d2583e, 0x3869e05f, 0x2f778095, 0xa4efd7c9, 0x730dca20,
	0x7e715a26, 0x1ece911b, 0xa722609c, 0xd7ef98bb, 0xe700b6b2, 0xc99bf5f3,
	0x9fda1d16, 0xc314fa47, 0xa3fabdd4, 0x7416dcf8, 0xb9f10768, 0x902ae98d,
	0x2b7ed966, 0xcbef01d3, 0xa3f7f4a1, 0x3b3c93a5, 0x8f04731e, 0xe604bb62,
	0xfc46284d, 0xf9f3fac2, 0xb7e05718, 0x3fefc366, 0x5b18b394, 0x1e1e1793,
	0xa5d57682, 0xf005e4a1, 0x6cc7c5de, 0x8feb5fc4, 0x85463dbe, 0xa52d4ffa,
	0xec624ca9, 0x007fd901, 0x7676bae9, 0xc01b29f0, 0xb5fdeeeb, 0x1ba7ac7b,
	0x28722dbf, 0x5bf78657, 0xcc3aaf00, 0xaa51a5b9, 0x5c342a08, 0x6bb0e55c,
	0xe08d7bf3, 0xb7c875f7, 0xef9c77c4, 0x11aebe0d, 0xfc835ffc, 0xfe67ed0f,
	0x403fe01f, 0x2c47edf1, 0xc4a65eb4, 0xdd2d7307, 0x33b6bffc, 0x1769f38b,
	0x1bef07ff, 0x3fd3f807, 0xac43b597, 0xed6dff9b, 0x42f5bc7c, 0xfa77262e,
	0x61e434a8, 0x91ce525a, 0x73fda017, 0xf2c63481, 0xbcef8b18, 0xf21bda95,
	0x0903fd00, 0xff380e51, 0xa01e50db, 0x3fa655fc, 0xf130fc8c, 0x2795165f,
	0x72699340, 0x24e1ef28, 0xbffcf92c, 0x233d3ebb, 0x9319e9f4, 0x0fbdbd3e,
	0xa13bfa7d, 0x5cabbf1f, 0x5172171c, 0xf9b760e1, 0x9fbeb90a, 0x2feeeaed,
	0x27d26b3d, 0x1e8bf748, 0x8ffbf50b, 0xebc5f79a, 0xbf1ff79c, 0x45703ee3,
	0x7ad103ec, 0xa87f419f, 0xa97cbff7, 0xc2fb8820, 0x09f60c87, 0xe317d394,
	0xbec4873c, 0x6c46fb40, 0xfb6af07c, 0x96734fc2, 0x5f63e95d, 0x03ff9960,
	0x87c182fb, 0xf4c7c97d, 0x10a7869f, 0x61673fff, 0x790d5fa8, 0x79058b69,
	0x65b7f981, 0x7bead20d, 0xdf631793, 0xceb4ac90, 0x0437f199, 0xca7b33eb,
	0xf69cb44d, 0x53e0a394, 0xd97c002f, 0xdaf88839, 0x5e432390, 0xe432790c,
	0x8f908564, 0x4d2f211a, 0x9991be99, 0x064e51a3, 0xf3d87a8d, 0x218bf89d,
	0xaa48ad7f, 0x355fc863, 0x97f24650, 0x2afe0fa3, 0xfdbebcc9, 0xbfb44f22,
	0xcf4d7f16, 0x7fbb53b4, 0x474d7f20, 0x5fc2f4fc, 0xdff9f033, 0x5f065fcb,
	0x3c237f4d, 0xbef883ca, 0xbce1a5d1, 0xfa66f9a2, 0x309fbe15, 0xebc82b87,
	0xafd442f5, 0xdb82f93d, 0x355e8617, 0x7ba0d7f8, 0xbd847d17, 0x0fe902b0,
	0xde59fde5, 0xef8eb80d, 0x5247774a, 0x442deed8, 0x764d87fa, 0xe5f65f42,
	0x4faf330f, 0xfcc8acaf, 0x41a57a6e, 0xd07ffdd0, 0x83e86cbe, 0x77fcf7ce,
	0x0cb33ce8, 0xf0801cfe, 0x1d379f69, 0x80bf79e8, 0x287d77f5, 0x8c4bf33f,
	0xbc9bb7fa, 0xf813ea32, 0xe08d1c73, 0x83c24e65, 0x9709df80, 0x0fe9fb43,
	0x58ebd574, 0xbc42793f, 0xd1799f78, 0x1fda3154, 0x1b870cce, 0xe26fff69,
	0xcbb7f278, 0xf01161be, 0x115d8028, 0x7c144970, 0xcb77b780, 0x7ea54ced,
	0xa0ce5c82, 0xc2314b7f, 0xa0ba7f46, 0x65c4f7af, 0xd52cf3c0, 0x9d0176c2,
	0xbe0e936a, 0x50e8197a, 0x9f016ad3, 0xfa0f0227, 0x09de7c9f, 0xb45f07a0,
	0xc23ff808, 0x6ec61cde, 0xb7e1c23d, 0xa4d47e0e, 0xe05fa2cb, 0xdd02f5ef,
	0x578b16b6, 0x97d6fe82, 0x99598258, 0x56fdf13d, 0xf3199f17, 0xfcd4ad81,
	0x5d27b33e, 0x6f48fbdf, 0xde8b3f7a, 0x63ae390f, 0x981305fc, 0xdd8bd837,
	0xd7a167fc, 0xf7c547ca, 0xa679ff5a, 0x0dfff1c4, 0xf0f8c6c0, 0x3fac0e68,
	0xfd7c8bd8, 0xb61b8c45, 0xaf3e055a, 0xc37e2134, 0xdfdf0376, 0x4ddf2136,
	0x4f8bac66, 0x7c606f90, 0xeb7f370e, 0xcbe1c86b, 0xebe146f5, 0xa77deb6a,
	0xe3779f4b, 0x97a28f4b, 0xfef82ae3, 0xf6f82f7d, 0x5d0fdf98, 0xf41f5e8d,
	0xedf05f78, 0xbd8f836a, 0x978f7e26, 0xf19fc47d, 0xed151649, 0x317ddbeb,
	0x7457e88d, 0x256c67cb, 0x8cc62de1, 0x8bf96ea7, 0xbbf944ab, 0xae8f0bbd,
	0x7d07a8dd, 0x5cf6aed6, 0x86be0d1e, 0x8f81f3f7, 0xf7c6d4d1, 0xbb296407,
	0x0be242f5, 0x8e5827aa, 0x3cb47798, 0x13c144b6, 0xc857e4a2, 0xf40fe91f,
	0x684f0143, 0x9d26d77f, 0xf8227bb1, 0xc7166c64, 0xbe16e7d3, 0x7127843f,
	0xc59c333b, 0xdc5985cb, 0xed152cae, 0xba7166a6, 0xf0236386, 0x109fe660,
	0xeb1131fa, 0x4c2d3c26, 0xb0b9e432, 0x53f00672, 0xcfd79138, 0xaddfce69,
	0xd1c377a7, 0x2e6bcdfd, 0x8895d4ac, 0xa721f5fe, 0x050baf11, 0x0f3616de,
	0x822bad3d, 0xcfb429ce, 0xfc06df90, 0xa83ea3a1, 0xf4b0fe41, 0xaccc8fe4,
	0x47a5fc1e, 0x5db5efbd, 0x3dc1fde5, 0xbd46f7df, 0xd7496ccf, 0xdba0bef3,
	0x56ba288c, 0x3cb5d144, 0xe036ae0a, 0x1aff49a0, 0xeb69797a, 0x3029edee,
	0x4187758f, 0x7e48b2cf, 0x72895f1e, 0xf8354ebf, 0xb5e10277, 0x3a6f9f9b,
	0xeccffb8d, 0xbf5f8316, 0x9ff71bb7, 0xe3c3d44a, 0xa839e1ba, 0x589e0887,
	0xdc8f8de9, 0xbf54bcaf, 0x5f68c1a0, 0xf8f49bba, 0x49bfa336, 0x84741b04,
	0xe892b59d, 0x561de86a, 0x5fdf1a7e, 0xbf7f22fb, 0xe9f26b31, 0x5343caab,
	0x440e5e14, 0xfb547ac1, 0xdfd8d73d, 0xbfbd45b6, 0x31beaa39, 0x051fde0a,
	0x5fdf9837, 0x83c79cb2, 0x203f0096, 0x32e5a221, 0x640e3f9a, 0x5d39d975,
	0xf705b9fb, 0x499837f7, 0x73d7a6ae, 0xd9acf1f8, 0x044a0d95, 0x12a73cdc,
	0x58fc09f5, 0x8c6d2f90, 0xd5ce80ff, 0x5b07e025, 0x4f737a1f, 0x16deb456,
	0xde8fc9eb, 0x7ffd79ef, 0xd1fd9fe0, 0xbb26667e, 0x8664b8e4, 0xde624a8f,
	0x1bd392fa, 0xc0687c15, 0x438c4afe, 0x5e67df4d, 0xa2bbf817, 0x7965717e,
	0x16c45da4, 0xeb189f13, 0xf94fda34, 0xc70915db, 0x5179b17b, 0x5f5063e5,
	0x5b94293d, 0x2756fd07, 0x4bf612f2, 0x5aebf709, 0xf299d711, 0xfdc3e492,
	0x94363ab2, 0x6230a1bb, 0x0f25ac9d, 0x6ef479d7, 0xd7a3e889, 0x096c3f73,
	0x1e154703, 0x3b5e632d, 0xf8fa86cb, 0xc38f4df8, 0x96efc77b, 0xfd3ee136,
	0x297ea6e1, 0xd9818eb8, 0x1e3d9fdc, 0x0aca437f, 0xddc68f80, 0xe8f6fa46,
	0x1e54c9ce, 0x3a3bbc93, 0xd4fec654, 0x14a9535c, 0xe13c7d60, 0x6b59f7e9,
	0x7f00b72a, 0x43cb31ff, 0xaa27f0f3, 0x6f68ad29, 0x43b1b2ef, 0x46979c1e,
	0xf725a5f1, 0xe1768a3a, 0x4d0cb67c, 0xe973fb41, 0xf4a72bcf, 0xb74b7687,
	0xa3b434db, 0x066aadda, 0x6bbfcfce, 0x97eb1db2, 0x7ea5136f, 0x7caf9533,
	0x6ef5cffb, 0x88f1df68, 0xf6866b45, 0xf2dd7d37, 0x578070c6, 0x486b6435,
	0xfec197a2, 0xb39c6157, 0x250707fb, 0x628fcbe0, 0xc59b5eea, 0xbf6c33db,
	0xa9cf1bea, 0xbdb0a359, 0xf6856ea4, 0xda39e0e7, 0x91eee7cf, 0x2f382d9a,
	0x02d62bb7, 0x37f73a4b, 0xb9c97e46, 0xc6208eed, 0xfe2acef1, 0x9c71fbc5,
	0xf4b436fd, 0xc78b39d9, 0x743c016d, 0x4cae6d66, 0x1dcf8feb, 0x139b9e82,
	0x585e8096, 0x1fe2ed62, 0x26564fda, 0xf9b3b870, 0x8043caee, 0x0e0f73c7,
	0x6bbe2376, 0x99ffbdb3, 0xca2af805, 0x9617fef1, 0x7df0c51f, 0xa56f95eb,
	0xff8ed0db, 0x29a5c5ed, 0xb3941718, 0xdcbd3cb9, 0x696534b9, 0xf2b55d84,
	0xe0f89973, 0x2367bb15, 0xd895f7ce, 0x8f8c1641, 0xc3f41f01, 0xe172fab8,
	0x6f3f00b7, 0xf62f75fa, 0xdc5987d5, 0xd3fa3b1e, 0xdf4809e4, 0x45debe6e,
	0x0dfc94fa, 0x77b39380, 0x6f61d6ee, 0x89b1d8ff, 0xd4f6847d, 0xd7147ee6,
	0x1e84ce5d, 0xc7863278, 0xf25ad31f, 0x5d3be322, 0x7fda2872, 0xaf08bba0,
	0x8c7b401f, 0xffa07e87, 0x9e94c5c9, 0x5db957ed, 0x9f171a3a, 0xd2325cb8,
	0x703943e3, 0xdef047ee, 0xb46c47ca, 0x247cac0f, 0x8e077379, 0xcb937c0b,
	0x496bae7a, 0xd5d68db6, 0xfdb25ca7, 0x2213e595, 0x957d95fd, 0xb96fa55e,
	0xefbd911c, 0x4ab972aa, 0xca69fae5, 0xca1f3623, 0x2ed1aad3, 0x5d808d99,
	0x0f5791e2, 0xdd567e21, 0x80ec5311, 0xc47aaf89, 0x776af441, 0xea1574b9,
	0x9c976efd, 0x824de500, 0x3db38bbe, 0x4c499654, 0xb9531676, 0x97b0e30d,
	0xf0019c30, 0xec0f4d85, 0xf9c611bd, 0xdfe70594, 0xe4bbf808, 0xe97a7ce5,
	0x78c41488, 0xf2bd932e, 0xab97d04c, 0x3513d719, 0x2f6d7f27, 0xd7573f85,
	0xfe819aad, 0xeda09ae0, 0xa9f0bb6c, 0x775ef5d1, 0x07130cd8, 0xfcb5fbc0,
	0xedabd811, 0x5a6a2fa4, 0x596aedcc, 0xf41257e3, 0x7e6adb57, 0x95db373e,
	0xc3286e74, 0x60317298, 0xb3aa5d86, 0xda5831e5, 0x0ae4052a, 0x807659d6,
	0x6d5687c7, 0x980e8292, 0x1e3f596f, 0x0038fe3f, 0x7ad3b774, 0x55e01575,
	0xb37ef87b, 0x4e82598a, 0x03e6f3f8, 0x0728c877, 0xfc71666f, 0x1f30b12c,
	0x3147f5f2, 0x0bc6065a, 0x43123e56, 0xe8f55d78, 0x107f7f9a, 0x32df6bde,
	0x9fd22933, 0xc0fc8b5e, 0x899ccaf1, 0xb27cfddd, 0xc81927e5, 0x04ff65f7,
	0x67ac317e, 0x6a7b0255, 0xa9d22661, 0xe947867f, 0xeb6ab76e, 0x1dbc79dd,
	0x3fe0d5f8, 0xe247b92f, 0x1d678b71, 0x8c81ffb4, 0x5b7891ab, 0xdda4edbe,
	0xa62ff7ce, 0xdabb08a6, 0x31bbfa83, 0x67fbc12c, 0x08525ea1, 0x447b7a7f,
	0xec36fcdc, 0x0fe93fab, 0xdaafae3f, 0x366db96a, 0x4761d3f5, 0xb679fe79,
	0x31baf885, 0x4bb5db9b, 0x38c5b432, 0x1cfb9a8f, 0xde4cd6da, 0xcc46348f,
	0x1abafc03, 0xc625786b, 0x1c6fd985, 0xddab4f14, 0x718de316, 0x7de21f93,
	0x95adfa06, 0xc44f6c99, 0xefd43d7e, 0x17d70f7a, 0x193dfcf0, 0xb8b8d79e,
	0x0049ac3e, 0x419c2b7c, 0x97ffd0ac, 0xef3657f8, 0xeef0ffaf, 0xb7c6bbf7,
	0x0c17d774, 0x9bf57c47, 0xf8f3855f, 0x0af24495, 0x04afb8c8, 0x495fbaed,
	0x5e9fd123, 0x29f1cf72, 0x3dd75fa8, 0xabe2a45d, 0x877a9e4b, 0x827587f6,
	0xdf68edce, 0xf0017ee3, 0x253e50d3, 0xb12fc5e4, 0x2d8216ba, 0xa34773a6,
	0x1b1ee6be, 0xf406a9d1, 0x9a8e2a38, 0x7ea7bf2d, 0x14e15c6b, 0xcf35afd4,
	0x1ea0c6da, 0x7fcc5a7e, 0x134196e9, 0x59fe03de, 0x71578b6a, 0xcfaf5a3f,
	0xbebc23b4, 0xf77042c9, 0xc819c97b, 0x7b6d9f8f, 0xf27c8dce, 0x17284c51,
	0x3b8e9df7, 0x5c66b462, 0x73e3ca80, 0x6dcb6d9f, 0x72cdb8c6, 0x40b2ec35,
	0xd98df2fd, 0x3f9fa889, 0xac764354, 0xd325b0ff, 0x5557b08a, 0x95ec2027,
	0x19fc1047, 0xc116aaa8, 0x6e5fa83f, 0xae7a70b7, 0x3db8f27f, 0x9dfbc60b,
	0xbfe7ef58, 0xe30f277a, 0xe119353b, 0x8037dc3c, 0x110379de, 0x68584fcf,
	0x49fdbddf, 0xbc331bc9, 0x23b7de9b, 0xd6be41bd, 0x7edf3a0a, 0x221fb9e4,
	0xf48edfdf, 0x2fc9ee2e, 0xe827b7c0, 0xa70733f9, 0x09fefe30, 0x9f630be4,
	0x0d9b7802, 0x873b36e0, 0x2fe85dff, 0x9fce5e78, 0x27a485eb, 0x7da08f41,
	0x7defcd19, 0xb672f7d1, 0xe2db4f38, 0x597a7d20, 0x3dfb7df0, 0x7e91bacf,
	0xf8eaff9f, 0xae27186b, 0x61760679, 0x2f7c2f4f, 0xeb8b51f0, 0xc9fcd377,
	0xf5c5a87e, 0xdfd7bbba, 0xde42e7c5, 0x9f5f196a, 0x595adeb1, 0x17a8dfac,
	0xd62d7fef, 0x7c099eb9, 0xe5cc191d, 0xca13c84b, 0xc661da2b, 0xfc89fcfa,
	0x073f837d, 0x49f5f0e4, 0x528fc239, 0x1f88dc5b, 0x19ea2fa4, 0x7daf1fe0,
	0xd01bd08c, 0x61a7f3e4, 0x32f411fe, 0x87243fe6, 0x35e82df3, 0x3762426f,
	0x6caddb1d, 0x9ae76f75, 0x1e3872fd, 0xcd4f6ccf, 0x7dfc0568, 0xc4957e06,
	0x11cabf38, 0x637c19e3, 0x2ff6578c, 0xdd70d395, 0xfb087fd0, 0x50fdc637,
	0x9fb1938f, 0x0f97190f, 0x5c86fe63, 0x9a2fd596, 0x76c6e456, 0x0bb2bb9f,
	0xfc7cdd71, 0x952a3921, 0xe007b45e, 0x85ab6f7d, 0x8467d4e2, 0xfb667f1f,
	0x85a5ee73, 0x9f9efcdd, 0xbdc53163, 0xf069e7a2, 0xd33f045f, 0x2e76cb3c,
	0x31b08698, 0x34be68df, 0x27f066f0, 0x764c9cdb, 0xd69f344a, 0xe3b19fa6,
	0x0dcfd178, 0x8c23e57b, 0x3ffca0ab, 0xfc92096f, 0x7227636f, 0x4361f622,
	0xc28fc3af, 0x13ef74c6, 0x35bcbec6, 0xf7e68b27, 0x97b16b29, 0x7f5f1e82,
	0xedc53c3e, 0x6f03b6e9, 0xc5243afa, 0x48e8bc63, 0xbee47166, 0x09e2feb6,
	0x161ad3e2, 0xcd7e81de, 0x99de7b92, 0xe3f22379, 0x422ec12f, 0xb27dbabd,
	0x35ebed1d, 0x418d9687, 0xe06d9f3a, 0x6d85d6fb, 0xfb471fa3, 0x03c36cf8,
	0xf10acb29, 0xe329b2bd, 0xdd92f9e0, 0x8fc74445, 0x1133c262, 0x624bb8ee,
	0xf8def0cd, 0xdf37a343, 0xd778f00a, 0x9eb8090d, 0xca931f0f, 0x7dd045c7,
	0xdf375339, 0x1c98f68a, 0x7c1ca2af, 0xbd57f428, 0xbd65d38d, 0x5d65f3e0,
	0x5967a725, 0x9e1e7d7d, 0x041c7797, 0xc4e789bd, 0x084b4f76, 0x95297dc7,
	0xb05afbec, 0xe912d209, 0xa1ec9a9c, 0xece676d5, 0x9dcf4c5f, 0x49f9e1fd,
	0x5c2ef85b, 0x5cbbc9cf, 0xc7105b45, 0x966337d2, 0xe4963b72, 0x1a57ec03,
	0x625f0bbf, 0x0f8275fc, 0xde33fba3, 0x1dfb436f, 0xff989cf5, 0x9cbf6d85,
	0x85d3fb8f, 0xb889b9c3, 0x8a5e4ffe, 0xe67b4069, 0x5bd71b13, 0x5f60ff46,
	0x5f651c7d, 0xa3b06099, 0xd3f0304c, 0x6bfb66c7, 0x27ebcd2b, 0xca3b6639,
	0x3beacbe0, 0xf323e372, 0xd9d87a04, 0xf9d127ef, 0x26e75f7f, 0xe519efd1,
	0x2c2000c5, 0xb455ec0f, 0x1b7e31ed, 0x875fb7f7, 0x726eded1, 0xef580ea8,
	0x78dfc8c7, 0x91acf4be, 0xfdf9c067, 0x064767e3, 0xf95b9fd1, 0xb657873e,
	0x94788258, 0x4ef7627b, 0x00afdb09, 0x12d52f7b, 0xd9eebf61, 0xe0c51f3d,
	0xd1dfe692, 0x3a5fda1f, 0xa020f3cc, 0x5bb2895a, 0xf9efeb5f, 0x8d5bb3df,
	0x0693c038, 0x21a635de, 0x1b7c0dde, 0xc02bcbfe, 0xddc52517, 0xb022fb78,
	0x8bd6ec9a, 0x5f953f01, 0x37dcce5a, 0x15d9f91e, 0xfcdca1af, 0x6901f5b6,
	0x48fdd220, 0x87e837d1, 0x55e2538e, 0x022fdf94, 0xf2fce89b, 0x4a8ea062,
	0x1c46ee83, 0x4723a6ec, 0x5a2fbde9, 0x1e38be47, 0x89597bde, 0xd06d3d27,
	0xe3af3a33, 0x9a969b4e, 0xa246fb40, 0xdd06fe89, 0x12adf58d, 0xfcc61c79,
	0xa711fd3f, 0x787c177b, 0x7bd71b99, 0x2f7ee1f4, 0xc77a458e, 0xaf68abc5,
	0xf5cfdb9d, 0xfc6779c6, 0xde8033e3, 0x49cc0fe7, 0x572fa061, 0x1f3b9d1c,
	0xc97caf9f, 0xae9da2a2, 0x46e954bd, 0x72cff1bf, 0x12c55bbb, 0xfee10bde,
	0xd425072f, 0xd82ae353, 0x2e3f6c1c, 0xf40f3324, 0xe7067633, 0xe517b19b,
	0x7cf01e20, 0x6e29cf06, 0xc52c4df1, 0x1fa7e02d, 0x78ac77e6, 0x0c3bc79e,
	0xd77e183a, 0x78ceb178, 0x7fe24b10, 0x84acbcf1, 0xc0e4ff3f, 0x7f6167af,
	0xa9b31e17, 0x1e2fef38, 0x6bff51b3, 0xc2b25fc1, 0x730fe778, 0x98e1047f,
	0xee6f944c, 0xe16dac77, 0x1dcd477e, 0xbe3daf36, 0x45967f27, 0x0ebf43b4,
	0xdc70799e, 0x0cff8235, 0xe5eb5dbe, 0xfb0b5beb, 0x9a37ae1b, 0xcb58138f,
	0xb5d3c40e, 0xf2bbf9f8, 0xd66b9cb1, 0x42dbef1b, 0x9f100bc9, 0xe28d2527,
	0x87f07d30, 0x03d45781, 0x7e5dc7c8, 0x9e7e7ed3, 0x5452d89e, 0xf068fc8a,
	0xf46fa187, 0xf71f2c49, 0xcb3b7ad1, 0xdd1cfcc7, 0xbce74b1a, 0x86c78a95,
	0xa49cc2fb, 0xcf4472f6, 0x6fae5cfa, 0xd7ab32a5, 0xbd53fb8a, 0xb448f483,
	0xe5c8ca1e, 0x99105176, 0x931ffa0e, 0x636c12ab, 0x184fe475, 0x10642c25,
	0x7195d7ee, 0x40f17f89, 0x07dc8293, 0xff30cb66, 0x7789f1ca, 0x158c6b65,
	0xe1c83ee5, 0x6da38991, 0xefd72f50, 0xf00e5d9b, 0xe0ef5cac, 0x2f7e88dc,
	0x841d4a1c, 0x43e781eb, 0x486e0172, 0xfac30ff2, 0xfa42bb5a, 0xc74b4bfd,
	0xdd994df0, 0xe4bf4fed, 0x9eb7f0fa, 0xc6ddb86e, 0x8442b432, 0xf2f2f98d,
	0xa8ef5cae, 0xcf9ee4dc, 0x1db63297, 0xf54b1ee3, 0xed0f7d7f, 0x39f1f812,
	0x08b7ce81, 0x54ea5abe, 0xd6574842, 0x65d8bb60, 0xc0698067, 0xf91978b4,
	0x87e09661, 0x51d0e45b, 0x6d80bf7c, 0xc939cf53, 0xa5703a14, 0x1dfadf5f,
	0x19cec030, 0x7c5f01fd, 0x01f58369, 0xcd805b5f, 0xde622536, 0x41aacaa6,
	0xfc5e59af, 0x7ec4ffd7, 0x1ed675eb, 0x56ae7843, 0xcc2c9f91, 0x6502bd6f,
	0x387b9c4d, 0xcfbc35c6, 0xd00a42b9, 0xe2afc371, 0x18d7ff88, 0xd66e0df6,
	0xf2a67f98, 0x7e34b0f5, 0xe0977f8e, 0x2c024fb7, 0xfc440727, 0x0bec7673,
	0x34b1e619, 0x788d5fc6, 0x337d6f5f, 0xe5078363, 0x768ddeb5, 0x494fe7c7,
	0xf586aa1a, 0x8f648ec2, 0x97b90b25, 0xbea11342, 0x99a0b32d, 0x2fc11df6,
	0xf9193317, 0x0716fac1, 0x6fb201e5, 0x0ddc678e, 0xcdd64570, 0x1797fa1a,
	0xb399de9f, 0x80e4e802, 0xceb0ddb1, 0x0967d0a9, 0xb006d54c, 0x41bde744,
	0x75ea07ea, 0x91df3c37, 0xe70640f9, 0xf5c3e633, 0xf031f418, 0x301e83de,
	0x569bda34, 0x3fa1b327, 0xa80ec059, 0xe9bae2e7, 0x7d9d1932, 0xcf0dc390,
	0x06c7b8f2, 0x3182eb0b, 0x1389f36e, 0x9e8bdaf0, 0x2af939a9, 0x6e209dd9,
	0x1cbf49ba, 0xbefbd658, 0x8ed07258, 0xef4fff5d, 0x7a1bf78f, 0x911588a5,
	0x834b823d, 0x368956fe, 0x8f6aa593, 0x7649eb8c, 0x1b0fc86a, 0x454ec91e,
	0xf7858b7f, 0xed183f10, 0xc47e81d8, 0x25323b27, 0x569affc2, 0x03e62658,
	0x3ca00eb5, 0x89ad19c7, 0xd33bba54, 0xc785f9e8, 0xf5c518df, 0xcccfa70d,
	0xa24ea45f, 0x0c5fd43c, 0xc798d2a6, 0x066fc106, 0x04f92f9e, 0x7df24f9e,
	0x4ecb836b, 0x17acbffe, 0x639e53c4, 0x0082c49b, 0xc7393dcf, 0x6295f886,
	0xd23b5f39, 0x0bd3ccac, 0x1e821cde, 0xe6589e31, 0x75ffb489, 0xfced186f,
	0x2e3ea205, 0x9eaa313f, 0x58be6dd3, 0xf56502fe, 0x4bb79c0c, 0x671a601b,
	0x1b4a7ba7, 0x517495f1, 0x89cafca6, 0xcf0fd616, 0xe2a3aa59, 0xb0cd736b,
	0xa457c26d, 0xa2136d5f, 0xe86ccde9, 0xe6bc3a7f, 0x1d066de7, 0x2441580b,
	0x4fe07b1d, 0xc35c9271, 0x026fbd2e, 0x6cdbf3c0, 0x76e1e82c, 0x97ebda1c,
	0xdbe20ebc, 0x6f02319d, 0x21695196, 0x625f1f68, 0xd7825fc6, 0x157eaf8c,
	0xfb24fc66, 0xad4878cc, 0xf7d532ca, 0xd5310ff7, 0x6c5d5c0f, 0x8dd50782,
	0x61bfb533, 0x9c1324d3, 0xb5334fa9, 0x6d986ecf, 0x6e9b7382, 0xbc1fb535,
	0xbea9a97f, 0x54d6b820, 0x06f0f43f, 0xe5ac3c13, 0x23f6a6c7, 0xea9ab75a,
	0x4cbb428b, 0x7edb23f5, 0x87478266, 0xbfb5321f, 0x5366bdf1, 0x27f6d8fd,
	0xcfe3f54c, 0x6f82633f, 0xd4c178ea, 0x31e7627e, 0xdeca5c13, 0x732fb530,
	0x278263be, 0xb5327fab, 0x23ed39bf, 0xcf54fd53, 0xe9faa667, 0x704d97f9,
	0x9c9fdd95, 0xa679aa07, 0xef4d7ff6, 0xfb9e62cd, 0x2f1f0027, 0x216ab248,
	0x80f35380, 0x1758e2ef, 0xfee3a5df, 0x0e5af689, 0x9d3e40cb, 0x11084d2c,
	0x345ab5df, 0xf7a237f4, 0x9f33f927, 0xec67e317, 0x31d90b39, 0xc9df60f1,
	0x7825e311, 0x7620e09d, 0x542afdc3, 0x4bec9c13, 0xad4fb533, 0xfbea98f2,
	0xf54df3fb, 0x266b5703, 0x895d5078, 0x9b0dfda9, 0x533826bc, 0xcfb530af,
	0xe099f06e, 0x532aa6dc, 0xfdfbc1fb, 0xe082faa6, 0xd0fd536a, 0x782675c3,
	0x5326cb58, 0xbaad11fb, 0xd428bea9, 0xd91faa60, 0x478264d6, 0xda9bf787,
	0xd05ef8df, 0xfdb63f54, 0xfc7ea9b0, 0x7c1316f9, 0xa9ab4753, 0x90cec4fd,
	0x27652e09, 0x9ccbed4d, 0x64f04da7, 0xf6a60ff5, 0x319da737, 0x5cf54fd5,
	0xf61bd530, 0xaffcf4c8, 0x7d85cfcc, 0x4ffb5332, 0x24fafbd3, 0xd0fe432f,
	0xf568b19f, 0xf237b01e, 0xf4053c78, 0x848c7b76, 0xf28f8cf6, 0x5131128c,
	0xbc56f40f, 0xc2be216e, 0xe29ab72d, 0x4fb4493f, 0xc1e296d1, 0xe7d81a7c,
	0x6565e8dd, 0x1b7da266, 0xa5676dd7, 0xddf9195f, 0xe89daced, 0xef9f01db,
	0x7aaa9528, 0x99dc1fcb, 0xa7e2edc7, 0xf39bfcf2, 0xf13fa346, 0xb3b414f4,
	0x077d30d7, 0x54b273ce, 0xef0edf18, 0xc7318a9d, 0xaa728c31, 0x23933cf3,
	0x3193beec, 0xbdc5e94d, 0xdbbafdc4, 0xc8f2645f, 0x7c457e88, 0xdfeb02c3,
	0x7dffd110, 0x39c807e0, 0x4005358c, 0xfa46c0ae, 0x78254059, 0xe08d204f,
	0x950f01bd, 0x54f903fb, 0xa8d0143e, 0x84a040fe, 0x5e0347e0, 0x0a818382,
	0x3e039b2a, 0xa058fe7a, 0xc1c7e08a, 0x30f2c65f, 0x3e58cff8, 0xd6307e01,
	0x317e093f, 0x74054fc2, 0x0d025b2a, 0x4099fcf4, 0x0247c113, 0x4dfe09fb,
	0x6b654820, 0x2f9530e0, 0xfea85a04, 0xc12b40c5, 0x0442072f, 0x046d0287,
	0x09840b1f, 0x8f78113e, 0xed02d7e0, 0xce05b654, 0xa07af953, 0x0cdfea83,
	0x4ddc1274, 0x1bfdb34f, 0x454fcf8d, 0x3b09959c, 0x1fe09571, 0xc3edc496,
	0xd8159c95, 0xb6b7c12a, 0xa2bdb049, 0xaf2031fd, 0x47a1f319, 0x13e55f23,
	0x3d79bd5f, 0xffb47bf6, 0x67c09465, 0xc3be7fdc, 0xc634e3c2, 0x06f22efe,
	0xfabdfd8c, 0x2eb7ee2e, 0xcf177b02, 0xe18fde03, 0x3aa5e7f6, 0x71da3e5b,
	0x0d5896d5, 0x754ba5ed, 0x88fb267f, 0x883639e1, 0x3a2f6dc8, 0xf08aee0e,
	0x7de1aadb, 0x4b7fbc2b, 0xa7cd2646, 0xe8d9b59a, 0x5e66547c, 0xc26ae409,
	0x71efff20, 0xc83b587f, 0xad1f93aa, 0x6fd0f304, 0xffc8325b, 0xa97e7c47,
	0x846bc56e, 0x73a3551f, 0xee0e99c2, 0xbf8076af, 0xbebff18a, 0xf22b51f0,
	0x7facfbc0, 0xda3a42f9, 0x4adf15e1, 0x29cfa47e, 0xe30aab9b, 0x790b9f07,
	0x6acf3cfb, 0xe418bf2a, 0xf7f288bf, 0x62dd5757, 0xaff0a02b, 0xf1e3bbdf,
	0xe3bb333b, 0xeba0b73f, 0x2572f609, 0x5f28d8f3, 0xcd5f7991, 0x31e6ae84,
	0x980bc13f, 0xe96de54e, 0x3f60bffe, 0x6090590b, 0x464738ff, 0x9e8aeb6f,
	0xe22c1b17, 0xa6ad83db, 0x7fc33d32, 0x4bcbcf85, 0xf6353af3, 0x975c3ce6,
	0x0ceaaf31, 0xc137bf0f, 0xf9c51e3a, 0xafa5f5fd, 0x7bb259ce, 0x803fc7f2,
	0x269c142f, 0xde7863b4, 0x3a098f51, 0x23ff5f50, 0x1bf9e50b, 0x818d517c,
	0x336f7c42, 0xf244b73c, 0xfa07f009, 0x741d495d, 0x24f80fff, 0xc9f2307d,
	0x83b74958, 0x1aca793d, 0xf9d0b3cc, 0xc63b0af1, 0x01255611, 0xcdf5647f,
	0x7b8bb707, 0xe073c60b, 0x48c1bcaf, 0xcc6fe7d7, 0x978b3ca7, 0x5f107ac7,
	0x0f7e56f5, 0xc45d7f49, 0x97ea8443, 0x38a30fc6, 0x0d359326, 0x1d334de3,
	0xc1dbe87d, 0xa54e7f9c, 0xd4822ad9, 0xa59cf99f, 0x54add054, 0x0b7df3d0,
	0x7d5ebca3, 0xfde11c6c, 0x2f18b1d4, 0x36f6e3e2, 0x72c639a9, 0xf4ddfe15,
	0xc11c817a, 0x67adb5df, 0xd17b78a6, 0x7cc5cbeb, 0xec927e0c, 0x2541ff2e,
	0xfc5dbe72, 0xf8f8815d, 0x77f0026b, 0x39f7f136, 0xe59c673c, 0x802fc4f0,
	0xa09a1db2, 0x27ffeefd, 0xa5c2fc95, 0x3972a34c, 0x0ab951f3, 0xd9f901d8,
	0x23b6efa7, 0x16b2d61d, 0xc97b7e7a, 0xefe414b2, 0xf93f5695, 0x3331ebcb,
	0x597dcf17, 0xac1a7947, 0x96c35e77, 0xad00d357, 0x4f769a73, 0xecee78c6,
	0xb15792e0, 0x72cc7cac, 0x4154f30e, 0xf38fbe5e, 0x6dd4b76a, 0xdfe3001f,
	0xf6e964fa, 0x967cf081, 0xdec4e9c4, 0xf43274e0, 0x41baf449, 0xdf21963e,
	0x4bc135fc, 0x15dc92eb, 0xcad8f966, 0xeea496bc, 0x792ef97c, 0x1ff75929,
	0xc9af5103, 0xa837141d, 0x8891d97d, 0xb8cb5ff4, 0x1af1609d, 0x3ec31171,
	0xebffc460, 0xed86ac58, 0xfefc153e, 0xfc4620e9, 0x19d029fe, 0x7619d1ef,
	0xa7f0cb2b, 0xef776715, 0x27d6b5e3, 0x609e2387, 0xf131ff9f, 0x3b2d47f9,
	0x3f71328a, 0xdda06608, 0xa1c27b62, 0xf69a67d5, 0xae25761b, 0x9f75de3b,
	0xa2a3c78d, 0x792965e7, 0x4ed13fed, 0x8e99d871, 0xef2023e7, 0xdbf20c6c,
	0x5bc93b00, 0xe316a23d, 0x1e7c9366, 0xee6b0e7e, 0x6f9894ff, 0x9fb8dfdb,
	0x307ac3ac, 0x1c73d27e, 0x62397fbe, 0x7d21c7bb, 0x9c68c292, 0x66d30687,
	0x531e35d6, 0xaed1d3da, 0xbfd62bbf, 0xc46be91f, 0xb33f0c81, 0x1c93f32d,
	0xbb8dbb8a, 0xb4fd8d50, 0x2930758d, 0xc52cf493, 0xe1296ec7, 0x8c5bb1f1,
	0xa884d878, 0x5c545878, 0x3de84d86, 0x6be8663e, 0x87f234c6, 0xc6fbd80b,
	0x632e29fa, 0xfb1ec7e8, 0x4c242c2d, 0xc50f6b71, 0x35e2ba31, 0x679e7645,
	0xeb4219e3, 0x79fd0bb1, 0x2deb8faf, 0x2ad4fde3, 0xfe4c6d70, 0x98e59385,
	0x04d50bfc, 0x334baa0f, 0x9361bfb5, 0xa99f54c7, 0xb3ea9be7, 0x9c13341b,
	0x6a6254db, 0xd7bf783f, 0x2b041704, 0x1e87ed4c, 0x61e099f6, 0xf6a6552d,
	0xa6fd5a23, 0x6ad0a2fa, 0xb6c8fd53, 0x3a3c133a, 0xfed4c9bc, 0x5374f7c6,
	0x06f6d8fd, 0xf3f8fd53, 0xa6f8264d, 0xf6a6fd8e, 0xa6833b13, 0x4bf652fa,
	0xf3997d53, 0x593c1369, 0xfed4de7d, 0xdd6fb111, 0xf4d4769c, 0xa4e7aa7c,
	0xf9e9bde9, 0x23f04da7, 0x83946748, 0x83927685, 0x4c1fda99, 0x414eb3ef,
	0xecfe18f7, 0x45abdb40, 0x580f0fa8, 0xa72845c3, 0x33db588f, 0xe2d47cb1,
	0xf80fdad9, 0x29427b24, 0xcb73bb85, 0x72c56c97, 0xd62d8cf0, 0x63d00f64,
	0xb8adc1ee, 0x3ead0e7f, 0x78014d6a, 0x5b33f2d8, 0xebef1053, 0xe22a522d,
	0x3d66637b, 0x97372396, 0x3f50694a, 0x7a92db7a, 0x3637a3d4, 0x36825e9e,
	0x3e641ba6, 0xec83768c, 0xd8dcfe25, 0xdef34adf, 0xf2963a38, 0xa71deeea,
	0xdccce8c8, 0x1b652bbb, 0xddef09c6, 0xe580dc55, 0x83ebb00e, 0xc01ac676,
	0x1772c7ae, 0xf041f5d8, 0xfe9e3651, 0xa3ca0273, 0x699bc37a, 0x73bf7e78,
	0x559aa7d2, 0x98f5fe83, 0xef8027b9, 0x7963931b, 0xa5c0233e, 0x8bdf2760,
	0x85f00932, 0x98b9c4fc, 0x3f0d1ba7, 0x9c97d43f, 0x372f728f, 0xd7bda265,
	0x3f165fa3, 0x445244f7, 0xca9700bf, 0xef5fa5df, 0xf4c9f90d, 0x86fcd7bc,
	0xefbe7c9c, 0x1ab7c85e, 0x979448f9, 0x28744dc5, 0x07892ec1, 0xb638d67d,
	0xf00abfcd, 0x1675ab2a, 0xfb8c2fdc, 0x9f447428, 0x58c4f04d, 0x7bc4d380,
	0x8bfa15f7, 0x180a3d71, 0xf823672e, 0xc0396d25, 0x0fb1fc11, 0xa7367bf0,
	0xdbb63e7b, 0x7a0cbaac, 0x3ecff6c1, 0x1e71834d, 0x4e4b145e, 0xd9bb3ee7,
	0xf915c8be, 0x798c3b25, 0x4347337f, 0x3e4768bb, 0x0c1ee7df, 0x38f82eb4,
	0x2d0ffb07, 0xd4f018f8, 0xf988797f, 0x9a299f41, 0x0a14c34f, 0xebab3d5b,
	0x869cbfcd, 0xfcf03497, 0xba49f8e4, 0x7c83ff07, 0xb5fdc10f, 0x80f75a26,
	0x646fd0e5, 0xb3ae4dfc, 0xea411e60, 0xce0b3ae6, 0x69f5552f, 0x9cc7ce78,
	0x78fba629, 0x5b5e9ba9, 0x4fe831f0, 0x61a7c05b, 0x8374db3b, 0x444e431f,
	0x38ad65f6, 0xbce55d9e, 0xe7e76959, 0xbbd57d4a, 0xa3af5f8b, 0xc562d2bc,
	0x8f474783, 0x07552914, 0x0ff7a17b, 0xdd1a7e04, 0xe315f1e6, 0xe9e840dc,
	0xfbe32acb, 0x3bdf9084, 0xf46c3813, 0x71516773, 0xbbe755ea, 0x4dce999f,
	0xc41c611b, 0x4737e353, 0x46feb89d, 0xfda077cc, 0xf13ed182, 0x0ff3cfe8,
	0xa4f4b2ee, 0x047e0f63, 0x462f8a89, 0xd60f68fe, 0x8ab83c83, 0x5e3f74ec,
	0x0b4ac1f9, 0xac69bdee, 0x9474128e, 0xf26de5d1, 0xafccabf0, 0xa987ccca,
	0x329f337e, 0xf29fdfd9, 0x8d1d05f9, 0x6e9a387d, 0xa9d92bb6, 0xf17764d9,
	0x270dedbc, 0x8fe312ff, 0xe0b37bc0, 0x24d612cf, 0x638c9ca1, 0x604e542d,
	0xc7bf2a61, 0x32f4a83a, 0x1272c655, 0x672ca8d3, 0xb0a72a3e, 0x582b2a3a,
	0x58d39513, 0x5833950b, 0x63f04a98, 0x9531f4a8, 0xb0d9adfc, 0x9739636f,
	0xcf9ca8f9, 0x823ca8ea, 0x5e720c7c, 0xbe089ac5, 0xd950b595, 0x5787f20a,
	0xfd005fb2, 0xa08be586, 0x397cb0df, 0x28654690, 0x3c9e61e0, 0x53e4078c,
	0x51a02279, 0x84a05af9, 0x9780b6ca, 0xa81ebdda, 0x80cdf2a0, 0x8153ca8f,
	0x01c32a2a, 0x3b7bb53f, 0x77ca9ab0, 0xfe547503, 0x9513607b, 0x2a7405ef,
	0xa06818ff, 0xc8ced732, 0xa1f9672e, 0xff80d9a2, 0x5eec8ff4, 0x5bf1d00f,
	0x5ee3c781, 0x1241726b, 0x18664fd2, 0x8fca54f7, 0x1e285313, 0x6b87dd2b,
	0xcb631cf0, 0x14f7be00, 0xa95cd3b7, 0x9503b22e, 0xf30c13a6, 0xed2d5b0e,
	0xf2d01c52, 0x7315fcdd, 0x9527b09d, 0xc5b6c8be, 0xddaf0869, 0xe07d84e3,
	0xeeb85b51, 0xadfea19f, 0x7ea8abc3, 0x6567eb9c, 0x3c7fc00a, 0x9d0f6abc,
	0xea8f3bd7, 0x2efda193, 0xcc5ccd6b, 0xe856fd7b, 0x7455f007, 0x43ba67ca,
	0xa2a67ca1, 0xb84563a6, 0x53ad8d91, 0x1db9998a, 0x6afa05c5, 0xbc6f5d17,
	0x8a4d70f7, 0xfc6eeb84, 0x2cdb9933, 0x84543b3d, 0x7ec8a7f1, 0x7c6ddfad,
	0xfc655d26, 0xab9676c8, 0xa15f77f4, 0x57dc53f7, 0x75f37ffe, 0xaedb3f34,
	0x4ada7f1c, 0x0c477cfe, 0x02736fca, 0x601d2fd7, 0xd33fa287, 0x2dc6e028,
	0x36976459, 0x3f68791b, 0x39bea991, 0x86d4bb56, 0x8a1c96f0, 0x7826343b,
	0xfdb00b63, 0x33d22cf6, 0xf28c71e9, 0x5ed5eecb, 0x72113d53, 0xf7c05c9e,
	0xafa6e551, 0x87a865d5, 0x3c33227f, 0x27e1bec2, 0x0cddb6ef, 0xb76cf378,
	0xf8b748aa, 0x40adde9b, 0x2cdc117d, 0x4e84918f, 0xf4bf5463, 0xee93f471,
	0x79b1ecd5, 0x8883d740, 0x1aabb43a, 0xa01dfe14, 0x3ba2a17e, 0x32edbc61,
	0xd68b13cf, 0xf8c48b67, 0x30a8d756, 0x742ddf9d, 0xf1571c7a, 0x9e031b97,
	0x4e573c0c, 0x612ff589, 0x0aa3cfc0, 0x5eda481e, 0xdb9bb002, 0x0e0a930f,
	0x767bc5cf, 0x74cf228d, 0xfc95927b, 0xe538a570, 0xafd114a0, 0xf0790f62,
	0x0ab15f3c, 0x69eb15b9, 0xf29d27bc, 0xd3ce7b78, 0x763bca63, 0x088f3069,
	0xe228dbbd, 0x8de35d03, 0x8a50701c, 0x8e299f88, 0x19e34690, 0xde3195fb,
	0xbc6fbfae, 0xa4fe457b, 0x8c6b9e31, 0x7b2e7d79, 0x12e7d698, 0xde3186f6,
	0x5ebeb8bd, 0x39ae31f2, 0x722fae1e, 0xebcd1bbc, 0xb4c23973, 0xedc4973e,
	0x76f1ae93, 0x5f5e3ef5, 0xca8dece3, 0xa5ca33b3, 0x02de3c05, 0x0b3b1866,
	0x70774ff4, 0xe4547e7e, 0xeaed1949, 0x513d3f05, 0xdb61f7c8, 0x6c97ae44,
	0xdfba7629, 0x7e729a53, 0xb2b5f237, 0x4fe74ac7, 0x646bd24a, 0x6fa9c92f,
	0x3efc8932, 0x1fcf82d6, 0xf4f7f0b5, 0xf9af7b64, 0xc1037b2b, 0xf6113905,
	0x6756aa5f, 0xd2a87cc1, 0xf1863694, 0x4ec92576, 0x9c9257eb, 0x28ff8c41,
	0x3db0131a, 0xabf00718, 0x0140fe85, 0xe34533cc, 0x649292f2, 0x4a79883f,
	0x6fd055a9, 0x151e3e04, 0xf6e4cc7c, 0xfb88cacc, 0x8a16cf36, 0xeb90a1b8,
	0x8779f9e8, 0x83343c70, 0x3af98eff, 0x5c79631d, 0x01a1d4e4, 0xbacc2fe4,
	0x7e8bd62f, 0x867ba9f3, 0x6bbc1394, 0x9fb39d1c, 0x0a6e343a, 0x76b30ffa,
	0x6c12b34d, 0xef186d61, 0x56ebb598, 0xcf4f3e2b, 0x8eff4466, 0xafd27633,
	0x15ad76b3, 0x053c7fed, 0xf55897db, 0x4138c17f, 0xc70f0fc9, 0x9c641c61,
	0x588199eb, 0x6fb6b29e, 0xdd08efc4, 0x437fb2a2, 0x25b7ccf3, 0xbb2a85d1,
	0x1b2c9ef2, 0x2cbf55fa, 0xcef9a2c8, 0xcf1b5e61, 0x1f91f0c7, 0xf870e13f,
	0xfde15e38, 0x19474b5e, 0x5b7a2b1e, 0x4e5813d5, 0x8d78690a, 0xf9b79599,
	0x2539604e, 0xe68e575c, 0x4d7bc56b, 0x8ef4b027, 0xf112fff0, 0x6307e87b,
	0xe3017f8a, 0x6e68fc64, 0x5937da2c, 0x0f27435b, 0x46d67c52, 0x96f6c4f7,
	0x18241af8, 0xe7c7af6f, 0x6f687dc4, 0xf4959652, 0x6add426b, 0x58a0e75a,
	0xabdceb86, 0x0b1263fa, 0x3d92ef49, 0x1fd83aff, 0x9eba87a8, 0xcfe7f2c7,
	0xdbbe7015, 0x949cfaae, 0xd709856f, 0x3b0a0768, 0xd37991ac, 0x5d942370,
	0xe1c620de, 0x1eb97af6, 0x87ee15d7, 0xe01df362, 0x4d15d08f, 0x653d376b,
	0x23e7364d, 0xfd833983, 0xea1da2ca, 0xe0938c42, 0x618455b5, 0xe1dfe0ff,
	0x743f7c61, 0xcf142929, 0x8f2fe637, 0xec22fe82, 0x6cff9c48, 0x633dfba5,
	0x3c85f7dc, 0xb5d627bd, 0x33fbcfd7, 0x8141fbe6, 0x82bf7c47, 0x1f38ac79,
	0xd607cc49, 0x4f988d61, 0x5f5a3b44, 0x9699bcd7, 0x7a9fefc6, 0xca97bf19,
	0xfac4723c, 0x539f0edd, 0xaad07da2, 0x34baff22, 0xbbf9e52b, 0x7e50df94,
	0xbe3af47e, 0xa9f1e02a, 0x4310e5fb, 0xe69a6c3f, 0xf7972865, 0xa3b25eab,
	0x49cb0164, 0x2792eedc, 0x88b6624c, 0x9349caf5, 0x6834dda8, 0x69c4f18f,
	0xf21a7125, 0xb2d674eb, 0xff76e54d, 0x5f981c89, 0xbbe2632e, 0x5bcf3c5b,
	0x55c3f016, 0x7a6654cf, 0xd3596af0, 0x8bb47cd1, 0xf9495aee, 0x4c36db3b,
	0xa6f9c36b, 0x3471dfe5, 0x5f7dea11, 0x22b3ba71, 0xb81b871e, 0x07e53647,
	0x700d5ff7, 0xdfb639e4, 0x983f030c, 0xa57c1bda, 0xb4542a58, 0xdf71ac23,
	0xf985ceec, 0x7fbe6ecb, 0xe6cb4583, 0x27a9eb0e, 0xc095f07a, 0xb49f41bf,
	0x7f443921, 0x6778e159, 0x1e739a1d, 0x1bf113a7, 0xd5e309fd, 0xde62d883,
	0x14b97d7a, 0xae95fbc4, 0x192cf6ae, 0xa74d1ae9, 0xeec7472c, 0xad7f5c5c,
	0xa3c8f295, 0xc4760af1, 0xb3e44cbc, 0x0f5449f5, 0x1c2f29cf, 0xfaba7b33,
	0xcd837a91, 0xfb56b8f4, 0x37705887, 0x3f353fcf, 0x7e2a4b4f, 0xf9147f3d,
	0xb3271afd, 0xa3773eb9, 0xc318ae99, 0xaa9e3d41, 0x077e20b1, 0x39e97aed,
	0x9cb9a92d, 0x6ae93d29, 0xbf7a5df0, 0xbffcf5de, 0x1e9f3d09, 0x47cb4ea7,
	0x256c9f3d, 0xfe218ffb, 0x92647e00, 0xf8e2ed8d, 0x4f581495, 0x11426c49,
	0xd4bdc9e6, 0x2146fc54, 0xf5252fc0, 0x21eac22b, 0xeefb9cbf, 0x2427800c,
	0xde611727, 0x9fa70ef2, 0x2c0bd7f4, 0xee28f274, 0x27e06d83, 0x9f2dbb42,
	0x212750ef, 0x61a6359d, 0x8f3194ae, 0xcfdc21da, 0xf74dadf9, 0x94ccde91,
	0x7f3f3359, 0x418ae6fa, 0xa16f1e0f, 0xc2d95dbc, 0xead3e8d7, 0x4c5f68ea,
	0x8a0e642f, 0xd0d78763, 0x9631bbbe, 0x5b3543be, 0xc23ef96d, 0x30a62fb3,
	0x5b37f42b, 0xe096d8f3, 0x27b08c79, 0xad9aa8e7, 0xe34d4b14, 0xf9fc9dcf,
	0xcf4bd55c, 0xfe5e6ae7, 0xfb7ee15c, 0x070f553c, 0x4a79bfa0, 0x9bfb07a2,
	0x7d78f9a7, 0xdfea83a7, 0xf70ebf04, 0xae8c6775, 0xce9bfae2, 0xd779f95b,
	0xb7ba58f2, 0x6e295db2, 0xe91cefc3, 0xdfba5655, 0xdd10f606, 0xfaabde43,
	0x7ef21ee8, 0xd71fd756, 0xecd542f9, 0x17bf9406, 0x6f74ac92, 0x95af05e9,
	0x747ff7e1, 0x11efccbf, 0xa1797e0a, 0xebbe9d3a, 0x44c88594, 0x49cdb879,
	0x1e3b60fa, 0xeafb61ec, 0x4f1cfc01, 0x1c1e1bc4, 0x95f9d2a3, 0xe1f621db,
	0xbffedc85, 0xb135827f, 0x70fde502, 0x068fdd0e, 0x9bc932fe, 0xda89355c,
	0x22a13ec3, 0x78d0cfbf, 0xad87f57f, 0xac83c441, 0x5d23bf00, 0x3f74631f,
	0xdbd56f7b, 0x6e10fde5, 0xf38934d2, 0x3205e913, 0xaeab615d, 0x927a5aaf,
	0xaadcb0f0, 0x1e7b52e6, 0x3e5fac97, 0x83c431e9, 0x1c86cf21, 0x400fa82a,
	0xd151945e, 0x7c2346fa, 0xa24d14a6, 0x933c4dfc, 0xd07f3947, 0xc5eb9fce,
	0xc90b9d32, 0x1d487255, 0x03df2dde, 0x90b2bf44, 0xcb354543, 0xb361c14d,
	0xe4243d7c, 0x921641f4, 0x1efa5d71, 0x72b8f746, 0xb194e4a2, 0x47ee0b16,
	0x9f9bd603, 0x15d854bf, 0x21e131d7, 0x72cacf1a, 0xd7a2f7ae, 0xa6aebdd9,
	0x2eb479a9, 0xd0975f2b, 0xcfcab96b, 0x26ae79e8, 0xa60f1e6b, 0xf6df054b,
	0x0e727d00, 0x028860cb, 0x3facaabd, 0x43397d43, 0xcdad4997, 0x0bd26164,
	0x76f75ad7, 0x5e8aaf11, 0x6efaf467, 0x73f12219, 0x8fbf6cb6, 0x32fea3ec,
	0x0db647d9, 0xc08d21e0, 0x5dbed7eb, 0xdda26737, 0x21ddfb3a, 0x77ec6fa0,
	0xce3155ad, 0x7fa107fb, 0xce24576c, 0xfe73775f, 0xc8cea5b5, 0xf2bfbc8f,
	0xfe9311e7, 0xf1ed0430, 0x0e4f972b, 0x5a2771e6, 0xb33eb47f, 0x1e78e50e,
	0x2fce6edb, 0x363e7f1c, 0x9cce1f2a, 0x73b1385f, 0x5c3e5440, 0xdc3e5476,
	0x64fd5350, 0x3e546475, 0x7ca8f8dc, 0x3c1332b8, 0xa9ba7f3d, 0x8e6d4cfd,
	0xe4a5be09, 0x95f6a6fb, 0xfaa665de, 0x4ceb1539, 0x777cf3f5, 0x5505e09a,
	0x2fda9b77, 0xea9bd7f4, 0xa7fabfbf, 0x17d07aa6, 0x9581c6bd, 0xd82fdca1,
	0xd30de696, 0xe040b487, 0xfbecbd7d, 0x44772a92, 0x87dddfd2, 0x2873311f,
	0x8623efa7, 0x9b76121f, 0xc9acaae2, 0x8c0cf74d, 0xdc686bb8, 0x3ffa2734,
	0x152d0e99, 0x16f66ff7, 0xee9837df, 0x4b23c536, 0xed41507f, 0xd1642436,
	0x6043c6b9, 0x60f3fb4f, 0x3f9e41de, 0xab074032, 0xdbd6e31b, 0x037684a0,
	0x3fcced3a, 0x2c1e6232, 0xc57bc796, 0x4f319cb9, 0xf3e38de6, 0xf7cfe18b,
	0x0f309c63, 0x952735fd, 0xe718a5f7, 0x7ec31a7d, 0x9d76255d, 0x05470ff2,
	0xbe61da8f, 0xa23f40db, 0x72f0962a, 0x15b7c63a, 0x82f59e2d, 0x337f2e97,
	0x6af74690, 0xdd21e594, 0x0c965d06, 0x0fe7f47d, 0x9f8afbc2, 0x7ca23c51,
	0x5be7f068, 0x18a93f60, 0xb9f9a1ea, 0x7de78e64, 0xe17c7f8b, 0x84cbea10,
	0x17e7ba14, 0xdb7a9f5d, 0xbd5eafe6, 0x45befd4a, 0x8ac3f83f, 0x78bfbdab,
	0x11ed99d3, 0x5fcd7df5, 0x6f300656, 0xd8641f04, 0x8d57f7cd, 0xdf286ab2,
	0xd9c76bdf, 0x49392e29, 0x0a1bcff2, 0xfee397f0, 0xe13b07eb, 0xbfca2fbd,
	0x10fa8c5e, 0x4d0d579e, 0xd78476a6, 0x652fd22f, 0xa1f4f3e0, 0x3ee3e760,
	0xcd7ac31b, 0xfd17ab8f, 0x1dd5a9cb, 0xd82787e4, 0x6dd7983d, 0xf9d0b673,
	0x5c546b43, 0x6ffd11a0, 0xbbdb9e50, 0x1a5f63fc, 0x143f99da, 0xf44ebffc,
	0xdd3a9cc7, 0xf0512523, 0x439f2960, 0x3fe788fd, 0xd1e1e057, 0xa3e53b04,
	0x83cf2a4a, 0x8a12d496, 0xb0e04807, 0x4b8bb9e3, 0x70bf9309, 0x6b0c6134,
	0xd0a47187, 0x9457aa58, 0xb27f4310, 0x1a3ef11e, 0xdfb312fd, 0x591e736e,
	0xabc8f1f0, 0x0be3cff5, 0x01e31cf8, 0x9a89c63d, 0xf5878e07, 0xb41ce3d1,
	0xae3fee33, 0xa71af674, 0x69687e78, 0xd323d203, 0x66fbbed1, 0x7a77c794,
	0x8946bbd7, 0xc8c1f179, 0x9e50cc78, 0xf0f9895f, 0xc13e08c1, 0x1848f7fc,
	0x20f74c28, 0x64ad8608, 0x33142390, 0x7a13c718, 0xe46bb25e, 0x1ce3189f,
	0x087af210, 0xbdcb0978, 0x0fde9fc2, 0x43e58a72, 0xb0ec9501, 0x085f2003,
	0x50f01a3f, 0x53e40c19, 0xa8d01cd9, 0x0940b1fe, 0xbc078fc1, 0x540e1f04,
	0xc044f950, 0x0c9fcf47, 0x54fc1154, 0x4b654fc0, 0x7f3d3560, 0xf0475026,
	0x8226c091, 0x9f76837f, 0x0d0ae78c, 0x6810be54, 0x0317faa2, 0x397e09fb,
	0x1432a410, 0x8fcf4c38, 0x3e085a05, 0xf8256811, 0xe08840b5, 0x951b40b6,
	0xf4c207af, 0x7bc0cdfc, 0x4eb13c7c, 0x074e28f0, 0x8ba92f00, 0xe3b41eac,
	0x9d2d1752, 0xbef00e5d, 0xd7ee992a, 0x2f942ca6, 0x78be041c, 0x6fc99348,
	0x4adab7db, 0x9abd1bf1, 0xaafb8ddb, 0x51942437, 0x6faa5cfd, 0xbb2588ca,
	0x3b72ff6b, 0x1acaa7d9, 0x15b2af6e, 0x8a57b50a, 0x687faa64, 0xc620dcf5,
	0x0a711aeb, 0xab73fdf8, 0x6c64cf7e, 0xfa4ad4b7, 0x7c547f79, 0x9f4103f6,
	0x5cca860f, 0xa8c70e9e, 0x3587e791, 0xb826092d, 0xfabfb5b6, 0xacdf0471,
	0x8db0e313, 0xfefc8e4c, 0xdffbe7e1, 0xeb0e5f9d, 0x3ff9275c, 0xe2fcbe40,
	0x80f9d9c0, 0x76756626, 0xdc9e51d8, 0x43efbdd9, 0x818b4296, 0xbf8893bf,
	0xf84c9a7d, 0x9c6da7db, 0xc3fe8396, 0x27be9922, 0xfe48ba91, 0x0195fd0a,
	0x7fba650b, 0x2991aca9, 0x5916c7ae, 0xd2363e05, 0x9c2c07ba, 0x0deaf54b,
	0x3c3c526f, 0xf089cd65, 0x004bb464, 0x8744b95f, 0xbbf012c7, 0xfc45fd48,
	0x2c527f74, 0xcf4581e5, 0xdff852c7, 0x3ea6cfc4, 0xec2963f1, 0x890f3f05,
	0xc403d6fb, 0xf1a213f7, 0xf49f7c64, 0x03fdc621, 0xc38f237d, 0x134bb747,
	0x62e62cf6, 0x6a4df7d1, 0x071fd264, 0x3c9ef058, 0xba65c7b2, 0xa4e0fbaf,
	0xc20e67b5, 0xfa14167c, 0x0f3e7093, 0xd0c7cb97, 0xe0ac4fa6, 0x5eb0dffd,
	0x0af91c7e, 0xe3cd75f8, 0xade76ed0, 0xa0f3a769, 0x8e7ba7ec, 0x75d51c62,
	0x7efe81e3, 0xf4dedf31, 0xe3c09e7e, 0x8388af01, 0xfe303cc2, 0x53d9aca6,
	0x9b8f8270, 0x64a6e385, 0xaf1538bc, 0x76e67bf6, 0x0e506c58, 0xc0ef9228,
	0x4fdf1cf1, 0x25e3893b, 0xbc635eeb, 0xbbef1c22, 0x47e329e2, 0xddbda9e5,
	0x1f4beeb3, 0xde0f4b5e, 0xddee2858, 0x5103640c, 0x6b683e0f, 0x7eb378a7,
	0xa641eb9a, 0xb6fdd225, 0xcafa71e8, 0xf02c98d7, 0xcfc1dfd3, 0x9bdfa20d,
	0xe897e5d5, 0x2a038f02, 0xb2697f29, 0xcf43be2c, 0x50de9fc8, 0xb96eab1a,
	0xcfcab9ca, 0xa302ff50, 0xfd831ee1, 0x4fa6f01d, 0x7958fde5, 0x3bb1373f,
	0x54552e08, 0xfcf12afd, 0xf29fa23d, 0x1eefae42, 0xeef575bc, 0xeb9ef0ed,
	0x98e51b0d, 0x6eff24b9, 0x496f3bd2, 0x58a57fe4, 0x8f1cd69b, 0x58856fe8,
	0x809e718f, 0x62281679, 0x5a42b9c6, 0x1140f835, 0x5bde36f8, 0x0fe1e22c,
	0x04c3f37f, 0xda2867ca, 0xddf68318, 0x3e24e63e, 0xb5216c50, 0x8a7f0228,
	0x26e77f85, 0x0b3bfe7a, 0x27f7c6ed, 0x7831d294, 0x3df8c81e, 0x18a3d460,
	0xf9bbf12f, 0xbd168cf7, 0xc6047d3b, 0xe996be4b, 0x4565211c, 0xfcdfbf2c,
	0xe5e52b67, 0x7ee22cbc, 0x9cbdbbdf, 0x61a57bee, 0x7ee17e09, 0x9e0143f4,
	0x216999b0, 0x90afdf7c, 0xa75377bf, 0x6fd2367c, 0xfec15643, 0x14679fc6,
	0x21df1e27, 0x8d77ee9b, 0x0f6e6f3d, 0xfed097f4, 0xb7376b49, 0x3ffa154b,
	0xe412b465, 0xf0905046, 0x7db7f29b, 0x4fb46505, 0x7ffe92c4, 0x9e499358,
	0x1ca51e1f, 0x9d3b76c4, 0x81fa02ec, 0x154e85ae, 0x94d1c0f5, 0xcaabd258,
	0x8fb258c8, 0x731fa677, 0x18e29da2, 0x768aaefd, 0xff8720fc, 0x1fa0c620,
	0x3f359c2d, 0xf1e92c6d, 0x96fbefee, 0x9783bec0, 0x65be0815, 0xcc1ce4ef,
	0x1392b07f, 0xb59c2c1f, 0x27054757, 0x29976bbe, 0x1e7843a9, 0x16bc175f,
	0x4a8d29e3, 0x478c06e2, 0x37ae162a, 0x7fc23b7f, 0x0fea10a8, 0x8c52f55a,
	0x6ba6a637, 0x4f071e7e, 0xf9b2f922, 0x27a842eb, 0x6762b51a, 0x721b7ca4,
	0xbf72bd72, 0x5d8f9c4a, 0xd5affe4b, 0x5e725f6f, 0xaee5c05f, 0xf0df3f2f,
	0x33fba3e3, 0x1b7ff6fc, 0x2edfdfc2, 0xc67eb9f4, 0x1fdeabde, 0x93eb8c36,
	0x30af9112, 0xbe82a92b, 0x6f4b3ee7, 0x523f3197, 0xe6edc61e, 0xca2ec97d,
	0xc997d843, 0xd7071842, 0x81fdf217, 0xa7e20af6, 0x35438a2c, 0x9eaac25a,
	0x219ae78d, 0x0529d20f, 0xbffc2efc, 0x5ab78d17, 0xba7df483, 0xbf063fa0,
	0x98fd0713, 0x719efeec, 0x17bdfe20, 0xf78c9e23, 0x7111edec, 0xef555716,
	0x3a9ba3f1, 0x4ec4f0cc, 0xccca5c33, 0x732971df, 0xaac9e19a, 0xf424be19,
	0xe669cdc8, 0x663d53e7, 0xe6c2c078, 0x2fbf2b18, 0xe328f141, 0xde7e1748,
	0x40d7b8c5, 0x4d4b6401, 0xb033d794, 0x83e93d7d, 0x9066fbc6, 0x5fc747fc,
	0x96dd58d2, 0x9bc60b44, 0x0a53cfcd, 0x53fad34f, 0x01cfcdaa, 0x4738260f,
	0x847785c8, 0xed0c39df, 0x179e3cea, 0xa6f92d99, 0x0d8dd1e1, 0x9416ed78,
	0x8e9cc5f7, 0x537f643b, 0xc769d029, 0x0fca24a8, 0xba707128, 0xfe311476,
	0x2e26f9dd, 0x656aac47, 0xa9f1fa03, 0x3e28b3a3, 0x3fe5dad7, 0xb2bf49fb,
	0x8e291b13, 0xa65aafbf, 0x77f765ef, 0x585eb4ea, 0x1c5325c7, 0x85cbe0ca,
	0xd603bcfc, 0xf587aa63, 0xc3f3325c, 0xc60e88cf, 0xf51e50ba, 0x1ca2f588,
	0x7fed11ea, 0x3f9fc237, 0xc797346c, 0x3931e7c8, 0x57ba36ed, 0x97d3d62c,
	0xa17a1a5c, 0x1b2b9c44, 0x8b5f64f9, 0xb27c8d31, 0xb41f228d, 0xc3c66dd5,
	0x289355d7, 0x7875f04e, 0x17bfac4e, 0xd7b94539, 0x63dcb8f3, 0x43de13b9,
	0xcdfbdeb9, 0x1e38a992, 0xe23d01ea, 0x17af0c7b, 0xbbfc3972, 0xb046caed,
	0xd844c72b, 0xf8fe6795, 0xbb233d78, 0xa9e20672, 0x7e59d066, 0xbf7c5cdf,
	0x5fb175ea, 0x6f9c714b, 0xae97cafa, 0x7547ceef, 0xa8a5bae2, 0x514bbbfc,
	0xf020daf8, 0x497fbc65, 0x5d3c22cd, 0xf6732b6a, 0xf4262785, 0x11fa1323,
	0xab329bbf, 0x64c6ccec, 0xc3d5b18d, 0xefc7cc8e, 0x775acc3d, 0xc0065466,
	0x8710b0fa, 0xc8e6717f, 0xd9fa6840, 0xcbe737b0, 0x0f59feb0, 0x1d3af99c,
	0x2ffd15ea, 0x7601cbf3, 0x6313f38b, 0x7778c6be, 0x46f6e30d, 0x2867a6ed,
	0x1f64c0ce, 0xa7d6439d, 0xfeffc8f8, 0x8dc3a932, 0xc9b503e7, 0xaf4b291d,
	0x376bd7a2, 0x7dfc86fd, 0x634e6986, 0xd187ef30, 0xc8db3e26, 0xe730af6b,
	0x6bddbbb5, 0x4c1dae49, 0xc5df5157, 0x0e74bd38, 0x1e61b7fe, 0xa63ccf9a,
	0x7073f155, 0x67d22e4f, 0xaf4b3ad6, 0xc33ddff6, 0xd0d7fc8c, 0x89971a77,
	0x2539fa7c, 0xe13a9da2, 0x9e671c59, 0xf71dbbd5, 0x5d8ddffd, 0x617c8c94,
	0xed0d29e4, 0xd8f6b7be, 0x3c87dcf5, 0xdfe54234, 0x7f7e1101, 0xa5fff85f,
	0xf1ba8fd8, 0x6578a5ef, 0xe397a27d, 0x6f70ed5f, 0x7427fc41, 0xec2d6ca4,
	0xe83d9d7b, 0xa7eeb510, 0xdb998cf1, 0xe5f212c9, 0xd064f0b5, 0xaadbc8c1,
	0xc97278b7, 0xa50f092e, 0xc711a778, 0xe3c38304, 0xc7cef573, 0x60346f18,
	0xe28f9a7b, 0x2d24b645, 0xeb78f31f, 0xcd7a95bf, 0xf048fe6b, 0x2c7716e3,
	0xddea8dc5, 0x1d1b8a76, 0xb8a2ef75, 0x41d95390, 0x37772978, 0xdb6bcc30,
	0xe85ac996, 0x7951059b, 0xb75cdbbb, 0x3e64faf2, 0x0d536dcb, 0xd6e5c57d,
	0x5ab2ef18, 0xa6f8d57c, 0xcfffcedc, 0xeef55f46, 0x7f3c69c4, 0xfca76dd7,
	0x5ede295d, 0xeefe5bd7, 0x8f4f82f3, 0x7092bae2, 0xa3b2761d, 0x3d38f58d,
	0x9f110f3c, 0xbb73c1c7, 0x97ff4fc7, 0xf3f758c5, 0x7b461e82, 0xa18ea787,
	0xf2fe075e, 0x62951ea0, 0xfb8e9fb9, 0x3e847e44, 0x323fc634, 0xbfef46cc,
	0xead2f82e, 0xacc2fbe4, 0xc6bd2cb7, 0x661ebfd1, 0x32b92eb9, 0x95b665f8,
	0xf218afe7, 0x7bb1573b, 0xab9fdf71, 0xcd7e51a4, 0xf3c0605c, 0xbfed1189,
	0xbbdf80b7, 0x5f8a3594, 0xe27e33be, 0xf800efb3, 0xf1174c36, 0x1b54f6f4,
	0xdb7a3bdd, 0x3ae8bcc2, 0xfa0fe746, 0xd193097c, 0xc665b95d, 0x9a686d99,
	0x284f721d, 0xa8723d46, 0xf786ccad, 0x881ec00d, 0x64fa8e1d, 0xbc76e679,
	0xbaa0b08f, 0x625bbe88, 0x856b71c4, 0xf9249fbe, 0x3c5387e3, 0xe559d3f7,
	0x191dce24, 0x11471df4, 0x97688dc7, 0xca9dda24, 0xa0eace24, 0xd497fd7b,
	0x613f76e2, 0x4473e783, 0x12e913e3, 0x0ec37ff9, 0xc574f08d, 0x3d945915,
	0x8cef091d, 0x787ca16f, 0xe86a3f63, 0x7eac3f23, 0x8683d0b8, 0x81738a7c,
	0x2277e618, 0x8f8b249e, 0x9f8795db, 0x9489e278, 0x9772bb6e, 0x7e8c6fd8,
	0xa85bf2e2, 0x89e44e32, 0xf12f5458, 0x69eaac9f, 0xe1abac3a, 0xefdfbd6f,
	0xeb9c379e, 0x3b992db1, 0x797db0d2, 0x7e86968e, 0x761e7451, 0x3498e67d,
	0xa9fabf94, 0x39aa3ec6, 0x68efe523, 0xf1efde66, 0xb3694fdc, 0xf5f3c8b1,
	0xe78ed2e8, 0xabc95763, 0x8d7b8bb7, 0x758d8e3b, 0xd9bbffe2, 0xf18714a1,
	0x9287753c, 0x95ee4c54, 0xa293a662, 0x45383cf0, 0x456971e3, 0x466a79e1,
	0xccd1ccbe, 0x460f08d7, 0x87b86d3b, 0xfc6a8de7, 0x16ac427e, 0xb23176a4,
	0xaa3cc74f, 0x76462498, 0x7f938c65, 0xdf2e2f9f, 0xf8bd9cca, 0x6dc305ed,
	0x7a7cdefc, 0x51ec9871, 0x38a0f645, 0x4e2b48ec, 0xf8893d23, 0xabbb38c6,
	0xdf745f0b, 0x2e70f560, 0x3ff45d9f, 0x78b9d7ca, 0xf2dcc553, 0xfa0f6891,
	0x7ec70f16, 0xcc4ea595, 0xa35c9507, 0x06dfdaae, 0xfd9ebf41, 0xfd13ce75,
	0x24fec6ad, 0xfd8ab157, 0xffef58d9, 0x98b3704f, 0x1dceb5d7, 0xe296e4f0,
	0xf7198c44, 0xdb7ad3bc, 0x89d28c47, 0x7afd09e7, 0xdb77f7be, 0xb8e60d87,
	0xf785d823, 0xa4d75ca3, 0x94ad7d9f, 0x70bb709e, 0x5ef8ac7b, 0x64efb091,
	0x6edfb795, 0x8d24f7e5, 0xf61980ef, 0x05ce2c9e, 0xb707f6bb, 0x5597cf19,
	0xacb88f1e, 0x44938a30, 0x37e5ebcb, 0x21ee9b8f, 0x15ea3ee0, 0x68963376,
	0x78ed7a0f, 0xd6e5c3fe, 0x53bc6790, 0x55d47a85, 0xa247bfc5, 0x8acd56a8,
	0x24fe0778, 0xcfee35be, 0xb57a915c, 0x7414bea3, 0x6b56a4b3, 0xa84abf24,
	0xf968cb00, 0x66f2903d, 0x81ebca01, 0xa9fb5d69, 0x9093fc4a, 0x9e0fefc3,
	0x66f6ac9c, 0xbeeb5ed7, 0xaeecfb82, 0x4d1f693b, 0xffe8fbe1, 0xed85fdf6,
	0xb8d5f629, 0xcc5ab76f, 0xa105fa7e, 0xf2163f57, 0xe994eae1, 0x85abf5fe,
	0xbf21dffe, 0x2abeacd8, 0xd40e8bb4, 0x47bf26cd, 0xbee03c06, 0xb4c3607a,
	0xff7ff3a8, 0xc847869f, 0x9d83496b, 0x0db4ffbe, 0xcff201fc, 0x8d18e8a2,
	0x06de833f, 0xe7e2aaec, 0x4b7d0661, 0xc8909553, 0x22bb25a3, 0x05a56925,
	0x954a54f5, 0x6177e2df, 0x13d930fb, 0x3c3bb57d, 0x4647ef9c, 0x57fb057b,
	0x5ec57e70, 0xdc249dfe, 0xd9d7e043, 0x6b07fffb, 0x9a30e546, 0xeb09c7e3,
	0xaa9b1f72, 0xb09df9d2, 0xfc8bb76b, 0x94757af0, 0xbef11bd3, 0x39ca3094,
	0xea5f8229, 0x68f388fb, 0x11ecba23, 0x7233bbca, 0x47b425f0, 0x914ecf30,
	0x03c5762f, 0x358fcec8, 0xf8c683d9, 0xdde3e7d1, 0x8f9ce1e7, 0xc8a3ab2f,
	0xc2c7941e, 0x81f60fbe, 0x0df96125, 0xfcd9ffb4, 0x780a94ff, 0x8383f8e8,
	0x143f61f2, 0xe42ed8f2, 0xa5bd2fb1, 0xb97463b3, 0x813b2b6e, 0x4f802e97,
	0xdce9e38a, 0x3a6add34, 0xe1ca314f, 0xd8bd9d62, 0xbe23d927, 0x3f927d9b,
	0x7da7b922, 0xe447f682, 0x1dda3739, 0x88bd08de, 0x64d78776, 0x7fdca89f,
	0xdfc46ab1, 0xd69e6ca7, 0xa9ff5876, 0xbbe9e29b, 0x1ed0a733, 0xebbb062b,
	0xb0726717, 0xeba5967e, 0xfec2117b, 0xfd830463, 0x53e70e35, 0xf16b7cc9,
	0x4b66adff, 0x3cc1d8be, 0xdffe8bff, 0x88e8b5c9, 0xee518d77, 0xb43de276,
	0x5687ba42, 0xd8f9dbd1, 0x40fe2e86, 0x68e22595, 0x7ec07eb4, 0x47aa7c44,
	0xce2a2ddc, 0xae906186, 0x9eecdbfc, 0xf37e77ed, 0x69d7dd34, 0x56da62ac,
	0xf8d55f80, 0x9fa36379, 0x52dd3c91, 0x35938e62, 0x3f18dfe2, 0xbbe8ce5a,
	0x735e9598, 0xe88a9cfd, 0xe39b2cef, 0xb67cf367, 0x91eaf9e8, 0xf7035ff9,
	0x5ab8a5ac, 0x745a788f, 0x79f18d1c, 0x9e3c68a4, 0xd69e23de, 0xff02e338,
	0x055d634e, 0xb7486fdd, 0x466f8c32, 0xbebad9c7, 0x2cbccbbf, 0xf19f7ef2,
	0x85948d5d, 0x509dfe56, 0xf7d5227d, 0x5783a2ef, 0x5ee94d29, 0xac1dca57,
	0x49c53dab, 0x65d7def5, 0x0ad30bc4, 0x9e085a43, 0xecf817f7, 0x09f1cd5f,
	0xfbc536eb, 0x6ad9ed0f, 0xe113ffa1, 0x499d3507, 0x079f3078, 0x15d130b0,
	0x2a367fd6, 0xa382689e, 0xd96bf5ed, 0x64f687e9, 0x62bdfaf5, 0x38e234a3,
	0xd83be23d, 0xd1e92001, 0x6cdce211, 0x76861b18, 0x8dc2ca4d, 0x404b8744,
	0xcc27ca07, 0x0cdcfdef, 0xadcc77ed, 0x32728c9b, 0x6674fd1a, 0xf301befa,
	0x6f2794ca, 0xb573e129, 0xa171f3f4, 0xd21e642b, 0x5a60b10b, 0xdc5b1c81,
	0x1cd3f24e, 0x3bf1800e, 0xd17be208, 0x3c9cd54c, 0x9ef8dd3f, 0xa7be9042,
	0xc6bf57d0, 0xf98ca877, 0x3d32fd19, 0x9dfe1fba, 0x83f5aba1, 0xfa3ddc79,
	0x394f9ae9, 0xf98c65c5, 0xbef785f4, 0x41f427be, 0x79a3bbd9, 0xf89d297c,
	0x3f199ab4, 0x7497af9c, 0xfa4cadf1, 0x9d519960, 0x71861e16, 0xc577b385,
	0xd5ef7469, 0x5d3e8f58, 0x675cf5a2, 0x48f35d7f, 0xfcf064f3, 0xd12eb17f,
	0x8baef5df, 0xd9f4227e, 0xf24666b6, 0x23147db2, 0x26925339, 0x1ce9905d,
	0x168f7cc1, 0xf446ce7f, 0x49d8edb7, 0x7ba13ffa, 0x636c7dc5, 0x6fcd14dc,
	0xa9e9fbc1, 0x97bcf055, 0x2e518338, 0x929efc67, 0x38ddaf31, 0xf946ffc7,
	0xfbf900ff, 0x80007392, 0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00,
	0x30000d41, 0x4bb10008, 0x38e130d0, 0x4fdac846, 0x6b57aa77, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xc7f6db6d, 0x9daecf1f,
	0x0080008d, 0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41,
	0x4bb10008, 0x38e130d0, 0x4fdac846, 0x6b57aa77, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xc7f6db6d, 0x9daecf1f, 0x0080008d,
	0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41, 0x4bb10008,
	0x38e130d0, 0x4fdac846, 0x6b57aa77, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0xc7f6db6d, 0x9daecf1f, 0x0080008d, 0x00000000,
	0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41, 0x4bb10008, 0x38e130d0,
	0x4fdac846, 0x6b57aa77, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0xc7f6db6d, 0x9daecf1f, 0x0080008d, 0x00000000, 0x00088b1f,
	0x00000000, 0xc5edff00, 0x30000d41, 0x4bb10008, 0x38e130d0, 0x4fdac846,
	0x6b57aa77, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0xc7f6db6d, 0x9daecf1f, 0x0080008d, 0x00000000, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x00088b1f, 0x00000000, 0xe4e3ff00, 0x51f86062,
	0x38dbc10f, 0x722e1819, 0x0143f822, 0xe8433117, 0x0bfa404f, 0x6463bf10,
	0x48cf7860, 0x0e457ebc, 0x3b077b04, 0x2062c303, 0xf03ecdde, 0x6c481afe,
	0xbb3f4dcb, 0x1768e8fa, 0x9f9db831, 0x8053a181, 0x105f4181, 0x88223fc2,
	0x8fc1df2a, 0xa514df60, 0x14a7aecc, 0x0606a7ea, 0xb1a5b400, 0x00040033,
	0x00000000, 0x00088b1f, 0x00000000, 0x7dd5ff00, 0x45547809, 0xbedd68d6,
	0xa7776fb7, 0x42ce9d3b, 0x61d2c216, 0x25e20413, 0x769b0840, 0x20e88812,
	0xe2822c26, 0x9021ecd2, 0xe1e66445, 0x86ebce3f, 0x38e3a220, 0xf0199941,
	0xd041a747, 0x206944e8, 0x6984c060, 0x64661940, 0x3a2a2834, 0xb0c504ea,
	0xa2c2484c, 0xbea0df0f, 0x76eaa73a, 0x21ddbdf7, 0xfbff9971, 0x14e7cf5e,
	0xaadeeb75, 0x73ab6753, 0x48aa9d4e, 0x7a188d92, 0xfc1df213, 0xa764226e,
	0x19190848, 0x68f2db2a, 0x6f108239, 0x4db7c996, 0xffb02420, 0x8924cddf,
	0x33b5f390, 0x420ca69c, 0x05330c0e, 0xe7eda26e, 0x133eb97d, 0xfddfcf6d,
	0xf5a25d9e, 0x04a2ddd2, 0x16fd86ed, 0x9375befc, 0xb97a83e0, 0xb189f1a9,
	0x5bbedeb4, 0xd7685b24, 0x90336024, 0xcd9a4264, 0xb19cfd84, 0x61685f58,
	0x07cdd2d5, 0x8af185ee, 0x42c44ceb, 0x15ae6fbf, 0xb65f505d, 0x3a11f04d,
	0x47dee95e, 0xbfb4eee4, 0x6fc13e45, 0xb6fad271, 0x9633b275, 0xfffb5590,
	0x11b26f61, 0x2663ce72, 0x51e7194e, 0x48421fec, 0x41476f89, 0x497dfa77,
	0x6818a08d, 0x2e9b25ff, 0x257c02b4, 0x22fec6b5, 0xb5496fed, 0xb2073895,
	0x3023bfb1, 0x718fa1de, 0x7ec6ddbc, 0xd5f15e30, 0xc2226407, 0xf82e8d3c,
	0x01c294ae, 0x3dc756f3, 0xe380d9e7, 0x7d2cf8a9, 0xdf478e91, 0x50457b2b,
	0x06658a60, 0x5a3806e2, 0x3d665af7, 0xadf98367, 0x86c40794, 0x1ece63cf,
	0x6f894798, 0x03605cb3, 0x0bcb36f8, 0x5bfa8487, 0x5adffd52, 0x4df436f8,
	0xebb58771, 0x8a1e73cb, 0x7aa101d2, 0x3f2e2109, 0x3e4897ed, 0xe86868b9,
	0x3c42c7f9, 0xb5497bd2, 0x50e69c48, 0x84f294ff, 0xffffa374, 0xc527fd1e,
	0xd621b783, 0x44232db7, 0xa00e65b7, 0x176e8859, 0x528e9c1d, 0xff78767b,
	0xd004f96a, 0xe553c283, 0xa4f96071, 0xf5cb1527, 0xede2271e, 0x58819ef7,
	0xf828f06e, 0x0e4f69fc, 0x2e3c9b96, 0x4cf59f2c, 0x29e7d2c2, 0x78b6f7c4,
	0xd5b96166, 0xcfe7c6e3, 0xacb18a7b, 0xf3e054f6, 0xb02b3c97, 0xf178f1ac,
	0xb59e2bf9, 0x553dfa58, 0x7a04ee58, 0xe3d6b2d1, 0x78f6f7c3, 0xf3acb1aa,
	0x3ef9f1f8, 0x8f961d4f, 0xc7da3c73, 0xe2895c91, 0x0e22eec1, 0x3092764a,
	0xa46b95d9, 0x564284f5, 0x9bdbbe4f, 0xb27ad32b, 0x5e29d69b, 0xe40d2fba,
	0x7bbd689a, 0xf5ef6b05, 0xd333c910, 0x6b2f2f7a, 0x2bb8f3ef, 0x7deb42cf,
	0x80fb58aa, 0x18bcde4d, 0x63e01f5a, 0x04d7d7ed, 0x7eb4acf2, 0x67b59fbd,
	0x1b7c93d6, 0x580667ad, 0x2ba8eb3d, 0xb3d6963f, 0xfb3d591a, 0x9dbe6f63,
	0xd89bb3d6, 0x7c5a63f7, 0x4916d3a2, 0xe7469d87, 0xb569423c, 0x4b8b7bc9,
	0xb2eb4d1a, 0x50a201f3, 0xbaa778fc, 0x0f8a34a4, 0x03db0ba3, 0x5ed8d9de,
	0xfdb0bb2b, 0xac7cef1d, 0xb1ba31ef, 0x94b794fd, 0xb63765d5, 0x05fde57f,
	0x5e8cebd6, 0xf4af376c, 0xc5ecbab0, 0xd72beef6, 0x8cfbff62, 0xb21f6c3e,
	0xefb61d72, 0xfed87d93, 0x5da7eae4, 0x52bd6813, 0xf81eff70, 0xa4c59691,
	0x3f93f02f, 0xd3f290b5, 0x02cc811a, 0xc0dffdfe, 0xd72f9474, 0x8728c9a4,
	0xfd9eff3b, 0xfe2fc81c, 0xf0bea092, 0xf032c7f9, 0x3f623ffb, 0xd88fda46,
	0x6f593f79, 0xc9fa68e5, 0xed58ab7a, 0xabde1aa7, 0x9fad74b4, 0xd18d6f9d,
	0x8956f3c2, 0x840ecfda, 0xf36bb627, 0x9c7b7aca, 0x97b79e16, 0x43ecfdaa,
	0x06bbe278, 0x5a7bed4f, 0x17bed4fc, 0x8421cfc4, 0xe0d75ba7, 0x16bef119,
	0x0fde233f, 0xf628e7e2, 0x7eb5d693, 0xe2d7df6a, 0x20fdf6a7, 0x79c3de7e,
	0xbcdaecf5, 0xc5a07c46, 0x820f88cf, 0xe114f9f8, 0x3f5ae8c9, 0xe2d13e7b,
	0x4127cf67, 0x7ec69cfc, 0x5e6d77fa, 0xf16a9fd9, 0x1069fd93, 0xcfd8ed3f,
	0xb3f5aea0, 0x7e2d53e7, 0xc41a7cf6, 0xcfd8d7cf, 0x2bcdaed0, 0xfc5a9ffb,
	0x8833ff64, 0xfd00831f, 0x3c1aeb0c, 0xf1685f75, 0x1045f753, 0x67ec563f,
	0xc9e0d764, 0x27e2d669, 0x9f8839a7, 0x3ee80124, 0xd4fd6bba, 0x53f16b35,
	0x4fc41cd7, 0x7c67ec4f, 0x7395e6d7, 0x9c9f8b5a, 0x0cfc41d3, 0x52e579c0,
	0x087807b9, 0xe3b627ed, 0xd79df67e, 0xf9df67e2, 0xc06e7e20, 0x7ed2267e,
	0xcfde76fa, 0x7e2d5698, 0xf106b4c6, 0xdcfd8393, 0xf67eb5d2, 0xb3f16ab5,
	0x9f8835af, 0x6dcfc45c, 0x98d79b5d, 0xc67e2d36, 0x0cfc31b4, 0x6f915e3f,
	0x2d74eda7, 0xc9fa4454, 0x4b9716d8, 0xc1d175a0, 0x2143a2ea, 0xaa889760,
	0x5d1a41bd, 0x56defd22, 0x18f59f13, 0xf23bb709, 0xb15e608a, 0xb70b1ad4,
	0x6272e23b, 0xbc4e7634, 0x4f53412b, 0xf35dd49c, 0x3ec2b77e, 0x5994f69a,
	0xd3da6bd7, 0x7a9a59dc, 0xcd18f17a, 0xf22b3dfb, 0x2bdef534, 0x9fbcd56e,
	0xa9aa9de1, 0x977b5df7, 0x55fefde6, 0xd7ed3573, 0xb4d1286d, 0xd32df20f,
	0xff5707d4, 0xa1fde697, 0xf69a55fe, 0xd31eea1b, 0x3c0b0fb4, 0x3f0fa9a9,
	0xfde6b4f2, 0x345b8d91, 0xbc4ea3ed, 0xdd1f69a4, 0x1f5353b4, 0xce9f667b,
	0x9a39b3ce, 0x08baf307, 0xdd984f7c, 0xbda3269f, 0xb1958817, 0xa1b7772e,
	0x76207f1d, 0xa514f3a1, 0x9e707caf, 0x17d28933, 0xbae84a68, 0xf8bddb9e,
	0xfcfa26ba, 0xd7dc6317, 0x5ff3e839, 0x1c1beec8, 0xca53ec51, 0x8549020f,
	0x528069d2, 0x9188fedf, 0xfa5e63f1, 0xe92701d5, 0xf686e5f7, 0x6eb4f101,
	0x00377310, 0x182b3eff, 0x44634f90, 0xc5ef0152, 0x05fa0898, 0x3f64648f,
	0xd7e30de7, 0x1ca93db5, 0xd77ea10a, 0x60a9dd1a, 0x79596c67, 0xc8760bcc,
	0x5e749e9a, 0x4e7909dd, 0xf6f01638, 0x5cf7dfa3, 0xfda6ea98, 0xa76a6499,
	0xd32f8f87, 0xf8e087f1, 0x2bfe30d5, 0xea6f8c1d, 0xdf19a393, 0x3358abdc,
	0xe3a659be, 0xb03da83b, 0x3e3e43f2, 0x4218c225, 0xe21f0976, 0xc55ea6f8,
	0x3223fe38, 0xc7c257f5, 0x5f8e098f, 0x1fb2f207, 0x65191fc6, 0x68c67dfe,
	0x44abdfe7, 0xcd997f3b, 0x93cae0ff, 0x9c18fc7c, 0x24e121ff, 0x12af7f9b,
	0xeb137f36, 0x3dbe3837, 0x3023ff88, 0x9a3ab7ff, 0xda71df7f, 0xaa5ef7f9,
	0x8d89bf9d, 0xb3caceff, 0x8e1b7c7c, 0x9670aeff, 0x52f7bfcd, 0xb9365f1c,
	0x391fe015, 0x47c2a63d, 0xa83d27c7, 0x76014a62, 0x3940e3a1, 0x35328130,
	0xfa11bf21, 0x88bf1c20, 0x55f6fc61, 0xd437e50c, 0x4e7c5e37, 0x65b3547c,
	0xf38bbf53, 0x5c9a92fa, 0xb612f419, 0x01657f53, 0x9d7e7507, 0xd64dfc88,
	0x29fd7c9b, 0xa275adbc, 0xd7f3ea17, 0xfe81f78f, 0xfb91372b, 0x893be10a,
	0x17f9e004, 0x25ba1bbf, 0x72fa5e7c, 0xb9b19541, 0x82de4c29, 0x191e547e,
	0x9be14158, 0x32304c08, 0xfa8cff54, 0x17fa8441, 0x833f531f, 0xdcfc9650,
	0x94fbc6c8, 0x6f504bfa, 0xb412fea2, 0xbf12b213, 0x4f1ddda3, 0x7217f0a5,
	0x98933ff8, 0xb7767ebc, 0xf952f3e0, 0x61c1eafc, 0xb7dea7e8, 0x1e914ac2,
	0x378e6382, 0xf3a75351, 0xda9d02f2, 0x5b7c9af7, 0x13afc404, 0xa28455f0,
	0xb5bcc849, 0xa1d714e9, 0x64a03ff7, 0xbfa8a34f, 0x298cb883, 0x967bfdf4,
	0x741d3d0b, 0x532e19dc, 0x5c275b16, 0x6b9406e9, 0x21c86e92, 0x30ed6a64,
	0x1481ed23, 0x359f8cb9, 0x6d3b8d85, 0xa33eb692, 0x356f5b50, 0x0a068cba,
	0x40916b57, 0x677ed336, 0xabb6d2ce, 0x090cd8e3, 0xbc7cce8c, 0xdf0664c2,
	0xe0b3284c, 0x3ce903b1, 0x55bec1cb, 0x679f29e1, 0xd02c2ea4, 0x008ddbd3,
	0xf849bd5d, 0x360e5dde, 0xb3bc3d6f, 0x2157668c, 0x39ace79d, 0x5bf80fa2,
	0xfb47ff0f, 0x26432ead, 0x653ed72d, 0xf9c88624, 0xd3bfe1e8, 0xdf8f9fad,
	0xecf0eb08, 0xc673fd62, 0xfe9ccd37, 0xd07f019f, 0x07f034f2, 0xe714ff85,
	0x655e908f, 0x726e51fc, 0x687e014f, 0xa41228df, 0x3b97e72b, 0xa82cbf38,
	0x2105f2d2, 0x71d0236e, 0xeb212cd1, 0x983e30b1, 0xd160f9c9, 0xdcdf2d06,
	0xb4c6bc43, 0x73b97428, 0x5387e6fd, 0xfbf3919d, 0xeccdf384, 0x7e200fc7,
	0xe8c9e722, 0xd3a72f74, 0xf6da153d, 0xef5d383b, 0xb59d74e1, 0x541bdd61,
	0x9cbb907d, 0x7bc8233e, 0x7a552ff9, 0xe9e86936, 0xc3d4f4e6, 0xe7a72f79,
	0x7a320fbd, 0xe26de1ea, 0x70da6cf4, 0x44fa48c9, 0xef87abc2, 0xf31115be,
	0x739e8191, 0x59e9d1bc, 0x789b975e, 0xa979ec2a, 0x53c496ff, 0xa4b67261,
	0x5f5348ba, 0xf353bbec, 0x730da2fe, 0xaa0bed34, 0xe7da6b16, 0x535fbdad,
	0x507de39f, 0x2b7dfef3, 0xefda6a56, 0xd35478a9, 0x9d78bb3e, 0x7ba77ea6,
	0x99fde6a3, 0xda6b36b3, 0xa8be1467, 0x69369f69, 0xe45ea687, 0x5f79abda,
	0x77b8bfd8, 0xeeabae13, 0x3c40a63f, 0xf21343f1, 0xa9df5ea9, 0xc794f17a,
	0x3d9bcf89, 0xe33cb103, 0x39f9f051, 0x2b960e4f, 0x75d37f41, 0x9597b0c1,
	0xe9ce4fe5, 0x7b8b08ed, 0x7a546e7c, 0x4ced9e81, 0xebefaa1f, 0xa5fd1ef5,
	0xd453b347, 0x0a40a972, 0xe36c1d61, 0xfcfab476, 0x09275f02, 0xb9728559,
	0xbb726654, 0x1e5a6774, 0x303d43b1, 0x7c4a22a0, 0x7ecf2826, 0xa0b3e701,
	0xce06afaa, 0xeb061b45, 0xe382dbe0, 0xd70df62c, 0x3d525f3c, 0xcb5df356,
	0x2be11101, 0x0d1f1903, 0x41e159cb, 0x3817c003, 0x50da6bd4, 0xc875d780,
	0x5d4beb00, 0x5ae7b437, 0x4f12933c, 0x42e78049, 0x6678cf2c, 0x71ecd961,
	0x53ca7963, 0x9e67e58c, 0x3c9b2c0a, 0xd4fcb02b, 0x63f2c5e3, 0x3f2c5acf,
	0x796154f2, 0xcb01b3c2, 0x2c3e3df7, 0xb1aa7b8f, 0xc7e3c77c, 0x8753d1b2,
	0x85c7ab65, 0x612f2aa5, 0x2d3bd2fc, 0xfd545f8c, 0x33c7eaa7, 0x01ce5f9c,
	0x8be344bf, 0x38be5a2d, 0xbe40ac6d, 0x3d43ebd0, 0xeffaf41d, 0x48c3f287,
	0x7edbb303, 0xe8843f2c, 0x77a3ae9d, 0x4de8cedf, 0x8f7a30c4, 0x3c183834,
	0x06bfde9c, 0xebd8a378, 0xef716143, 0xb9076616, 0xcbfe2cac, 0x02d4f4e3,
	0x3e5ff164, 0xb77d2576, 0xdf25ed11, 0x17c7d040, 0x01dffe07, 0x78bedf10,
	0xa99d44c2, 0xa7a7e78e, 0x2078875f, 0x161bf42e, 0x30a2e8fa, 0x12ddb23c,
	0x316af0c3, 0xae844990, 0x7ff68f17, 0x043b995e, 0x804912eb, 0x514a7def,
	0xa97e946c, 0xedf80a0d, 0xb195af0c, 0x7f42655f, 0x3bff4fcd, 0x0691ca1b,
	0x1cc68766, 0x261ed112, 0xc014e781, 0x9bdf506f, 0x1b885494, 0x1d97f7b7,
	0x6cfb1eb8, 0x6979fc5a, 0xbf843b3d, 0x1a8e2947, 0x4aab3d71, 0xfbf5fc45,
	0x175a406a, 0x9e99d7f0, 0x739f0cec, 0x23ffdd7d, 0x7f4cecf8, 0x88b7a675,
	0x1d4af9cb, 0xfedb7f9d, 0x398f59a1, 0x61f54f41, 0xf8074ffe, 0xf47bf756,
	0x1f0314f0, 0x1f3aec8f, 0x7cab25b7, 0xd08bd8dc, 0x7903de71, 0xac5ffda1,
	0xe80e2ebd, 0xbb41fb42, 0xb7377dbb, 0xeba13b9f, 0x7f6d0cf9, 0x82fe5ce5,
	0x44c9c5fd, 0x1b8e81b8, 0x8e24cb2b, 0x7ba2c3ae, 0x837e8885, 0x7f05e4d2,
	0xa955bf7c, 0x763f8274, 0x1380adee, 0xedfad47a, 0x673c8f17, 0x5966ff07,
	0x2a71c1aa, 0xb2d51d0a, 0xb0e19fd4, 0x7501fb85, 0x2ac5fada, 0xfd1f9261,
	0xf4dc6724, 0x380eb0a1, 0x81faa71c, 0x52c54e5e, 0xaa5967ed, 0x889538ec,
	0xa47a67f4, 0xccf51e26, 0xdf198f39, 0xe8e1a9fb, 0x1c109fa8, 0xfa73e4b5,
	0xbbe2903d, 0xdfbf1dbe, 0x97481ca1, 0x92178865, 0xe057e37a, 0x7fe859bf,
	0x7e81f5df, 0xfdabac25, 0xaf45fb96, 0x5e7806e9, 0x7e8f19a3, 0x32f754e7,
	0xe58ebbe1, 0x2acd224d, 0xedba53bf, 0x4badfbe0, 0xad0e2daa, 0xa9af185d,
	0x39a5d797, 0xfc227634, 0x59e10c03, 0xb77c0482, 0x9b5db394, 0x7c0b5b64,
	0xe30438f4, 0xf605df80, 0x49b9a95e, 0x3f613b76, 0xf3fd1633, 0x1f04eb65,
	0x362a13e8, 0x73a7c08d, 0x57077873, 0xa1d95429, 0x4a0ae8fe, 0x8f3eb40c,
	0xc57dd4d7, 0x264bb5b9, 0x05f5bac3, 0x79bfa2f1, 0x86caac56, 0x7f8964f8,
	0x74a2ecb3, 0x930c4f3b, 0x93cf3e40, 0xc3c3ec77, 0x5163f1e4, 0xb79a3946,
	0x531f6b56, 0x5f5359bf, 0x5f5b41b4, 0xc326a648, 0xf5c2f2fe, 0x4013e246,
	0x8fdb686f, 0x77ec0e8a, 0x0358a911, 0xb5e7fceb, 0x0b18efc3, 0x99f57c78,
	0xcc2b886c, 0x54e9cda5, 0x1f54955f, 0xf7c038c3, 0x7c317f1d, 0xae39159f,
	0xfd88af3a, 0xd2878e56, 0x8be5c16a, 0xe59faeb2, 0x5bd548fa, 0x89a1c976,
	0xd5d77413, 0x247f307f, 0x3c7f0d11, 0x520dba2e, 0xe00fc637, 0xbb52091f,
	0xfd31feec, 0x6ff446a7, 0xeffb49ff, 0xd6cffb41, 0x27fddff4, 0x045fbfed,
	0xf5a203fc, 0xcbeafa5f, 0x3f54bc7b, 0x9dff6c94, 0x3a11509d, 0x2b25552b,
	0xb74bbe94, 0x3a076c3d, 0x76bc919f, 0x3eb3bbe0, 0xca2f9271, 0xa4b773fa,
	0x1365dbd2, 0xff052e20, 0x7b9ffda4, 0xafe8d7e9, 0xe8cdb57f, 0xb55378c0,
	0x72a26029, 0x78bb5655, 0xfac4c932, 0xe47f5649, 0x3af50882, 0xbc95ff2d,
	0xc864bbf0, 0xc29ca03f, 0xb4012fe3, 0x7eb6cb4f, 0x0ceb8051, 0xd0794769,
	0x5fe3077f, 0x367d4049, 0x6c8b8e47, 0x1fa270a7, 0x52f1ce5d, 0x0bebfb5e,
	0xd5fe1da2, 0xfeadfe84, 0x676e62fd, 0x26c526de, 0x9a935335, 0x40a3228c,
	0x20f8a9bf, 0x8a67663e, 0x09933eaf, 0xad96c571, 0x3085da6f, 0xf176a93c,
	0x3fbcff45, 0xac7673ee, 0x9ca95b3f, 0xea33db85, 0xe3ace3fa, 0x2b3d71f6,
	0xf6031a97, 0x2dcf54b1, 0xbc546cdd, 0x97d2f1f4, 0x69fe7b9f, 0x687df388,
	0xfed3fa52, 0xc6fcbc97, 0x7d6863fb, 0xd2630ec9, 0x9b0d3664, 0x4ba21c90,
	0x456ffd39, 0x250e8856, 0x9d90debb, 0x87f3d943, 0x58f44212, 0x4c80e3b2,
	0x23e24686, 0x6e407fdf, 0x8ba145b2, 0xac0164ff, 0xdfabe2f7, 0xb3f740c8,
	0x929205fb, 0x9b9f0511, 0x1cf5c0df, 0xe47484f0, 0x4dd20a74, 0xa5397ef7,
	0x955fe80b, 0x1bf6fa4e, 0xfe813eb8, 0x9f90439c, 0xf147d95f, 0x4991fc53,
	0xbf17f981, 0xe61d80f2, 0x60aa5a71, 0xc3ccfd7c, 0x6e3a2ec9, 0xec9bd1b1,
	0x2f3d92c0, 0xc8e7f67e, 0xfd8e8b6f, 0x2de3193c, 0xc06695c4, 0x069bc3b5,
	0x69b05bf3, 0x216fce06, 0x15df2371, 0x8216233f, 0x2252fbfe, 0x91447693,
	0x5cb8778b, 0x0d42de9c, 0xd3bf3a2a, 0x7cc07974, 0xcc447793, 0x7ee4223b,
	0x73fff202, 0x72ba173e, 0x334bfd61, 0x928bd3a3, 0xab5157ea, 0xb75f9c31,
	0xf408d23e, 0x95d3d739, 0xe510fb02, 0x7c72f244, 0x7ed1df08, 0x531363c5,
	0x53887d18, 0xd1dfe6ca, 0x9e1f3b75, 0x468dfbc3, 0xf3532597, 0x232ef91d,
	0x3e72fe34, 0x063b853e, 0xc9d3dbd6, 0x6fceedd1, 0x538d4125, 0xfe309236,
	0x266f930a, 0x651f5bef, 0xbbcaadf2, 0xb41268af, 0xe4ce3e5f, 0xf583be07,
	0x4815c287, 0xd303f6c1, 0x2607d405, 0xd7268812, 0xae5c8d5b, 0x9f2aedb5,
	0x2125b850, 0x085f8c2e, 0xf34f1f5b, 0xeb8587fd, 0xfa6177e9, 0xb3c61cb2,
	0xcaa7f647, 0xff2e22ed, 0x1ff9077f, 0xb27f921c, 0xc77dc989, 0xf11790f6,
	0x7be8d4b3, 0x579069fe, 0x275e9f2a, 0x10b1abc8, 0x9aaffde6, 0x45dfef43,
	0x7e5fe4e5, 0xfab54e55, 0xc5a72f53, 0x6892473b, 0x9b2ffa72, 0x29caa242,
	0x4e551e7d, 0xc7c84d6d, 0x53fa53ff, 0x3a97dfc5, 0xc3eaa9fd, 0xd7a8f08e,
	0x4e4a4f87, 0x1f5ea7c4, 0x9271dfd2, 0x2a7fc91d, 0x56fca9df, 0xded2a7f2,
	0x7c8277a0, 0x905df2a9, 0x8bbe552f, 0xf06a6f88, 0x33ff6fa7, 0x4f8074c4,
	0x046e1bcc, 0x08acc0bf, 0xb5d7e728, 0xce8f3018, 0x7f40423c, 0x0906e06a,
	0x8e0cc7eb, 0x4e576091, 0xbfeafb19, 0xdfdf241e, 0xe5a1ff9e, 0xa7b61eab,
	0x7eca17b2, 0x4e14be08, 0x0cf551c7, 0xc4a3f2ce, 0x81f507d7, 0xf30c2c4b,
	0x991b677f, 0xe3f57b3e, 0x8f01c39d, 0xe2436db9, 0xf64f509a, 0x9cb0ff42,
	0x5e8b8deb, 0xd3e81c67, 0xd17df58b, 0x4478bbff, 0xcf968d8c, 0xefa722f7,
	0x45de209f, 0xa4adb6cb, 0xd6fca44a, 0x6ed1da46, 0x93356ef0, 0xa3f6516d,
	0x2f4c8c0a, 0x007c58fe, 0x2f1f01fd, 0x0a0a9a5a, 0xb3b1d8a3, 0x1ca77cf8,
	0xc7d71afc, 0x1b37ebeb, 0x7eba5ec0, 0xc7e341ab, 0x5eb91a17, 0xc05922c8,
	0x5a0e53d7, 0x1e004762, 0xe40a888f, 0x5fd7963d, 0xfc51dd90, 0xa1fcfd3c,
	0x1eb7b07f, 0xdc703a36, 0x79fe8cd7, 0xced78780, 0x7fec099b, 0x96ab95ed,
	0x54b38344, 0x3dee7066, 0x53f2e8c5, 0xcdb725e1, 0xf883c816, 0x7c8256cc,
	0x8267491b, 0x9ab17e7c, 0x006656f8, 0xaf5645bd, 0x4ac79821, 0x38cdf941,
	0xed2aeef8, 0xaf3e4c35, 0x27f1dbab, 0x5657be81, 0xb40c382f, 0x926a4cbd,
	0xebca5f81, 0x63d045e2, 0x3e6a9cc3, 0xf4e863a7, 0xd87bfe30, 0x0f3ce128,
	0x366d798d, 0x8b52e5e0, 0xdedf604c, 0xe63b7af5, 0x1faa5ec5, 0xd1d6fc8e,
	0xc87976bc, 0xe824138d, 0xd11ea087, 0x4d4871d3, 0x363ea68c, 0xe01ddddf,
	0x5a6a629a, 0xbbc144ae, 0xeff5b328, 0xcecf92a7, 0xefcb2eca, 0xdd7e5571,
	0xdf186162, 0x7832371d, 0x2537e4c3, 0x5b2efc9a, 0x79814ce9, 0x9be86b2f,
	0xf65cf802, 0x68b76357, 0x87b2f57c, 0x79db85f9, 0x2d5b6bfe, 0xc21bdf95,
	0xca96b7e4, 0xdeb8946f, 0x27e1a37e, 0xa7ca9bc1, 0x46fc832f, 0x9f18ef81,
	0x99bf2aaf, 0x7e5127f5, 0x9a0d6b33, 0x462391bc, 0x28752ebe, 0xe9b742bf,
	0x2a375049, 0x1afa28d6, 0xc97100f0, 0x0f6e3ced, 0x7f1c80e3, 0xf8e53dfb,
	0x1cb0ffc1, 0x304ddb2f, 0xde9225cf, 0xed978e4c, 0x002c72a5, 0x2f1c99dd,
	0x8e2c206b, 0x81df93a2, 0xbecbf211, 0xefb00b2f, 0xfe32ebcb, 0x2f1d3770,
	0xcc5465cb, 0x90acfdf4, 0x970c8f3c, 0x923b6fe7, 0x935d23e7, 0x9e5cdde7,
	0x51f69ca9, 0xa955d0a2, 0xbd5be6d7, 0xcd74fa36, 0xbfcbe02e, 0x1d27e88b,
	0xf6bb3033, 0x47a7d1ad, 0x928c5f00, 0x9c693c19, 0x2f1ead0e, 0x66305ff6,
	0x49c83263, 0xbf55ebfe, 0xd2e53c87, 0xfa0246ad, 0x24f6acb0, 0xf8faa1fa,
	0xe9576a8a, 0x1eaa2ce3, 0x9659c7d1, 0x43eb6b54, 0x6245f8f8, 0xde4bc213,
	0x516d9516, 0x47486ef8, 0x7aa91e70, 0x042236df, 0x1ff16767, 0xc19d1e75,
	0x532bcea5, 0x30ddebe6, 0x83e21c32, 0x2f288f14, 0x3851bfde, 0x730b5e29,
	0xf7f26bfb, 0x87387047, 0x43e6e557, 0xf208a258, 0xda8fc06b, 0xd861ff70,
	0xc2791af7, 0xf4e60599, 0x372631d8, 0x5a2f53f8, 0x559e51da, 0x74e22cba,
	0xf6fae429, 0x7915eeb5, 0x75e56fc0, 0x9dd60382, 0x78d7c0f2, 0xc6d0e14e,
	0x8f800aaf, 0x0e083716, 0x05e1f213, 0x02bcfc19, 0x3f02feba, 0x80bfaf0d,
	0x86e2ef76, 0x5fbe115c, 0x04c057bc, 0xd3f0cef3, 0xe02dba55, 0xf00cbdf0,
	0x76ce00db, 0xf871aeb6, 0xc972f6d4, 0xff3f81ab, 0xd26b2be9, 0x934edc19,
	0xc8ef0433, 0x4473bc20, 0xe117579c, 0x19def155, 0xae648bbc, 0xdf1d38f7,
	0xe309771e, 0xbe3ea441, 0xf7cd7e4b, 0x93954b8d, 0xd4cff446, 0xa2e3d4f8,
	0xf8233efb, 0x38da398f, 0x18ed212f, 0xfa09feaf, 0xfead713f, 0xd008bfc1,
	0x352feb75, 0xcfbe21cf, 0x0a7274bf, 0x6bc965d0, 0xba533122, 0x92c4d6b4,
	0xf86bee00, 0x4943a064, 0x78c2e8ad, 0x9ec8148f, 0x8f8e1b16, 0xed8f864a,
	0xb25cfe2c, 0x4c9be4d3, 0xf3d92fbf, 0x33d82679, 0x0fdaabad, 0xffdf83a7,
	0x4c728092, 0xb0994dbc, 0xb12253af, 0x7e3d1afd, 0x7d99959f, 0x3ad7b2db,
	0xa841e40b, 0x4a85e766, 0xa68d33fc, 0x77f87b30, 0x0f7d51b2, 0x2fbcd4f3,
	0x05e7980a, 0x539f85f0, 0x5a67f351, 0x497e645e, 0x07d19d49, 0xaa4a8ee7,
	0x9c42b477, 0x0984e4a4, 0xeaf2b5d7, 0xcdd7180b, 0xea32fedf, 0x513af2df,
	0xf84727e3, 0xc062d5a7, 0x6d55fe04, 0x69cbc629, 0xfdd624fd, 0x9d34e3d1,
	0xb64b51f9, 0x52f1ec37, 0xf5d92e14, 0x1dcf1d82, 0xa3b36e35, 0xed7d5a9f,
	0x3f8450f8, 0x9af47fea, 0xce39e8fe, 0xb5917f1f, 0x4ea928fe, 0xc2953f44,
	0xc5185d97, 0xfdf20f5e, 0x0b3e5fcb, 0x9d96d2f1, 0xe0167aff, 0xa5edfa5d,
	0xf1497f67, 0x1c5bf648, 0x5fcaffa0, 0x4de30f7a, 0xb92777ea, 0xf8beb7dc,
	0x5ae9c602, 0xd029343f, 0xe9c36b5b, 0x6aaf105e, 0x3275f1dd, 0x1bcb27d8,
	0xb5bda226, 0x0a7e777c, 0xa81f6289, 0xafadf025, 0x3d42710b, 0x1ed50ebd,
	0x9e7005ea, 0x2d86f4a7, 0xc17c60be, 0x35e2ca5f, 0xa8571e4e, 0x8d8f1e89,
	0x4ed42388, 0x08fc7dbb, 0x938a8d28, 0x709e2174, 0x86f1d29c, 0x86afd02e,
	0xd11dedf9, 0x83fc3cef, 0x593be9d2, 0xb2f98f1b, 0x9f1fc176, 0xc4dab686,
	0x8109e30e, 0x8d4de02e, 0x5d951ef7, 0x9b902631, 0xf8c27f9d, 0x326dd00d,
	0xcbeb689d, 0x3882f65f, 0xfb6319f9, 0xda4fb8bd, 0xeffdc260, 0x500f8692,
	0x1f775a7e, 0xf0937b43, 0x092b6bb8, 0x8c9c58fe, 0x6f9692e7, 0x0871658d,
	0x53887f8e, 0x9cf8ed38, 0x1f1823c7, 0x8e8a71ab, 0xa67913e2, 0x942f3c3e,
	0xb74a51c5, 0xba2643fe, 0x13908fb8, 0xa23be75a, 0x07078a93, 0x785461e0,
	0x1c7a2dbc, 0xe5971828, 0x41fa02f4, 0x4f182d9c, 0x101ef5a3, 0x1f09f15f,
	0x19ef5e10, 0x375b7e45, 0xab5d78b3, 0x12579b51, 0xc38b13a2, 0xe2e9378d,
	0xc5aebe6f, 0xc79b3adf, 0x50d3c5f7, 0x4647a458, 0x6ae5abe2, 0x36ee7d74,
	0x1f6e3f09, 0xdfa0ba74, 0xf80fb9c7, 0xa4f6b4b2, 0xea87790c, 0xb7cea67a,
	0x2de3db85, 0x3798892f, 0x087fc6bb, 0x6f5eb9f5, 0x8639c194, 0xe32ef028,
	0xb1d596f0, 0x6765a2f5, 0xfb46cfac, 0x17b83969, 0xe6acbaf9, 0xfda5eca4,
	0x25deae1d, 0xc991ff33, 0xbe17ac11, 0x5e5bf830, 0xe2c99039, 0xd7fecc8c,
	0x7135e38f, 0xfa3ea87b, 0x1735e538, 0xf12ce334, 0x079665fa, 0xcef1ed7d,
	0xd099ae49, 0x2346b9df, 0x73c83c81, 0xb452717e, 0x2679ca7d, 0x575f8f23,
	0x5d3b38b1, 0x48dcf137, 0x22273b2c, 0xf718c826, 0x739b1e58, 0x4a092e22,
	0x50fe09d9, 0x4f964ae5, 0x252bf954, 0x195de815, 0x65c6077f, 0x75f874ab,
	0xe1723924, 0x426388fc, 0x576008e1, 0x7789debd, 0x2ff03419, 0xe2949d8f,
	0xa6ae70a4, 0x4d79c0fd, 0x8e782922, 0x4c17b445, 0x0e88f982, 0x2512c383,
	0x15b4661e, 0x5e187712, 0xb9ed0e8c, 0xb8757213, 0xf751fa13, 0x1b9a975b,
	0xc3a3630f, 0x495f0025, 0x773c7f7c, 0xdde703ba, 0xc0282356, 0x3b2d54e2,
	0x0f2cc91d, 0xb68fd600, 0xe499719d, 0xb890fc06, 0xe562bae8, 0x039a85cf,
	0xad2f4007, 0x3c5713b6, 0x558a3395, 0xce17d8a7, 0x0b330cdf, 0x2f4f817d,
	0xed1af5bc, 0x122f52d7, 0xb36fbad8, 0xae4079a9, 0x2b339078, 0x3df31c79,
	0x4bbf9580, 0xcfa9c10c, 0x4af02103, 0xee7ce872, 0xf186d144, 0x449b8b8e,
	0x72456bf4, 0x31c61ffd, 0x00f89d3f, 0x2caebe7e, 0x845e70e1, 0x2f9fde12,
	0xa2ec7e63, 0x0ecaeebf, 0x70874610, 0xd24e257c, 0x2c1b8dfa, 0xbfd84cf6,
	0x23575e21, 0xe7cf1be4, 0xd42b75fd, 0xe2a1df9e, 0x593f05e7, 0xd7ffbfcd,
	0xa02382c2, 0x17bbe707, 0x994f7ea2, 0xa3df3da5, 0x5e11e3b7, 0x72a003c8,
	0x6910b4f7, 0xafd717d7, 0xde79035b, 0xfe9ebb7a, 0x40fe4206, 0x20518909,
	0xe76f59cf, 0x39bd069f, 0x6c49d008, 0xf58ec780, 0x6df82765, 0x7187f01a,
	0x5f89ae23, 0xd7ef0025, 0xc73ee2c4, 0x43cebfa2, 0xd54a64fd, 0xd4e2d7e2,
	0x503ad7e2, 0x9e2d478f, 0xde2d1563, 0xaefb9b28, 0x1cb8e785, 0x3d29b9ed,
	0xed42259e, 0x7c5bb071, 0x8ff40282, 0xdba887c8, 0xe677708c, 0xb999c53f,
	0x4af1c8fd, 0x64e6857f, 0xee01b2a6, 0x72802934, 0x74a397a1, 0x7f80405b,
	0xadf24cf7, 0x5894afc4, 0xe54803cc, 0xb3e611f3, 0x4720acef, 0xa0abc022,
	0x08c9c11c, 0xf256f3d0, 0x02d9a3b1, 0x7c9cfac4, 0x7a63b837, 0xfaf4503e,
	0xabf4b9c9, 0x37bfc04d, 0xf3b15ca0, 0x57c4094f, 0xaa720199, 0xf6fd6038,
	0xf9cecc7b, 0x27239c12, 0xe0fdf9ce, 0xcb03b8fc, 0xfbd8b227, 0xe608436d,
	0x9703f981, 0x953f4193, 0xa085202f, 0xdb909eff, 0x5b9f80a7, 0x4afe6169,
	0xe58c8b3f, 0xdf751603, 0x6f5fc272, 0x56d8f2a2, 0xf9c2746f, 0x6dfab6ba,
	0xaf50fee6, 0x771cf113, 0x20d57c79, 0xdeb5bf18, 0x6f9ae0c8, 0x7f07f5f6,
	0xeb88c1be, 0x71fceb41, 0x68254e78, 0xfdb3d5bf, 0xcffab6c2, 0xf4c2f3ed,
	0x53dd6b79, 0xb0de2083, 0x9f7d10d1, 0xe1b376f2, 0xc1abf907, 0x223ab7f5,
	0x3376e34f, 0xa278a3cb, 0x59479d0f, 0x0ebe45d1, 0xcb187933, 0xc2fafce9,
	0xbbfe715b, 0x4f5fa9eb, 0xde2051e7, 0x74a1b3fd, 0x93dfa39e, 0xae257e98,
	0xd99273c9, 0x7f781d11, 0x0152512f, 0x13c7a31f, 0xf479e401, 0xf7f70487,
	0x442c5447, 0x3b35eaff, 0x17ca73e5, 0xdf29ea13, 0xb16b9e82, 0xb23f1da1,
	0x65f0d251, 0x21f704fc, 0x9d4737f0, 0x476fa820, 0xe7b6d09d, 0xe3889f10,
	0x8f9f6934, 0x2fada33d, 0xcb7b7331, 0xbf81924e, 0x11155fd7, 0xa276b6ae,
	0xb6fda2ac, 0xf78eefcd, 0x865db406, 0xbcb44fd3, 0xb68a4e2a, 0x66643fce,
	0x2651b17c, 0x5c6cbeb8, 0x82fdc368, 0x304b0b83, 0x07abf9ff, 0x9da3bddd,
	0x4bd30ba7, 0xde1f6c71, 0xa7814715, 0x605abd7c, 0x0b4aaef8, 0x4b529fdf,
	0xbe558f95, 0x6d39f956, 0x5a3b8c61, 0x616c8afe, 0xc2de4876, 0xfe0c8281,
	0x00817ed9, 0xb9575b5e, 0x11d57935, 0x95590bf6, 0xd794f00e, 0xdb7b425d,
	0x1f3d1f5c, 0x9db319ea, 0xbcab7ff9, 0xe36f212b, 0x41285417, 0xefdc763f,
	0x2aaff47a, 0xdf0a7821, 0xe0e6ab99, 0x6605a679, 0xb1e205b2, 0xd4da5552,
	0xfcfbe058, 0x7850d65b, 0x20342e9f, 0x151a379d, 0x4a5bdf84, 0x2419c608,
	0xa63dbf26, 0xe7e1cd90, 0xe7305eba, 0x7a5332ee, 0xb03b32ec, 0x22b744ff,
	0x37cafc00, 0xf60ec7ff, 0x1315db4c, 0xf73bb1d2, 0xdeefd483, 0x4d3c3332,
	0x865eb8b7, 0x127149ef, 0xb6e287ca, 0xc227e73b, 0xf78a4ef9, 0xd5287128,
	0x53704d2e, 0x49e146dd, 0x7f7019b0, 0x4e5cb888, 0x409f9a87, 0xf2617bf8,
	0x81020240, 0x9f5505fc, 0x2042f50a, 0x08fff296, 0xfe002db3, 0x9d314246,
	0x42c10537, 0x46bfaccc, 0x3e7825a9, 0x291bf30d, 0x5243665f, 0x07fcc13b,
	0xfe82b848, 0xeaab3d55, 0x04f1d5e7, 0x75eacdf5, 0xf692af92, 0xb26a49b3,
	0xc3251c40, 0x2d83cce5, 0x89c904e7, 0x167ae6e7, 0xf6b47933, 0x683e267d,
	0x1f6150af, 0x5f78adf6, 0xd5be78b4, 0xe9e8ecc2, 0xa0fbf716, 0xb48f322f,
	0x46b3041f, 0x94f1b0b1, 0x9f68cc37, 0xb706f507, 0xbaf80ac3, 0xb60bfa3b,
	0x37024c7f, 0x1a865e61, 0x0debd7af, 0x8aef072a, 0x485f5720, 0xb939cf04,
	0xd5b2ffe8, 0xfd3091d4, 0xecc9d7c1, 0x68438aba, 0x0e4389bb, 0x7d8e3f01,
	0x4734cf13, 0x475191e8, 0xef0095dd, 0x7a1fd50f, 0xa016187e, 0x33e9c8f2,
	0x7de709c4, 0xb43ac11d, 0xa7aead7f, 0x1524df5c, 0xbb41488d, 0x1e99f396,
	0xeb5caabf, 0x856b3de5, 0xbd84c872, 0x59dc58fa, 0x42110e37, 0x82fb3870,
	0x822a3a3e, 0x4b96df7d, 0xf5c285f9, 0xb03b9047, 0x6efb2fcf, 0x5f59be01,
	0xe405b37f, 0x1faf07e3, 0xb0ebf4b5, 0x44bfe3f5, 0xad858a77, 0x43c0761f,
	0x7ccb81d9, 0x9d2008fd, 0xf2a57483, 0x51171e11, 0xe7cf5ef9, 0xc2545caa,
	0xecbee3c1, 0x47d0043c, 0x5848fc14, 0x00e4d913, 0x35f6aabc, 0xfe63c6f1,
	0x1b0772f6, 0x1f3f1367, 0x4ae2dcb1, 0x1e86b849, 0xfd42bf2e, 0xe7bcb095,
	0xfd1da972, 0x322bf2b1, 0x08fe25f1, 0x7e29f8fc, 0x19f83592, 0x8919196b,
	0x9b90149f, 0xc05fff91, 0xdf4f4d3f, 0xf8219c47, 0x6bf712c7, 0xb3ee544d,
	0xc690d81f, 0xa78e4ee8, 0x9f9dd386, 0x7e48ec53, 0x82fca873, 0xaf21187b,
	0x5d1d393a, 0x10d4e54f, 0xb18aa729, 0x51f7ef10, 0xcfa8ac1a, 0x997b72f4,
	0xcadcabcf, 0xa2d99efc, 0x51e80cbb, 0x05ef686e, 0x24e9957c, 0xb0299389,
	0xda227599, 0x5131a4f9, 0xae444eb3, 0x67e65edf, 0xc6af7d73, 0xca3a8523,
	0x4fb076b7, 0xbe020fdd, 0x6fcc1d2a, 0x60410384, 0x7660bee7, 0xadcf043f,
	0x3818b614, 0x9030318f, 0x5a1ce2c1, 0x2e48e939, 0xf7be3aac, 0x7f5c2407,
	0xe9fd74bc, 0xcf0c742f, 0x433c4b38, 0x6006d53e, 0x26c8f45f, 0x8232b06c,
	0x323d7b79, 0x1efa39d9, 0xabdeec59, 0xf0fdb9a7, 0xabdf5cdf, 0xc2e60be5,
	0x466f00a7, 0x594d7889, 0x006e1c3f, 0x9b7fe215, 0xd075ae2c, 0x0b92799f,
	0x20ee91e7, 0x28f9408a, 0xb00bf25d, 0xd4b094cf, 0x1fb8b029, 0x9405eb61,
	0xc9f4bfb4, 0x6f585cce, 0x006721d2, 0x253b07de, 0x5ad49c8a, 0x4e2e3f8c,
	0x6f911355, 0xe0e5cb5c, 0x9be74cb0, 0x1be59938, 0x142de307, 0x6b6fc07c,
	0xd9381dec, 0xfe592fd6, 0xe19e3782, 0x0137ef59, 0x125e60c1, 0x132c3faf,
	0x7e8092c9, 0xdf00d78d, 0xd7e8cc19, 0x07e28958, 0x85b6f7bd, 0x2359a79d,
	0xfea16b28, 0x0cdda95b, 0x7ca80df7, 0xa9b8c4fd, 0xb15f448a, 0x0998bf8f,
	0xf3e526be, 0xadbc01bf, 0x580e2ee3, 0xef68338d, 0x25cdf8c5, 0x551bf26a,
	0x3519d5ba, 0x1c40b374, 0x956e8c23, 0xe5fa32b1, 0x028c42ad, 0x62eb4c7e,
	0x9829c181, 0xe424fcf9, 0x857c60bf, 0xc22e19c7, 0x90b74ce6, 0x59f3a71e,
	0x0e56718b, 0x4e7cf077, 0x7b43ec91, 0x471e7750, 0x7d675e7f, 0x92de3046,
	0x8558f986, 0x4271dc32, 0xd15bd62e, 0x33b72a6e, 0x43f3d6b9, 0x6b85280a,
	0xf8a1739c, 0xa57c076a, 0x41e22b18, 0x73dca68f, 0xd5f40eca, 0x2f3d41e3,
	0xf7183f88, 0xc7e6e268, 0x2e258ed0, 0x05bbef56, 0x78f094eb, 0xe183817f,
	0x30a58163, 0xaf9f5c39, 0x248b98f7, 0xc6ef5429, 0x315497e3, 0xb3c6f9b0,
	0x19ef7e21, 0xe1fb0454, 0x9972e0ff, 0x0a7e2e4c, 0x6b0b1efb, 0x2dc40aad,
	0xcdba2cfe, 0xce2f9431, 0x047b9cbb, 0x042bdbf4, 0x8ff4a380, 0x033a7902,
	0xbe2c23be, 0xf94df1c8, 0x88fe6d2b, 0x3a2539d0, 0x2898b8ef, 0x2466d27c,
	0x56c71075, 0x4f893ce5, 0x2a33d559, 0x7f80939d, 0x90aa7f60, 0x572abdca,
	0xc9abf87d, 0x9fc33f18, 0xaf97ff50, 0x8fb53ec1, 0x563943cf, 0x640c80f9,
	0x7a02c97a, 0xd66e2c22, 0x4f41f0d6, 0xe4fa97d8, 0x61629757, 0x529fe27f,
	0x85e82c7b, 0x1bbd0f33, 0x9fe0fb0b, 0xe7fcc43c, 0x7d76757b, 0x57d30c56,
	0x070a62ab, 0xf3eebcc1, 0x4ae7837c, 0x057bfa82, 0xa62fb38b, 0x3cf689cb,
	0x697cf69b, 0x9e7f5fa9, 0x2ff88bd4, 0x7fc7a295, 0x38b0c517, 0xcd9ae2c1,
	0xc613ba72, 0xf1858f77, 0xe5bf70cf, 0xf7bb2d4c, 0x6e678541, 0x6c1930cd,
	0x9bd67ff9, 0xa36cbef8, 0xd73be991, 0x7167d864, 0xe1e9bc73, 0x8adfbc3c,
	0x9df82dfd, 0x1cf4f688, 0xaa0ad63a, 0x2cf5dc37, 0x8f3f544f, 0x0b389f05,
	0x82f6fce0, 0xd3f40547, 0xa887fde0, 0x78af75fe, 0xf463f704, 0x879fd4f3,
	0x51bf9fd7, 0x9c45fbed, 0x1b89f3fe, 0xf6224df7, 0xbed9ebf1, 0x751e3ea9,
	0x2b5f48f1, 0x189effcc, 0x93671f6e, 0xbf5fb051, 0xb89f48f3, 0xb509e56b,
	0xe7c3f3f0, 0x19e17e78, 0x5072c10f, 0xd39d938c, 0x00563fad, 0xb756557c,
	0x7d0dcf03, 0x5a5fbd5f, 0x177ed67f, 0x6a7fe909, 0x72003cf7, 0x8d050a45,
	0x99b6543d, 0x427dc7fa, 0x3f9bb878, 0x8be61bbf, 0x9eec7cfb, 0x1a97bb88,
	0x2fdf872f, 0xed18cbf2, 0xf04b4f7e, 0x479b343c, 0x757f9729, 0x1e7e7a7e,
	0xfe6bf9c4, 0xdd35a2d6, 0x1b2b94e9, 0x79e2f74e, 0xac2f98f1, 0x1f9e8bf2,
	0x8ad9fd16, 0x7ba419f2, 0xce106ffd, 0x6573eb05, 0x9216e658, 0x3dd91b8a,
	0xbe54de53, 0xf10a946f, 0x40f8ce89, 0x6356ef4f, 0x4f902f53, 0x3b5bbd3d,
	0x3abcaf38, 0xf367ad86, 0x8802ae9d, 0x85202c97, 0xeb611c6b, 0xeaa919e9,
	0x6e412ff0, 0xd5be32b6, 0x4de417af, 0xcb3bae23, 0x70299d62, 0x61d20def,
	0x9b3fec34, 0x3a9ef0bc, 0xa5c7b34e, 0xcf0093f4, 0xe73cb093, 0xf5fa5429,
	0xdc2fb50b, 0x710ec978, 0x0481b6c0, 0xb1ad04e3, 0x636b785a, 0x36a78444,
	0xa5dfe986, 0xffb7e352, 0xb5b39d00, 0x9bd5f711, 0xc338f2af, 0x68a4d355,
	0x7f9b7cf3, 0x1efdf847, 0x51b972f7, 0x38fbe2ed, 0x67adeedd, 0x3773a6fb,
	0xe97f2115, 0x2a38abef, 0x69d20a38, 0x30ff6e57, 0xa7afe819, 0xe6e502cf,
	0x235fa0b3, 0xe71e44e8, 0x7cc6e97c, 0x441bf990, 0xf4f5abf4, 0x583ab6cb,
	0x02b3b7de, 0x1d2588fd, 0x561eb9e8, 0x8f9af7c3, 0x6a731e7e, 0x7a7bd405,
	0x5d6d17f8, 0x813ba6b9, 0x45f9b3f9, 0x03d023ce, 0xa79f0cf5, 0x44f9af3a,
	0x46ff03b1, 0xdd343fec, 0x02f3c244, 0xc3cfd717, 0x3a32ce3c, 0x14e2c27f,
	0xe1507718, 0xcfd5e157, 0x316c40a3, 0xb84e219a, 0xdf405042, 0xe223de46,
	0x3453dcd2, 0x0f40faa7, 0xd4b35fa0, 0x96e206b4, 0xfd015ecd, 0x098fb692,
	0x6b6da22e, 0xe9afdc05, 0x2cf57e90, 0x3a63a4ef, 0xef70c856, 0x28ea7cce,
	0xa2e3a346, 0xbf4ab90d, 0xd8b3bd30, 0x4fd28b77, 0xf31faf03, 0x17549610,
	0x59c79e69, 0x33b8fab5, 0xd1152379, 0xf954aaf3, 0x954de552, 0x93ab6cbf,
	0xef92e3d9, 0xe8067a70, 0x3f6875e9, 0xdbdb3d53, 0x77cfe3ca, 0x36ca57d2,
	0x9fc4d25e, 0xfa30e417, 0xe327102c, 0x07d68ef3, 0xbe8d078a, 0xead5641d,
	0x1f3b1fdb, 0x5caa1e75, 0xcbd3f3a8, 0x6aff1e85, 0x074f46dc, 0x14c5fe3d,
	0x63b040c3, 0x40a31889, 0x6e98b19e, 0xc749d8a8, 0x72d37b11, 0x2a9ba408,
	0x565a1ce2, 0xc228dfe5, 0x234afeb9, 0xb035b7df, 0x1c2a4073, 0x6a1c3993,
	0x785acab9, 0xfcf7e02b, 0x56d98ddb, 0x7b443716, 0x7b85c716, 0x7fea04e4,
	0x6fbd71d1, 0xcc77cc10, 0x0087224a, 0xcae256df, 0xb32b7901, 0x86ff7026,
	0x5fd0d7ed, 0xc98a943a, 0x50a9cbb0, 0x2bf5f879, 0x309ee113, 0x40f0ce25,
	0xb22fad06, 0x74f562ee, 0x070ca5c3, 0x96b5b79d, 0x2e1b07d5, 0x25f5a1f5,
	0x0eacddd6, 0xe0540b1b, 0x267bad4b, 0x38c0877a, 0x6a57a60e, 0x3f81835c,
	0x9ff30325, 0xc63283a4, 0xd8fdd531, 0x04a0d4d5, 0xf80ca93f, 0x66bfbe89,
	0xac9fde65, 0x73ca2710, 0xf59f6139, 0xbacb5871, 0xc552f0fd, 0xe03568ab,
	0x025005bd, 0xf1ce7ffe, 0xd485d2a9, 0x5e4306ba, 0x06bbf11a, 0x957afc43,
	0x0ac2bdd5, 0x8da3b9f1, 0xd75f0237, 0x3651f3be, 0x9bd8afde, 0x28fc33f5,
	0x7ce97db5, 0x73dabfce, 0xd03ef873, 0xafee6b2a, 0x064a3be0, 0xa705b75c,
	0xd74ddc83, 0x2fea4ae9, 0x25217dca, 0xd7176b43, 0x3ae80502, 0xf0a639b7,
	0xe92ba061, 0x45796011, 0xa3c6f8a1, 0xaf2dbcf0, 0x19d189e9, 0x690738a1,
	0x7e52e84c, 0x42b99c89, 0x9095fd04, 0x2e62775e, 0xd99fc9c8, 0xba814c39,
	0xb55f90ab, 0x049f783d, 0xc2b5a7db, 0x53e82d3e, 0x937aa485, 0xe2cb3fb9,
	0x3b292440, 0xf3e7fecc, 0x804fdfa2, 0x594629fb, 0x9d1e3ed9, 0x7bfa08a7,
	0x39627118, 0xbed3fc1c, 0xac6e72c0, 0x13fe23ef, 0x3ffda4bf, 0x28f96169,
	0xf1a26ae6, 0xd9588ff7, 0xc6d97afa, 0x8c621ff2, 0x67a0a9fe, 0x07102e63,
	0x67b6d9e8, 0xf9f70964, 0x30cfc725, 0x40d87d4e, 0x8c17de00, 0x49c4073e,
	0xce4907db, 0x5fd4242d, 0xdabfa71b, 0x73b293ef, 0x5fd9f810, 0x85fd58db,
	0xb5e7e65c, 0x6afe659f, 0x22b9ba42, 0x00e49f7c, 0x5c706eff, 0x07406bde,
	0x810c437f, 0xa7ed47f1, 0xcfa51c06, 0x2cb26a9f, 0x01db1fc0, 0x090f1447,
	0xd0fdc726, 0x0a25c25f, 0x773e066f, 0xe7257e21, 0xdf8a38b0, 0x9cdab731,
	0x0bc69f70, 0xe8adff16, 0xc06cbf27, 0xcbb6757b, 0xb7d4114a, 0x203a745f,
	0x8642f04e, 0xf3e7063f, 0xb3e701b2, 0xfafda63d, 0xc7ee1465, 0x2f984a06,
	0x64895922, 0xcab9004e, 0x9f4fde73, 0x5e7e7237, 0x2572606d, 0x3d3c98da,
	0xb3f1d029, 0x945cbde0, 0xbcdf7527, 0xdbe59dad, 0x28de9b77, 0x14c75f02,
	0x40787ea9, 0x5c7c3f04, 0x6df5c121, 0x73e8cd9c, 0xb2e873a2, 0xbff4a1cd,
	0x7dfd3091, 0x314bc7e3, 0x702947ee, 0x3f97ee1c, 0xf305e944, 0x37fbe352,
	0x4f193e71, 0x6f58449a, 0x4a215fc7, 0xd3778e80, 0x7aea2915, 0xfbf7913b,
	0x38a440bc, 0x65ee5efa, 0x977c04a7, 0xe1ebb44b, 0x67050dc4, 0x6f98ce21,
	0xf5873dd6, 0x4971e114, 0x3a26cfa0, 0xd417edb4, 0xe917a3f5, 0xa1af9e15,
	0x8a2769c6, 0x7ae23643, 0x0056493e, 0xae6c3b2f, 0xc1ff600f, 0x6db8dd4b,
	0x7b3963a4, 0x6af2c3de, 0xc1895e06, 0x4fe52d38, 0xf5c5f01b, 0x16bcaa1b,
	0xfbebef3a, 0x0f81feb1, 0xf75ccf41, 0xe822524c, 0x5e9ccdfd, 0x1df2a96a,
	0x8e2397f0, 0x86e397f1, 0x6dda7c90, 0xcaa2ee2c, 0xf41df01b, 0x9be8cfb3,
	0x877f6d1d, 0xd6ddabf2, 0xd041e60d, 0x9a75fd8e, 0x99c81679, 0x1b74ce3a,
	0x95d1ffdf, 0x3b2e566b, 0xef57f100, 0x98fd6c97, 0xe60afdd0, 0x7afda937,
	0x52df98e2, 0x369aacee, 0x6c2df205, 0x26b38c46, 0xe13df3f3, 0xc61692fc,
	0xb5df2a2f, 0xab9f98da, 0xdefe4ff2, 0x3c7f3177, 0x1c424bff, 0xaf682419,
	0xa373fca9, 0x8de1f197, 0xd1bad847, 0xdab8ff19, 0xcc20131d, 0x4737c111,
	0x51e4df18, 0x27bfc0fe, 0xe8ff01d0, 0xc6c726f9, 0xf90ea8ed, 0xf01daae6,
	0x3f21bcb3, 0x41e75ae5, 0xfcda3cea, 0xda397d2b, 0xef3f3d1a, 0xf7be38bf,
	0xcb3f55ca, 0x9b717d04, 0x407d0141, 0x2a7d22b9, 0x31bdf3e5, 0x15993dea,
	0x43bea17d, 0x4767fa62, 0xcff509bd, 0x8ddb9b0e, 0xeca9d7f9, 0xdc9113bc,
	0x526f104d, 0xe19d9bba, 0xd9c702f7, 0x8dfa1f18, 0x21a7d181, 0x4657f49e,
	0xb2db9cff, 0x9210e6e0, 0x61d19f36, 0xb37919c4, 0xc6f9fb48, 0x46db3b96,
	0xe815fae1, 0x5387e00c, 0x2f239e32, 0x5ea3253b, 0xb1ff757c, 0xa8eb8802,
	0xf6a37c79, 0x1bc82b1d, 0x7d33ef02, 0x6a978f3a, 0x419b531d, 0xd9eeea4f,
	0xfe984d1c, 0x5993dfd2, 0x1993fc08, 0x1fdfd76a, 0x008a9339, 0x9b533bac,
	0x16a08994, 0xce47f7f4, 0xf68adc0c, 0xae138cf9, 0x28ceb189, 0x7e7247f7,
	0xee3483b8, 0x7f519701, 0xaf5d219f, 0x75f2097f, 0x0c80cdfe, 0xe5f95157,
	0xefccc18a, 0xfa0be8ae, 0xfc3b9547, 0x3ff9bc51, 0xbfb9a819, 0xb79700f4,
	0x9d8915c7, 0x31926fbb, 0xc21bffee, 0x75f3f3be, 0x3dc8236b, 0xf96b2f7d,
	0x1f41b32b, 0xe1762f0e, 0x38b74afe, 0x5bf6f111, 0x05f73012, 0xe612297a,
	0xce8dfbef, 0xe842d3fc, 0x0e15223d, 0xfb36f384, 0x870cc5ba, 0xb9b1bff1,
	0x44dc0137, 0xdf023f6a, 0x35931a8d, 0x6db6f41c, 0x5844ead8, 0x29b854c7,
	0xd9b6935c, 0x70a87042, 0xfc636a3d, 0xce6d8df8, 0x7c3fa026, 0xeea87a07,
	0xbe19b364, 0xdfc0f957, 0x3fd18170, 0xfe801f8c, 0xee107e21, 0x878aba83,
	0xd40f9c6d, 0x0fcf4ffa, 0xaf14dfd4, 0xafe00fc1, 0x3f147fd9, 0x83f38434,
	0xdc41af6a, 0xff979e1e, 0x1600eaf3, 0xd8f16267, 0xe5de2251, 0x2b31ed4d,
	0x9adcf7de, 0xf9c0a79a, 0xbbb4b2ec, 0x74fca4b0, 0xd718efe9, 0xaaba458d,
	0x3fca9f76, 0xec5cc5b3, 0xee099157, 0x16fd93ff, 0xdc4277f6, 0xdddf18f1,
	0xb5b060e5, 0x8bdcd27d, 0x13e4aa9a, 0xd5fbb31b, 0x0587957b, 0x874fb404,
	0x37724551, 0x503d7fda, 0xcf1c2a8f, 0xe01059a4, 0x0dcc24be, 0x353b074d,
	0x0fe30890, 0x800e4d33, 0xdeb4ecdc, 0xc9f30e98, 0x0beb8eb2, 0xe067b97c,
	0xa96137f2, 0x78bdd3db, 0xc86756d7, 0xe5f552ee, 0x3aadde21, 0xa3e70b7e,
	0xcf2c5c9b, 0x387df41f, 0x01baea1c, 0x843804e4, 0x77c34cc0, 0xf5f3d456,
	0x000eb04d, 0x071e941c, 0x760b5204, 0x95c1ae45, 0x61f60f94, 0x700480b7,
	0xdd7c35b6, 0x9340e20b, 0x0272ffeb, 0xeeac9de0, 0x7dda288b, 0xae3dbd11,
	0x7faa49da, 0x1251daa2, 0x6f6a8445, 0xee11fb41, 0x1ee038af, 0x02f75866,
	0xf85f3c66, 0x20e745e4, 0x897b9717, 0x9f3263ce, 0x11a4edc7, 0xbf5722e1,
	0xa51c6efb, 0x8f8e14cf, 0x204847c9, 0x09da1326, 0xee0b2db9, 0x38de2171,
	0x8a6dce3a, 0xe30b3e40, 0xb473dbaf, 0x98ddf875, 0xb3a7ea1c, 0xcaebf5f7,
	0xfd9c5d58, 0x3c4796c7, 0xdfefdcec, 0xe75cec3c, 0x57a23e98, 0x27388582,
	0x74e79d8d, 0x911c3c30, 0x7373afa3, 0x8ffc9963, 0xc2653431, 0xfb03b679,
	0xeaeb8dfe, 0x7eff7dc1, 0xd1cbec1f, 0x79022567, 0x8ece6369, 0xba7dc388,
	0x57dc549c, 0xff2dfb52, 0xd84ad6a2, 0xf51fe473, 0x14c3e9fe, 0xf00c971e,
	0xad7cb199, 0xa0a7c9e5, 0x24a7cbbf, 0x5cf79e12, 0x41fbbb20, 0xdf80ac9c,
	0x60587e43, 0x7eda9676, 0xfbffdf98, 0xf70358b3, 0xee251b9f, 0x1853133f,
	0x22a36f9d, 0xa215971b, 0x26676deb, 0x2332959d, 0xcfbf03e9, 0x46bc3e54,
	0xa5676bde, 0x1ef68e7a, 0xe8723f8e, 0xbf4fcc43, 0x097ef6b9, 0x539bfaec,
	0x1b0ae245, 0x95a716f7, 0x19e2c2b8, 0x767563d3, 0x9f17a1f1, 0xf704929a,
	0x0a98882c, 0xe3bf5e54, 0x37a84ccd, 0x17cf518a, 0x737bf1eb, 0xf012fdfd,
	0xa25021ff, 0x7f1f3b23, 0x4f94f5cc, 0x13ba006e, 0x0b661f66, 0xfa7a4728,
	0xdff7dc1e, 0x3a434d89, 0xf44777c6, 0xb5e1d3d7, 0x97dc3c96, 0x7a1e8ce8,
	0xe74fddbe, 0x0bf3a5e9, 0xa97a79d0, 0xe3d0771d, 0x9eebfac0, 0xfcabac54,
	0x5cf0de5a, 0x2a81d822, 0x644c4e9f, 0xef7a337c, 0x16c48953, 0x6f1e97a2,
	0x9bf4e07f, 0x53199449, 0x0b773fe8, 0x0bea2c4a, 0xfc84692f, 0xe30e428b,
	0x6805e3cc, 0xcf9e10b7, 0x66ff5fad, 0xfef0438a, 0xffef4ee4, 0x046b97ee,
	0xe75fab75, 0xe06a5ee0, 0x36fafd6b, 0x049568e9, 0x48155dd7, 0xe31e99cb,
	0x970abdf6, 0x91efce9e, 0x47479c42, 0x40f9ea70, 0xd76aaf0f, 0x5361f7ab,
	0xa04c4c7c, 0xe6754dfd, 0xd622fce2, 0x8e978e6f, 0xe68eedd6, 0xb5ab1b55,
	0x999d2fef, 0xb7a036f0, 0xd3d37923, 0xeaaedf4d, 0x2018028f, 0xd82f4b0b,
	0x93628731, 0xae0a1e51, 0x7905c4c8, 0xe42c3d4e, 0xc07cf0f3, 0xdf91bdc9,
	0x67b0701e, 0xd95bf11d, 0x27710315, 0x58cef886, 0x7c0aceb7, 0xb2aa57b7,
	0x78cd7ec2, 0x1c65515b, 0x2f84d7c5, 0x39e3a6f2, 0x810326de, 0xfac4dbd0,
	0xfe20870b, 0x60827e50, 0xfd5e6f7e, 0xd3e07c81, 0xf446a5d7, 0x132edabf,
	0x3ecc2eb2, 0xb4afabad, 0x9756fd82, 0x1ca7cec4, 0x3c9a278e, 0xc676b9c2,
	0x2ea775af, 0x6945714e, 0x766768df, 0x4ae234dc, 0x3975c4ca, 0x0526e316,
	0xff380d6b, 0x46f28209, 0x772dd812, 0xb467e80a, 0x237a8c35, 0x7adbc289,
	0x99ea3c4f, 0xdc8f7589, 0xf084a0ef, 0x9f1c337f, 0x9411cfb7, 0x02bdf42d,
	0x82f582a7, 0xdfb819f9, 0xc4dbea3d, 0xfda19369, 0x45fa2316, 0x12a5c513,
	0xa7ceb1c4, 0x67e0590a, 0x569a13ee, 0xf303dfc2, 0x8871b116, 0x7e089bc3,
	0x13933beb, 0xd0dfe187, 0xfef5aa70, 0x885277f8, 0xbe5bbfce, 0x1301d2fb,
	0x433e5f6d, 0x89bbfcc0, 0x0de2748e, 0xb5829fe3, 0x5ed49e94, 0x929f5a9b,
	0x6d3d7c07, 0xcfdcf692, 0xf12b428c, 0x0a53ef85, 0x3c2c230e, 0x659e7987,
	0x31efc0bb, 0x2b7e72e5, 0xb399f7e7, 0x15df3512, 0x969f6611, 0x3dd916ef,
	0xefecb91a, 0xf5f2a9f1, 0xb7872e33, 0x4efabf72, 0x8e06ba77, 0xa1dd10c9,
	0xd9db369f, 0x97eddd3e, 0x2e79709b, 0x3e3e3f12, 0xb3f78e9b, 0x587f3a81,
	0xf91aba5c, 0x93ed9522, 0x186c80cc, 0xf6a6f411, 0xb473dbbd, 0x7c7228f5,
	0xeaa13d4d, 0x220d1983, 0xc8cccbee, 0x481678a5, 0x7dff7d84, 0x8328c5f5,
	0x91c406f2, 0xe1715ea6, 0xfa11f7fd, 0x3f49e3e2, 0x4abc5f48, 0xca873065,
	0x5f3b58f5, 0x9e927b37, 0x8a2637a0, 0x1f014f35, 0xd375d1b5, 0xd48f8514,
	0x138d4775, 0x06395014, 0x492d21be, 0x789dc718, 0x6273ca85, 0xd4104e28,
	0x512ed423, 0xb34bd8a2, 0xf7357dec, 0x4af50494, 0xcc625d98, 0xc976f1fe,
	0xca8f6a44, 0x0f5f0059, 0xfa8e1de2, 0x0599e30c, 0x71024890, 0x180bd4c5,
	0xa8972a1f, 0xf3eb8bdf, 0xd1cf4c73, 0x2109097f, 0x2bdbd0f9, 0xb8fa7c6a,
	0xb4a7b55d, 0x538c127c, 0xbc62374e, 0x0293e548, 0xffc827c0, 0x41e31174,
	0x3a8df19d, 0x12fc677e, 0x4e28faa0, 0x70bf06b8, 0xfcbefbf9, 0xa4f955e2,
	0x15d7e91f, 0x43f9513e, 0x7afd17e5, 0x1c5d37f3, 0x66f5a3a9, 0xf1193d9d,
	0xf37ad1db, 0xea2340c6, 0x9aeccef5, 0x9e98e247, 0x81d628ff, 0x6683ade5,
	0x39aec0d8, 0xec047a0e, 0x056ebe4d, 0x181b61e3, 0x34d1bc9f, 0xa87d8257,
	0x191fd072, 0x71a83a21, 0xcb2f9564, 0x9b8c12d6, 0xab7ae64e, 0x11c581b5,
	0x3e8827cb, 0xafcfe948, 0xab14f75f, 0x5442fbb3, 0xf9c6defa, 0x203a5724,
	0xbc77dfc1, 0x8814115d, 0x1c78b94b, 0xd915ca72, 0xd488cce7, 0xa7dd2a57,
	0xefc1eff1, 0x776ff782, 0x12ea3e09, 0x69b3e847, 0x115d9857, 0xf7054f61,
	0x1f989d6f, 0x3f97e7a2, 0x4def74ab, 0xed27ff7a, 0xa13ab78a, 0x677dfab3,
	0x8c14fe74, 0xd81ff43b, 0xc760207d, 0xbe6f9d03, 0x1fbf6122, 0xc27eb5da,
	0xdfac96e5, 0xdfc9efa2, 0xa623dfd7, 0xe3674f9f, 0x05fd551f, 0xe3a83fee,
	0x73b12ade, 0x49f5fadb, 0xf5d3a71d, 0xa7af7f88, 0x747b25df, 0xc7d54fbb,
	0xfae7f811, 0x75fa23ba, 0xbd55afa6, 0xd7d69ff8, 0x7aeaff6a, 0xd7ab8ea2,
	0x91f91de3, 0xb35e5eaa, 0x9bf180d9, 0x1f5fdcf1, 0x7dcce3cf, 0x17e83eb8,
	0x6dc5e2c7, 0x600d9a5f, 0x6c8df9d7, 0xc07bcd1f, 0xeda87186, 0xb43d99fb,
	0x1e4fc791, 0x938c4416, 0x80d23c3c, 0x42fa9b7a, 0x52de61c3, 0x6103211e,
	0x8b3bb85f, 0x8148d7ef, 0x8afbd442, 0xd61ce044, 0x8be31b7a, 0x677a0f87,
	0x7f0fff43, 0x8950c036, 0x2340ec71, 0xb2a3f1f8, 0x8b4fdc24, 0xee313937,
	0xc260dadd, 0xf6da6b7b, 0x4603affe, 0xa24be7e8, 0x7af96b80, 0x9fb82983,
	0xa2647a05, 0xbc845478, 0x8276b68b, 0x9b8d3af7, 0xff07c815, 0xac693c6c,
	0x18c03884, 0xeb4fe599, 0xcf90b4f1, 0x11bfbf5b, 0x6068cfdc, 0xac7e59f6,
	0xeaa7eec8, 0x4ea33f68, 0xcee07cc6, 0x2f7233f6, 0x22d3b413, 0x98ea33f6,
	0xfbbefa5e, 0xf7006319, 0xc5a7bf94, 0xe913f569, 0xbb635f60, 0xdac1f6cc,
	0xd809198f, 0x524ce4df, 0x6751b8d4, 0xf77b1bfb, 0xfee0b8c7, 0xeffced88,
	0xdfddec1a, 0xeccce5dd, 0xa6ccfdf8, 0x56583cf6, 0x954cd7b7, 0xe3ca6e30,
	0xa0b8c1c0, 0xff1caf1e, 0x14ee7c7a, 0xc42b6ac8, 0x0995eb07, 0xb87517e0,
	0xc2eed42f, 0x478aba71, 0x37b64e55, 0xcf80b8c7, 0x777737b7, 0x39d3f8c1,
	0xc7262abf, 0xef27e09b, 0x0631753d, 0x976587f7, 0xf692fc13, 0xcec2b378,
	0xf7be31c9, 0xc1f00da7, 0xfe64f5fe, 0xf698f6dd, 0x0a4e0dbf, 0xfb61e7df,
	0xf3b9ea3a, 0x5e60994a, 0xf2c0d789, 0x3b78f44a, 0x2efcc717, 0x5ad786c5,
	0x53926313, 0xa987968c, 0x063cb3e4, 0x9c8df3fd, 0x1f017bbf, 0x38ddf2d0,
	0xb16ad706, 0x5fbff090, 0xd3bd6049, 0x79832bd7, 0xfdfe0ad4, 0xb86ac54f,
	0xec7da4e4, 0x9bb1edf9, 0xb8643f31, 0xb4be81e1, 0xd3dbf8de, 0x30d63eac,
	0xf210a8dc, 0xcdccf7bc, 0x57bd6813, 0xb8b6e17c, 0xb6371091, 0x653c85ad,
	0x4ac917c8, 0x5f85e90a, 0x9cc2b5d3, 0x5acb8a15, 0xa16bc44d, 0x979e32f5,
	0x948be6ae, 0xec7dd459, 0xf24f7626, 0x79cd14fc, 0xbf4cab1c, 0x6edfdfa3,
	0x78c2d772, 0xdd80e6a5, 0x7cbee949, 0xd7bc44ef, 0x0738dde6, 0xaef077ce,
	0x0fc0a9b1, 0xffbaae14, 0x12feb861, 0x2e122dd7, 0x718193c8, 0xce0e765a,
	0xb831fd07, 0x0aa19c37, 0x41aa87d1, 0x13f16e7c, 0xa5edcfc2, 0x1955fd82,
	0xc73e632f, 0x3d2a71bb, 0x791197a3, 0x8a867132, 0x88fcb41d, 0x03fe3fef,
	0xd7bd41c6, 0xeefe0bde, 0xf7b47108, 0xd5943a9a, 0x98a2de81, 0xebe70ed5,
	0x4589efdb, 0x68f49d3f, 0x3df214ff, 0xb07bb83f, 0xa3f9fa02, 0x598f8618,
	0x4d953ebe, 0xe1d5beb4, 0xf9e602fe, 0x73f35091, 0x00125f9e, 0x57baeff8,
	0x82a0f3c4, 0x33f96bab, 0x3312e391, 0xd1b51dfe, 0xb8eaaf0c, 0x4f788714,
	0xff3c07f5, 0x2f8e0c2c, 0x3821be81, 0xf10bfd7c, 0x5e6d775e, 0x948fea95,
	0xf88f73f3, 0x7d681df7, 0xe60329d7, 0xd8c6b5ff, 0xcc13fdf9, 0xf5c11dbe,
	0xafbfe8d4, 0xaa4e73c2, 0x00fffe9f, 0x1a0d1944, 0x00008000, 0x00088b1f,
	0x00000000, 0x3aedff00, 0xd554746b, 0x3399dfb9, 0x09266673, 0x83c999c9,
	0x10093ef0, 0x18e21212, 0x75878602, 0x5114080c, 0xad88ac07, 0x24404eab,
	0xb4dc35e4, 0x6bb4bb7a, 0x46904931, 0xe3e37971, 0xd5d6dcb6, 0xa2e85835,
	0x2609d892, 0x4e84e818, 0xf5a81140, 0xdc2b5106, 0x147c76de, 0xc3124311,
	0xf7bc54bd, 0xedf7ee2e, 0x26730fbd, 0xb6ae960c, 0x7c7c4eff, 0xcefecfb3,
	0xb1fbdfde, 0xfc0399f7, 0x76a7bcaf, 0xcc03a405, 0x187eb7e9, 0x9767f073,
	0x8e9bbff1, 0x69a517fa, 0x7c4fdf08, 0xc805e00e, 0x3f405801, 0x4202be71,
	0x98054c32, 0x5bc44b17, 0x2e7d4f00, 0xce0bbae3, 0xa9773e26, 0xa4ceb263,
	0x30f18fe2, 0x1eccb2fe, 0x46bd685b, 0xe46f5f07, 0x280cfccd, 0x015ab001,
	0xa2803764, 0xf08150c9, 0x02ddfd32, 0xf119b5d0, 0x6df6000a, 0xeb383076,
	0xd11d751d, 0x4559b3df, 0x9b038064, 0x993c1973, 0x3439e381, 0xa9400f0f,
	0xef951f61, 0x869c9b73, 0xef7ee3cc, 0x0976425b, 0xe158c6e0, 0xd8e2168f,
	0x2106d476, 0x7ce7ce2d, 0x2611a721, 0x12aa842c, 0xdcfe220a, 0x1d9b3f63,
	0x5cf647c5, 0xfe06680b, 0x680a5a9c, 0x6a71f185, 0x2c613ba1, 0xc297a4a7,
	0xe823f80d, 0xf5c5cfed, 0xc7f58b67, 0xac27c678, 0x67fc2103, 0xd192db2e,
	0xe4bdc07b, 0xcc7c84a8, 0x415eab4e, 0xe45464fc, 0xfe5bac27, 0xa13d68e6,
	0x39e5f0e0, 0xf38fe448, 0x7077de90, 0x537f80de, 0x00249056, 0x7c4fbf15,
	0xfb26d00e, 0x1fdf2166, 0x765f3e27, 0x4b5dbd2d, 0xa3fa509e, 0xbd7f5985,
	0x44de5d3c, 0x4b2e6679, 0x2fb66794, 0xd7639e51, 0x9c6dca24, 0x132e513f,
	0xcc2667aa, 0x9654da4f, 0xbdf29e30, 0x79f809f9, 0xf184cac1, 0x09e5d6d4,
	0x56dbd3f8, 0x6c678c25, 0x7e0266ff, 0xc26d6851, 0x9aeef17c, 0xacffd2eb,
	0x1e026370, 0x15f2d789, 0xe7a1bffa, 0xfe7d84d1, 0x1d6ffad1, 0x661fffa5,
	0x972ff300, 0x657be017, 0xb4b64300, 0xb99f0956, 0x71fbd690, 0x71bc8aec,
	0x0cbf4249, 0xa2416a56, 0x3c1cb823, 0xbcf7382d, 0xdf0093ec, 0xb6a2809f,
	0x62d8dc60, 0xfa30ea81, 0xcb16d3fb, 0xb8b4be03, 0x9550ff9f, 0x513ffad8,
	0x2774eac0, 0x892aade2, 0xa430e9e3, 0x69fe185a, 0xf1d22f92, 0x12d6bb4d,
	0xaa77be43, 0x8d9a90fe, 0x52684b63, 0x57bc9714, 0x2126de0d, 0x78362d1d,
	0xb8eb87c0, 0x446a4b20, 0xa82f0198, 0xea498a67, 0xa5465da0, 0xbb42569c,
	0x1f74487e, 0x10bb3d97, 0xc4122dff, 0xe1cffc38, 0xde5f90b6, 0x4d2bc7a7,
	0xe81970cb, 0xfa1e4119, 0x2d56b049, 0x3c8e1003, 0xb3c59538, 0x03b6df53,
	0xc294fde9, 0xcff1d0f9, 0x4e76788a, 0x8a01b3c4, 0xf9f10563, 0x8dcf1dea,
	0x539d70d1, 0x6c2cb085, 0xe4844f90, 0x80fb4d93, 0xbbdcf44a, 0x74eaeb80,
	0x43db36cd, 0x596afeb8, 0x8f2d3c7d, 0xfc13b89e, 0xa0ae77f4, 0x72fd072d,
	0xf3c966f8, 0x4f578e22, 0xf50bab00, 0x1c133ab5, 0xbdf1372e, 0xf1377ce9,
	0x7679295d, 0x368d2be1, 0x37e21ffc, 0x0a1997de, 0x7def7ae2, 0xf20d967b,
	0xaf06ee01, 0x3dfee28d, 0x2663ffe0, 0xedbef3ea, 0x6899b7e8, 0x2fc34d07,
	0xfda4823f, 0xb752e6b1, 0x929cc284, 0xf927efe2, 0xf86aa1ff, 0xfdf0fbe7,
	0x185e0f53, 0xfd212fe3, 0x1ec2f970, 0x74e7db3b, 0xbf029ecd, 0xd5a72e41,
	0xe755df5b, 0xa2e28190, 0xb7d6aef3, 0x2652910e, 0xf4251a87, 0x4e9147d3,
	0xeb636e38, 0x28da7ae9, 0xa798d4f4, 0xa9ea358d, 0x3d15cc71, 0x353d258d,
	0x9d9992ee, 0x433af636, 0x2bbe7480, 0x73d81df4, 0x3547e5e9, 0x264f0c1a,
	0xf508f8bf, 0xfe7ea1a5, 0x30d2fa84, 0xfa827ccf, 0x64b7f1a2, 0xf9f100df,
	0xa51f53d1, 0x6fdd69fb, 0x43dd1f5c, 0xdf7bf0d2, 0xc783ba42, 0xc08d9db8,
	0x2e2c7bc8, 0x24691576, 0x2efb45ef, 0x7ce127bd, 0xb35d9743, 0x2bbcf8e3,
	0x8427e476, 0xc2025fbf, 0x593a886f, 0x92e86890, 0xaf9c4e42, 0x3adce9e9,
	0xed35c701, 0x4c29cb2b, 0x7a21d207, 0x95efcd0b, 0x7f38cd42, 0xf4b47366,
	0xeeb869e3, 0x68674b81, 0x7c03c1dd, 0xa39bb3dd, 0x07739405, 0x81fd56f7,
	0xb2ebabd6, 0x38f51383, 0x132a8ae8, 0x294ebf68, 0x8755fb4c, 0xfd68519f,
	0xa72b9dea, 0x76a17aa1, 0x69f4df77, 0xb8313886, 0xa1a284ef, 0x9ebbaa9c,
	0xcaf02259, 0x3108ba79, 0xdff9d4ff, 0xb02bea18, 0xfe15e31a, 0x8b1d920e,
	0x215bf778, 0xa99135ff, 0xf44e242d, 0xf22e71e3, 0xe2fd5fe3, 0xbd907ffc,
	0xf5d9eef4, 0x5f94e118, 0xcff19c9f, 0x0750f647, 0x8187cfe2, 0x6235c711,
	0xd5e22758, 0x1527b3c6, 0x9d9aebb2, 0xf10933b6, 0x4ad53734, 0x3e82b5f8,
	0x4568275c, 0x476ba97f, 0x19f884bc, 0x48637c53, 0x17dea31f, 0xf9766c74,
	0x21cd746e, 0x4dc282ff, 0x544c18c4, 0x3c255c59, 0xf0ab5414, 0x4a5e60b7,
	0x5fca1768, 0xaa561b4e, 0x407f6ed0, 0x55a7c808, 0xe2d6561d, 0xf02dd5b8,
	0x5da11df2, 0xfdf35779, 0xe4cacba8, 0xbf07c8ed, 0xf0e86e31, 0xe91e699f,
	0x4e7f9c39, 0x837ce189, 0x3f215676, 0xaa7e8868, 0xa07f4868, 0xde2583e7,
	0xec3def24, 0x66d971e2, 0x28ef55f1, 0xa35bfb8f, 0xc8931cd4, 0xd0cff67f,
	0x826ecc82, 0xb75f4631, 0x163e2353, 0x6e74fbed, 0x67deb0cc, 0xa6d36f68,
	0xbf0dc7c5, 0x46d4a0fc, 0x83e57b72, 0xf898eb52, 0xb49cc1f3, 0x3a5250ea,
	0x3c7fbc78, 0xf69677dd, 0xd767dfad, 0x38bf999a, 0x97f2513d, 0x2307aa48,
	0xd28bf92e, 0x97f46e5c, 0x0ddd18fb, 0x9e83d911, 0x2b3d0d03, 0x7f0c4dfd,
	0x20d4878c, 0x241adcf7, 0x1f5595bb, 0x5ff86fb3, 0x5ef50fdc, 0x2ed1bf46,
	0x2d7f2edc, 0x2d35a1d9, 0xbf68dd3a, 0xe4d8960d, 0xe7f48966, 0xe0d5bb6f,
	0x505a72cf, 0x7922ce6b, 0x2d647a66, 0x859b3fae, 0x8b5065eb, 0xdc71bba5,
	0x43d719b2, 0x3f460c79, 0x6ff9274d, 0xa0e759ed, 0x4bb37238, 0x82547ae5,
	0x0ae38a9a, 0x7c556e31, 0xada7e4d5, 0x71402939, 0x99ba2602, 0x3f25fcbf,
	0x47ff2418, 0x0fc0dbd5, 0x85078794, 0x024e0dbd, 0xed518756, 0x53267646,
	0xdc9536bd, 0x5e12afd2, 0xf4afa7a0, 0x83bf0363, 0x10f5effb, 0xfe14b67d,
	0x7b70e43e, 0x4eefbd1d, 0x5b8f8761, 0x6addb6d6, 0xf1a3a7c8, 0xba78145e,
	0xcc1ac01c, 0x5b8b78a5, 0xefd9937b, 0x8fe5576c, 0x771e8fc9, 0xae290afb,
	0x202c595b, 0xd29254df, 0x2321f881, 0x4724d3fe, 0xf3628794, 0x27d724ab,
	0x8a6d5c84, 0x0319c98f, 0x7c7e4684, 0x257cbf85, 0x0af59fa9, 0x4bcd6a3f,
	0xbc68fbd4, 0x9b3c095f, 0x96bb9825, 0x33283ce8, 0x86d219bf, 0xbc75fe99,
	0xae25e8a1, 0x3b85c8ff, 0x79e7e4bd, 0x9e7d99ab, 0x995145fb, 0xb4f7586c,
	0xec9fb95a, 0x47c125f0, 0x4b982dab, 0x6312ef74, 0x2ec98f9d, 0x4f09afdf,
	0x6260cfaf, 0x09d975d6, 0x23defa88, 0xf7d627f2, 0x757c5685, 0x943c5208,
	0x1d453a2f, 0x4ab0c56b, 0x1e0a9276, 0x6685948d, 0xc8059bf3, 0x059f4b5f,
	0x7a61c49e, 0x2335448b, 0x1c0a99b0, 0x09bd16cb, 0x55b03af0, 0xc327262b,
	0xfccf93f9, 0xc82db2d7, 0xca087eef, 0xa6f01d6c, 0x5fea1955, 0x695e4af0,
	0xfb11532e, 0x26ad7f2b, 0x82fadf79, 0xfafc85bf, 0xf3adf52f, 0x252a96a2,
	0x5fefafe3, 0xd625753f, 0xf05443c1, 0x42e15122, 0x68e17f6e, 0xf093ab0a,
	0x6fd9366f, 0x9c69c527, 0x0e6c97ff, 0xd0b06915, 0xf0b802e1, 0xd6d6c5cc,
	0xd35fe889, 0x6e34ff38, 0x7947dfa1, 0x1fa572dd, 0xab266d7e, 0xc90e311f,
	0x05541fac, 0x56f4a32d, 0x6417f58e, 0xa13b8cd2, 0xf91e8e9f, 0x6ee29d32,
	0x77fb5b87, 0x31f0cbd2, 0x73eea819, 0x2b8a635a, 0xa3ed5f89, 0x9aeb147a,
	0xd90cb879, 0xf247a381, 0x877f7086, 0x17aa05e6, 0xa37aaa9c, 0xf3aff06c,
	0xd6875e2e, 0x593d391f, 0xbcf0bac1, 0x12f4cde5, 0x7baebf5c, 0x0fb23a6f,
	0x9edea7b5, 0x8179a54b, 0x2372efd5, 0x1da4e7ff, 0x37940e05, 0x494a86b4,
	0x7e68e13e, 0xb37dd506, 0xcb4f98ac, 0xb027a6ae, 0x49358cbd, 0x0cdddb0d,
	0xdecc8ace, 0x204ffd40, 0x3da5f9ca, 0xd455386c, 0xd83c6c03, 0xf5a6e2d3,
	0x1deebf02, 0x4f69f14f, 0xf8a1ac36, 0x3317d2f1, 0xb056fbf9, 0xdb817e12,
	0x643cec25, 0xec8b8559, 0xbe1e21b1, 0x8585f837, 0xcffbe9e1, 0x5655b9ea,
	0xa24a0ed1, 0x0e28876d, 0x56762338, 0x02773997, 0xeb044797, 0xe0411445,
	0x3ca052e0, 0x8f02e434, 0x291df384, 0x1a8eacc3, 0x2f6bb5ee, 0x36b7244a,
	0x50ef3f20, 0x8451df78, 0x2d37b906, 0xcfdf5cfe, 0x5011f919, 0xf0bb461e,
	0x5a73de52, 0x34e6e0db, 0x30c7bca3, 0xbb0a97ba, 0x5a8948ea, 0x9f9ea8d2,
	0xd194318e, 0xd813a715, 0x459d3abe, 0x2877be2c, 0xcb1e67c3, 0x64a97462,
	0xe9c04507, 0x8d0cc884, 0xf5539be2, 0xaa9c3e32, 0x574a09e6, 0xc52815d3,
	0xe6fd0e42, 0xe2b866e9, 0x81d7e4c7, 0x81d8f894, 0x0f91d0be, 0x9e8befc2,
	0x38d0bc58, 0x115300c6, 0x67feff7f, 0xb2d89f8b, 0x04f79d90, 0x56355465,
	0x6e31c159, 0x7c6353e2, 0x66f4d462, 0x78397197, 0x0ea94e50, 0x1f057f3e,
	0xc68d3ced, 0x63cf1c69, 0xe7975357, 0xf5617f31, 0xf7f0835d, 0x33d14aef,
	0x0ebfa0b7, 0x28cbe33c, 0x2c06be41, 0x47691e87, 0xc2aacfbc, 0xbe17d405,
	0xb837f8a9, 0x7f57bf71, 0x2cdb76bf, 0x361db78a, 0x3b8a0acf, 0xacb3e0b1,
	0xa6c97e9e, 0x3bf0693d, 0x439c3898, 0x9f7a3bf6, 0x67e6a9c0, 0xda1e5ea9,
	0x8d0e692f, 0x64f0eee2, 0xf221bba2, 0x3cf14289, 0x5603ffb0, 0xfd32db1f,
	0xa87f21df, 0x445a69e8, 0x6d079d72, 0x8baf142d, 0xce105d45, 0xe464f1e5,
	0x9b17829d, 0x37f87a0c, 0x86fbe8b7, 0x3f2853fd, 0x1ebf8445, 0x6111fea4,
	0x537ddf77, 0xd16efd69, 0x35efeadf, 0x2409a1c1, 0x8d7866f7, 0x26f92bc1,
	0x76465d64, 0xe39efc56, 0xff01af01, 0xcfffe139, 0x330afd89, 0xbd104ffd,
	0x2a1f7db5, 0xc7e7c4e9, 0x2cd4c9e1, 0x55cfb187, 0x2b91c493, 0x9fca3bfe,
	0x8561d602, 0x816703f0, 0xf7d415c5, 0xdfd40c96, 0x667af79e, 0x6ef3e156,
	0xd50649d4, 0x2ceca709, 0x7cdb778f, 0xe9bf0813, 0x14a58bdd, 0x25231ec7,
	0x7b17bfe1, 0xdc90a76b, 0x532bfed0, 0x813acfc8, 0x4fdd35c5, 0xf14fc84b,
	0xffb212fd, 0xb1171a72, 0xf4a1dcb8, 0xd97e672f, 0x4bf2016d, 0x0fe67fb4,
	0xe52aff68, 0xfd1512e3, 0x833fbd81, 0xbf4779f9, 0x58eacbc5, 0xd9d3eb8c,
	0x1a6ef2b8, 0x562ff477, 0xd05b9f99, 0x5fc8cb9e, 0x3ad887a3, 0xa4e98061,
	0xc67c093a, 0x2bbcff3e, 0xc7add19d, 0xf0c1ffcb, 0xa85c3043, 0x8f907865,
	0xf04e5954, 0xe49e430f, 0xad479163, 0xf13ff799, 0xf40bfa3c, 0x8aa13c8b,
	0x8f3ef8fc, 0xb911dffb, 0xf9f5f1aa, 0x3d53b577, 0xcd995bfe, 0x0ce7141f,
	0x87276151, 0xe50339c4, 0xf3f50d0d, 0x9d37389a, 0xc62f6383, 0x4ddeb9d1,
	0xaaa6a88b, 0x9876d658, 0x785f7ce0, 0x0b8a9511, 0xb61ff4d7, 0x262f3771,
	0xf43aebfb, 0xc52b62f5, 0x5fbc53bd, 0xf872faec, 0x1ca12f0f, 0xf288391e,
	0x90a7924f, 0x587f661d, 0xdc804d5f, 0x2487e7ab, 0x0d824711, 0x63fea75f,
	0x8f8e4bb0, 0xa0363f31, 0xf4f8d361, 0x044f75b3, 0xa660fc71, 0x24c93ff7,
	0x19f966b6, 0x65f13a1c, 0xf765b90e, 0x3eb21f3b, 0x16f14bbc, 0xe574fd93,
	0xc49aeb63, 0x6db98f4e, 0xdb968e2c, 0xf9b25361, 0x0a0fc2cb, 0x624db082,
	0x86acb67d, 0x92ef0fa8, 0x3fd60abd, 0x7ab82167, 0x711bc501, 0xf41eb79e,
	0x37ab2f3f, 0x2f43e2ea, 0x3121ebe9, 0x0bf54f5c, 0xf93ab1e6, 0xd1f90afb,
	0x12dbcf43, 0x4066dbce, 0x91c52b6c, 0x13c94ec0, 0x0bf571c5, 0x9135f389,
	0xf61ef64e, 0xb1cf09a9, 0x57a84d1f, 0x5eb1bb2e, 0xd1aa0629, 0x82bd52a6,
	0x82e2c476, 0xed470acd, 0xb3bbb768, 0x1f5483fc, 0xf970b1ee, 0xfe653c60,
	0xf912e838, 0xa1c792a5, 0x6210f3e1, 0x7c3bb2fe, 0x9ae91d38, 0xa1e79edf,
	0xf95be63d, 0x3c9efcfc, 0x1ac05f96, 0x02a25792, 0x25febc2a, 0x7a0e8eac,
	0xbe45c9df, 0x047c45ab, 0x6d579f95, 0x16a87214, 0x50c6dc75, 0x20f3dd22,
	0x6cfb42d4, 0x6bfc8dd8, 0x4b60ce74, 0xc405cf5a, 0x4fdb753a, 0xb9e3a11c,
	0x5e2270fa, 0xaa38ea80, 0x9f127a17, 0x09b605ef, 0xf214cd4c, 0xd9930c99,
	0xebd1f6b9, 0xb33ea3eb, 0x6de2baf1, 0xbf3e8eb1, 0x4bdb9328, 0x71479203,
	0x87242ea2, 0xa5aa5ec8, 0x6baf3a60, 0xe90aad21, 0x85dba75e, 0x3ca0ff86,
	0x59f2141e, 0xf182ec27, 0xbfd7ef85, 0xf8a28520, 0x254f83fe, 0x5c3ebfd2,
	0x768264b5, 0xb754ddb5, 0x5b5d58db, 0x39d89b03, 0x237655c6, 0xa6d001e4,
	0x6d1afe50, 0xe97e0d3f, 0x7af3741a, 0xbba56ffc, 0xe76516d6, 0x2affb547,
	0x7f448279, 0x74293fd7, 0x0f9a389e, 0xf9fabf5d, 0x5fd7ce8c, 0x9903cfcb,
	0x099f5ea2, 0x977e9933, 0xff675e65, 0x77475893, 0x463fdc2a, 0x57bcfcac,
	0xefd19fb7, 0xf875112f, 0xe0c0edd2, 0xe90b9ef9, 0xd43b7e74, 0x0c0e923f,
	0xde51965a, 0x4334f1a3, 0xf26409bc, 0xee6b77fe, 0x9d534f47, 0xe6d3b4be,
	0xea0e0ac1, 0x947cd926, 0xbd26eb9f, 0x90cd339e, 0xe4ce1e4f, 0xced2e4fd,
	0x8a4ecdf5, 0x3c90bf13, 0x91437ee4, 0x38d10f87, 0xa6792ed8, 0xfa47fbe3,
	0x405ade47, 0x9d4dc8fa, 0x7a05eb4b, 0xc0ee2b6f, 0x671791f1, 0xe4fd8c7b,
	0x6fe73711, 0xcb1b24e9, 0x53e30397, 0xce82b67f, 0x983bbd13, 0x781c0f1f,
	0x1f3f2145, 0x172090ea, 0x7b923a37, 0xca20e5f8, 0x09df607b, 0x45f08a85,
	0xd894275d, 0xe701d457, 0xb28acdb1, 0x8536d6f3, 0xf75f19fa, 0xd518949f,
	0x603f3b45, 0x3d354ee7, 0x35238b12, 0x0d21c82f, 0x7dee1e7f, 0x6a3b2155,
	0x6c609768, 0xc6de719e, 0x327331e6, 0xf9c13e7a, 0xfb714b1f, 0x51ec2b5c,
	0x5edd4fb7, 0xb3388ad7, 0x1ed135ae, 0xd6ef021f, 0xfafef8f1, 0x4f162af6,
	0x8f25b7d7, 0xdabc7a33, 0xc6237d40, 0x13db0dfd, 0xb15e36f1, 0xff3b20c3,
	0xc2cf1d1b, 0x82299c7a, 0x91c3b222, 0x5629dae8, 0x278bfbb4, 0x9240a66a,
	0x45378cfb, 0xe5f3d6be, 0xd83ae4b5, 0x3ca14173, 0x63689817, 0xe26042fd,
	0x3b462b7f, 0x64ec2039, 0xa673e449, 0xbe91159f, 0x1ddfb4c5, 0xf923afe0,
	0x554911de, 0x115dfea9, 0x3cbb7ee3, 0x24850f62, 0xf2c2cfa2, 0xde101ddb,
	0x3a1ffa42, 0x8de7e768, 0x07562407, 0x1b638881, 0x0837bc84, 0xfec06ef9,
	0xd519426a, 0xde7fbcc3, 0x88e3b858, 0xc41be71b, 0x8763baf3, 0xcbce49d3,
	0xe599c781, 0x74671e61, 0x6279e97d, 0x06639fb4, 0xbbe936fa, 0x27876236,
	0x1176ff11, 0xc76f6e67, 0xed5d2338, 0x52e343f7, 0xbb04bd99, 0xf3a3bd39,
	0x22574362, 0x6ccc91fe, 0xa2237fe6, 0x4a333d9e, 0x21862b5f, 0x5bd704b5,
	0x109ec9ae, 0x4adfab7b, 0x952d1ffb, 0x51dafdd8, 0x3f866a6d, 0xf8751e89,
	0xf5d3a896, 0xae745df1, 0xb561f885, 0x87d8cd2d, 0xfe78b2fb, 0x072799a8,
	0xbe86fe49, 0xbcb2aee5, 0xffcb7da4, 0x6fdd2265, 0xd4f75c4c, 0xc5bec68d,
	0xec80a3bb, 0xcfb907f0, 0xf8a328ad, 0xc9e3ced0, 0x9bae0560, 0xb0387541,
	0x6ed036ba, 0x117f510f, 0xfaa23b40, 0x09d9297f, 0xba4467f9, 0xeb04ec8d,
	0xd216677e, 0x864b12b3, 0x657fe42c, 0x5647af0f, 0xd99cfe2e, 0x9c69b1dd,
	0xd8db946f, 0x5e807d64, 0xc17c37ff, 0x79fd4ceb, 0xfac63583, 0xc4888680,
	0xd0ebb6ec, 0x4879c9a5, 0x9fef50ef, 0x5c215727, 0x77cfc590, 0x1fc32abb,
	0x5efb863e, 0xad2470ec, 0x6dc4af27, 0x93f30b69, 0x872c5b06, 0xb1fb1dd5,
	0xfb09bbae, 0xb1cfb786, 0x90eba1be, 0x4f5601f3, 0x514ff5ae, 0x4d4f42bf,
	0xd2eaccd0, 0x20c2d866, 0xbac62fd5, 0xf00a836d, 0x1e112c3d, 0x5eaef912,
	0x9d928b4e, 0xbea271eb, 0x7df78e22, 0x7087f7b4, 0x2595af8d, 0xadc1178b,
	0xe3aba40b, 0x8ec96d44, 0x5fdad4ad, 0x5944ef5d, 0xdf5d1b7e, 0xed12b2f8,
	0x14ede9b4, 0x1d0ea756, 0xcb3a5593, 0x74feb945, 0x586fd53c, 0x3927e79f,
	0xec273cbf, 0x3fdc4072, 0x4cc85536, 0x1c79966e, 0xca10f5ea, 0xd0cbd98f,
	0xd510b489, 0x5f07c5f9, 0xd7fd27cd, 0xa33c46ee, 0xfcfea1df, 0xfb8b8054,
	0x2a70fa9e, 0xe7d1dbbb, 0x757c1cf7, 0xd359d926, 0x70165fdb, 0x502a5cbd,
	0x9f4daeb2, 0xf789250e, 0xf78916af, 0x58d6ddaf, 0x814df53a, 0x642fb2fd,
	0xe7aea7d0, 0x603f612a, 0xfafa7de5, 0x55f98d2c, 0x85db8453, 0xdc4397a5,
	0xa73f357f, 0xaffdb1b1, 0x7b44af9a, 0x06bc8af9, 0x38ea1744, 0x76661b60,
	0x61613817, 0x8c4e04f4, 0x7bf318e4, 0x4b1dd690, 0x0ea9af71, 0x05491c58,
	0xc718b38a, 0xdeefd482, 0xd593befe, 0xb7f2474b, 0x2b7160ad, 0x5b8a065f,
	0x335dbc8f, 0xce1f98c3, 0xf12b65d1, 0xa5c87245, 0xbe79e56a, 0x334390bf,
	0x3e7d12ac, 0x517ae3b7, 0xd47f628f, 0x3fa49594, 0xb77adeba, 0x740ed7a9,
	0x6d381bfe, 0x5c77df67, 0xfac0ddec, 0x3fc2f86f, 0xf80ce283, 0x7c1037fd,
	0x1986e0e4, 0xc1e2fcf4, 0x73b0378d, 0x2139a94b, 0xbe89057f, 0xde8baa5c,
	0xbe70d1cd, 0x1cddf7be, 0xe8c6d060, 0x7f31b1a7, 0xebc59b3d, 0x273ea1a2,
	0x20909f3b, 0x4c01db9f, 0xaeb7584b, 0x475675eb, 0x5ec8f5d4, 0xefe83da3,
	0xf9d628bd, 0x61076eb9, 0xdcf4cbc9, 0xcf5d61c9, 0x5a9e8c2b, 0xb1e9985b,
	0xe7c6dda9, 0xfac4383b, 0x041fbd92, 0xefe89077, 0x7e6b73a4, 0x29cec19f,
	0xc7f99310, 0xe8516148, 0x86ff1c49, 0x475ca11e, 0xcfe01642, 0xb95eeced,
	0x0cd4e8e5, 0xa391fbb2, 0xcb2564af, 0xfdd26f17, 0x3c7a9207, 0xa317f78f,
	0xf367d7e7, 0xa7e3b7fb, 0x7e3b1c78, 0xb2467fab, 0x4a841678, 0x424b67de,
	0x65b65dde, 0xd6d1eec9, 0x4f76f589, 0x7e271e0c, 0xec9d3a06, 0xc5c06d1e,
	0xed1743cf, 0xa4cd663d, 0xcd25dbbc, 0x5b51fca1, 0x99c5bbf8, 0x4e5c6c59,
	0xba36ba79, 0xd617dd9f, 0xf12e77b7, 0x2ca3a126, 0x72dfdb9b, 0xe43df925,
	0x4eef9105, 0xf45b2782, 0xb82cdb47, 0x3615c9df, 0x675649f5, 0x61c6d378,
	0xc453bdfc, 0xb0efbbdf, 0x24e4bab1, 0xdf7e3668, 0xee05efc0, 0xe7a449a2,
	0xef97114e, 0x938c48aa, 0xc7805f2b, 0xa5605ee9, 0x777d7937, 0x157f588f,
	0xeb80d77d, 0x112cbdde, 0xdf511eef, 0x7c4be3dd, 0x7f1e99fe, 0xe280a00b,
	0x3ee3186f, 0xc8a25efb, 0xedeaf2c9, 0xad27a6b3, 0x066c8e0b, 0x51c0fdf6,
	0xae811df1, 0xdfa2a6f7, 0xbc757cb1, 0x2ecbd4ef, 0x909db716, 0x2b3ee49f,
	0x7f74af9e, 0xb7d706ff, 0x57a827b8, 0xdeba8d39, 0x63e763cf, 0xf5d28f3c,
	0x53f42e9e, 0x1aa9dbbb, 0xc3eaf7ef, 0xa07184ae, 0xb1fa9c67, 0x0ad7ce21,
	0x6fd8c6fb, 0x3c739e35, 0xb3d3fb25, 0x31c03ee9, 0xe469eac0, 0xe42de580,
	0x6be0b26b, 0x8f90ddb2, 0x4aab8fce, 0xfe71bf6a, 0xf71e41dc, 0x2bec18b3,
	0xabbf33b2, 0xba214b0f, 0x728faa87, 0x46ffac3f, 0x287f3b06, 0xdf63eae8,
	0x2c5eac2b, 0x7c3cbc79, 0xe9f443bd, 0x839773f6, 0x4edd6fe7, 0x5dfca1ee,
	0xb09b906a, 0xfca3c223, 0xdfc8a77d, 0x0669eda3, 0x7da12ff4, 0x1e4af5ee,
	0xb46dbefa, 0x735aad5d, 0x46d4ebe3, 0xb423b68e, 0xc9c51b37, 0x935476d1,
	0x3d939fed, 0xab85f587, 0xc77ae167, 0x4c993e8b, 0x0d70d376, 0xf365f1bf,
	0x2d3bb6fc, 0x7df29c78, 0xff715edd, 0x27a8b7bd, 0x0a38f246, 0x701bdeac,
	0xe46d6ff5, 0xffbb3075, 0x3d3a8fae, 0xa48f9a51, 0xee349c7a, 0x49994a6a,
	0xf64461fd, 0x4578e2a4, 0xd4c589d7, 0xe728af9f, 0x283477df, 0x74deacc3,
	0x89cbfcbb, 0x7d3c3bbe, 0x3adef709, 0xf3b2d79d, 0x1d6d71d1, 0x1ffb2509,
	0x09d66f17, 0xbb1e34b9, 0xb7133390, 0xfbf55cfa, 0x5e871ec9, 0xeba1497f,
	0x57ccc0b1, 0x846a6497, 0x3bbc31a7, 0xd0b6fbda, 0x7f4eabb1, 0xe8ca9657,
	0x4d0b6e3b, 0xc9647564, 0xd25f7df5, 0x528dffb4, 0xfb079baa, 0x062a958e,
	0xc4681efb, 0x7f449cf8, 0x7e11604d, 0x9250656b, 0x86fa8956, 0xf7a071fb,
	0x1b9d0e70, 0x96ff900c, 0x9d377c10, 0xe77d62f2, 0x54e9f4c9, 0xa8737467,
	0x223e77af, 0xc6b03c33, 0x6319ee0a, 0x7e71efa4, 0xebe61cee, 0xee0ac400,
	0x6f9c659e, 0xfffb7bf9, 0xf52764d3, 0xff82588e, 0xaec272eb, 0xc8fac83d,
	0x9f767683, 0xc623f74e, 0x125eb2ef, 0x9b09bbfa, 0x79d3f21b, 0x953c1f74,
	0xdc2b314a, 0x442b634f, 0x059bbbe9, 0x01cf6510, 0x3df8b226, 0x937fec57,
	0xdf47da35, 0xf713ce49, 0x9fa1f389, 0x860d7de1, 0x6a82f419, 0x1e095825,
	0xd11c2b06, 0x977c29db, 0xe932c384, 0x75639a3f, 0xefb0719d, 0xbe99200e,
	0xc2b372e3, 0x321e5d19, 0x26c13bdd, 0xfcd1dfb2, 0xf1f9d61c, 0xa543b8f2,
	0x591f7d04, 0xcf766101, 0xc4c4337d, 0x3e72777d, 0x469f6016, 0xa3375cf7,
	0x7930a4ef, 0x42fe1884, 0xc64e47e2, 0xa676ec4f, 0x12ac5866, 0xc734527d,
	0xfaf53972, 0x01ca18f9, 0xbafa6eb6, 0xcac7c1e1, 0x9e84f7e3, 0xd3ef1bc8,
	0xd79251f7, 0xf4f7becb, 0x13df4438, 0x895c0eb5, 0x15d8f963, 0x8b7daf67,
	0x54d24dfc, 0x81f827c6, 0x3631477d, 0x5c257dfe, 0x9eece4ce, 0xef7f89cd,
	0xb9b77fa5, 0xb34ab43b, 0xc9ac7da0, 0x3ce47872, 0x5bd7ddf6, 0x8e654f64,
	0x39d12797, 0xa12d37f0, 0xb8bcb987, 0xb782a53d, 0x8496f882, 0x4edbe97c,
	0x38a093b2, 0x40e60eb7, 0x524eae88, 0x90386d31, 0x7f686d9e, 0x7ab3370e,
	0x853fbe8d, 0xa8d22fef, 0x72eaddae, 0xb36ea878, 0x71a99d13, 0xfc1c5b3a,
	0x7bfd073b, 0x6bf2d1ad, 0x99fbde41, 0xac1c79df, 0x2c707e1e, 0xaef997bb,
	0xb56af9ca, 0xfe8987fb, 0x1ca98eef, 0xf16e754b, 0xb2e6172f, 0x5ff91bba,
	0x896ff3a8, 0x9426bff3, 0x18d312df, 0xf7a67fdf, 0x0fed4b4e, 0x4d0a3f73,
	0xfcea3927, 0xb199e0a2, 0x3a7e42a8, 0xe443aaff, 0x45ea2f33, 0x5c7e6bd7,
	0x3852db2e, 0xb2fa36ff, 0x577b2a63, 0xcd1cff23, 0xf1925ef7, 0xd09a131c,
	0xa1342684, 0x42684d09, 0x84d09a13, 0x09a13426, 0x1342684d, 0x2684d09a,
	0x4d09a134, 0x9a134268, 0x342684d0, 0x684d09a1, 0xd09a1342, 0xa1342684,
	0x42684d09, 0x84d09a13, 0x09a13426, 0x1342684d, 0x2684d09a, 0x4d09a134,
	0x9a134268, 0x342684d0, 0x684d09a1, 0xd09a1342, 0xa1342684, 0x42684d09,
	0x84d09a13, 0x09a13426, 0xc0b7f84d, 0x1a3907ff, 0x8000b9ae, 0x00008000,
	0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41, 0x4bb10008, 0x28e334d0,
	0x4fdac844, 0x6b57aa77, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0xc7f6db6d, 0xb02edf1f, 0x0080005b, 0x00000000, 0x00088b1f,
	0x00000000, 0xc5edff00, 0x30000d41, 0x4bb10008, 0x28e334d0, 0x4fdac844,
	0x6b57aa77, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0xc7f6db6d, 0xb02edf1f, 0x0080005b, 0x00000000, 0x00088b1f, 0x00000000,
	0xc5edff00, 0x30000d41, 0x4bb10008, 0x28e334d0, 0x4fdac844, 0x6b57aa77,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xc7f6db6d,
	0xb02edf1f, 0x0080005b, 0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00,
	0x30000d41, 0x4bb10008, 0x28e334d0, 0x4fdac844, 0x6b57aa77, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xc7f6db6d, 0xb02edf1f,
	0x0080005b, 0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41,
	0x4bb10008, 0x28e334d0, 0x4fdac844, 0x6b57aa77, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xc7f6db6d, 0xb02edf1f, 0x0080005b,
	0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d31, 0x48b0c00c,
	0x45e234c5, 0xed3b1258, 0xabd53bc7, 0xb6db6db5, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x3fb6db6d, 0xa5a1c37c, 0x00733031, 0x00000000, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0x00001000, 0x00002080, 0x00003100,
	0x00004180, 0x00005200, 0x00006280, 0x00007300, 0x00008380, 0x00009400,
	0x0000a480, 0x0000b500, 0x0000c580, 0x0000d600, 0x0000e680, 0x0000f700,
	0x00010780, 0x00011800, 0x00012880, 0x00013900, 0x00014980, 0x00015a00,
	0x00016a80, 0x00017b00, 0x00018b80, 0x00019c00, 0x0001ac80, 0x0001bd00,
	0x0001cd80, 0x0001de00, 0x0001ee80, 0x0001ff00, 0x00000000, 0x00010001,
	0x00090404, 0xccccccc1, 0xffffffff, 0xffffffff, 0xcccc0201, 0xcccccccc,
	0x00000000, 0xffffffff, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x00088b1f, 0x00000000,
	0x95d3ff00, 0x51f86062, 0x9259c08f, 0x3cda0c0c, 0xc4b462a8, 0x0c0c9cd9,
	0x11f8817b, 0xed023310, 0x6062e7b5, 0x71620268, 0x7886066e, 0xadfac26e,
	0x6c181899, 0x881ed881, 0x2bf8811d, 0x37c30303, 0xbfede206, 0x10c0c82a,
	0xf7e08628, 0x120dd903, 0x60fff3f4, 0xe89453c3, 0x32a71f6b, 0x36af0303,
	0x1a1f18aa, 0xbf1b5f9f, 0xf2680219, 0x217c6882, 0x9bf7fa3c, 0xf4d5f2a2,
	0x865cf951, 0x66290c0c, 0x3ebabe08, 0xe3a0b77e, 0x93bd4049, 0x43d348cd,
	0xcd000c4f, 0x00bcd6dc, 0x0000bcd6, 0x00088b1f, 0x00000000, 0x7de5ff00,
	0xd554780b, 0x733ef0b5, 0xc9999cce, 0x3c81323c, 0x014f0e79, 0x90849d09,
	0xf0eda406, 0x6297a230, 0x1f05b810, 0x9de40830, 0xc5ea444c, 0x0f0cef6a,
	0xa1b52879, 0x741a0a8d, 0x06834182, 0x9048301d, 0xc4580380, 0xb1686b56,
	0x08315a3e, 0x8c988405, 0xeb5585f1, 0xfbdad7bf, 0x9939ce64, 0xfdfb6c11,
	0xe3fff7b7, 0x6759b7e7, 0xaf6bd7bf, 0x7bdaf6bd, 0xa446c924, 0x037c8481,
	0xe4223f7f, 0x3210814b, 0x52129a2e, 0xb92ad3cd, 0xcf884ec0, 0x4399ff41,
	0x0e5d8548, 0xc8441cae, 0xf0c6dd94, 0x5c29928f, 0x144d0427, 0x60b01c36,
	0x832d477e, 0x43d976c3, 0xf587fe68, 0xfa6da614, 0x5ff7ad4c, 0xbb23f345,
	0x9a15b245, 0x2060911d, 0x319c84a9, 0x4397f613, 0x0a425ce1, 0xa8ac0c2d,
	0xea1f383b, 0x889b3717, 0xb157b685, 0x55c668b7, 0x6a3a2e14, 0x62a45024,
	0x0fb90adb, 0x42824b85, 0xc9cee008, 0xe7817c6c, 0x5a36e0c5, 0x9ad1d3be,
	0xc846c73a, 0xb899bf79, 0xd9564264, 0x8f67535b, 0xb834a426, 0x95ea1f33,
	0x036e0a36, 0x3b6c7981, 0xdaf30192, 0x2e4db82e, 0xac1aca42, 0x8d8235c4,
	0xfffa1be1, 0xfc312699, 0x94bf9a23, 0x76d093ce, 0x3e75488b, 0x8dffa111,
	0xc51ecbb2, 0x13bf79df, 0x8ae051fb, 0x5a1fb4ed, 0xc119f2af, 0x34ac530d,
	0xf6886f10, 0x32d7b1df, 0xcc1b71f7, 0xdc3c856f, 0x2b5af30e, 0xe0a2b943,
	0x2e2de7c2, 0x9c9d5f18, 0x6b4bf34f, 0xd1c2e4eb, 0x1acaf6d1, 0xb5c76b7a,
	0x579a4869, 0xcf4faf95, 0x0d7109fb, 0x84a5c28f, 0x5db44278, 0x99e50522,
	0xa7efd199, 0x29211248, 0x5c48bed0, 0x14fb68e6, 0xf03df893, 0xc527fd06,
	0x1dbf6057, 0x6dd0aaf1, 0xdbfe93a9, 0x975ba515, 0x8a51d393, 0x57dbaae4,
	0x0e81fbd2, 0x80d53c74, 0xe06e9a27, 0x244c73e3, 0xbeda2493, 0xc09c43c3,
	0xa3e6f17a, 0xb246d5a4, 0x16bed090, 0xd23d3207, 0xe4cb0a78, 0xe426e236,
	0x3d73ab57, 0x0bfc2953, 0xe30f9de2, 0x62de0d16, 0xa12113a0, 0x35dfe074,
	0xf30b9902, 0x34184fff, 0x41935fcd, 0xbde293f9, 0xc7dceafa, 0x3d8f8145,
	0x27c2e019, 0xed841dee, 0x323b6114, 0xa5c8676d, 0xe7e671db, 0xe671da69,
	0x54ed2b17, 0x97093b61, 0xfe754ed7, 0xf278ed04, 0xee76954b, 0x971c76c4,
	0x35e72f37, 0xb9e3b513, 0x49db1ca6, 0x5e26ea9a, 0xf8545e5a, 0x447ab481,
	0x4c6b6f9a, 0xa897beca, 0x3df262f9, 0x2a76ff20, 0x48be6a25, 0xf0d04bcc,
	0x97a79261, 0x392da606, 0x61c95ccf, 0x4661c4e8, 0xc8fb94b9, 0xf52617a8,
	0xee78e331, 0xbd4363e8, 0xef04c770, 0x0e3a4e15, 0x50649be8, 0xcf7ef658,
	0xe9af8319, 0x0e920538, 0xa900cba9, 0x91ad7f3e, 0xdf7261e1, 0xa49f86af,
	0xc8867df5, 0x6f0a24f0, 0x063d2614, 0x0c46d8f3, 0x91049f88, 0x04b94154,
	0xb4fd4113, 0xe3ee5076, 0xd69e1501, 0x17f4a7f5, 0x33aeeda2, 0xbf81d37a,
	0x013993b6, 0xfd35b7e0, 0x21f790a9, 0xecc0a9e4, 0xf5a24070, 0x03a617fb,
	0x95324d3e, 0x32ff756f, 0xf6347fed, 0xbff42cff, 0xd71ffa1b, 0xe0d37fb3,
	0xe6ff4d3c, 0xfe9ac501, 0x9fed32cd, 0x725efbf2, 0xe29fef0b, 0x2f21026f,
	0xfec66e04, 0xb18a034d, 0x2932b5ff, 0xd09ff4d6, 0x308bffdd, 0x9bc4dfef,
	0xda09e0ff, 0xd5280ff9, 0xf3665fce, 0xe12c857f, 0xfce027fd, 0xcc581b7f,
	0x94a03fe6, 0xdac4dfcd, 0xd1dfeeed, 0x61d7ff8d, 0x9bc46fde, 0xda8990ff,
	0xd72c0ff9, 0xfac4dfce, 0xf0549b7f, 0xffd86dfe, 0x3672813b, 0xd8e581ff,
	0xbaf26cbf, 0xbee48f81, 0xda415509, 0x0547e93f, 0x94750d22, 0xbd11d307,
	0x6bf5a108, 0xc3c460c8, 0xef8c091d, 0xfca04b3e, 0x3bea8b66, 0x4512a412,
	0xe72559f5, 0x49c6b2f9, 0xcc59e832, 0x096f7aa7, 0x66e2ea1f, 0xd49af911,
	0xe8c38298, 0xc59a3b78, 0x6b8bc000, 0x7114107e, 0x0a0b23bd, 0xc2449ea0,
	0x0faffdf0, 0xcf556e64, 0xa92e9f4b, 0xd3699e36, 0x4f1b11c8, 0x51193260,
	0x3577c745, 0x28b8c130, 0x51ea867c, 0xfbe7f542, 0x7a428f54, 0xa3fb48d6,
	0x3d534fdf, 0xdcb5644b, 0x78eb60ac, 0x911f1c80, 0xfd827a0a, 0xbe18919d,
	0x82132ccf, 0x36cfff80, 0x7e8326de, 0xa56d525a, 0xc38e8f48, 0xd914e9c7,
	0x156e0a6b, 0xc02e9f10, 0x14504fcf, 0x92977909, 0xb6a28335, 0x4d6f5368,
	0xf0499bbd, 0x7e5a749e, 0xfd8586d1, 0x37fe749d, 0x8b6535cd, 0x4f107eb0,
	0x31ca035f, 0x23c86be9, 0x46d36e64, 0xfc0a5f63, 0xfdf1ae64, 0x79fd5536,
	0x537c2d5e, 0x30ee16b1, 0xb0068d06, 0x52044a37, 0xa5bddb47, 0xf4af9b4a,
	0x62f42493, 0xfdfde574, 0xef1b2a67, 0xc366902d, 0x75d22767, 0x55d593be,
	0xcbbbe3c6, 0x5eb8c248, 0xa410a5b6, 0xf3960a7f, 0xf5bcd93a, 0x346f9de3,
	0x78e80a7b, 0x2229dfe6, 0x6fe3f53e, 0x18f5603b, 0xd374d0c6, 0x416046c7,
	0xe3f47cfd, 0x3f5cb05f, 0x61da271f, 0xeffa030b, 0xfcf44f8c, 0xd49e6be4,
	0x5caab4fb, 0xdedae845, 0x55fc55a7, 0x035330d6, 0x69e70497, 0x5a6d17ca,
	0x525fc9a8, 0x5fc9a25d, 0x0d36eeb4, 0xa77030bc, 0xe582fca6, 0xb7f9342b,
	0xe4d7ad54, 0x51bc54df, 0x6ef3cf03, 0xc9ff94d6, 0xbe4d3adc, 0x6064a070,
	0xef55ea1b, 0x2bb00cc0, 0xe01136df, 0x15df8547, 0x4fe73879, 0xdfbcf4c7,
	0x900ae985, 0x86ff2a53, 0x6df52cbd, 0xe410385d, 0x59d3c15d, 0x9000d563,
	0xebdf3d27, 0x6fe7a9f1, 0xd637d7fa, 0xe5a4a43a, 0x3d002902, 0x67d7c9d7,
	0xae45fbe5, 0x89590907, 0xe4ccb969, 0xc6577cb6, 0x3800e264, 0x16cabc3c,
	0x12125dbf, 0xac041e70, 0x1ba014e8, 0x5d0d56e5, 0xd9c66887, 0xfec4507e,
	0xc776412b, 0x560aaa03, 0xe10f2008, 0x656603c3, 0x2b3c78c2, 0xc14e6e11,
	0x3fddb7f5, 0x0969f7ad, 0xe98057f0, 0x4c5cff39, 0x98bdf8cf, 0x6317f69e,
	0x0abfbefa, 0x72ff36d3, 0x03f84f4c, 0xbfc5fe98, 0xfc77d30e, 0xe5be98d5,
	0x9fe984df, 0x3b4c41fc, 0x154c1efc, 0x93d6edbe, 0xe4aedcc9, 0x215d3ff6,
	0x73e2ee10, 0x5bbfe911, 0xe9dd1e51, 0xb65d8f20, 0xdd8386cf, 0x8996f5dc,
	0x0f1e5d80, 0x887e7a5f, 0x41e2578b, 0x4830a2bb, 0x9ed8c395, 0x460496f9,
	0x4c818b27, 0xac6f5423, 0xfb84f61f, 0x4b08d1d6, 0x0fd417a4, 0x63da67ba,
	0x20943bb4, 0x27452ebd, 0xb98c89e2, 0xcce3d281, 0x42e65fc3, 0x3af917bb,
	0xc4587095, 0x1f8492f5, 0x54bd0377, 0x27f5c378, 0xe5eb9bb2, 0xc3efe04b,
	0xad7f0514, 0x274d0803, 0xbfe44e08, 0x911326ae, 0xd62d8f00, 0x74eda120,
	0x01dc7d1d, 0x74d2ddeb, 0x0c74f383, 0x4569283c, 0xa6d39068, 0xb59a275e,
	0x30b55770, 0xd37a842d, 0x133b3895, 0x3ce9caf8, 0x9fe8143d, 0xced2a98e,
	0x79d974d2, 0x8fe237ba, 0x126345c9, 0xb7dd29f2, 0xf57fb961, 0x13b5e238,
	0x3913471d, 0x5ee3eb45, 0xf7a5c864, 0x2de83d23, 0x0017227d, 0x9f8c5a9d,
	0x409e7ac1, 0x3066ffff, 0xac212bb4, 0x890bebb4, 0xe0f7d301, 0x3fa6a37b,
	0xeca5cf5a, 0x7c5ea189, 0x19c8957e, 0x6aa89f85, 0x80341bfb, 0x538b38fb,
	0x3493f7ab, 0xc339afb0, 0xe00759a9, 0xc9ee541f, 0x7e02415c, 0xd3dce729,
	0x09d6d929, 0x086f7c74, 0x026fc62e, 0x6e61572b, 0xd3f4bd93, 0xb476ddd2,
	0x646e961f, 0x96ca62fb, 0xdc1760ad, 0xf81bc79a, 0x372a8e8a, 0xc0d51eda,
	0x45e140c4, 0xa7f6521c, 0x4d9536b7, 0x57f7bd07, 0x53619012, 0x9d5881f2,
	0x6948760b, 0x50f64ea8, 0x0c487dba, 0x3fff80d3, 0x8c707f24, 0x860bed55,
	0x97e46419, 0xebb4eb45, 0x34a3b521, 0x2d26d170, 0x486e485c, 0xac2f7e05,
	0x00a09231, 0x4fcda972, 0xbe713831, 0x0d6aa445, 0x9aa713ac, 0x55e7fec6,
	0x5b3dc780, 0xbccec172, 0xa5f76695, 0x70da5ef2, 0xefc2ed0c, 0xd4097fda,
	0xafd9eecf, 0xfb1eaf32, 0x8a878e76, 0x8c13c106, 0x1b642eb1, 0x04df6e04,
	0xc7c29d30, 0xd789d8af, 0x749be0eb, 0xfe0e9170, 0x9927f987, 0x0de7f868,
	0x61bd7bc1, 0xb017e31c, 0x22290497, 0xf699ff7b, 0x7fb47bd3, 0xfdb4bfd3,
	0x5cfdb47e, 0xff45fb4d, 0xf687f6d2, 0xb1edff18, 0xb3d8afda, 0xd500f9e3,
	0x3ecfa51f, 0xc45420e0, 0x53aa903e, 0xe5fe94dd, 0x0071eedb, 0x02939c1f,
	0x0fcbe00e, 0x60b4e282, 0x76f27d8c, 0x2fb407e0, 0xf601363c, 0xda4ff031,
	0xeea7f9fe, 0xc5eb019b, 0x4e8cdb67, 0x98349fdc, 0x772a26c2, 0xd3254d95,
	0x4f8418c9, 0x47ed7832, 0x5acdc022, 0xf27d2cfe, 0x77f05481, 0xf6e14e51,
	0x9fed187b, 0xe6bffaca, 0x23e27ac3, 0x7d179411, 0x62ffe83d, 0x0b77d42f,
	0xf99ec4e5, 0x57689c74, 0x7c5e38fb, 0x247df74d, 0xb491af82, 0xaea3bf31,
	0x63b7317c, 0x93d8361e, 0x8d9350cf, 0x1f7c9f7c, 0x0f829ff4, 0x8c766412,
	0x18cb67b8, 0xd7b687d8, 0xa821ceff, 0x5dd8a4f0, 0x8f45a15d, 0xaf8ae0bd,
	0xbef83b5f, 0x882f5a2a, 0xdccd5cf5, 0x69616afe, 0x00ec31b9, 0x9d7964bf,
	0x9fa01dd1, 0xfe3c77cb, 0x2fb0c3c4, 0x1ee4db7c, 0xdb2fdb46, 0x4d3f9bf1,
	0x4ed970a0, 0x3674f263, 0x1a909b0d, 0xfe8f8ba5, 0x4a3b3cbf, 0x7ee7d287,
	0xd932bb23, 0x457bbbf7, 0xf3b651e9, 0x7b324ca0, 0xe84a63e2, 0x8b66dca0,
	0xc9d09741, 0xc493b07c, 0x40cb5f3d, 0x080e0ff7, 0x0c506d24, 0x06fdd67c,
	0x13c07bd7, 0xa9d391d2, 0xf2ba6e9b, 0xd0174a3e, 0xf49d0acf, 0x7d7377f9,
	0x46b9ed02, 0xf33f3f23, 0xdf71f802, 0xfe61b931, 0xeedccfc5, 0x959c7980,
	0x6f5f18aa, 0x43d527b9, 0x06362dfb, 0xb2989d52, 0xfe8fc5ef, 0xe8adf914,
	0xd9534fd8, 0x6193cbfe, 0x9025b5c0, 0x525bf301, 0x57e7073b, 0x77c8bc48,
	0x02c45bc5, 0x4a9f8fd0, 0x18ceda64, 0x64503172, 0x2b767172, 0xfce89c35,
	0x03e5d2ce, 0x107f9afd, 0xffd0db83, 0xf9011b70, 0x8fe2a9ff, 0xfe114b26,
	0xf4e8ccd4, 0xdbb14199, 0xe6a6d5a9, 0xadb5fad7, 0xfdf39f40, 0xb7e0693d,
	0xc02911f2, 0x437c21f1, 0x5d8f15db, 0x43e8c69d, 0xaf2e525c, 0x29f5d747,
	0xb7ca1df0, 0x31963d1a, 0x9be47a9a, 0x97fed141, 0xb8e9fef1, 0x3e3d6013,
	0x438a4a9b, 0x1ff7e631, 0xd00eb2a2, 0x5fc55875, 0xf266f92a, 0xc99ebf5e,
	0xc1ef22b7, 0xff20d399, 0x7e4ce393, 0x4fac1ea0, 0x34e15c74, 0x5b383fcc,
	0x22607d40, 0x5d7258e1, 0xad72e46f, 0x84f857cd, 0x12125b8e, 0xd842fc55,
	0xfb9679fa, 0x686b0aab, 0xf4be953d, 0x9e8e7f41, 0x5b7229ed, 0x8fbfe5c4,
	0x527f95a8, 0xbe3ee4cb, 0xfc4014bd, 0x4f831b94, 0x4af20c3c, 0x02e033e5,
	0xc0163579, 0x1e342fbc, 0x548dd3fe, 0x14842e4e, 0x4fead539, 0xef169cbd,
	0x7f0026da, 0x42f4e5ea, 0x622ab531, 0x1efd29c9, 0xdb8b4e53, 0x4feaaffe,
	0x01937f05, 0xf146577f, 0x78c3e8a7, 0xc3ebd478, 0xc42e0cf7, 0xd21f5ea7,
	0xb724e3bf, 0x7c29ff27, 0xe95bf0a7, 0x410315d3, 0xa5f374ef, 0x7cdd77c2,
	0x0f5df0a9, 0x7f06877f, 0xf01b7cfa, 0x8293e502, 0xf7e46fbd, 0x6f2cf4a5,
	0xb43ae761, 0x298011de, 0x8cb83c9e, 0x7d23ea91, 0x5070d593, 0xe5748707,
	0x40b83a3d, 0x83abde57, 0x83e574ab, 0x7cdfbf6c, 0x07c82658, 0xe3794d61,
	0x83b0124a, 0x88bf6d9f, 0x3a4eb9fb, 0x7eb435e6, 0x60a0e367, 0x7b83ea80,
	0x1c9f6c2c, 0x80d79149, 0x4674eafe, 0xb600bd1c, 0x6742ff30, 0xa491c441,
	0xb64f0fb2, 0xdb7fa888, 0xda9a6482, 0x879510ff, 0x36bf4855, 0xf99f2f12,
	0x6d16af0d, 0xfec39603, 0xc3745ab0, 0x8af17396, 0x85c0389f, 0xe432d9d1,
	0xfbf4b9fa, 0x3c445792, 0x704ce88e, 0x9171818c, 0x50ca4780, 0x48e7f9d9,
	0xe089c1e0, 0x76616c07, 0x3a0de2fe, 0x4cb6dc7b, 0xed487d06, 0xfeb5f7f1,
	0xa5d7c64f, 0x5ae29dbc, 0xd9297e6d, 0x2704fc80, 0x2adfb040, 0x7be6d7ad,
	0x31e57ef9, 0x48b3cf85, 0xd809ea16, 0x993ec088, 0xc5abd5eb, 0xa5cfd7d1,
	0x2a3cef78, 0xae93e012, 0xdef11116, 0x6beca8d5, 0x2a5e5052, 0x99f50449,
	0x90769f82, 0xbebe3907, 0x6efddf69, 0x48b45dee, 0x1e7ff3f9, 0xdb4d08f3,
	0xf87b7f9f, 0xbcf7803e, 0xa4cfe039, 0x0729f967, 0xed67e82c, 0x73c7603c,
	0xaffdce91, 0xe00bb80d, 0x8c3726bd, 0xe7c0f3b3, 0x3a6f8063, 0x418a9a57,
	0xa7f6755f, 0xaae9a774, 0x698f9ffd, 0x3571f5c3, 0x22b7ebd2, 0xb57517db,
	0x4842797c, 0x0ace9486, 0x5603fdd6, 0x5ef817f4, 0xbf3ee0b0, 0xb8e7ff73,
	0xcd57f99f, 0x7f9f92a7, 0xdcc9da74, 0x24be305d, 0xedf637e6, 0x0af8ff1b,
	0x3a6dbf38, 0xf9a22f28, 0x7afc5e53, 0xcec1e80c, 0xe99ecc5d, 0x0a3db630,
	0xc437fdfe, 0x291856b7, 0x18403abd, 0x58d5d0fa, 0x181c98ca, 0x5f2f0b1d,
	0x72e2ffa3, 0xf80ed1f1, 0x80dff948, 0xedcf010f, 0x41ec5bca, 0xfef300b3,
	0x419fc4e2, 0x90980ffe, 0x5ef9952f, 0x7b40ad08, 0xb6f352e3, 0xf85bff4a,
	0x2de772e0, 0xde672f84, 0xe7cdfea3, 0x385d121d, 0xf41cbd3e, 0x77fdf3e4,
	0xeec3bc20, 0x265ef1c6, 0x6ff75fbf, 0x4cefff3e, 0xee945df7, 0xbbcf4b8e,
	0x96f7fa44, 0x7f74f8f3, 0xbba73e65, 0x7dc7ce13, 0xe38d7e2f, 0x6e7aaefb,
	0xdd39bffd, 0xb15fcde3, 0xb8365fcb, 0xf2d1678e, 0x0db548d3, 0x2b6b8a0c,
	0x4592bd0e, 0x77ee5f73, 0x3bc60938, 0xe8a79f99, 0xc482f7c7, 0x85933df6,
	0xb4bcb7ec, 0x7764925f, 0x3ae1736f, 0xbea0fb8f, 0xbbe87edc, 0x8fed10ac,
	0xc17efdbe, 0x833806ec, 0xb97978a0, 0x9c20c2d7, 0x1e6cbecb, 0x435d8127,
	0xf31b032d, 0x83f76bb3, 0x03c4088f, 0x077d8947, 0xb051c7fc, 0x13f5fb4b,
	0x29a56ed1, 0x9553abda, 0x66b2e5ef, 0x4bad72df, 0x4fc98fbb, 0x5e77eed6,
	0x7ac34c72, 0xc7c19357, 0xaff8e8b3, 0x419d1b36, 0x276bfe3a, 0xe3c02579,
	0xa90219b5, 0x4f1b9d56, 0x7bdb69b5, 0xf2a1e610, 0x9b9915ff, 0xb63f03af,
	0xfee02dd9, 0x03768af6, 0x8e7313ea, 0xb11df380, 0x98f84249, 0xf00e39c1,
	0x3daae33c, 0xe024ee17, 0x2cc8f4ef, 0xf980a4ae, 0xe6fabfaf, 0x8f10899b,
	0x4457f1c5, 0xb531ffff, 0x92d717cf, 0xef9d0270, 0x12048912, 0x53bf817b,
	0xfc6bef20, 0xfe185a9d, 0x6d1a987e, 0xe3e552e7, 0x3abfe1f1, 0xfef943dd,
	0xbdbb8a7d, 0xeec50e90, 0xea3ef525, 0x5f0c2dfb, 0x704957be, 0x16b73b30,
	0x3be7540b, 0xef8c8d83, 0xd765fcf6, 0x4cc7d858, 0xc89d1cea, 0xda2871e4,
	0x5f6e3e97, 0xa2571176, 0x38f206db, 0xadcf1124, 0x58f68a8e, 0xf9db5b71,
	0x3869eafe, 0x6769a4cf, 0xc116a93d, 0xf41127ce, 0xcdea05db, 0xf88c5b64,
	0xf151bb01, 0xd1ba704b, 0x6dd2913f, 0x2ffd6131, 0xd51355a1, 0xfe9f6b74,
	0x27a63481, 0x7defe01d, 0x3fc279d5, 0xcfd85f8b, 0x5bb77e01, 0x620bf2da,
	0x2340edc8, 0x38ccc7f3, 0xbbfa05f4, 0x19d4b546, 0xd547ce40, 0x62e7341b,
	0xbf6e4669, 0x186c9367, 0x16438cd7, 0xe5d00e7b, 0x7886e8a8, 0x47cb5f39,
	0xb9c637b2, 0xd09f1e8e, 0xe74ff83e, 0xb7489d18, 0x22d0c67d, 0x0fbeebc0,
	0x57f604cd, 0xb2eae57b, 0x597ce358, 0x425ce366, 0x198fb742, 0xdf87eff4,
	0xf0b69d49, 0xd4afd864, 0x9eeb9413, 0x8f9047fc, 0x10481abb, 0x6fec31f4,
	0x35742f40, 0x280f5c12, 0xfb017e4a, 0x3fef2a33, 0xafdbef52, 0x34f9de68,
	0x2d9523ac, 0xca5c1382, 0x0c9b5295, 0x735f397e, 0x3b7a0892, 0x13c4a5cb,
	0xab67333a, 0x518e62e4, 0x9e1efc42, 0xe826efb0, 0x9976e3f7, 0x79e6bac0,
	0xbd00e229, 0x58cb71ff, 0xf3788394, 0xae4fce7a, 0x3b412a9b, 0x3a73d984,
	0x98dd187e, 0x12af81a0, 0xbe407dbd, 0x96da9866, 0xefd063b9, 0x9767ce73,
	0xff82dfad, 0xe3b7e99f, 0x8af37e8a, 0x7a392a05, 0xa54de391, 0xe962d2df,
	0x2b82a5b7, 0x74bef00d, 0xa03490ff, 0x8c57d2eb, 0xdbf4b129, 0xd73b3f0e,
	0x81c7967a, 0xfd513676, 0x7e953df6, 0x2dfaa26b, 0x76fe39c6, 0x6faf81a3,
	0xc16fd097, 0xdbf919ff, 0xc62dfa01, 0xfa745b7c, 0x49cb4c6d, 0x9a636fd4,
	0xc9789a0c, 0x8fdc8ce7, 0x09bf5719, 0x9ec1b329, 0x5b746a3a, 0x0ecff063,
	0xcb3dbf6e, 0x1fa060e3, 0xa05d73d0, 0xbe5dc6e7, 0xe5e3fb9e, 0x21ffb9ea,
	0x6e7a2b3c, 0x71826ee9, 0x90f93da4, 0x7ba5b9e9, 0x80139ea9, 0x5b9e991f,
	0x3f309fba, 0x8dbf4e8e, 0x08dfa1e8, 0xb30caf96, 0x41e6befa, 0xdb4cdd0f,
	0xdd18f6cb, 0x3b3e5a66, 0xa9c6efaa, 0xe8175df5, 0xf43171bb, 0xd3cbd1dd,
	0xbeb9bb77, 0x306c7aa3, 0x7f3d57e8, 0xf1b45bb8, 0x9fc6fbb6, 0xe40e7c6d,
	0xcf1135e5, 0xd8198e97, 0xc7efc079, 0xfe01cd9f, 0xe36656ba, 0xfb332fe9,
	0xc01fc3a4, 0xc4bca7f6, 0x636157e6, 0x4d95b871, 0x6cac3ecc, 0xfa2e8214,
	0x5f09fccf, 0xc95139e0, 0x51a4817e, 0x9589a678, 0xe72a4f27, 0x967a6423,
	0xe7161f8a, 0x775fa195, 0xe0cc44b1, 0xe5b32db7, 0x6c76007f, 0xf3f31e59,
	0x25eff196, 0x01adb4af, 0x66c9673f, 0x94c7cf01, 0x8e2541f8, 0x7979c7b2,
	0x07f40acb, 0x67cdcfea, 0x199778f0, 0xbac10b4f, 0x65f6e718, 0x87f85a0d,
	0x8a679f9c, 0xf22f886d, 0x16dee8ba, 0x72947e43, 0xca3a78dd, 0xe22f54f1,
	0x278dda7a, 0xa0d7378a, 0x94a2789e, 0x1a959e9e, 0x6bc94bc5, 0xf139be74,
	0x4de0abe7, 0xdfc56f3f, 0x89dbc659, 0xcf050787, 0xf1cfe63d, 0xf510484e,
	0x1e1f1ea4, 0x2c99eb99, 0x4ce21632, 0x9ea0df28, 0xc456fc09, 0xa4c152fd,
	0x04fb9a61, 0x632f1cf9, 0x814d27ab, 0x1099ebe3, 0x6de70bb7, 0x023b6e9b,
	0xdee377f1, 0x72c36572, 0x9304d57a, 0xb6ddce17, 0x07a8225b, 0x587c3e15,
	0x32c07666, 0xfafb87ce, 0x7dc64d54, 0x04e0b361, 0xb617c43b, 0x147d5e20,
	0xc3bf70af, 0x3e63f7c7, 0x7f208fca, 0xc67f3787, 0x705fb8f0, 0x5f203f81,
	0x2e80af59, 0x16d8fcb4, 0x505f1746, 0x90e4ba40, 0x2bdbfa08, 0x30ee0937,
	0x0eb9afe0, 0x67e8a7f1, 0xd35367fa, 0x52bfc549, 0x42c5fe2c, 0x8cb2f5aa,
	0xaa619b97, 0xf3f013fe, 0xa48d278c, 0xff4dd10e, 0xd67e36fb, 0x825c7fc7,
	0xbc71376f, 0xda7c00ef, 0x66116f00, 0xc0bf8577, 0xbe4a26fb, 0xf0680a4f,
	0x8be1e539, 0x71af8adf, 0x8f80be0a, 0x2cb5bf41, 0x6c2e0114, 0x41ef4816,
	0xe70be73d, 0x2f796a5f, 0xb5927fd9, 0x937045bf, 0x6cbef318, 0xcfc38ebe,
	0xc16f94c5, 0xaf8f1ebf, 0x587a78f5, 0x23ebf6ee, 0x12deff3f, 0xf02c7579,
	0xe5017ef3, 0x6924b49c, 0x905eb1ce, 0xbb693ed9, 0x9d3df285, 0xa315e477,
	0xa7abab7b, 0xe39a783e, 0xea0ff617, 0x61233cfb, 0xd7e71022, 0x2d78c660,
	0x6660c71c, 0xf3f5aa9f, 0x99490b0e, 0xfdbf139d, 0x78fdbcbd, 0x670291f6,
	0x9f107f42, 0x1bfb4cdc, 0xbf4fed11, 0xfefb283e, 0x08ebcd4b, 0x747fc397,
	0xdf3f4a5e, 0x47c5fe35, 0x4aae915a, 0x821bcc1c, 0xec11b877, 0xbc6d3cb9,
	0xd7391d19, 0xfb74ff5b, 0xe2e38d87, 0x9dd24fb7, 0x76e95f78, 0x89ddf2a7,
	0x24e059fc, 0xe2683cfc, 0x7feeb09b, 0x5de761ec, 0xc6f20639, 0x263f5844,
	0xd5f0091b, 0xd11aafc7, 0x54f1f96f, 0xfd792f16, 0x6fd1876b, 0x818b3d74,
	0x138fd722, 0x0c759f70, 0x760f1e9a, 0x867899b8, 0xc2c6fe23, 0xfaaca8bd,
	0x2a2e29ea, 0xc10dd9d7, 0xa7ba9055, 0x0f7f9244, 0x12249b74, 0xa7ab5ba0,
	0x851b14f7, 0xc92bff6f, 0xb5199702, 0xf67eb00f, 0xe5029251, 0x70527826,
	0xe9be331b, 0xe8b3e393, 0x2abfc638, 0xdcb45dba, 0x1b36c3cc, 0x88f4f6a1,
	0xaaf1035a, 0x048135f0, 0xf2b9c157, 0x599ed3f8, 0x6a62ee30, 0x7e1c40ef,
	0x2add4b71, 0x02b5c007, 0xbc05f7d6, 0x9f3a0ef9, 0xca3e9b1d, 0x02f412bf,
	0xf8cd072d, 0x5f39596a, 0xd086e0bd, 0x8d96c2d2, 0x7a8dea32, 0xed6c2f01,
	0xccc40a08, 0x699a0dda, 0x696a3bbb, 0xbf581cfd, 0xb7687d68, 0xb3e3a3fe,
	0x71d0ef40, 0x7646fd62, 0xeb485b0e, 0xea5e40b9, 0x4af6c36f, 0xf702056a,
	0xd91b8a05, 0xaafc54ba, 0x4df90dd1, 0x7ae33707, 0x97f69d3b, 0xa1d60831,
	0x77bc54f0, 0xe2705631, 0x7f77347d, 0x1275d3f4, 0xb1723f46, 0x0263d32f,
	0x47bef987, 0x99d6fbb1, 0xa16d5c58, 0x9bdc857b, 0xbcfbf3b6, 0xe4064194,
	0xb0648fab, 0x7c534ed3, 0x8fbe297b, 0xc384f8f1, 0x36e4a779, 0xcdb8bad5,
	0x77e50434, 0x3c24f371, 0x0a425fb7, 0xc67edcf0, 0xbe6f6678, 0x504b03fe,
	0xdd7ae3a0, 0xdf07e918, 0x84c0ff0f, 0x30763bdf, 0xbfd1dc3d, 0x67b3fd0d,
	0xee048d6b, 0x15aaac09, 0x6d9c5f51, 0xb539e234, 0x7a88c5b8, 0xb30768bb,
	0xb2d70e3f, 0xdd82cf76, 0xc8727e06, 0x76d170a7, 0x99f7ef81, 0x9ff6569e,
	0xde764e85, 0x0adde8ae, 0xeb1eef3e, 0x190acd50, 0x6faf5658, 0x2e3eb82b,
	0x2fdc6125, 0x056ef5eb, 0x403abb9c, 0x4171f52e, 0x063ee8b6, 0x05fc20f8,
	0xabe575f2, 0x18fb0246, 0x3e7b54e1, 0xfd83fb8c, 0xc7b9fa02, 0x381e08b7,
	0xcb7e2eef, 0x3bfb4414, 0xcfc170b8, 0xdb797d60, 0xf4e42044, 0xea81d00c,
	0xe4533ca9, 0xdfa6bf2f, 0x8666383f, 0x37ca1008, 0x4aef110b, 0x36ce667c,
	0x7391bf16, 0xee1526ac, 0xbda9924b, 0x6d140f51, 0xa5578912, 0x3c103e27,
	0xeb646eb3, 0x1dec1383, 0x72399e85, 0xafac2175, 0x5e989a6f, 0x42336d76,
	0x6ff9044c, 0x01fdd30e, 0xec965dc6, 0xab2a98dd, 0xff64a0f8, 0x7e9154c6,
	0x1fe3c35f, 0x4afac156, 0xacc895eb, 0x8203929f, 0x8fd54eb3, 0xaed28ed2,
	0x1bd597bc, 0xf1a59fb2, 0xf1812fda, 0x953f3ce1, 0xdbe85f41, 0x9c7fd1e9,
	0x78fef276, 0xe3a046b1, 0xc45d7bca, 0x53bce360, 0xcfa887d3, 0x89549401,
	0x6e3dc853, 0xfe151e20, 0x4092fef2, 0x377a2a3c, 0x4f72a38d, 0x66e3f7e9,
	0x00116821, 0xe457293e, 0x3904ec20, 0xe7fee4af, 0x7ceca9ca, 0xd8eb29a7,
	0xe9fb906a, 0x03f20239, 0xdee57809, 0xb9af68c9, 0xccfe05ee, 0x688bf561,
	0xa6c7907d, 0xa93e4ccd, 0x1e81709e, 0x98ddaca9, 0x05ebe58f, 0x54dfb417,
	0x91ed10b7, 0x60913ce2, 0xb449fd7e, 0x4f9b8a8f, 0x531c8326, 0x7b01adb9,
	0xc9a272a0, 0x915c7a09, 0x5fbe4547, 0x8905f7e7, 0xfe0999d9, 0x7c2051fe,
	0x5ae53d29, 0x75e9957c, 0x4793235f, 0xd7931e5f, 0x611877d7, 0xdf239786,
	0x1b67cf28, 0x5b8abc98, 0x7dc3e4e6, 0x2c6da2e3, 0xed70e52e, 0xe9ec1914,
	0xd70141b3, 0xcdf29e9b, 0x7cbd56ec, 0xbad812af, 0x4bed5df7, 0x3915be45,
	0x863f7fa6, 0x9ca9cafe, 0x5e8839c2, 0x431867ae, 0x8e9dba7f, 0xe867faf7,
	0xa778e87c, 0x474ef0fc, 0x524f4a9b, 0x42e01538, 0x7335c789, 0xb12152bd,
	0x3cefaf38, 0xd3ff5d3e, 0xefff5a4d, 0x58929b7f, 0x11bd72bc, 0xf252fef9,
	0x2ece43d9, 0x572f3e53, 0x9f252eae, 0x7ee2ff4a, 0x0dff3b6d, 0xb3d71fc4,
	0xd78a0ebd, 0xcbebc530, 0x5c638f8d, 0x9d4f87e7, 0x29f4019c, 0x1cf947db,
	0x4ed1abf8, 0xa4e7a0c2, 0xa557ae20, 0xe307a24d, 0xee70a55e, 0x8e5abb2c,
	0xd94f7c59, 0xbf4e2cb3, 0x38299774, 0x7d2fd69d, 0x8c18d4fe, 0xc11958bb,
	0x53c0a3f8, 0xb40e5edc, 0x2839018d, 0x919c5895, 0xccd82f5e, 0xdf6e7ecc,
	0xf30b9d6b, 0xfdd81a13, 0x4fd0d2fc, 0xb9d5268c, 0xb2366884, 0x56bdcff8,
	0x500c073c, 0x91fb863e, 0xbdf53e30, 0xa8be2570, 0x13d33b7d, 0xdc46cda5,
	0xec369607, 0xd17880ec, 0xe84cb7d2, 0x7c35f2ef, 0x53eff184, 0xfe81dd9e,
	0xa8b35f14, 0x11eb3f39, 0x8620d7a7, 0xd667104d, 0x7de78154, 0x70893e14,
	0xeabc7628, 0xcac9e2a5, 0x7cffdd9e, 0xecb0a280, 0xa01d27b9, 0x6eb7ce5f,
	0x69de0073, 0x271adfbb, 0x2f2e23db, 0xe35bfeb4, 0x3fc3cef2, 0x338ce0a8,
	0x1b1ae2eb, 0x491da37a, 0x105b97c7, 0xdba39ce3, 0xe9f1df2e, 0xde3710a3,
	0xa3c2ebbe, 0xbff2de30, 0xc428fc7f, 0x1603910f, 0x4f7cef5c, 0xb77181bd,
	0xcdebbd4a, 0xfdb43fdc, 0xee578c49, 0x86e4db78, 0x9ff63ad6, 0x6371001d,
	0x48bf3b1d, 0xb2e5bf05, 0x5fa357fd, 0x29eed977, 0x7ac62469, 0xb7c0a4a1,
	0x9788cbc1, 0x70ebd3d6, 0x738c61d3, 0x1bd290fa, 0x9c775ff4, 0xc582a865,
	0x7c78baad, 0xb8ec6365, 0x94f11ef4, 0xffaeb34d, 0x26fde801, 0x325e3f66,
	0xa538f2ae, 0x832ef7e3, 0x5f8a8d7e, 0x3efd3620, 0x878c7f84, 0x5c6d7e78,
	0x4b4da7e5, 0xf2187b1e, 0x8dc77a9a, 0x065f0cab, 0xf7b894de, 0x72cf6609,
	0xaed7c833, 0x158e31a7, 0x05dd36e8, 0x03a7cfeb, 0x39c0bee0, 0xde3e6463,
	0x726fdb0b, 0xe9611c42, 0x7e5137fe, 0x431f763a, 0xf1e1343f, 0xfba41de7,
	0x0b0bc58f, 0x76f59e7c, 0xf1c98f16, 0x2e9af10f, 0x71e77e07, 0x958f8c99,
	0x7178cd78, 0x60f3219a, 0xe3c92e76, 0xffea2bf1, 0xa31ee3cc, 0x80f212f4,
	0x35bf274e, 0x83c155fe, 0x68e1eb93, 0x78ec71dc, 0x74f8eed8, 0x1fa02f4e,
	0x71dd43ac, 0x97ee14c5, 0x37a37e8d, 0xc7fb8709, 0x3a8edf90, 0x61dcb716,
	0x8cdfded4, 0x23c589d2, 0xb7a3ad3f, 0x7278df32, 0xa5ebc8a2, 0xf15df1e6,
	0x411808f4, 0xd5f13d29, 0x7d6c55fe, 0xff2e7bfe, 0x967df0ff, 0x3efe82d9,
	0xb8666bcb, 0x5274d2cf, 0x7c147166, 0xdbe7cdbf, 0xedebfdce, 0xcf18894f,
	0x187426ba, 0x6f5eb9f5, 0x14bbc254, 0xc6dbc631, 0xccd95bc7, 0x5df68bd6,
	0xb68da0f6, 0x2f687ed3, 0xe36575f2, 0xdb403949, 0x9cf0d23b, 0x98a9cecc,
	0x117ac11c, 0xfdbf8d54, 0x50638399, 0x2ff7f37f, 0x99a3c87a, 0x625ad7fb,
	0xfc6be3f7, 0x594fd348, 0x6d3b2420, 0xbcefee97, 0xb409f9e4, 0xd995be77,
	0xe243e785, 0xb9f758b4, 0xb3f5f18e, 0xba1dfdfb, 0x1f3be26e, 0x87aef676,
	0x3b4048e8, 0xef3d9973, 0x4864c4ad, 0x59f38c65, 0x05c782b5, 0x0e9ddcfd,
	0xbf655ef4, 0xef78c08e, 0xfcaafc01, 0x97a7463d, 0x4c6a7d80, 0xff01c82f,
	0xc8ef5e82, 0x541206c9, 0x7d997fd1, 0xcf0b9a5a, 0x80fdc23d, 0xceb2279e,
	0xf7dda11a, 0xf7aafe74, 0x8d26b224, 0x80bdef8e, 0xdb415ee0, 0xea9d5f25,
	0xd9ef605f, 0xef7b02be, 0xa5fe3516, 0x04e4534a, 0x8bc84fec, 0x10738c16,
	0x3df0580f, 0x16a3df05, 0xdde1ef9c, 0x76813f9f, 0xc22663f6, 0x2ee87fce,
	0x915ff286, 0x7671b593, 0x7e8fe7f7, 0x54347609, 0x3d17fda6, 0xfec3cb4a,
	0xfb8ad1a1, 0x895dce9d, 0x523fc063, 0x335de2f4, 0x5915af40, 0x3d163f19,
	0x455c169b, 0xc2933bdb, 0xfa3b33e0, 0xb2fdfde3, 0x378c765d, 0x4f7bbc3c,
	0x1d4fac25, 0xac095acf, 0x722f1d4f, 0xfe69ff7b, 0xa326d01e, 0x5c771d4b,
	0xfa972442, 0xc019471e, 0x83ef1f2c, 0x972e5fe0, 0x355bf023, 0x0ffde227,
	0xda6b076a, 0xb918d0f9, 0x1c7c8dc3, 0xbdeec3e8, 0x3e80fb84, 0xf25397d0,
	0xcc196fbf, 0x7ad305ef, 0x9f7968b6, 0x7064291c, 0x4fa61f75, 0x54fcb15a,
	0x2527930b, 0xacbb67bf, 0xd30b64fc, 0x5876d1e3, 0xdefe4afd, 0xaf7f9e87,
	0x29f930b7, 0x8afaf86b, 0xc459ef58, 0xff7e3f18, 0x060240a9, 0x5a7657b0,
	0xb8219df0, 0xedf10f07, 0x7ceccbcf, 0xc611dcab, 0x71f644f7, 0x109e5c7d,
	0xfa4df7c6, 0x794071f0, 0xedb98980, 0x6aa77c19, 0x7bc0858f, 0xda2f1537,
	0x8aef403d, 0xf33f3fe7, 0xb3c40e48, 0xba9e3159, 0x42ffc5e2, 0x8530a83e,
	0x443c83e7, 0x56c89a76, 0xaf9df390, 0x6d79000c, 0xf4078637, 0xbb7396fa,
	0xf749908a, 0xc79b001e, 0x366bbf79, 0xee565bdc, 0xd1c69653, 0x66160d33,
	0x78b32f4f, 0xde505a96, 0x9ce6efb5, 0x059dcff7, 0xf295e4f7, 0x7ad8e6a5,
	0xf8c58d71, 0x5b71e9cf, 0x6b897b8f, 0x921f3c60, 0xfff054d6, 0x1bfb5254,
	0xc36979f4, 0x2fe07ea0, 0xee516438, 0x6112bb91, 0x74643a3d, 0x521abee1,
	0xce733af5, 0x0d259eef, 0x88ce3f05, 0x479d1259, 0x8547dd67, 0x1fc4087d,
	0xd2c6e65a, 0x562c9b7b, 0xd9a947c4, 0xaf7589e4, 0xd7e71b71, 0x1ff9b0b5,
	0xf903fac7, 0x643dfa50, 0xee1ea20c, 0x72c2e09f, 0x047f74a5, 0xe61acbdf,
	0x73bcd2cd, 0x39635521, 0xcf88a72a, 0xe7235212, 0xd2b7f4a8, 0x9cf2c95f,
	0xf858d259, 0x9badfd2e, 0x9d28c55f, 0xed192049, 0x98e38943, 0xdcd48cd4,
	0x058c902b, 0x4c9fc066, 0x08929c0a, 0xf28d52ac, 0x9842409e, 0xc5d9a8da,
	0x22aa83de, 0x75cf27a0, 0x304163bf, 0x4eebe28d, 0xfe81fbd4, 0x041b0c84,
	0x895df9f7, 0x76fe154e, 0x1e381c59, 0x98455493, 0x84ee98be, 0xf01083fd,
	0x3f286f92, 0x9b4ff2ad, 0xff48fc05, 0x0cff703c, 0x7c7420b7, 0x2f91e70e,
	0x280a1ec0, 0x90fda6ef, 0x14515704, 0xfa291843, 0xf6132757, 0xb7bad7de,
	0xf1df7a88, 0x0903a726, 0x663d441c, 0x08bfd123, 0x82ad4185, 0xf8955dbe,
	0x4f383cf7, 0x184939b4, 0x8dab43ec, 0xb534ad84, 0xabce968d, 0x4391dfe5,
	0x3a9f1561, 0xf5f36a27, 0x9af54172, 0xe210dfae, 0x89fbb68f, 0x744fddae,
	0x6df27eed, 0xf2782aed, 0xc016b799, 0xf8f7037b, 0x58de380b, 0x378e667f,
	0xf0119f8a, 0x2431195e, 0x38b9f9b8, 0x8f8135e2, 0x87e504c6, 0x830c73c0,
	0x4bee9f90, 0xf881103c, 0x89bc9259, 0xb577fec0, 0xfa69d6c0, 0xd5536057,
	0xca334e23, 0x4fde7ae1, 0xf3c30272, 0xd54fc56a, 0xef05bca3, 0x6f28f72b,
	0x213e5789, 0xbc7b7976, 0x8e6358f1, 0x99eabbe7, 0xfcdf17ca, 0x76c79c3d,
	0x45271beb, 0xdf46ae65, 0xdd802724, 0xefe67498, 0xd985f86d, 0x5a7ee68d,
	0xbf0025fa, 0x1849fe52, 0xa7aefdaa, 0x597e3c7b, 0x6141e7c8, 0xd79d065b,
	0xa9ffbc8d, 0xfb3cecf5, 0xffcc65e6, 0x1e7db746, 0x2f137f28, 0x08b9a37f,
	0xf92708fd, 0x6f37473b, 0xcde17662, 0xee788b77, 0x1f1de3dc, 0x9f9507f8,
	0xc10b965b, 0xef58a0f0, 0x91fa9112, 0xbc05fdb4, 0x3f3bfd7f, 0x5fcae25e,
	0xe77ac627, 0x7299f187, 0xeeff4aaf, 0xc05262c0, 0x7ed26fdf, 0xece2cc7f,
	0x94d587d6, 0xf28da2ce, 0x6255d82f, 0x63df1b82, 0xe7851e4a, 0xf2de8a61,
	0xbf80ce01, 0xf71808f7, 0x2575e5d1, 0x7d96faf6, 0x5cff16ff, 0xe1dcaf8c,
	0x80e984df, 0x2a0c1e65, 0xfa089a94, 0xc5fceac1, 0xa9b33df8, 0x7038804d,
	0x1426d9c9, 0x7f9b74d2, 0xbc1f7e39, 0xb33e5b5a, 0xe56065c9, 0xf728065c,
	0xe58bdf98, 0xa157f71e, 0x5feedc5e, 0xfe93f087, 0x6bc3a600, 0xbba578d8,
	0xf71e78cd, 0xcb1abfb4, 0x1e98f6d1, 0xff4660db, 0x2b136653, 0x2f36bc37,
	0x9c96f308, 0x462c6e1c, 0x907f59f8, 0xf3d689c5, 0xdc585af6, 0x376580d0,
	0x716dde6a, 0x66ab7ddd, 0xbabc1fdd, 0xccaf9354, 0xa586e863, 0x4d99729a,
	0xd1a2c341, 0x699fde30, 0xa0ce4bbe, 0x462dce01, 0xb4d4aed4, 0x5efeaa33,
	0xafe3dc5d, 0x9a63f934, 0xeec0d61e, 0x581aad96, 0x45f94fa1, 0x537be0aa,
	0x14f8bbf9, 0x53f36bbe, 0x809027ab, 0x395ac2f1, 0x40be0cb9, 0xfc52eb3b,
	0x83df90f0, 0xeb0b5c78, 0xb67870d8, 0xeb3fd981, 0x7dee1c79, 0xa5134ef0,
	0xbbf82fcf, 0xefe4bf3c, 0x8ff46cf2, 0xf6bfefc0, 0xc07e11bb, 0x66f0879f,
	0x1f8434ff, 0x9c2017f1, 0x80f16562, 0xb01e3c74, 0x996f48db, 0xe6d127c5,
	0xf574dce0, 0xcf189196, 0x3178245f, 0xd26ce584, 0x06f5fc9a, 0xcfa03f26,
	0x94fcb84a, 0xfbe0ecb5, 0xef026ad4, 0x5d51a588, 0x9b10e78f, 0x95b0efb4,
	0xb530b504, 0xf770355f, 0x75f96abe, 0x9dea94e4, 0x87b9631a, 0xaa49bec0,
	0x94e3899e, 0x8bee09ca, 0x05ab6724, 0x9fb5c5d6, 0xfd15a408, 0xf0331eb6,
	0x0665eaff, 0xb065d7ee, 0x061d99c5, 0xc324b43e, 0xe76a38ed, 0xa65f38ba,
	0x5f5db8b3, 0x9819e45a, 0xe46f1536, 0x4d59c937, 0x9376548a, 0xb9dd8e25,
	0x186d7ada, 0xf6a16fe8, 0x64c39887, 0x6983fc04, 0x2509b78d, 0x977dfeb4,
	0xc61d9718, 0x61d8eb45, 0x1f5eb45c, 0x1ac4f137, 0x35c61d97, 0x8a4be71a,
	0xc7b0e354, 0x71d3dfd9, 0x052131fd, 0xae029df2, 0x9e0953af, 0xfae32bb7,
	0x16cb8c25, 0x1c495c7f, 0xbe0a495f, 0x8ff7043c, 0x752571fa, 0xa829cbe3,
	0x1f1495f1, 0x5c60675f, 0x3040a449, 0x6b66be02, 0x4bebf5f1, 0xe3852be0,
	0x57c1452b, 0x500f7b01, 0x6e94ae3f, 0x6a08157c, 0xc7c4a57c, 0x474017d7,
	0x7c6d3f73, 0x04d0c274, 0x8db01e8d, 0x57c9a5ee, 0xf4e473da, 0xf3d9c6d1,
	0x0e2738f9, 0x35ef7cd6, 0x4e069475, 0x69ad9e9e, 0x04f6753f, 0xf37e9c0d,
	0x67dc0d64, 0xfa9a75f1, 0xd06fcafd, 0x1cdda7e4, 0x5c9eef66, 0x53d7aadc,
	0xfb18d629, 0x1ca34ea2, 0x3a107780, 0x161d9933, 0x161da810, 0x79755f43,
	0xb5776f19, 0xbf81d664, 0xf9e71c89, 0xef8f964e, 0xbc432564, 0x8fe815e8,
	0xbbf2e72a, 0x7a80dfd3, 0x087f39e6, 0xee6ecef5, 0xe3c3d8e7, 0x437b9596,
	0xa85d97be, 0x1d5fca67, 0x3b9d022e, 0x05cf335e, 0xba5875fa, 0x784cc61c,
	0x98e2293f, 0x511fe143, 0xc0ec0a33, 0x8b4c894e, 0x701fc745, 0xef72b67d,
	0x3ef813d9, 0x0b8b5ecb, 0x285ff9cf, 0x3f076059, 0xdfcc3bf6, 0xaedf4f11,
	0x5a277ab6, 0xf7b39f51, 0x7d772ae8, 0x593be784, 0xe822498d, 0x27565199,
	0xdb1bf3f3, 0x21bec006, 0x34a7a5fb, 0x7579cff8, 0x593e8697, 0x5df0852f,
	0xca1e8523, 0x71e941fa, 0x1593f40d, 0xb16f1f87, 0x465e8a0a, 0x0f0d4c3d,
	0xc7e87fb6, 0x4b7675f0, 0xe56be20a, 0xd2ed546b, 0xd35ac2fc, 0xe1679856,
	0xd64715a6, 0x3dfc860f, 0xc2ecfe47, 0xb4f46861, 0xf4a8cf12, 0xf3f55df3,
	0x95cebb3f, 0x92baf4eb, 0x406c5d96, 0xa1c374bc, 0xdd33efd8, 0x5e22b56e,
	0x7bd3e27a, 0x085ba33b, 0x2eca13cf, 0xf5df833e, 0xad89f5e3, 0x53739c32,
	0x6bdf8c7b, 0x73bee173, 0x65e3e719, 0xe77c2159, 0x248ed960, 0x15ac2af7,
	0x2d7c054a, 0x5b49e71b, 0xabe87a0a, 0x5511be6f, 0x7c7eb6f6, 0x8d268de5,
	0xdfd94fbf, 0x95221a76, 0xc1b51a10, 0x52d5f2fa, 0x8fefdc06, 0x906c0074,
	0x1a7aba5e, 0x3355479e, 0xc42ba4ff, 0x761cbcfd, 0x0eb360ea, 0x50ff4296,
	0xcb45579c, 0xdf702385, 0x55e71550, 0xb461fa8b, 0xedd13f76, 0xd7678e77,
	0xb4c533ee, 0xbb46bb6b, 0x3a3e40d2, 0x46ff1413, 0xcb57cf18, 0xba3335d6,
	0x71871d1d, 0xfef817dc, 0x9062fcad, 0xcb20abe9, 0x1948b8af, 0x42b7e917,
	0x60b847e3, 0xcb5efd88, 0x27e656bb, 0x23f968ab, 0x70571b9e, 0xf2e0a9fe,
	0x22517155, 0xcd77ca1e, 0xfb961356, 0xe982d59d, 0x8ec1b05b, 0x36366725,
	0x90ce453f, 0x1e6f0056, 0x33953084, 0xace472f9, 0xbbf7e382, 0x7cbbd9ca,
	0x36dcc45c, 0x6959f81c, 0xcaef3f47, 0x29e2076a, 0x456e9f6a, 0xeadabf7d,
	0x43c823f9, 0xf680a379, 0x09b37944, 0xd77dd1df, 0xd37c62ea, 0x5fe78494,
	0x609f17e5, 0x7eb12272, 0x7d45e9e2, 0xcdd5653f, 0x21ed791a, 0x767dfccf,
	0xb92ff7fd, 0x2e22eb5e, 0xcf47df7c, 0xc45f0a1f, 0x62e2b76b, 0xdd1c6682,
	0xb3a6eef4, 0xed1ce903, 0xa9decccf, 0xc1427ae1, 0xe7cfc523, 0xc513f0b1,
	0x51e23e4b, 0xebd2af39, 0x2abae89b, 0xde8bee68, 0x473a3fe7, 0xc6b4afed,
	0x6d23efd1, 0xfbd75f8c, 0x292fd0ab, 0xc138f21d, 0xe2dab5bf, 0x8c50fc0e,
	0xb9cc93f2, 0xc248c129, 0xa938e8eb, 0xdcf184ed, 0xfdc03ee0, 0x57e620d8,
	0x86926c92, 0x0a64e47f, 0x3550f46b, 0x434cbdfa, 0x6bfc0089, 0x1fcda7ee,
	0xe385eb66, 0x56c477bf, 0xee3a42e7, 0x43f88d5f, 0x1dbde200, 0xd1127de0,
	0x69a5d3ff, 0x716925ef, 0xfa7c5cef, 0x139cff09, 0x7faabe69, 0x00a750cb,
	0xa9af4876, 0x3c7a7ada, 0xf3a50c24, 0xab538cd7, 0x03b325af, 0x8a2819cf,
	0x70889f98, 0xa84884fb, 0x993ad68f, 0x75695a3e, 0x19aebca0, 0xd63a4068,
	0x83d3ff70, 0x1b0277e0, 0x3fa12cc3, 0xa05dc211, 0x40189cbc, 0xfc0592bf,
	0x29d02294, 0x5e1db08c, 0x5e711170, 0xc449c002, 0x4deff385, 0xff606bc2,
	0xeda939da, 0xcbdef80e, 0xa3649de2, 0xa32cfbf4, 0x7e0084f5, 0x15ef02c7,
	0xc49bef20, 0x844b9640, 0x59225277, 0xcd006e50, 0x4b17ab7a, 0xb1fc4207,
	0x319e7557, 0x8511e718, 0xc0f09ec5, 0xbfce92e5, 0xea15d5ff, 0x4f1665fc,
	0x6dd28d81, 0x17bd8595, 0xc04a7c93, 0xb75576f5, 0xe500b95f, 0xefc6d0a9,
	0xb8f4e97d, 0x837ed844, 0x47c808b4, 0xe8a71e8a, 0x6692f59e, 0xac0d6e5c,
	0x7177cfd0, 0xd40f46aa, 0xfcabff03, 0x8f2543ec, 0xc3a8fc01, 0x6ff7e9aa,
	0x71f623b1, 0xac580e7e, 0x8092ff4c, 0xa79af408, 0xad2abfbc, 0x51127066,
	0xcc3df0fe, 0x317f15b7, 0x2760cd59, 0xb2b77c83, 0xbf3d29f3, 0xdb596bcd,
	0x79da7e0a, 0xe08b192d, 0xf99e62bc, 0xba42bfca, 0x643918cf, 0xa7f7fb05,
	0xf1b82ecc, 0xa08c978d, 0xdf1f772a, 0x578bf78a, 0xcf9c98da, 0xd0231127,
	0x329c4bd5, 0x510737f3, 0x6e256f8e, 0xa08c870e, 0x070e6f47, 0x4298fce7,
	0xfc14bcb7, 0xf39f2c31, 0x037e468f, 0x9c86f568, 0x55d3e8f9, 0x8fbb35ea,
	0x8bd59830, 0x3eff81e2, 0x79c66484, 0x466de745, 0xa4f3283c, 0xdd9e9125,
	0xf1efe278, 0x9ee97828, 0xeba6f5b7, 0xe9e39840, 0xcce679d5, 0x5738b2bf,
	0x9e3d2e36, 0xaa2c813e, 0x3cdbd737, 0x2dbf028f, 0x831e79b7, 0x191cdcb4,
	0x79460d20, 0xa1e41c78, 0x4c0ef452, 0xb0f878a5, 0x148af7bf, 0x8b2b47c0,
	0x6fd789b7, 0x9cffffb7, 0xf82b2f96, 0xf76ab1fa, 0x4fe08915, 0x688aff38,
	0xbcf6fb00, 0x77bf9d91, 0xf8915c35, 0xe733f16d, 0xcba4bfb8, 0xc5fbfcc9,
	0x42f283c1, 0x3fa89f38, 0xba3adf28, 0x2e053967, 0x4194ee0e, 0xefd495ff,
	0xbd056f94, 0xe8e9efcf, 0xc6d97fdb, 0x1bce9bce, 0x1f18f943, 0xc27043b2,
	0xe3595779, 0x7bf023ce, 0x49f5c528, 0xdc1e70d9, 0x692f0efd, 0x2df4031d,
	0x77da8a09, 0x4ecc438b, 0x18eb5221, 0xe5383df5, 0xfb550a1d, 0x77f73ef8,
	0xf2d17f6d, 0x6f54e4c9, 0x4e73f738, 0xf03d3b02, 0x45efe328, 0xc4223d53,
	0x27584f0b, 0xfc7a3ee0, 0xfa0236e9, 0x124d5175, 0xdd177681, 0xbc1674b9,
	0xead9507b, 0xfd036e6a, 0xc3dc1410, 0xde269268, 0x8a73f596, 0x310e078f,
	0x1b7c003a, 0x8f36c5d8, 0x0bf2a6cb, 0xb2ab1bb7, 0xb74f209c, 0x1f603cd8,
	0x79ed9c2e, 0x48a9f81b, 0xbf041f0a, 0x85cf32b3, 0x80f2bb37, 0x2c86172f,
	0x44cd4c1e, 0x727aa04a, 0x90cc44a1, 0xb244c9a6, 0xe4f2dc00, 0x85b0eca7,
	0x812d37cd, 0x57f7d998, 0xbcfe00be, 0xfad641b2, 0xf85a4307, 0x385acd7b,
	0xc785ac2b, 0xf9c2d51e, 0xca926ef0, 0x9fb43cee, 0x5d97539d, 0x5efdf760,
	0xc23273a0, 0xfb3076fc, 0x4b594a77, 0x2ea5f82e, 0x4037633c, 0x59afbefe,
	0xbb646a9c, 0x3b1fdf05, 0x49024ef8, 0x67bc3880, 0xff215b2d, 0x17284242,
	0x3cb445fc, 0x82902fc6, 0xef7870d0, 0x8451f9fa, 0x18823ffb, 0xdffcf0e7,
	0x647abc59, 0xfc0829bb, 0x93ef6175, 0xf505dccf, 0x05edf7b6, 0x082fdd71,
	0x1bb40301, 0x3ae8cf58, 0xd1a1c121, 0xda0d657b, 0x3b54d573, 0x1f9d63d3,
	0x8e200bc8, 0xda4d8ae9, 0x6a0c8f79, 0x817601e1, 0xf7d537eb, 0xec4e7041,
	0x7c0e935a, 0x798938f1, 0x9d98700f, 0x3d4f37ad, 0x28fc2b25, 0x88c2f7f2,
	0x7f7a352b, 0xfcf45f69, 0x385f5966, 0x0c5c07c7, 0xd32f7e8e, 0x1fb4abf5,
	0x39d9ebe1, 0xd61d3bbf, 0xeefe649b, 0xe1e0b9fb, 0x0fdf9054, 0x82a70fea,
	0x17f79efc, 0xbe5ffae3, 0xb02f5b73, 0x1fb7ca47, 0x9d207876, 0x13fdc4f7,
	0x2edbeec0, 0xf41c6086, 0xd99bbe3b, 0xe38dfa1e, 0x5cfdfa26, 0x756cef7d,
	0x2d3e873c, 0xaba56609, 0xcaef96ed, 0x39efdd7f, 0xf61e193b, 0xfacc15e4,
	0x596ba531, 0xa336e8ad, 0x1ff3985e, 0x5adf8099, 0x2d4bde23, 0x77c469df,
	0x57757dc5, 0xacbd7fa1, 0xbe3e58f1, 0xa179b777, 0x2b99c61b, 0x1b310291,
	0x4366668f, 0x3765ae7a, 0xf6572bbe, 0xb92c8d6e, 0xe5a1ff60, 0x8857ca03,
	0xe5b2ba2f, 0xeebc00de, 0xa4f18159, 0xf39ef7ca, 0xd3d7d6d5, 0xd8aec2a5,
	0x9a8464c1, 0xbd72fabe, 0x1fd007a7, 0xea9cbe52, 0x5e9d9517, 0xe31aba7e,
	0xa0fdf4d9, 0x2f3aac05, 0x85d1f586, 0x69f7c772, 0xe7334ed4, 0x21cf78f2,
	0xee77c60c, 0xfe608f80, 0x1754c8a3, 0x81bc47dc, 0x05f4834c, 0x28bf7c21,
	0x78c5f932, 0x94561dda, 0xdb6776df, 0xb8508f13, 0xef1331bd, 0x7ae1f699,
	0xc615ddbf, 0xdf950177, 0x3277681d, 0x82c5b4b8, 0x3e171071, 0xad6f5194,
	0x282bf880, 0x60c58cff, 0x85d876a0, 0x4327bd9d, 0x887b5f5c, 0x3e7b03bd,
	0xfcb27bd4, 0x5eafeb2d, 0xf175954e, 0xae93fc24, 0x7bb2bf9f, 0x3d07617e,
	0x3dc59abf, 0xcaaef5a6, 0x27418aaa, 0x5cb25ea5, 0xfd02e595, 0xbdcd8b73,
	0x8353d995, 0x7977bf40, 0xc710ddd3, 0xed6050b1, 0xf058923e, 0xbe0bb430,
	0xbffd0f31, 0x2b7151d7, 0xd129d7f0, 0x4873877d, 0x716c1cf4, 0x7fef178e,
	0x1e2cd592, 0xc244916f, 0x176bb512, 0x831f5e81, 0x45bbea30, 0xffc602b5,
	0x9da0de2c, 0xaa4bbc0f, 0xe18a975e, 0x4086a697, 0xd308473c, 0x7e6d5ae2,
	0x0e13ac09, 0x73c0d38c, 0x6d7ad2ee, 0xdc61213e, 0x7e37975f, 0xb7858a63,
	0x3f32894f, 0x853d934f, 0x3c836f9f, 0xbd2224d5, 0x484e777d, 0x896df587,
	0xefbb2769, 0x42a5d7c6, 0xa9e0c552, 0xbd9fdc24, 0x1d60415b, 0x0126625a,
	0xe1833647, 0x47cc3ede, 0x99437f7d, 0xfd43cc0f, 0xf4671c9d, 0xc2116b2a,
	0x3de88e99, 0xba8f9820, 0x279f395c, 0xf7d48ff8, 0xfe202a44, 0x9a46e212,
	0xda6931be, 0xba1ffee5, 0xa50b120e, 0x7add03c3, 0x56323834, 0x8e09f85c,
	0x14e6078f, 0xfdfc8066, 0x3ec9ec12, 0x7479611c, 0x376707df, 0xcd621813,
	0xb1849fb4, 0xe7e630dd, 0x7bf064ae, 0x4dfccef6, 0xcabee8fd, 0xbb00cde8,
	0x7058916a, 0x0d1bee04, 0x014f7a73, 0x78322d1f, 0x87284806, 0x37e8e19e,
	0xffe6ce5a, 0xc8d57650, 0x947618aa, 0x8507af42, 0xbcec1850, 0x8eb65ec0,
	0xc97dcbe9, 0xa1e24bf5, 0x8fb38c36, 0x7ef016ec, 0x24e166df, 0x7cdb7fde,
	0xa2ac8bad, 0x0fa53a70, 0x02cdbfe8, 0x4bef0d59, 0x780934e5, 0x34d1500e,
	0xe1b0ac49, 0x62dd99bc, 0x7f03aaad, 0x1182da4e, 0x82afc0d9, 0x1f7ec5c3,
	0x70592c62, 0x5f4fcd03, 0xfe041819, 0xc143c4be, 0x4720ad86, 0x0f780999,
	0xc6e28d34, 0x75d30bde, 0x93a47f60, 0x97a083ac, 0xb2bba7d3, 0x80f85fc1,
	0x629fb583, 0x04cc1710, 0xc19b293b, 0x678872bd, 0x2367d22b, 0x226693f6,
	0xf07c60d3, 0xda3fec1d, 0x322767ac, 0x75d19069, 0xf416554a, 0xa584369f,
	0xe31872c9, 0x74d0c872, 0x7795efb4, 0x74e55f8c, 0x279fa4ff, 0x9194f511,
	0x224f36c3, 0xf92977c4, 0xd3c585a4, 0xfb39fb74, 0x96587933, 0xbef5fcc5,
	0xe812068b, 0x9bef2d1d, 0x63fa19fb, 0x1265177c, 0xdf69e950, 0xb85a5ec5,
	0xd62a5cbb, 0x204b968f, 0xcab1dec1, 0xd3504839, 0xd7b6d11e, 0x239639fc,
	0xb00e6d79, 0x6d9c3b67, 0x177d6fa8, 0xd15f6c25, 0x43419dcb, 0x9ced48c0,
	0xefcb170e, 0x2aaeefe4, 0x3af695e5, 0xfcfccae6, 0xb6ed8228, 0xcbf0cdfb,
	0x96e1e408, 0xcb88648f, 0x88396f2f, 0x90575eef, 0xae038c56, 0x20495908,
	0xbc2479c6, 0xfb8ea6eb, 0x843e2f2c, 0x457a14f5, 0x55e36beb, 0x86b55753,
	0xe6d6540d, 0xed723fdc, 0x4b47ba68, 0x2ae5c439, 0xcf5ae570, 0x1a2f9a44,
	0xcd667234, 0x143b96e9, 0x220c07f7, 0xe8c0d393, 0xaa2753b5, 0xbbbe5e60,
	0x9af3207e, 0x732e54a9, 0x0bfab346, 0xf2f31fee, 0x27aa294a, 0x1407fce8,
	0x59b055d8, 0xac28db07, 0xf2eb3bf1, 0xe9f97593, 0x2b1fb83a, 0x0f0f6edf,
	0xbf54dd10, 0x0d7d9fdd, 0x7b58befc, 0xdc3e7846, 0x8e20df70, 0xc42a66bb,
	0xdfb0e7ad, 0x116cabc7, 0x87dc2cdc, 0xcdd2afe1, 0x6ee6c0e4, 0xdf5ce193,
	0xc47ad39a, 0xc1397e80, 0x2dae7609, 0x308c33b4, 0xeaa973d4, 0xa9fed885,
	0xeb12743c, 0x847f6dc5, 0xbdc0f501, 0x72c7de23, 0x9397f297, 0xf7e68289,
	0xfbc5e20b, 0x577821bd, 0xefa2523a, 0x7cefb6d9, 0x66fbfa33, 0xe1944e70,
	0x4d7a8c39, 0x07d24f77, 0x5f7941e3, 0xd07df9a1, 0xe174477b, 0xce7f7efb,
	0x9603796c, 0x8fb2eb5b, 0xf6fd8056, 0x71d9c56e, 0xcf80cf60, 0x83f8f41e,
	0xfd02d042, 0x8e08683d, 0x96e1f584, 0xe107618a, 0xc613e909, 0x62702db6,
	0x19fef3bb, 0xc339c0d7, 0x7f5b7b09, 0xe79a69f8, 0x9c18f31c, 0x0e2f86d2,
	0x446f1338, 0xdfe89cfa, 0xe140dfd6, 0x0c758e3d, 0x05b6d61e, 0x551cf7e0,
	0xeb6cce0c, 0x24c13a2f, 0xf81aedbf, 0xce6dc83d, 0x0deff1d8, 0x959fa60e,
	0x7b07b9f1, 0xbcc0771e, 0x87fe99ca, 0xaa66786b, 0x9e97e6ef, 0xe28db1df,
	0xaccffe63, 0xb5b687a8, 0xd98ebacf, 0x880281a1, 0xf8e349c7, 0xf509f5c6,
	0x9efb84ae, 0x7a93580c, 0x1f69e945, 0x3d42ead0, 0x276aaa3e, 0xf9b4b1e8,
	0xdf8f51a3, 0x2524f767, 0x0ba68b8e, 0xe70a6992, 0xa64e89cd, 0xfa034577,
	0xb2eed2bb, 0x4bf29da3, 0x35b40efe, 0xdb179d87, 0x3bf65d38, 0xbf67bed8,
	0x77f3ed83, 0xf6c6afd9, 0x9b3c11de, 0x24a422cd, 0x96ba0160, 0x713da024,
	0x47d51d53, 0xe1abeed4, 0x38d9aee3, 0x4deaf512, 0x68e2cef0, 0xe8c9eef8,
	0x5f6a3a35, 0xd85164d7, 0xd4e7dd16, 0xa864f4cc, 0xa9ae9bdf, 0xbe8af963,
	0xeac419ab, 0xda49eb2b, 0xda4fd62a, 0x856e472f, 0x82255879, 0x7325ddfe,
	0x815d6f87, 0x380df1eb, 0x64f1e26f, 0x74f4bec0, 0xd80360c9, 0x667d0a7d,
	0x09bcf60d, 0x9f91b9f4, 0x527429cf, 0x644a4ffa, 0x2245abfb, 0x8845cf5d,
	0xfce2f03f, 0x863efae9, 0xd6c5fbbd, 0x007024f7, 0x97e28b8f, 0xe0e36d48,
	0x7843fffb, 0x815feafa, 0x9e387fa7, 0xa887a758, 0x78c271be, 0xd59f962b,
	0x78e10bde, 0x1b08507f, 0xef5472d3, 0xb0efd076, 0xf7673bbf, 0x653d41a6,
	0xaaeff3dc, 0x99503b40, 0xf6bff58f, 0x20df834c, 0xdea7cbd4, 0x8ef13b4e,
	0x17f80379, 0xd421c84e, 0x63ae27c7, 0xf8273871, 0x67629cb9, 0xecacfee6,
	0x9b57bc55, 0xf5bd6228, 0xf0032782, 0x03f29eb1, 0xcc0e73dc, 0x0aefd994,
	0x5e3ad907, 0xad39dfc3, 0xbc4af3b9, 0xda49d02f, 0xc81bbf70, 0xbb37a823,
	0xc70de7f3, 0xc81fca7c, 0x57ca1157, 0xc9a95fe0, 0x3529f162, 0x7e6146f3,
	0xc4b51fb7, 0xccd4fd80, 0x4fd58424, 0x7d037e47, 0xc78af80b, 0x98aba93f,
	0x9e48813f, 0x21dfea31, 0xf4c89f9b, 0x6da73581, 0x9fb09bf7, 0xbf4160d8,
	0xcf129018, 0xb0d3aa27, 0xf907ca3f, 0xbeca57c8, 0xc119d7e8, 0x375fb17b,
	0xdad7b7ee, 0xbf510b3d, 0x82eadcfd, 0xc85ad7f1, 0x27b5333a, 0x8adda96b,
	0x878f927a, 0xe7843f54, 0xbdb80bd3, 0x97715ef7, 0x3996ec1d, 0x6dfbdd89,
	0x6f7fec0f, 0xd6ff2c25, 0x6127adbb, 0xddeb731f, 0xb2553dec, 0xf68f6aee,
	0x358e81bc, 0xfcd7fc15, 0x0ec4536f, 0x3d42f078, 0x37ffb407, 0x79a79c3b,
	0x3ef766ef, 0x1fd68049, 0x0c5fad11, 0x707e0ef2, 0xf89f8d91, 0xef58aead,
	0x32271668, 0xefc749fd, 0xf4a7f751, 0xee976fa3, 0x6e404ad3, 0x70c3de28,
	0x73f2270f, 0x7ebf6ef6, 0xe472c9bc, 0x3f9a1617, 0xc1262fdf, 0x977b66ef,
	0xcabe71db, 0x45a41778, 0x007e807e, 0xac67fb5d, 0xa7e0b995, 0xe423f656,
	0x0bfed56e, 0x614722f1, 0x47abee11, 0xe3d35f70, 0xea97df3b, 0xfc847ff7,
	0xd72ea4dd, 0x0976d7ed, 0xbe73f1ba, 0xd0120972, 0xa7d5df0d, 0xc8e59374,
	0x75efb47c, 0xf9f056e3, 0xf9bbe710, 0x0fd1fc71, 0xb277c1c5, 0xda1fd6dc,
	0x21372ef5, 0x2bedf49e, 0x1643e9eb, 0xdf29a7aa, 0xe404126d, 0x5a774dd7,
	0xb4ec7d71, 0xfbc09e44, 0x41ae077f, 0x2494777a, 0xeace20b8, 0x5bc99961,
	0xa73b00e0, 0x36de1ce8, 0x03bbe41c, 0x2192a202, 0x0bac477e, 0xa820ca08,
	0xb89af47d, 0x63bff815, 0x9dacb5ef, 0x9ef65615, 0xee186032, 0xf4be05ed,
	0x94e51f83, 0x87c3dd81, 0xef512bdf, 0x657ee183, 0x5f547671, 0xf4064274,
	0x179cacdf, 0x9fb04b79, 0xdef0129b, 0xf041a57d, 0x5955dd80, 0xf0e30a3a,
	0x199dff09, 0x1a568f45, 0x3b30fee8, 0x8695f72a, 0x652f87f7, 0xa922487e,
	0xdcb457fc, 0x2b4fb04b, 0xc5686f37, 0x124ec6fb, 0x95051dfd, 0xc372b23f,
	0xfc61af85, 0x7dba4d95, 0x5f3f6ebd, 0x41a7e6aa, 0xbb413e51, 0x54c7f41f,
	0x76b5f182, 0xb5a75b0e, 0xc7cfbfa2, 0x8729f8fd, 0xf6affbd8, 0xff01109c,
	0xb31cefa6, 0xd4b4265b, 0x717d861d, 0xfed6b4d2, 0xf71f5d30, 0x61efe9af,
	0x28d96f8c, 0xb1443382, 0xcefb5477, 0xaa643791, 0x131f7653, 0x5fd0b1f6,
	0xb9027c1b, 0xf93ad891, 0x21275f20, 0xf4f40b1c, 0x702bea92, 0x0ef5853d,
	0x0fb29bf4, 0xfa077d06, 0x72739865, 0x5fc3e83b, 0x4d9f2739, 0xc1fac71c,
	0x32e045fd, 0x397887cf, 0xbb7f0fd8, 0x2de18bdf, 0xe99139b2, 0x9acf780f,
	0x33bf85c2, 0x071c61d6, 0xde3a6428, 0xa1065ba5, 0x36fc563e, 0xa3bbb0e5,
	0xfdc85bfc, 0xcfdc853c, 0xf5537e03, 0x4ff03abd, 0xaa71de6a, 0x3ffae361,
	0x053b50f5, 0x00008000, 0x00088b1f, 0x00000000, 0x7dc5ff00, 0xd5547c0b,
	0x73b9f899, 0x9992bcef, 0x24993264, 0x024df793, 0x49804821, 0xea2a024c,
	0xb3515e10, 0x71487876, 0xf090c2ed, 0x44c92448, 0xa57175b7, 0x4c5900cb,
	0x08d83010, 0x140e0281, 0x0db56e29, 0xc130180a, 0x16e22d01, 0x2b5aa1bb,
	0x08dbfffa, 0x32429401, 0xb568a582, 0x73bef9ee, 0x4dee64ee, 0x6edb54a2,
	0x9cbd3f7e, 0xef8f38fb, 0x6a673afd, 0x2111e0a4, 0xa4259086, 0x7a4440cb,
	0x722463dd, 0x2fbfc11e, 0x93357fe9, 0x9f4ad049, 0x30489ad7, 0xea6dae1a,
	0x642475e7, 0xf8843920, 0x4634bfda, 0x99a427de, 0x36426290, 0xdb31099b,
	0x742d8909, 0x1167fd67, 0xf5d7a121, 0x21329dae, 0x6495e167, 0xddfc2efa,
	0x638fc84e, 0xa58e3f4b, 0xba8947ef, 0x427c9e79, 0x6aa4747a, 0xde9085af,
	0xd873b2e5, 0x8f1e4230, 0x5866f323, 0xae57dffa, 0xab990e6b, 0x34fdf402,
	0x84908e9b, 0xc76ffbfe, 0xb25db1ea, 0x8c09b892, 0xb021af7b, 0xdffda053,
	0x2279e648, 0x09b1c9fa, 0x1b211ef8, 0x723035f8, 0x5a4268fa, 0x3a82dae2,
	0x1696ddfa, 0xf3a7e5c1, 0xe753b43d, 0x2bd2c7d7, 0x0838861d, 0x04305ff1,
	0x85c2ce9e, 0x7db475fa, 0xc0e4f9e8, 0xa1d5da1a, 0x87cea68f, 0xe42e87e7,
	0x976d22c9, 0x86aaa85d, 0x5139e5f6, 0xf7e028c4, 0x3fbe016e, 0x4d3c0c60,
	0x360635db, 0xa3c39abf, 0x3eda7e03, 0x5e6ef060, 0xe7fedb48, 0xe9a7aef5,
	0x813135b8, 0xf3e37667, 0x0e9f9764, 0x8f9e92f6, 0x7d9a307f, 0xc9f8151f,
	0x4f3c077a, 0x18a679c2, 0x8fe858e5, 0xf0244afc, 0x8ffd017c, 0x7dc844dc,
	0xb6edcf66, 0x982f1862, 0x75e1471b, 0x73d6c03a, 0x60163e9a, 0xf62b0ebc,
	0x793b8847, 0x4cefed21, 0x0d6b9253, 0xf4488fed, 0xccfcfa3f, 0x358151ba,
	0xc31bbd74, 0xfef80be3, 0x6a67bd69, 0xde9f6d32, 0x415ae05f, 0x0c79f51f,
	0x13a50341, 0x4e4be3df, 0x54843190, 0x4bede4ea, 0xa3873e61, 0xdc0a3d71,
	0x9717eb7d, 0xfddf73c3, 0x3126eecb, 0x7e1af103, 0x8848ddaf, 0x7aae9fa9,
	0xe8032849, 0x76554b74, 0xdb8e905b, 0x25d231db, 0x452753e2, 0x1b47a536,
	0xcf47b77b, 0xd4ea1ce0, 0xb7afde23, 0x44af587f, 0xbfc1f1fb, 0x081ab845,
	0xf11ae851, 0x0716d11d, 0xfa7c336b, 0xbc21250e, 0x6cffcfb4, 0x78003ef1,
	0x4fe27ba8, 0xf8452fef, 0x58677286, 0x90125d81, 0x83bce81f, 0xcf7dfa26,
	0x27606b66, 0x6196ef7e, 0xd3c68b5d, 0x33f7d27f, 0xd7f83197, 0x10ed26b4,
	0xc9b8f3e9, 0xd69afdec, 0x7da13b11, 0x7252d2f3, 0x2fbe9e26, 0x21530692,
	0xa3491abd, 0xa55ff289, 0x06ef6e51, 0x2028bc3c, 0x2ecdce1e, 0x4f7c0e3b,
	0xf3c0379f, 0x64b73a1a, 0xaee2fefa, 0x30cd92ae, 0x244dd22f, 0x1ed54e3a,
	0xada1ac81, 0x381aadc5, 0xd9da2205, 0x1db6dc74, 0x457ca122, 0xaf08fca8,
	0xe1afde97, 0x86e405f2, 0x17f27bea, 0x7e6e1aa3, 0x81873fe4, 0x6c5d27f1,
	0x22a1f012, 0xeb1c7e27, 0xfe4364d9, 0xf004961c, 0x1f7a273a, 0xb3b951b2,
	0x6e51f898, 0x5e209355, 0x4916f195, 0xeb031fc4, 0x61ec8137, 0xb642a8d7,
	0x5539488e, 0xefb7501d, 0xcf286d27, 0xe0f7496a, 0x951970f2, 0x96866387,
	0x17d48487, 0xefff8048, 0x0f205c59, 0x96c5c806, 0x0547e478, 0x2606494f,
	0x165e6f1f, 0x3f7e4910, 0xbab79e1c, 0xd7a0e67f, 0x06e222e8, 0xc77be6f9,
	0x42c79264, 0x29b243db, 0x4eb31e7c, 0x3a522674, 0xddc449f2, 0x77479f46,
	0x7a0ef711, 0xf8999b7f, 0x51293fa1, 0x069c7ec6, 0xc97a0746, 0xf3e80a43,
	0x20aed292, 0x0250abc8, 0xb61c81b1, 0xb7feb176, 0x8577e959, 0x87931df0,
	0xa44defe1, 0xfbe22a21, 0x946643d2, 0x5a0f5707, 0xaecf2003, 0xb4cfcdc6,
	0x0f7befd1, 0xf70e5159, 0x369cc9ea, 0x24439efa, 0xc7886df5, 0x49cfd8d5,
	0xfd5e165b, 0x009534a4, 0xa6770b2d, 0xb212cb02, 0xad44f512, 0x72099bde,
	0x2329e2e8, 0x7dfb4959, 0xfde326dd, 0xea68633a, 0x75be742d, 0x19000b2f,
	0x5a6178e2, 0x6bf69781, 0xdb3fbf14, 0x5533f144, 0x987a165c, 0x6e9b577e,
	0x27e919b1, 0xdfff3393, 0xf6d2f7db, 0xc4f4fb47, 0x7a7df808, 0x3d921cd2,
	0x0757ff34, 0x23bba7f4, 0x1ec972e8, 0x4db6bb75, 0xabb5f6dd, 0x566c17db,
	0xc851b9c7, 0x292fae9b, 0xf58d18dd, 0xf3a0ee1f, 0x4464be35, 0xe6cc7879,
	0xadba03ed, 0x018e85d3, 0x17998cbc, 0x9f0178c7, 0x700b1f1d, 0xe81a5235,
	0xde4bbc02, 0xab9fe04c, 0xa1cf0666, 0x4cff4be6, 0xdb9b843a, 0x26e7e0c4,
	0x2bcb9124, 0xfdc18f80, 0xfeba11d1, 0x6ca23345, 0xbb8ef12b, 0x8fca98bc,
	0x87e4c22a, 0x8f8ef5af, 0x5ef83184, 0xdcf1e035, 0x9d1efa74, 0x932b5557,
	0x2ba435c7, 0x8ebee806, 0x8a260c04, 0x8c7189b2, 0x8434960e, 0x9ff4824a,
	0x91b2f62d, 0x0be94f30, 0x7ef803c9, 0xa9bdfa14, 0x71497e7f, 0xd92f0f4c,
	0xa8f5b663, 0x6aa718e0, 0x6d93dafb, 0xb17c113d, 0x7139f384, 0xbbc81208,
	0xdf9ebe1a, 0x38a4de0a, 0xb7530fa0, 0xff1d2261, 0x313e2ff6, 0x2f17fe00,
	0x73d998ad, 0x940bca23, 0x46cda187, 0x1f8b9794, 0x57fde2f6, 0x8f9b4f36,
	0x966cdbeb, 0xb6e7ee01, 0x8bb74809, 0x13012cd3, 0x71ede7fd, 0xefd36b12,
	0x1c206104, 0xbf3b70b5, 0xe8139a75, 0xe3613ce8, 0xfe98dbf9, 0xf0a36f3b,
	0x40ef61ca, 0xb3dbe77f, 0xb5f00ed0, 0xe408fb4e, 0xa26de2d0, 0xe914f40b,
	0x1386bab4, 0xb9194f68, 0x5dfd02d0, 0xdf489f89, 0xc53ed96f, 0xd17de226,
	0x917e0013, 0xd3b75ddc, 0x71f6d2fb, 0xeaf3f432, 0x679b2336, 0xac37699c,
	0x442ff6e3, 0x1d248fb4, 0xd47d82f1, 0x048f7062, 0x3eb794be, 0x72f0153d,
	0x0e8a7a7e, 0x204e7fdf, 0xe38b72c0, 0xfdc22696, 0x01e482c5, 0xad6aac7e,
	0xb7d48f2e, 0x29d183bf, 0x2e6626be, 0x20b6ec4b, 0x7d06cd3f, 0x8f4dbb52,
	0x33abcaf6, 0x5efb7dde, 0xfd3f2447, 0x45d1096b, 0xffadcfe8, 0x7f04f484,
	0xc79012c1, 0x96df160c, 0x0ad18caf, 0x82e7d45f, 0xb2bc5c5c, 0x8836d73e,
	0x8be617fd, 0xef0f8cad, 0xef50138b, 0xcabb3490, 0x47c81cbe, 0x25b75c7e,
	0xb806e74f, 0xfdc45c9b, 0x1926bd34, 0xe540dda9, 0xa3e81f9d, 0x2606ae18,
	0x707d3f0f, 0x5d741bcf, 0x756f38c6, 0x12676d1c, 0x5de00177, 0xa94ad90e,
	0x46200519, 0x32b64fbd, 0x11da8ebb, 0x8d93a06e, 0xd8376409, 0xcbb8ca01,
	0x2e547f78, 0xf4fd083c, 0x18fcfa9e, 0xe32eb5c0, 0x01a798e2, 0x313ed70e,
	0x96bd74c8, 0xb2e5010e, 0x4021e5c5, 0xe98ebe2f, 0xbf7e4164, 0x98b9f55c,
	0xebaed7bc, 0xce3d38f5, 0x6108e7db, 0x33b0bf3f, 0x63896dfe, 0x6965b9f4,
	0x5b99da14, 0x4c33011c, 0x53e5affa, 0xd6d539f2, 0x26d5cf14, 0xaed36786,
	0xd022dc17, 0x0db04077, 0xf8ccb687, 0x6e6aafa3, 0x8fdfec00, 0xb1f8e576,
	0x4ba26fbd, 0xbb2ccfa4, 0x0d98d27e, 0xbbd76a70, 0xab8b7de0, 0xf7d6063b,
	0x3133aed1, 0x5daabeb0, 0x2abbae22, 0xc2e271f0, 0xf0b97efc, 0x0cdde08a,
	0xc12622f0, 0x3e1f2912, 0x712575da, 0x0b4d0581, 0x068b07a6, 0xb613cb87,
	0xfbe1db89, 0x78636fdb, 0x319cf0b9, 0x82ef7200, 0x08abea99, 0xcac17b79,
	0xa51b57f4, 0xfd238023, 0x21d80657, 0x9cf7f6e1, 0xdf13903a, 0x3bf5b1b7,
	0xc0196d0c, 0xd4107f8f, 0xa8dfdcfd, 0xdb2a0123, 0x68291bab, 0xf0ba3ca8,
	0x20198bcc, 0xfa7a3fef, 0x888a8cc5, 0x53bf69f9, 0xf19487ae, 0x4db9379a,
	0xa20abc74, 0x834c178c, 0xc65c2af1, 0x90be400f, 0x30ee29c6, 0x6bb364df,
	0xd5a4fbe4, 0xcfb0728d, 0x0e819465, 0xaafaef95, 0xc026dca2, 0xfca1310b,
	0x8310e8ab, 0xedcfe846, 0x3b00e61e, 0xd35ef95a, 0x9e9c67ff, 0xfd017684,
	0x10fce8c2, 0x2c6fe3ca, 0x9f142def, 0xa4f8fd89, 0xf0047e78, 0x1d0a6b54,
	0x1f48254b, 0xa19b8006, 0x7e8122ce, 0xe8c55c4a, 0x1d03f42b, 0x1486f5da,
	0xd9e405a7, 0x0d51b9ed, 0x8e88ca3a, 0x843198a8, 0x29e949da, 0xbfbef879,
	0x3fbdd194, 0x09560491, 0x80bd6430, 0xed46daf2, 0x6d3f7a5b, 0x7d81b13c,
	0x42cf6e9b, 0xab893b78, 0xbc41cc55, 0xfdd19e0b, 0x02f450f0, 0xc7c80fd0,
	0xe909820b, 0xd010e847, 0x6d75141e, 0xa1dfa173, 0x38b3e9e8, 0xf464cfc5,
	0x83ff6e14, 0x0fb249e8, 0x195e4f45, 0x1a69c9e9, 0x81649e9c, 0x13ef55fc,
	0xa7fc07bf, 0xc7af0e24, 0xfd09dcb9, 0xa2f884c0, 0xb7ac027f, 0x6e57f79c,
	0xd04504b2, 0xc5fd2e1f, 0x61bf08ee, 0xc163b52b, 0xbb06492f, 0x57535e9d,
	0x6f1197cd, 0xec1baba4, 0x2671e8c4, 0xe98f8fd4, 0x5ec0b2ba, 0x7ea1ba49,
	0xd245d02f, 0x55c2fcdc, 0xc5a537e8, 0xdd003e81, 0x2e8feb0a, 0x3a437462,
	0xfa70c084, 0x488eba5d, 0x96ebe720, 0x287aba96, 0xec75275c, 0xe7d1b02d,
	0x814b1abe, 0xaec22b31, 0xbb406e18, 0x3761eea2, 0xcd44d7be, 0xff1be050,
	0xfbffe674, 0x832627da, 0x31e7599f, 0xe8aec0e8, 0x7abf500b, 0xe315f02c,
	0xb35aff3b, 0x25a0fa0c, 0xf4015e4e, 0x1943f2d6, 0x7f03f4fd, 0x11fdb339,
	0x82dabfe8, 0x029690f1, 0x70cb5e36, 0xfda7e039, 0xf8b024be, 0xe20eff83,
	0x32d0bd02, 0x071c9ddd, 0x9aa341f6, 0xb8765bbf, 0x7ef4ed93, 0x8a02959f,
	0xd6b15b8e, 0x1149788c, 0xac49dc19, 0x81a3e989, 0x7804c272, 0x944f1c48,
	0xa76856bf, 0x4de6ed28, 0x72290f68, 0x8e8b25a0, 0xcd6ef143, 0x5c5964f7,
	0xcdb3ec84, 0xe9451e3b, 0xc6a45129, 0x85f8cdc0, 0x847aec1f, 0x61bb6b33,
	0x747527b8, 0x1cd02922, 0x84f266bb, 0x3f7b36c8, 0xf3bfbdfc, 0xf54e784e,
	0x4c39f870, 0xa567ea9b, 0x79d336ed, 0x7fed6a3c, 0xd7fb512e, 0xf1f02ed4,
	0x329cee6a, 0x5041c28c, 0x72692fc6, 0x6e3cb853, 0x22f1aa26, 0xfa6927e7,
	0x2dfed3d7, 0x7fdf7f32, 0xf7f4196f, 0x7df2a164, 0xce9ba35b, 0xbabd71ef,
	0xff29043f, 0x78ca1a1e, 0x6d3f27ae, 0xdfa13b5a, 0x4376a04e, 0xdfb8bdbd,
	0xddf4785e, 0x74b1e6f2, 0x15db68ac, 0x4561e803, 0x021cfbef, 0xfe5a23da,
	0xbe17695d, 0x1ced5d9d, 0xb4af5760, 0x2a7abb33, 0x47f528b0, 0x96fb8e50,
	0x77d80879, 0x0d593ed4, 0x5d4f7bcf, 0x3e84773c, 0xd9f19def, 0xde1954b1,
	0xd82e607b, 0x126bbec1, 0x8f6fabd2, 0xbd281018, 0x7d983a9a, 0xf23af54d,
	0xf73f4297, 0xc4fd38db, 0x73d009f9, 0x0c50a74b, 0xe4fd4ff4, 0x2e287b8c,
	0x1bdddacf, 0x7efd09ec, 0xffdd76a3, 0x84fe6765, 0x7374af2f, 0x4bbff42e,
	0xac376020, 0xb89d3bc9, 0x0fa8fd00, 0x7c461712, 0x24fedd57, 0x8f7ab3c2,
	0xfe38507e, 0x7e645d97, 0x6efdc1e5, 0x02172390, 0x2a88ca02, 0x3374d029,
	0xe955576d, 0x0a2ccfd0, 0xe517bfcc, 0x19031cc5, 0xccd7d74e, 0xcf6f9ef5,
	0xb0cdff4c, 0x409ffa6e, 0x2cf16d6f, 0x32df3e42, 0xf42164c7, 0xa5790bbd,
	0xf34f18c9, 0x67286c18, 0x932f2dde, 0x6d4a4e41, 0xd7b65f28, 0x8e310a59,
	0x2e9c8436, 0x373c3071, 0x77ff1e08, 0x46ce308a, 0x9966e322, 0xec2ecced,
	0xf1541bb0, 0xb33b0ece, 0xbbf82757, 0x1c390126, 0xc1a3ba96, 0xf711f65e,
	0x131fe0c7, 0x1a7e458f, 0xfe86dee1, 0x8cb963bf, 0xa3933df1, 0xf0b1b1fb,
	0xfe84827c, 0x7fba9109, 0x36f6e304, 0x086b5c39, 0x3f686ba7, 0x4d7e8f9c,
	0x75f7bc5e, 0xb70957c0, 0x4e0f7b43, 0xefc8a82b, 0x3a9aabb7, 0xe92b03a3,
	0xf2ac9afa, 0x27206513, 0x7e50953f, 0x6ba85311, 0x9f21d812, 0xaddfb1d9,
	0xa0b7ded1, 0xa073269f, 0xefeaf009, 0x452e3114, 0xe9106ee5, 0x1de8e5ea,
	0x8ef55fa0, 0x49740266, 0x6b8c11dd, 0x221e1c98, 0xff24f6d3, 0x7d00497c,
	0x2657b1a0, 0xfd07fc41, 0x03c60711, 0x0fbd394b, 0x673d58a7, 0xf86ed242,
	0x7edfbe32, 0x2cf9fe39, 0x762a6e09, 0xc5e4ce8d, 0x39e4ed78, 0x57ec0451,
	0x4c743ab2, 0xed13d747, 0xe76022e8, 0x3809b6d6, 0xf3de6d4e, 0x964bf006,
	0xf57e31b4, 0xc2823f71, 0x86ec032f, 0xae68f64b, 0x3d981bef, 0xa58eba4e,
	0x659f9c02, 0xbe8424f8, 0x47f48d67, 0x4a7be056, 0x2c95867f, 0xe3cb560e,
	0xe1d3543f, 0x1e8a6bf3, 0x251371e7, 0x3b8caece, 0xe2595d14, 0x47b177d9,
	0x0f815343, 0x40ae9443, 0x3e166cef, 0xb0f40a9e, 0xac990ef9, 0x25276da2,
	0xee10b123, 0xf0a41253, 0x56f4e22e, 0xac513ed7, 0x3c38b0b5, 0xe8a4ffe8,
	0x5df01dfa, 0xd43cbcd2, 0x1978f6b7, 0xfaf887fb, 0xb9dcfa0c, 0x60f59fd2,
	0xd8178c3e, 0x1bc613b3, 0x2e7a851d, 0x6ac0e289, 0xc4236bc7, 0xe0a49c9b,
	0x6745e808, 0xa6085cb9, 0xac3193dd, 0x389d04ff, 0xca3e7a6f, 0x29db6c5f,
	0x9c42761c, 0xc70e3e3f, 0x195a7ea1, 0x07ee0fcc, 0xfe0ffdb8, 0xfaa4d270,
	0x29371802, 0x937b5d87, 0x8bc61283, 0xa7f6f749, 0x8ddb1e81, 0x797f8036,
	0x80ef6bfb, 0x91372c9e, 0x53f81136, 0x62587f63, 0xa78f0e66, 0x74bbebf8,
	0xc27ffb6e, 0xe039eebc, 0xd41e22f2, 0x9fd68576, 0xede5c9d8, 0x2de07650,
	0x303b6af1, 0xdb9bfedc, 0x78fedc81, 0x0fed1a3a, 0xb8fb1e45, 0x7557d6df,
	0xcdf40639, 0x9e8578b4, 0xe92ebea8, 0x762a2bb7, 0x7c007f45, 0x340bf614,
	0x4ec343f6, 0x4034e766, 0xb1c6043e, 0x80fe781b, 0x201a43e5, 0xe2e9421f,
	0x9cbbeef8, 0x61ff21f3, 0x3f042a8b, 0x86efe157, 0x139446fd, 0x9f847bf4,
	0xed15b0ff, 0x07831aa9, 0xcf35f6e3, 0xc77cc70f, 0x7fcb0301, 0x799b0ff8,
	0x0ff6843e, 0xa943eef1, 0xb3d24ecc, 0x75ff877c, 0x89a8ef96, 0xbe8df962,
	0xf0104338, 0xebd99f7a, 0xbc862f8d, 0x32f31b88, 0xcca365e4, 0xbdec2ef2,
	0x8eb6011d, 0xa0ba7933, 0x0777ae81, 0xcf9875e8, 0xc21f255a, 0xbadf4944,
	0xe7cf1654, 0x26be90f9, 0x54a9e716, 0x59871cf2, 0xe792acfc, 0x58ccce33,
	0xa4a414f4, 0x32fa841a, 0xaeaeaff0, 0xe5718899, 0x8e989e87, 0x7546cad7,
	0xa9117c3c, 0xa455fbc7, 0x1c4aaf19, 0x0cb882ba, 0x8fedeecc, 0xdda8e9fb,
	0xa54a3721, 0x88b2e7a0, 0x79c8256d, 0x36b14fd9, 0xe81b5e8e, 0x416f8c15,
	0x227d8027, 0x00a23935, 0xe8368fcf, 0xfd8f80ca, 0xbc373a0d, 0xdac9d0a7,
	0x770fa678, 0x4af01bc5, 0x71801c41, 0x9e836b94, 0x7f79e3c7, 0x082e882b,
	0xaec09d57, 0xb2a4da8f, 0xd2acf4c1, 0xdebe835f, 0xdcec1134, 0x9bc61d74,
	0x73dc1aaf, 0xed579e00, 0xd7f004b9, 0x2c6fad60, 0x7791cf63, 0x1e439aae,
	0xc4ab7e7c, 0xdb22400c, 0x8cae4e41, 0x5a7f61d7, 0x566c2db8, 0x8a79b5b7,
	0x5dba80ea, 0x9223bc49, 0x3f5c5873, 0x2e4afef2, 0xc9aeaebf, 0x1976f0e2,
	0xeb2a9e40, 0xe0c6915f, 0xd7674ba6, 0x39d2f4ec, 0x10d90740, 0x2b82c9cf,
	0x95d2878b, 0x6fb3fce0, 0x1f480875, 0xc436f99a, 0x37f27a31, 0x5fe1f8b1,
	0xbced7f3b, 0xe44f8d9f, 0x0276ebfc, 0x0cda54df, 0x7af4e804, 0x686f1ce3,
	0x7f1bd1e4, 0xe5c47937, 0xf3c89344, 0x479436a6, 0x96b63615, 0x776b8233,
	0xa85bee10, 0x68eb003d, 0x3ec10b12, 0x82d33499, 0x6c3ba8eb, 0x565f800e,
	0x033bacbb, 0x695d75f4, 0x65bd6e77, 0xb6617c20, 0xe8c72292, 0xea0e157b,
	0xd03d8037, 0x0d57cea8, 0x4fb9cbcc, 0x07d7bca3, 0xc746bf77, 0x3de2d379,
	0x65baed07, 0xef60dda1, 0xddf87c5e, 0x55ef60a9, 0xb7e44434, 0xd56b7fe0,
	0x68d22ef9, 0x693878c7, 0xdaafdf51, 0x406ef9aa, 0xf119abfe, 0x1de0d1b8,
	0xfb7cfc09, 0x2bf46e6d, 0x30eb552f, 0xba29521f, 0xb9d28116, 0xc9db5664,
	0x1f0cac97, 0x4782877a, 0x31e02e57, 0x47801edc, 0xb1e02e57, 0x91bc4752,
	0x1e02d4fd, 0x386afe29, 0x1fed2f1e, 0xbc780b97, 0x2e5c77b8, 0xbea371e0,
	0x317c0dd9, 0x3b35e6dc, 0xa67b3ce8, 0xa22ed078, 0x7c0b9774, 0x96f4bd72,
	0x5bd350ea, 0xfcf390ea, 0x8641c4db, 0xc2237bd2, 0x3deb50f3, 0x034e4187,
	0x1930af7e, 0xc1ff52bf, 0x3671a0df, 0x12e31193, 0xb2bf3f87, 0x79f0377e,
	0x86f68887, 0xc961dfd2, 0xcef6039b, 0x2e9c77e1, 0xff7430bf, 0xa8f6e3bf,
	0x10fc44d3, 0x79ec50ff, 0xcad42ec5, 0x4c1c5bdb, 0xb870cf8f, 0x037fb05f,
	0xeb89513f, 0x4c77f156, 0x5ecc2b81, 0x58b825dd, 0xe30db75c, 0xf39d75bc,
	0xfdc7106d, 0xbae2c030, 0x300bfb75, 0x781d5bae, 0xe2ca9825, 0x23f0362b,
	0x107d77aa, 0xefd2c8b3, 0x737f527f, 0xc933e43a, 0x468354e7, 0x0c3efbc4,
	0xb4a9899c, 0x017fbce0, 0x23b466fe, 0x0a78c064, 0x5d08c3f5, 0x3a149d52,
	0x39d6fd06, 0x4503da08, 0x8cbf6aed, 0x7bae0152, 0x7280c78b, 0x10874b75,
	0x689c7900, 0x81a566f0, 0xb66922de, 0x7cfdd173, 0xfee1cf36, 0x7f47980f,
	0xdf3dd95e, 0xef1fd091, 0x8b1cdee9, 0x27addbf4, 0xabc81b6e, 0xaf2e56cd,
	0x8fe8be58, 0xef50e35b, 0xff7d1fe3, 0x0766018f, 0xe6009354, 0x2449178b,
	0x2d7c5128, 0x053ee59a, 0x1e7906f8, 0xc8f3c8d4, 0x5e0f92b6, 0x4d6bf902,
	0xbdf239de, 0x223d1e70, 0x87eaacef, 0x45c817d4, 0xfab3bcea, 0xaff99fb9,
	0x16961f94, 0x82afd3f6, 0xeb7e8507, 0x57d89c78, 0xd0357a75, 0xb05dafaf,
	0x71abdc81, 0xa1adfa31, 0xcc71937e, 0x6d277e40, 0xe4237e94, 0xfffc50dd,
	0xae3a8763, 0x83ff6e1e, 0x35bba0e2, 0x5facaf7c, 0xd787ab89, 0xbe3021d9,
	0xeb4bacd4, 0xe1e36a6f, 0xbd78bf8a, 0x2353b0f2, 0x8fff3b0f, 0x43ebe1e4,
	0xbe7543ca, 0x8796afe1, 0xc3bce77f, 0x629b9d53, 0x54545474, 0xcc9df967,
	0xf2ab736e, 0x8b4553b8, 0x4533e59b, 0x901857ac, 0xf2a7970f, 0xe7e3387c,
	0x888bf657, 0xb79e5aaf, 0xbab4edad, 0xcb2ad5e0, 0x6a9bcc62, 0x93f79af3,
	0x450153bd, 0x0d66fcda, 0xd7ce71f0, 0x3b2f39e7, 0x4f940eac, 0xfa82c932,
	0xb5529281, 0x72c57f7c, 0x811bde25, 0x6a7cd2ef, 0xd7420fe8, 0xec4fc926,
	0x03a9f711, 0x0af57c8d, 0x1a71a7af, 0x81d42348, 0x768d6e3c, 0xa9429f83,
	0xce7eeb0b, 0x84ba3dda, 0x1cef9004, 0x4bbf079e, 0x4f2e1474, 0x9e50dbe9,
	0x2e2d6bf8, 0xfc4a7f90, 0x86bfe945, 0x97af23c7, 0xd41253ce, 0xff6e1e74,
	0x587ef883, 0x8ff950c2, 0xb5a7c9af, 0xf8a8d852, 0x9efd2081, 0xd64ffc80,
	0xaa1dba40, 0x77e8a19f, 0x30a7825c, 0x63efd981, 0x5eb9cfc0, 0x145d12f9,
	0x7e82233a, 0x219467de, 0x0ff108ce, 0x936b8bd4, 0x5c92be99, 0x6a670025,
	0xbd40960f, 0xcff0fbd4, 0x1fb6869b, 0x0f8149ff, 0xedc31fb7, 0x68fd91bf,
	0x03be79b5, 0xe899eceb, 0xf6fd05ce, 0x1fce95a8, 0x8c67befc, 0xb685e432,
	0x6e7d199a, 0x925d1815, 0x1c4af1a5, 0x9e07c585, 0x2d757963, 0x504c2d5d,
	0x438593eb, 0x2beffbce, 0xcf081f3f, 0x3f2defe3, 0xf8818b3f, 0xf8fdd0e7,
	0x696bdd59, 0xd42dc217, 0x5fc81029, 0x75f0eb29, 0x4ad978b1, 0xfee55f3e,
	0xdf87ae5c, 0x02af7048, 0x94f17079, 0xa96244c9, 0x66f3c3c9, 0xc60b1e75,
	0x58daebf9, 0x32dd4a3d, 0x0ebbf282, 0x1f189ee2, 0xdec04e9c, 0xd779c633,
	0x7d1f9e01, 0x6317e2d7, 0x833f4e21, 0x7bd77d80, 0xd98fb58a, 0x7fa01bbc,
	0xcc6eb2df, 0xb8ccb42b, 0x2550f580, 0x5d595e5f, 0xc5f38456, 0x48c38138,
	0xd4f123ea, 0x00f2c091, 0x5860f5ca, 0xde31b89e, 0x8bda917e, 0xdc38b768,
	0x28378836, 0xb968ecf1, 0x75fce30b, 0x56d198fb, 0x90f5b222, 0x9e90d247,
	0x2c4df6ea, 0xdbb425f8, 0xe76005cc, 0xc167bc96, 0x87c5f778, 0x217eb053,
	0x07bbde2f, 0x0a2d6be6, 0x697601dc, 0xec071d26, 0xef7b8bdd, 0x2b798028,
	0xc4236ff2, 0x1bfbe9bd, 0x3678eaad, 0x1e3c7131, 0x60bf474e, 0x2f77b46b,
	0xe72367c0, 0x8d096243, 0xdf083e99, 0x249efc2b, 0xa4ffb0ea, 0xbf984cfb,
	0x46c1e456, 0x729af13d, 0x6b48e5fa, 0x73efbb02, 0x8ec17af0, 0x846eace9,
	0xaafc2db7, 0x638673c0, 0xa3cc2b4a, 0x76fa4135, 0x5d492579, 0xe08af18f,
	0x60484d6d, 0x7fe05af5, 0x1c628c53, 0xb31afa25, 0x066db39f, 0xe52b23a4,
	0x5117cc37, 0x7e3b023a, 0x526ba842, 0xb0e75d2c, 0x8004e096, 0x3a6be1ef,
	0xfd3493c4, 0x5aea0044, 0x5e360563, 0xa6eedace, 0xb15f1011, 0xa02b75bd,
	0x95b66e52, 0x18cdca42, 0xe50f79e7, 0x079f54a8, 0x56fe95e3, 0x2914eacf,
	0xd06e205e, 0x19935192, 0x7debbf47, 0x1af188d7, 0xae507ead, 0xeb12b27e,
	0xdfdbb313, 0x75bef8c4, 0x9b82a09f, 0x609abd72, 0xf9d5b841, 0xcd62a6bb,
	0xca0704cb, 0x3df3a957, 0x521bd83f, 0x87920493, 0x3adde834, 0x15afc833,
	0x7861e904, 0xf8074d8b, 0x2af5e4ca, 0x3cff877d, 0x8a7e8bc6, 0xe00fcf12,
	0xaf77d255, 0x5a4bff06, 0x1f9b7dd1, 0x4e2fb1f0, 0xfd0f9757, 0x8e30ea85,
	0x404d19d2, 0xe7b667ce, 0xb685bcac, 0x986d1b33, 0xb43bea8f, 0xfd28eb04,
	0x07c39d74, 0x13efe759, 0x29d07d58, 0x67522f4e, 0x99f40eb4, 0x60b881b4,
	0xb706acf4, 0xf8117e6d, 0xf9d212f9, 0x735e091b, 0xfe444262, 0xe614697c,
	0xdf50acf7, 0x9759ef44, 0x0adcfbbe, 0x206ededa, 0xa39eb055, 0xc0cd4787,
	0x24935df8, 0xfa95dc00, 0x9d4484d0, 0x0fd55f2a, 0x0758a3ef, 0x26f9dd9a,
	0x6e745fd3, 0x67a4bfd0, 0x393521f4, 0xf09c4076, 0xeb17ab31, 0x086d6f5d,
	0xb2df988a, 0x4ca8fcf5, 0x5a67f08e, 0xdba93e99, 0xad6ffcc3, 0x7a75f2ff,
	0x5aa24c64, 0xffdb848f, 0xa6e4fb20, 0xd0dff8f0, 0x7f6a212f, 0x68a76b4e,
	0xf601b7fd, 0xa1bfa6b6, 0x1ea515ec, 0x1c7fb4a4, 0x155b3766, 0xaaafc87b,
	0xb0b52997, 0xdd498971, 0xc6dd947f, 0x33f5e7fa, 0x15e4ab89, 0xfa1e6f50,
	0x913cc121, 0x2fe3c752, 0x7e36f565, 0x597f951d, 0xc66a2f90, 0x12549dfa,
	0x9b8c0414, 0x24f53ab1, 0xdfa1e3a8, 0x46cc4d4d, 0xae236e38, 0xa3e51146,
	0xcdbcc02c, 0x5911e750, 0x761d4a2f, 0x50cc3bb0, 0x4fef41d7, 0x1d7562aa,
	0xca031e29, 0x4c61948b, 0xfea99b6e, 0x50ebac8d, 0xf5942fea, 0xa6b87297,
	0x0c94588c, 0xc126c271, 0x5028f58b, 0x7a7c8227, 0xd580546f, 0x6e7a307f,
	0xf31a3759, 0x11f47d16, 0x28aa85ca, 0xcfc2d7b4, 0xf9f1b3ab, 0xbc88bf81,
	0xfd6084fe, 0xab014b49, 0xd38978f3, 0x441eb84f, 0x1ea55703, 0xfdeacba4,
	0x14dbe00f, 0xa551e991, 0x93a1437e, 0xcdf9fc08, 0x9d2ddc74, 0xad2f7ecc,
	0xfa7ae032, 0xf8c4efaa, 0x8eb55f63, 0xed2f9e80, 0xd3ba3230, 0x8e65b78c,
	0x5fa10481, 0xfac66029, 0xafff8e75, 0x5e295fb3, 0x7b7e20f3, 0xccd97974,
	0xbc84619e, 0xd783dcba, 0x26d0b33e, 0x398cfd42, 0xd2241734, 0xdd669b9d,
	0xf504dd25, 0x810ca12d, 0xad1dcc92, 0xd512e505, 0xa1097d03, 0x70bda1f7,
	0xf8e57dd3, 0xbb68787c, 0x647fdf40, 0x0fbd8853, 0xe94298b4, 0x5decf120,
	0xd0b7cb7e, 0x6d109f6f, 0x0033c4dd, 0xbdd25ad7, 0x42e30bba, 0x3115bf5c,
	0x1b264879, 0x252e2c03, 0x64ec7c63, 0xbbe61672, 0xfbd9792d, 0x9a79e0ba,
	0xf469e311, 0xc9fbd239, 0x73d913e1, 0xa49fe199, 0x04fd5959, 0x3c83f6e9,
	0x1135993b, 0xc0b5f4f3, 0xda7ed40f, 0x841ef163, 0x5d092ff1, 0x9c1f010f,
	0xf96ff29c, 0x0e97df40, 0xe40c323c, 0xb50334cd, 0x2f9107cb, 0x5f264e85,
	0x4696f4fa, 0x59fc1621, 0xe7e851ef, 0x53b9e89d, 0x4e7bc4a1, 0x1c4344fc,
	0x8cffdbcc, 0x812ef208, 0x166e2fe3, 0x26e317b3, 0xc7a8047b, 0xf366655c,
	0x6e4af048, 0xb3bc5fb4, 0xfae87b84, 0x9edc0957, 0xfa2c7221, 0x76395e1d,
	0x2cd6bd06, 0xb1eb107d, 0x37cfce45, 0xc1106db5, 0xf2cdfe5e, 0xb0d259ee,
	0x29bdf9fe, 0xf1ff5e0c, 0x611fbe7b, 0x068f2886, 0x62bd587a, 0x6fcaafc9,
	0xae8cfb82, 0x2d2cc4a6, 0x69e5ba82, 0x1045f5d1, 0x3f701d1f, 0x8fcfde96,
	0x7bd91b68, 0x8650a635, 0x6ed7e944, 0xbd019ef6, 0x07fe7572, 0x3edf010f,
	0x7df27294, 0xa9382ba8, 0xf03d6e27, 0x03cf326f, 0xf8087d52, 0xc719963c,
	0xd6b680f2, 0xced03149, 0x83bdf861, 0x5ccf3004, 0x97ed8b3e, 0x35748bbb,
	0xa6f7d374, 0x7772f539, 0x21dd5d04, 0xe577dbab, 0xbce5dba9, 0x5c9fe17e,
	0x9377fbea, 0xfef80490, 0x462ff8ce, 0xbeffde44, 0xcc29fdd9, 0x2605ca9f,
	0xef5e0527, 0x60fc10e5, 0x317a8c07, 0x578f0765, 0x7fdddd62, 0x7405bf71,
	0xffce9eae, 0x8c650786, 0x78e51e5f, 0xa624e51d, 0x3f933b4c, 0xf33f9006,
	0xb581fc99, 0x3bfb46df, 0xeb64ec50, 0xe07af4e7, 0x4db0c387, 0x5e3045e1,
	0xe78a2eba, 0x584a274d, 0x77f02807, 0x6f6c0ac9, 0x547574e2, 0x06c58f91,
	0x72f59e55, 0xcff59db3, 0xf7c7c7e9, 0xf77428c9, 0x11e26b4b, 0x0bc48bb0,
	0x15d1eb04, 0xfae8523a, 0x45e5c14d, 0x61356f3d, 0xd524b83e, 0x47740514,
	0x239873b9, 0x7cca4311, 0xf80e923e, 0xb4a6cf3a, 0x8226bb29, 0x1f68215e,
	0x74a9f92a, 0x377df853, 0xfe1c9fbc, 0xeb11a67e, 0xb6fb78e7, 0xcfae2ca4,
	0xf514fb5e, 0x832bc59d, 0xadd0af3f, 0xabf4da4d, 0x7f9864f2, 0xdd600fee,
	0x1b569de2, 0x4a3c99e8, 0x78ec7356, 0x4217c775, 0xa9f2323f, 0x8192e518,
	0x7d96674e, 0xc08a4b30, 0x96befd37, 0xfead1f7d, 0xb7bf49de, 0x431f7c47,
	0xf81fcfbf, 0x29ab2efd, 0xfd031ba8, 0xa8ddc894, 0x2758820f, 0x875f2773,
	0xbbbec898, 0x0e65d793, 0x83efa18b, 0xd753cedc, 0x2ef19047, 0x6ac7d613,
	0x09a621ea, 0x4e8192cb, 0x76d530ef, 0x5efed374, 0xa69978e3, 0xfb027ef3,
	0x9b9b5eb5, 0x9fc42afb, 0x5f944cca, 0x824f81b2, 0x7d2901ab, 0xc54fbd13,
	0xde3f20e5, 0x5fe74493, 0xd8477a27, 0xbe92fb69, 0x5903d879, 0x93b3e748,
	0x57ce0612, 0x5f32bbc1, 0x59d033c0, 0x799acf18, 0x7773f187, 0x6d7e161b,
	0x5c0476a3, 0x9082bb15, 0x2bf7567a, 0x8baff7a7, 0x5354c512, 0x67f030fd,
	0x23f6ab5e, 0xfb8b4e1f, 0xcd0dd611, 0x812ef64a, 0xfb19cd79, 0x2f048671,
	0x008fe73b, 0xd6f9d3bc, 0x57ce5ffc, 0xfa949fb1, 0xf3ddb0d6, 0x559eba91,
	0x3f968f99, 0xc47d7194, 0x59f619bd, 0x7df5e24d, 0xc61d2abe, 0x8d5da951,
	0x988ea6f2, 0x21cd3f70, 0xff33e981, 0x139f990f, 0x596a67b6, 0x5d7f6b3d,
	0x47f6f76c, 0x2cabef80, 0x7955aeac, 0x6cd907ef, 0xf762abff, 0xb3ecc03c,
	0x7cec5d70, 0xbd962ea5, 0x98485fef, 0xf89d355d, 0x62d60e21, 0x4af7e3b5,
	0x0ecb781d, 0xd96b1f16, 0xef86423f, 0xef564452, 0x36216e4d, 0xf98b371c,
	0xe6f72d03, 0xfe5cfc06, 0x75fd8908, 0x02a31bcb, 0x834eb123, 0x40b75de7,
	0xf22bf67e, 0xd493fbaf, 0xfb70b3f1, 0x1b3f146f, 0x03b6f36e, 0x77cc2c5f,
	0x5d29e867, 0x1c581a54, 0xd6e5d28d, 0x1975da2e, 0xf6061fa9, 0xfea41dee,
	0xd20e5d2d, 0x7f7861e5, 0x974a28ce, 0x7cba2a39, 0xc998a939, 0x4297983b,
	0xcc7a6197, 0x7941d6d3, 0x2dfbc38f, 0xd5ef6d71, 0x61d89d81, 0x4dfab174,
	0xe5a6bf56, 0x2cf988ff, 0x1c7cd890, 0xe9f388a2, 0xccd13e42, 0x23f87ae7,
	0x08932e92, 0xf8a183e3, 0xa2a24924, 0x4f9fb0bf, 0xfef66fbe, 0xf30dc61e,
	0x17e66acb, 0x68b7980c, 0x7d9aba41, 0xf813cb2f, 0x81be99a2, 0x1d32417c,
	0x7f1f3a7f, 0xbfa31376, 0x4062ffd9, 0x0fd3a47a, 0xf067fcc2, 0x6a3bd3e7,
	0xc6680eb1, 0x48e9fd64, 0x25e4ad3d, 0x66f7f0e6, 0x40f40a39, 0xd5cab3fa,
	0xdf3980f9, 0x7b88f963, 0xe61ebd48, 0xba967b3b, 0xed64399f, 0x34d750c7,
	0xfbea7be7, 0xe70a4e7f, 0x1e404611, 0x3fee55e1, 0x7c67cdf7, 0xc584cbf4,
	0xf4a01f5b, 0xf9c7e23e, 0x4fd7e085, 0xb5deac49, 0xba7fb681, 0xff6c06e5,
	0xefbef132, 0xdbe7849f, 0x593db173, 0x27bab027, 0x7a0167d8, 0x3bdee4a6,
	0xafb8e8b3, 0x0fbf799a, 0x19c0bb30, 0x4e996de5, 0xc98e73df, 0xc9bdfac6,
	0x2df4ce5c, 0x1aefcf64, 0x98a5656b, 0xa78c64f3, 0x76628e4d, 0x70559f71,
	0x89cfbd41, 0x1f3e2302, 0x3d8b293d, 0x0c7aa6cf, 0xfb67cf9e, 0x46144f9f,
	0xf8aec107, 0xf123bbd9, 0xc7c2abf9, 0xd19f2173, 0x00916b5b, 0x2c29753f,
	0x4f2a394e, 0x70a48e08, 0xe3e76c9b, 0x9775b2d7, 0x02933e17, 0x34b933fc,
	0xaef81734, 0x0314c537, 0x63d29172, 0xf5d293b6, 0xa6c4d728, 0xeeb3a01c,
	0x3d244650, 0xae9ef82a, 0x3564e1d0, 0xca3e51bd, 0xbd7c2673, 0x9bd154fc,
	0x86de9fb9, 0x79d13f8a, 0xe6bcc315, 0x27d6a2dc, 0xfc3471e1, 0x28771da2,
	0x48bf863e, 0xbf3fd6f9, 0x348be436, 0x01cab6a8, 0xf85669be, 0xcfac2a66,
	0x7dc2eba0, 0xeb829917, 0x38a8dc06, 0xe657de84, 0xbf310e97, 0x82f381c2,
	0xafb1493f, 0xfc039fd8, 0x3cfe34c4, 0xed00ea1d, 0xe3a2f3fd, 0x903806cf,
	0xdb3e6cd5, 0xf7c67a84, 0xfc558edc, 0xbd653acb, 0x96f5eaed, 0xccfdb144,
	0x6003884e, 0x86e0b7cc, 0x03afbcf0, 0x7c7aca0f, 0x32ce8f5c, 0xba06ac79,
	0x2ae27bb6, 0x7cb760f5, 0x83f7f897, 0xe2d5b2bd, 0x3a70025d, 0x8277f3aa,
	0xb890bfbd, 0xfa07ef31, 0xffa119df, 0xe16af995, 0x9c843754, 0x0b47aed3,
	0x75bc7e9f, 0xeca5bda1, 0xf7af0a6b, 0xd8a9d73a, 0x3a830e09, 0xf1e762fe,
	0x8f8f3b12, 0xfe814500, 0x2e51272c, 0xb927cfb0, 0x952f8c04, 0xf20ffd53,
	0xa08cbcb2, 0xe8b76abf, 0x586fb002, 0xf143c3d1, 0x31b7edc7, 0x435e5239,
	0xb62a3ef8, 0x261d2d2e, 0xa01fee91, 0x3792655f, 0x20f8802f, 0xff720dd8,
	0x2c2dcbfc, 0x53b4fa8e, 0x776b4ee0, 0x70dfe831, 0xedfe807b, 0x3039062e,
	0x17e75457, 0xf8b1afca, 0xc11afd9d, 0x83ebb96b, 0xf6bfd062, 0x9062eeb2,
	0xeeb1e91f, 0xf7cf80dd, 0xa9ce2c75, 0x4ef3e385, 0xbf3f929d, 0xf2d4fa2e,
	0xa1b7928f, 0xa07efdfe, 0xa7dfc57b, 0xbc097e7e, 0x978f19f4, 0x0b28c751,
	0x23d298e8, 0x39f20fea, 0xd7d29f1d, 0xe837f82c, 0x4803c70b, 0x51ffa09f,
	0xfae08c8e, 0xc8e4c3d6, 0xcbf758f1, 0xc2092e8c, 0x970e41e5, 0x5dff5c29,
	0xfc622ade, 0x6f3bb26b, 0x7db48413, 0x8024f5c7, 0xfd46ebfc, 0xebaf84b5,
	0x82743532, 0x56b3fef0, 0xbf1607b4, 0xfef1895e, 0x223aad11, 0x91b3e847,
	0xf9d52881, 0xd8f6a308, 0x6dd1ed55, 0xc7f7aa29, 0x9eab67b6, 0x506f0417,
	0x78f1bf3d, 0xdc5daaa1, 0xfdeab375, 0xaa94ef71, 0xdf7537da, 0x96ff7aa9,
	0xdaa8670f, 0xac123014, 0x8141f77b, 0xbeeba16c, 0xaacff435, 0x65b0ffef,
	0x71939e2a, 0xc49ffb86, 0xa3caeeef, 0xd0a05870, 0x750ab5f1, 0x2821417f,
	0x601c8094, 0xb2d60b7f, 0x1489e0ba, 0x2efd9172, 0xfdeb566c, 0x76eaadc5,
	0xd586c755, 0xd6072b20, 0xc297d41b, 0xbd6d41d6, 0x7cdb64c1, 0x3809d61d,
	0x3a001da9, 0x43c49e3a, 0x7c50d3bd, 0xcff875ff, 0x0ebec325, 0x56fdecff,
	0x8bcfda03, 0x24a17f5f, 0x9d196f48, 0x659bfc6a, 0xf3a3fe35, 0xbab7f8d4,
	0x1d8ff8d4, 0x9c7fc6af, 0xf8ff8d5b, 0x13fe3532, 0x27fc6a3c, 0x3fe351cd,
	0x7fc6abd9, 0xff1a956a, 0x7c6af5e9, 0xe3552e67, 0xbf7fcb33, 0x0d0f7cfa,
	0x99f915fe, 0xe6a0f8d3, 0xd11d101c, 0x4281d045, 0x553c0b47, 0xbc324758,
	0xe355dff9, 0xfa81e968, 0x63b03a75, 0xba53b516, 0x3e9fae14, 0x78c2f4a8,
	0x6e3e96a4, 0xa1f6e64f, 0x44bfd89d, 0x2776eefd, 0x2bb40c27, 0xa915b914,
	0xd3fd23c7, 0x00d9e4a1, 0xd5fdc4fd, 0xf813f521, 0x7f7ee6ab, 0x3d3a2875,
	0x682ed505, 0x78c5ad3f, 0x3636bdcd, 0xeb702b8f, 0xfe5f8826, 0x29dde51c,
	0x74f1c13a, 0x3d60a7be, 0x5153fc74, 0x70ce30a3, 0x1da2091f, 0xd1502ffd,
	0x079b0747, 0x3af4bf85, 0xad78c89f, 0x217afae4, 0xcdd8438f, 0x970085de,
	0x999bd13a, 0x75a6e308, 0x721abee1, 0xcebafe22, 0xf10d3813, 0x1e90896c,
	0x114b6788, 0xc89b847e, 0x5638088e, 0x40f2124c, 0x07a042df, 0xdf15ffe2,
	0x551f5015, 0x975d89fc, 0xa5fd3325, 0xaa5aaebd, 0xeb99b1c0, 0x6c07667f,
	0xf9f1964a, 0x2c20aa36, 0x0d972f08, 0x8fed3de4, 0xc27f95c5, 0xa5d2abf6,
	0xb8ecd748, 0x0bf1090d, 0x347d8678, 0x73cd89a2, 0xd74c44b4, 0xc451fde8,
	0x9adf768b, 0x794f9664, 0x8c22a24c, 0xf4037bf5, 0x378f96bb, 0x1022e2c5,
	0x2e9d1557, 0xa5567182, 0xfe1b584d, 0x5c4add60, 0xc1d38d2d, 0x71612b2e,
	0x2d9c4d25, 0x1412a455, 0x6cf440ea, 0x6a53afff, 0x31db7e65, 0x6231a357,
	0xe3e8845d, 0xd7d73f60, 0xb75037d9, 0xcea22e79, 0x7ebdc29a, 0x2e7dfd30,
	0xc6efe999, 0xe9efc7e5, 0x434b8889, 0xe1c4155d, 0x1fbd32cc, 0x3826dfc1,
	0x5fde8777, 0xf11ebcbd, 0x9edfbcac, 0x1e7ec76c, 0x86d07b4d, 0xeb473df5,
	0x2f9261e3, 0x6eabbd9a, 0x1babf663, 0x97137bd6, 0xb6d7e30b, 0x0daecc8b,
	0xe3674088, 0x45ce91de, 0x753775fa, 0x7cb7dbab, 0x94fb6ea8, 0x7c267673,
	0x51fc0519, 0xe8cbe9cb, 0x788af3a4, 0x6d0c16af, 0x4eb56f4a, 0xe250ef16,
	0x427dc6a9, 0x3fe3eb10, 0x60f101bc, 0x9465fce0, 0x5d3c4f60, 0x2dc9959f,
	0xc1b5e692, 0x8a431bbe, 0xacf8c3a4, 0x43f70cb8, 0xec27c785, 0xedcbadbc,
	0xecde2c49, 0xb61c86a5, 0xf684ec47, 0x3629f850, 0xa892cf75, 0x636c597d,
	0x07d2e757, 0x6f7daaf1, 0x140fcf3f, 0xf9f788eb, 0xf8c7f141, 0x83ef0c23,
	0x1903458b, 0xed2dde04, 0xf597bcaf, 0xb15de1cd, 0x13b56b24, 0xed9529f8,
	0x5dae36cb, 0x16158041, 0x7dc06cb6, 0x1614fa8a, 0xcc89f1f7, 0x082f25cf,
	0x9723ff6c, 0xf1b53f5f, 0xa2d69889, 0xc7111dfe, 0x7eb1b99a, 0xc5f9d01d,
	0x4f116217, 0xa1d29fbb, 0x04923bbf, 0x519eb074, 0xf9e05d94, 0xed8dd268,
	0xb4fa40b1, 0xa464405d, 0x08491b9f, 0xbf2a3ced, 0xf16648be, 0x10cca7d3,
	0xfef74d3f, 0x8349e594, 0x3973df28, 0x722ae47d, 0xfad255bc, 0xc60a62b5,
	0xd375d487, 0x71667811, 0x3bf113fa, 0x37287ef8, 0xc4ece76b, 0x1c48c776,
	0xa3a72167, 0xc49ee985, 0xddc4bac8, 0x199c3fcb, 0xe5c9f799, 0x967b1075,
	0x72733a7f, 0x14b4fdc4, 0x123ccf86, 0xe81efaba, 0x2ed17dc1, 0xa9e48766,
	0xce9316ec, 0xbdf3069b, 0xd01f2dd4, 0xf19b3ae1, 0xa7da9bfc, 0x82373d98,
	0xc3253e30, 0xed79aa9c, 0x359e6e59, 0x1ff8d299, 0xb17c1592, 0xec8bc871,
	0xe985ba9c, 0x7ed0c484, 0x41cfee16, 0xfbe3c97e, 0x5a3516da, 0xc7010103,
	0x527067cd, 0xfe3b47cf, 0x9061201f, 0xd5977280, 0x9624584f, 0xe5bb70ef,
	0x8d687f48, 0xfaf25f62, 0x5fde28b2, 0x1b8afcf8, 0x42dbfe58, 0x3f215aba,
	0x981e9435, 0xd1a59298, 0xe8269403, 0x09b162b8, 0x928d72f9, 0xca4f93a7,
	0xaf447758, 0xe2681f50, 0xcad47878, 0x782a5bf6, 0xfbe14ca8, 0xf75d38ae,
	0x03bd9899, 0x8882b171, 0x8e8ab57a, 0x946bb44a, 0x075f5a38, 0xec51bbab,
	0x3a4e6ac6, 0x3832af7d, 0x133b51f4, 0x1dd567e2, 0x9273b177, 0xe7847f3a,
	0xf0bed14b, 0xfe4abbbc, 0xdaa3657e, 0xcbb0598e, 0x1e4a3ab3, 0x822d2f68,
	0x0672e073, 0xfb5a49da, 0xedc29bc8, 0x80291720, 0xb599d938, 0x40a2c739,
	0xdc1165ae, 0x3e2a90d7, 0x6979005f, 0xc336f113, 0x9f244cf9, 0xcad65fed,
	0x06a90d9b, 0x6c09afe6, 0x16e1fe3d, 0x8a7bafd4, 0xcf783c59, 0x0f77cb91,
	0xcd8cfda7, 0x76755410, 0xf8f43363, 0x8c2993dd, 0x2908da2e, 0xb9ef2c1b,
	0x1bfdc392, 0xd3c7ade7, 0xade44425, 0x8fbbdb6b, 0xbf98cb45, 0x7602915e,
	0x62cfb1df, 0x435e91f2, 0x7f072025, 0x3c704191, 0x17d43798, 0x3c7dd5ee,
	0x9e0e9237, 0xf9f0914c, 0x5e76df93, 0x2ebcf56e, 0x7895bfe5, 0x0b579b27,
	0xf06f53f0, 0xdd646274, 0xbdaf3298, 0x7bef83a5, 0xee8a69f9, 0x15afd5db,
	0xdda7090d, 0xbda7055f, 0xd3e7c186, 0xb3f3e7c1, 0xcb7ed957, 0x6f85cf81,
	0x0d56df37, 0x9aed9efc, 0x9d16660d, 0xcfc2076f, 0xb18893d9, 0xb6bf0e41,
	0x459f4e22, 0xb0b8ee5c, 0xdef89016, 0xdf79871d, 0xf73d8936, 0x560517d9,
	0x1d75fa50, 0x7a099059, 0x88ca7adb, 0x9a7ddffb, 0xfd72853c, 0xdec75f13,
	0x38506114, 0x8fcfe65c, 0xfec0a89c, 0x48c77b1e, 0xf0341e40, 0xb31e1e73,
	0xdce099b5, 0xd08e0532, 0x457a842e, 0x0b916843, 0x989f45da, 0xe320cb64,
	0x8f78d8e9, 0x1946f86b, 0x4c5eb94f, 0x17f963c9, 0x721155e1, 0x784f8fdd,
	0x781fcf0b, 0x994248bc, 0xdfe18dfb, 0x094dcecc, 0x56f83fc3, 0x5e8cdde2,
	0xebfc022e, 0xdf31b384, 0x109f6da1, 0xc03e75fa, 0xf5c5e0cf, 0x9235defb,
	0x41d8831d, 0xa4fce3bf, 0xbf594fac, 0xadeb6f32, 0x0f9eb00b, 0xbf1301f0,
	0xd14be9cc, 0x6edcb113, 0x9ea17586, 0xfab12098, 0xaf5662bc, 0x9bf8f8f0,
	0x2f727eb1, 0x6e87e78f, 0x1e7a0c32, 0x1b2a766a, 0x6f6bb1ff, 0x5cf9c176,
	0xee3d0efe, 0xb752235b, 0xe1e42673, 0x7cf090df, 0x654f4a3a, 0xc8fecfb0,
	0x6031cb89, 0x32a667e7, 0xe5c99679, 0xb135df61, 0x4f1aeb0c, 0x2313627c,
	0x86a65fe8, 0x755f8b3d, 0xe2bd4175, 0xaf5642fa, 0xd9fae165, 0x0aa7a272,
	0xff196fe6, 0x0fa846ef, 0xa5b3be55, 0xeb3e111a, 0x1744a10d, 0xd49d9bd8,
	0xbce0b041, 0x708f9cf0, 0xc18db63d, 0x2a88aea1, 0x3f387c98, 0x21ff9d8d,
	0xc525a1c3, 0xe807de6c, 0x9f91a8fd, 0x79e12ad8, 0xbb2f1d11, 0x8dab7bff,
	0x98aa33e1, 0x7c7de3ed, 0x706c6fc2, 0x40ac48be, 0x0dbcdcf0, 0xbcca9d7c,
	0xbc30650e, 0xce8ffa51, 0x65fee077, 0x2a3c67cc, 0x1efc2175, 0xadb30db5,
	0x76770820, 0x264df0fe, 0x4fec67cc, 0xc2a616f5, 0x3c1f287a, 0x5d53758f,
	0x0f08499e, 0xb79e015b, 0xed1231d1, 0x5a701f89, 0x70ba4d1c, 0x322934bf,
	0x28bf40d8, 0x698ffbfa, 0xabb0589e, 0x3b78e11e, 0x5acb4bff, 0xfccacbd0,
	0xb0272ece, 0x5edc2ca3, 0x054cf2e8, 0xde222cb8, 0x2ccfe0d5, 0xfb55116a,
	0xbe73cec7, 0x8a2d785c, 0xbe23e304, 0x58cfff1b, 0x5af0bb07, 0xbb52090c,
	0x7fcf3cfc, 0xcf79e79e, 0xbf4ca939, 0x7ad7e02d, 0xfcc6fd7e, 0xd7f0d2e5,
	0xaeeddfb6, 0x4e6df260, 0x095dd42a, 0x4b9006dd, 0x0cfe6feb, 0x2ecf11eb,
	0xee6091b7, 0x9e33ad57, 0x09c62304, 0x84cd77bf, 0x8fda51eb, 0x44249d00,
	0x7082d7ae, 0xf9dcbb38, 0x554c7035, 0xffbfb1c1, 0x071c156c, 0xe38b9ff6,
	0xf79e5d9f, 0x1a8ffd35, 0x35597fa2, 0x877efeff, 0x47bdb8e1, 0x4d1a7e2b,
	0x7068fbe9, 0x209796e5, 0x88d87f6f, 0xf692a3e7, 0x8bac52b6, 0xbd608e7e,
	0x3f8743fc, 0xf1f21f7d, 0xb834ed0f, 0x7d3e8c60, 0x106bae68, 0xd88c3e79,
	0x80ee70fc, 0x9a995d72, 0xded1eb83, 0x1b014937, 0x794ddde4, 0x0c856d92,
	0x60575476, 0x09afd225, 0x771289e5, 0x82adfa50, 0xc98aaa83, 0x5b157d80,
	0x011bbda3, 0xd0ba7ddf, 0xcf3a0a81, 0x704fbcbe, 0x712103df, 0xf12bc768,
	0x9a3a8902, 0xf112be78, 0xd42ba810, 0xc1b77867, 0xeca63f77, 0x7103f10a,
	0xe42f2ef4, 0xbaf1d725, 0x2ee675c9, 0x2e422ba7, 0xfa553cfd, 0xa2daf476,
	0x6fc5c7d1, 0x7d320eef, 0x57a473f0, 0x30e7ebb1, 0x0fdf1f7f, 0xc06d2746,
	0x31d14cb8, 0x42a47f3c, 0xb51ac3f1, 0x38f481f9, 0xf89553b0, 0xb3380c46,
	0xb3d7cba0, 0x68cab47a, 0x55fcaed6, 0x800bee3c, 0x43904412, 0x3bef8da4,
	0xcb9571e0, 0xa67d0d7c, 0x5fe019f5, 0xc2bcf1f4, 0xf0578ee5, 0x8dcb9b3c,
	0x95ef11c3, 0xe7823f2f, 0xe14dec56, 0x2b4edf79, 0xa34a89ea, 0x51ce04ab,
	0xecc29bd9, 0x182936c1, 0x1f611853, 0xda569a3e, 0xbfdf4d95, 0x075c38d8,
	0xd702b3f6, 0xb039735f, 0x2215cb9e, 0x9ea04a85, 0xf05162eb, 0xf6a7a8d7,
	0x4b3eb199, 0x12d3e077, 0xbd67573c, 0x2d1bcf11, 0xe372303d, 0x729ff01c,
	0xefa82e75, 0xe3301dd2, 0x61ad2e7c, 0x5be1fffb, 0x07b5a7d0, 0xacffd152,
	0x3e610e8c, 0x95ca36b8, 0xcaa6f10b, 0x79e0b703, 0x8dd667a1, 0x70fd00cc,
	0xc0ce413a, 0x51d6d1f3, 0x9f75d3a0, 0xeec11cee, 0xbac38d37, 0x68faeb7b,
	0x57e760ef, 0x7b5ef228, 0x94dec0be, 0x8076de82, 0xca1348cf, 0x8b82b3fb,
	0x878f11c5, 0x4f39e066, 0x0ffb85c4, 0xbe172d2a, 0x5a40f3c0, 0xc11ef83e,
	0x5ba40efb, 0x8ed25fc5, 0x9aedc957, 0x5cd086bd, 0x72bee738, 0x81bb8715,
	0x752bade5, 0xe6d8b905, 0x39af5f70, 0xc69f4b2f, 0xcf5cade0, 0x3cf0909c,
	0x33a7aa13, 0xccebcea0, 0xd9d22361, 0x70a3f599, 0x5e328dbf, 0x8d898525,
	0xbb69e3f2, 0x6af0063c, 0xbf999349, 0x81f98ab7, 0xdd4afdca, 0x73c03286,
	0xfcc453a8, 0x142d9f60, 0x7947fa03, 0xd787694f, 0x39e221d3, 0x8e537bf0,
	0x3d29be20, 0xdd27a011, 0x3b3756cb, 0x13b8c9df, 0x88b179f0, 0x3ec1a3f8,
	0xfe88c77d, 0x234ed1d3, 0xa77da7da, 0xe038ff98, 0x284b077c, 0xbe50e203,
	0x7e515397, 0xb687a5f5, 0x8cd67b33, 0x9df489e7, 0x71e38ef4, 0x5e7e64c7,
	0x51d8324a, 0x41cd3b57, 0x15e8a3b0, 0xc9fb87f7, 0x3fde272e, 0xafc04d1c,
	0x1a00d7a7, 0x273ec286, 0x9a4d4f9e, 0xf85df7f9, 0xde1943fd, 0x1f8f2011,
	0x5bfda1ca, 0x7c1efbe0, 0x77b66aef, 0x45c58dac, 0x2978f852, 0x37ba6fd8,
	0x9f0bef13, 0xcd39d938, 0x1779fccd, 0xbd19f73e, 0xef1d70e3, 0x418ec959,
	0xcf6df9d6, 0x8b4d4905, 0xf32a3c47, 0xbb4670a6, 0x3b970b4c, 0x5cfc74d2,
	0x2d0f066e, 0xf9f1865d, 0xf883f335, 0x7497c006, 0x19ae3c30, 0xa4726069,
	0x9fda1469, 0x954a21a4, 0xc9d15d87, 0xaef591f6, 0xfb9e22b3, 0xa04deef4,
	0xf5274287, 0x30152e78, 0xc601c612, 0x172fce0f, 0x7554bd78, 0x5ed7cb13,
	0xc67ce678, 0xb7ec0b7c, 0x6fdaaf38, 0xdbecabd1, 0xc40c7223, 0x392e2c3b,
	0xd99f22a6, 0x8fce22c3, 0xd7ac99d5, 0x027bf8cb, 0xd12375fe, 0x90633fdf,
	0x1eefe00f, 0x03ad19ac, 0x31726aba, 0x666fe3d9, 0xfbf653eb, 0xb5f6fb2b,
	0x634a69f0, 0x7896b1fa, 0x3b8a81e7, 0x5e44e44d, 0x93e780bf, 0x28bfc154,
	0xe986abe8, 0x0f9466dc, 0x0617a8f5, 0xf862139e, 0xf81bdf9a, 0x4baf6dbf,
	0x4d674827, 0xe80c7f2e, 0xcc6d0fd5, 0x93d8a32f, 0x2255df01, 0xa59e275b,
	0xdafa0c96, 0x012d21b3, 0xfc3ca39f, 0x15cf6050, 0xfd603739, 0x0fd02f40,
	0xdafb47bc, 0xecc59691, 0x0c7a6005, 0x900dfaea, 0x93f457ef, 0xb074904f,
	0x4e27a81f, 0xec7a018e, 0x83b1ca69, 0x27115b5f, 0xd0461627, 0x8255ef85,
	0xa86460fb, 0xe7071c6b, 0x40c7bb56, 0x5daf6d5c, 0xe76bd7ed, 0xeec4fcf3,
	0x7fcf91b9, 0xefecc696, 0xce8f9c83, 0x075e11a4, 0xc31b85a8, 0xf78e62fb,
	0x36f79726, 0xef34f3f4, 0xe58d6e2d, 0xdfb9a0f4, 0x61bfd2fc, 0xfaab6d5e,
	0x00659b1c, 0x87ee3a7f, 0x617e0dc7, 0xd8a35c2c, 0x606c36ef, 0xf5eaae72,
	0x5987dcf2, 0x4d87f71b, 0x789ff1dc, 0x9d82f7ce, 0x12897253, 0xc7a08dcf,
	0x5cee1905, 0x9b42dfb0, 0x45f01b45, 0xf388ab55, 0x4d9a9269, 0x73fde99b,
	0xebb47aad, 0xce7cf8aa, 0x106379a5, 0x0c91126f, 0x24e7ee14, 0xadda0c6f,
	0xe679f99b, 0xf7d0759a, 0x070a92de, 0xe1898f81, 0x3393e119, 0xd49c1d08,
	0x44169e21, 0x73c3e411, 0x1f8c043b, 0xcef74b9e, 0xf50f7683, 0xc1dcf1af,
	0x8fdc6ae6, 0x39f785ab, 0x73e91793, 0x028f5f31, 0x0a38ed4f, 0x9e00fb3c,
	0xdf1d2f60, 0xf7cf7a82, 0x4b1408a4, 0x415c748e, 0xe76277bf, 0x77e1f794,
	0xa81b7c09, 0x9e8322dd, 0x7df5fecd, 0x451ae7a0, 0xe8af4bac, 0x1a2449cc,
	0x5efe0d7d, 0x62b31bc5, 0xb27a1174, 0xf3c445a9, 0xcd869ab3, 0xef885988,
	0xe81bbe5f, 0x4aecb4eb, 0x4f788c2c, 0xfd94174a, 0x557c2a61, 0x0c73f86e,
	0x56b5538c, 0xf052eb8f, 0x84e747d2, 0x1a39b7f2, 0x697d3ae3, 0xc157ec21,
	0x01be9853, 0xd13d0a0f, 0x6dd3f2f7, 0xca3f1c7c, 0x6f2c9ea3, 0x3a106b89,
	0x3a23f459, 0x6ad7f42e, 0xae95f3c5, 0x1e055c77, 0xbe737c61, 0x71e036c6,
	0xa9c6167b, 0x2c252775, 0x3cdd3b56, 0xb8f8032d, 0x880bea92, 0xa10a540b,
	0xab9cf1f7, 0x710ca34e, 0x4b0dcaf9, 0x9578c1e6, 0x783a8ca7, 0xda7873de,
	0x06979c18, 0x194e14af, 0x5f7bd183, 0x15c32856, 0x4f6a3f01, 0xeb2b7f20,
	0xce379889, 0xb851fa83, 0x8b2fba9f, 0x0e4233e2, 0x72674a8c, 0x336fbe80,
	0xfdb37d20, 0xdaf5e1fc, 0x69b5eb34, 0x4116fbd6, 0x2f2e26fa, 0xbbc167ae,
	0x5fdc1d46, 0xb95dc4f0, 0xacf4f7e0, 0xeaeb8499, 0x00c7bbb1, 0xd064f57f,
	0x979107fe, 0xeba09e0b, 0x758affcc, 0x5f119b36, 0x1ed3ae43, 0x62be4eda,
	0x759a659d, 0x18e4959e, 0x8393bdfc, 0xa07d8122, 0xfacf74be, 0x7f1b585b,
	0x67a7c27f, 0x10dbe0f4, 0xde94798d, 0x45c63d0e, 0xc7403915, 0xd07a4ebb,
	0x94f43d21, 0x03c71bca, 0x6d13ad7d, 0xb3d47750, 0xc35fc6e6, 0xeb3dca39,
	0x09d81b45, 0x7e0ca53d, 0xdea01e54, 0xdcf0c9ee, 0x7ac3ed8d, 0x338b9dfc,
	0x1b7e7fcd, 0xea75b5f7, 0xf3eb8265, 0x6d039fac, 0x6b905f3a, 0x99b32e14,
	0xf5c7aabd, 0xd93e3537, 0xadfdcf08, 0xfb7cf163, 0x0d59fa81, 0xa2b5aae7,
	0x24890f8a, 0x27be78e3, 0xaa5f7152, 0x612a6702, 0x521fc173, 0x59ed01e0,
	0xe2e1fba3, 0xc0b8fbe3, 0x38e7602e, 0xf0067970, 0x027a66c9, 0x8e415dea,
	0x50ee5d41, 0x7f2b4afa, 0xaad476b4, 0xcb515cb0, 0xefcd6ae3, 0x69afdd1e,
	0x8dc8d12f, 0x5af3cd1a, 0x9faa73cd, 0x4e2c1eef, 0x93d3857c, 0x0e0ac702,
	0xd95e2547, 0x3f404eb7, 0x0d9242b4, 0x3f3cffe0, 0x4ae7e991, 0x436e9889,
	0xeb8cbcbe, 0x834890ab, 0xbbee10b1, 0x127e910c, 0x68c1afed, 0x2628eda7,
	0x657be887, 0x22b68886, 0xecf9956f, 0xae51f3e5, 0x502e38df, 0x45638ea6,
	0xa6f615e4, 0x2bcc0f17, 0x2fd98a14, 0xeaff009c, 0xa57e88a0, 0x7fa675ef,
	0x3657e7c8, 0xf380eb3e, 0xc40872ef, 0x6bf5954b, 0x7ed7d8e1, 0x177e0625,
	0x01b8f7a8, 0x74553bf7, 0xffa297c4, 0x0a0d0f65, 0xde38d7f7, 0xa57afe95,
	0x91e998ee, 0x8ee93376, 0x2f411199, 0x9657ed15, 0xe14b3f83, 0xe42317e7,
	0x84ce99f8, 0x2b2bf052, 0x14a53bff, 0x485d15f6, 0xf97efc57, 0x6f816b27,
	0x1e311a0e, 0x1cfafbd1, 0xfbdf7c1d, 0x3ebf157a, 0xf4d0e784, 0x01933d9e,
	0xd4e8c7e3, 0x9f7f16fb, 0xba8ef3ce, 0x0adfb60f, 0x5250fff2, 0xb888aad6,
	0x10aea570, 0xf567e1fd, 0x6f30b9a1, 0x4237e76a, 0xcfd28b1d, 0xbf197485,
	0x1e783def, 0xb33f59cf, 0xc410bd3e, 0x11c1ef4a, 0x9ef6ffe8, 0x86d731ba,
	0x0bb247fe, 0x7ab3c2e4, 0xafe621f9, 0xf7c05d58, 0x0e307f4a, 0x0f7b03e4,
	0x78812b8e, 0x3629ef41, 0xf8c6da5f, 0x0fcf7d01, 0xbf4a2af5, 0x71f93a31,
	0xff239ba8, 0xe23f47ad, 0x92722fc1, 0x8c6e9f60, 0x0a3cf061, 0xbaea0df8,
	0x6f3895b1, 0xad4fdce5, 0x7880b15f, 0xc692bd58, 0x0fce52ff, 0x5589fad5,
	0xb77579a4, 0xa45fd030, 0x9fc9b886, 0xfcad7c08, 0x5fbea1b5, 0xa34be7b2,
	0x3f453cfa, 0xca134fe7, 0x8fca0ae3, 0x14de306b, 0x46bd7160, 0x68fcd071,
	0xd3b3065e, 0x65ff4537, 0x5e04776e, 0xe488eb4f, 0x6d3d70a4, 0xe1672620,
	0xd5e37e60, 0x06cff00c, 0x31e78bfa, 0x7919518e, 0xe81909de, 0x0d2e9e37,
	0x79d29734, 0xba235e9d, 0xaf320d56, 0xd46fd6bf, 0xd39caf7e, 0x80f2123c,
	0x3505ef50, 0xf2aff64a, 0x55f3d59b, 0xf5e669e0, 0xddf7da14, 0xf790af3c,
	0xc0dc4885, 0xac7a9df7, 0xf1de8e8f, 0x80fbc6c9, 0xb6f43b3e, 0x20f3192c,
	0xe7ff3c6e, 0x8dfb88a0, 0xc4ce3afb, 0xe67a0fdc, 0xa6588de0, 0x0e73f61f,
	0xe8cf988a, 0x0892bf6d, 0x0fda0f79, 0x9d7d77e6, 0x5f70ba4f, 0x98f310fc,
	0x3b7e2191, 0x134137f9, 0xde79e7c7, 0x72e71dde, 0x3953be41, 0xf6832338,
	0x39fb9bdf, 0xbba4273f, 0xce8fe804, 0xbef7ed0f, 0x2fb455c0, 0xa0e21d4d,
	0xc82c6fe7, 0xf9bb7c30, 0x8fcf564d, 0xcc0167ce, 0x9d679947, 0x9e80321c,
	0x877abafd, 0xae1707c9, 0x7df3fd84, 0xfc0b82cd, 0x221d0580, 0x1d05adea,
	0xe29901d1, 0x0b08f265, 0xb1b72bb6, 0xe2a9daba, 0xbe21b784, 0x889d78b9,
	0x3b23cdf1, 0x8f5b7a1e, 0x327a10f5, 0x7f44bd58, 0x1ebfc47d, 0x3f167185,
	0xe9dcbb09, 0x033df89f, 0x49bd5bf4, 0xab647020, 0x60624eb6, 0x5cf7447d,
	0x1f581c51, 0xeeb8fb01, 0xb556fda7, 0x5077f11b, 0x1293d606, 0xff626af2,
	0xc3790e79, 0x51f3fed7, 0x0ede7efa, 0xd7a1c203, 0x534efcac, 0x243bfa37,
	0xf585f6c8, 0x019b3c1e, 0xfa1df478, 0x8763c613, 0xc1d20fe2, 0xc89e31ea,
	0x94dbbf60, 0xbb95c5f7, 0x5fbc833d, 0x7b9ef3cf, 0xb014fef4, 0xb8ee8f63,
	0xefa0f28a, 0x0db38b20, 0x9bf13fd9, 0x682bbc59, 0x515c38c6, 0xe04eed9b,
	0xc20f6a13, 0x573b7d7a, 0xdb49d8cf, 0x32f497e6, 0xe1be5698, 0xe017e416,
	0x15dfc88f, 0x0f64f850, 0x7529bfcf, 0x6f3cf51e, 0x2879d4ab, 0x79da1f75,
	0xf51f7528, 0x7101f750, 0xdecf0cda, 0xd28d7a0c, 0xd6f7f085, 0x4340f5b4,
	0xeb68f7d5, 0x0279b53b, 0x6b10fe6d, 0xc70f40f1, 0x0692fdb1, 0x65e1d7aa,
	0xff19e8eb, 0xff577203, 0xd37e8896, 0x49bf1391, 0xabd3948c, 0x8818aea5,
	0xa7da5ea3, 0x10d6f9e7, 0x27f497e6, 0xa164313e, 0xc3bf66bc, 0xb86da3e0,
	0xa9209bef, 0x24e16f7e, 0xefae97ac, 0xd32e4648, 0x78fb92c3, 0xaf479d39,
	0x7600c2ad, 0x82c4febb, 0x7a27d032, 0x8d818567, 0x02ca6a5f, 0xc849c4bc,
	0x943bab17, 0xd06cbb71, 0xb4cf92bf, 0x0365bdc6, 0x68b0b0b9, 0x33e757d6,
	0xc9543e79, 0x9bf38667, 0x995f19ce, 0xf1ccbccf, 0x8d7e17f8, 0xe5bbfcca,
	0xb0672f33, 0x49d4e67c, 0xced58874, 0x33e783cb, 0xfaf3ac07, 0x990999f2,
	0x8637cb32, 0x3e443bd7, 0xd7ff4073, 0xd81ccf97, 0xccf910ff, 0x675ffd01,
	0x2fdc333e, 0xe43667cb, 0xaf1eb0eb, 0x8b231de1, 0xde589bd3, 0xa5f9c8cd,
	0x55593821, 0xfd5ca22f, 0xe79e3264, 0xc58fb0d4, 0x2ad92e59, 0xfa9fc06c,
	0x324f1638, 0xe065ddea, 0xece31aaf, 0x299740f1, 0x7b6e2c99, 0xe91eae35,
	0x1b352af3, 0xa9279f71, 0x21bb40f7, 0x3c88816d, 0x5a57c9a5, 0x9f96453b,
	0xf5c4c9bb, 0x38369bf1, 0xaa7f6cf7, 0x44666c77, 0xf8b580dd, 0x2513ac55,
	0xe04cdeed, 0x546d47df, 0x779d227e, 0x20c71c63, 0xb8829f78, 0x24653912,
	0x355d5760, 0x22d8477b, 0x4cf6f2f8, 0x82c7b703, 0x9f926e78, 0xd7d5e0b4,
	0xace1057e, 0xe79533c4, 0xb842123e, 0xe6e2bf03, 0xcf0964bf, 0x8fe3a789,
	0x3e76bac0, 0xf0bdb08f, 0xa3afc59a, 0xfcec637c, 0x7dadf302, 0x886ee852,
	0x8875b4ff, 0x9df091d1, 0x34a2f9cd, 0x103193fd, 0xef83ab0f, 0xbc9f2162,
	0x67f00464, 0x0634319d, 0xf0f47de6, 0x5c80c79f, 0x04b9dab9, 0x0f72df7f,
	0xbbf51f7d, 0x99175421, 0x91e6d667, 0x783993bf, 0xe74f797e, 0xc79814aa,
	0xb05710b3, 0xfbf6fec3, 0x763ec267, 0x08ff7113, 0x72a107e4, 0xf68dfd03,
	0x039c2299, 0x385bf757, 0xe6a28e03, 0x45cbd320, 0x790024e9, 0xdfcebae2,
	0x75edf9e2, 0xb81b06c5, 0x2c05519a, 0x6c551d4f, 0xaaa2f3c2, 0xf0f8d852,
	0x7720ccf3, 0x894e0e8b, 0x806dbc07, 0xff7a7642, 0x1bdfce4d, 0x03f73d32,
	0x79eefb7e, 0x7adc357d, 0x317af049, 0x726c904f, 0x3395bd61, 0x02233d90,
	0xa99affbe, 0x037627de, 0x52e785e7, 0x438c1eda, 0x03b01eb9, 0x2bba945e,
	0xe2cf1e52, 0x346792dc, 0xea060bc4, 0x2c2fe637, 0x3bff74cf, 0xff7943cc,
	0x1befb3b7, 0x1f841ded, 0x60d3fb14, 0xeb007b68, 0xe82d6a52, 0x09f840ef,
	0x6cc9fbbe, 0x826efe23, 0x9de42fb2, 0xe0c7b9e8, 0x8b2ab0a8, 0x8e9331b7,
	0x77bbe733, 0x70b686ac, 0x107e5e34, 0x777e63e8, 0xc7756109, 0x8d79e16b,
	0x47099bc9, 0xf74a5d7d, 0xa505888e, 0x87e789e4, 0x7b467866, 0x5fbf9d06,
	0xf8435755, 0x0e5aa4be, 0x72fbcb97, 0x7a6e8162, 0xbcc58f9f, 0x7fdf2f75,
	0xfbe7cbd7, 0x240bd521, 0x05565e42, 0x9ec01a4e, 0xd275deaf, 0xd7cf6910,
	0xed56faf2, 0x7c71cff8, 0x17e1785c, 0x5da11f57, 0x078fe1fd, 0x5beec172,
	0x75c45c22, 0xe4e67d5d, 0x3dbebe5c, 0x2e87beb0, 0x740c3287, 0x476d355d,
	0xed5879d8, 0x28527d7c, 0xd7d6abf7, 0x8a9aebab, 0xc0407174, 0xbbe51e3a,
	0xa7277dda, 0x55d6f9c2, 0xdf70e2bb, 0x8081c435, 0xa203ab1f, 0x57e4ce26,
	0x1bd586e8, 0x7973b973, 0xdf0f8729, 0xd9abd487, 0x06bef89f, 0xd0a5733e,
	0xdcc79814, 0x263a7165, 0xfaaa02d7, 0xd54b79d4, 0xec52aee3, 0xca0a1f87,
	0xfb639def, 0x073b3f45, 0xf2bba8c7, 0x5b884cd6, 0x4ff5668c, 0x2f28a35b,
	0x7feebf52, 0xf1b67e38, 0x1f7a0c3a, 0x4674f7cf, 0x1b9defb1, 0xeccf5875,
	0x74883d29, 0x8b3a93f8, 0xda44720b, 0x2767397d, 0xce13b9fe, 0x99fff911,
	0xfe0077de, 0x1975e2f3, 0xbc3ce16f, 0x797eb0a3, 0xed75fc42, 0x6c4199cb,
	0x637f967a, 0x6c33f875, 0x790b296c, 0x71266a5e, 0x7ba13ee3, 0xfbdf1788,
	0x0dc1af4d, 0xf86ffdf6, 0x12efa83e, 0x97bfde3f, 0xddaaf004, 0x01f0a457,
	0x0e79ffa5, 0x93e7ff46, 0x3e9ba444, 0xe8c9f798, 0x7bf0e931, 0x8d37d3df,
	0x4efe8e18, 0x77ea824b, 0xf79a8773, 0x71c18174, 0x1af7a643, 0xecb973f4,
	0x645bdb8f, 0x20a29df8, 0x452ebdfb, 0xe04e4c4e, 0x72d5f874, 0xd872eba2,
	0x5324b19f, 0x9d2ffc38, 0x00a83025, 0x0000a830, 0x00088b1f, 0x00000000,
	0x7dd5ff00, 0x45547809, 0xbedd68d6, 0xa4ee9ddd, 0xb2167493, 0x959d0810,
	0x09d09204, 0x34e8a88b, 0x74586248, 0x328222c2, 0x590081d0, 0x38e08b3a,
	0x9a4cc338, 0xc31c4455, 0x74545198, 0x3410483a, 0x18248d38, 0x480d3834,
	0x388b7106, 0xf28cff22, 0x02044412, 0x0fa30849, 0xefbf38df, 0xd375539c,
	0x9c449b7d, 0x7bfffff9, 0x5f9f8bdf, 0xd6eab751, 0x39fb3aad, 0x4efaaa75,
	0xb4eeffc6, 0x21674d95, 0x63332ff8, 0xd4fd8c51, 0xcae79fc0, 0x86391626,
	0xec8b36b1, 0x81e0900a, 0x347f7a4d, 0xca27f3d4, 0xb185936c, 0x6786af3f,
	0xb673ff50, 0xed8b5aec, 0xdfef46cc, 0x3e9dc62d, 0x50bad671, 0x5df797e8,
	0x940f18fb, 0x677443f9, 0xdb78d3da, 0x94fff0f7, 0x6175bac8, 0x564d4e50,
	0xdac69f3f, 0xf7864cb4, 0xc1b9e033, 0x31eefcfb, 0xf0877eea, 0xab58e19b,
	0x19320b91, 0x8e09621b, 0xaa12373c, 0xef88d823, 0xf1a6ea65, 0xf4ef4f5d,
	0x986efaab, 0x7b165dc7, 0x63106592, 0x72faefcb, 0x06844b01, 0x747f7b2d,
	0x1f156324, 0xa99d75f0, 0x19e89586, 0x606d5b3b, 0xcec654b6, 0x7ea99b55,
	0xca863abe, 0x2a16d58b, 0x51a7552f, 0x95b5577b, 0x0a580fea, 0x45dc7032,
	0xed68af1b, 0x54ad3819, 0xd8c71b0d, 0x7eff330a, 0x09a3c69b, 0xb738ef82,
	0xf87ad64b, 0xdb630ace, 0xdf8020a4, 0xab04fa8a, 0x9b4bda13, 0x5041addd,
	0xf20a7916, 0x3d2e504c, 0x658ad556, 0xecc635f9, 0x2f9b19a3, 0x8cb78c17,
	0xe5fdef85, 0xe0bb9ccc, 0xe3d557f9, 0xaa17fbe9, 0xcefdf46d, 0x372a7cea,
	0x63b7ec59, 0x474b5b3f, 0xb105846b, 0x876f4572, 0xe86aee81, 0x3d41c6d0,
	0x18d926d7, 0x1b76e3cc, 0x1812b973, 0xdbb3aadb, 0x635b8f11, 0x50b5d60d,
	0xf339989f, 0xfc6107f9, 0x7cf661ea, 0x533dcf5c, 0x9c71724b, 0x6a17c7bb,
	0xdfbddfb1, 0xfd011631, 0x8c6864d8, 0xdfe05c05, 0x612fae4f, 0xf20d8ca5,
	0xe05ca1e2, 0x525bf2e1, 0xa5051b16, 0x5bd3f2c6, 0x65c71e11, 0xd5e8f086,
	0xfc6154c2, 0x5c2353de, 0xf2edc04e, 0x0668a4a6, 0xb3ae5ef3, 0x78678744,
	0xfc04edc7, 0xfa9f54b0, 0x70629b9e, 0x70f57d7d, 0x857f37f7, 0xd73e7b71,
	0x17d3b758, 0x859ee7dd, 0x18a6ebfa, 0x4bb7e22b, 0x11bae6c7, 0x682aacb0,
	0x5de03066, 0x6ebceccf, 0xcef5891f, 0x00b0b640, 0x8d5ee3ea, 0x817c849b,
	0x79e8b3df, 0x4f680cfb, 0xc4e9f57d, 0xdfbc595f, 0xf25ee5db, 0x7ea167d7,
	0xea71a5d9, 0xee64a142, 0x5d7037ae, 0x7ad64c3b, 0xd24d2b78, 0x3a24ae06,
	0x16363175, 0xcaed16eb, 0xbf76c61c, 0xe7e0fcfa, 0xb09be9e0, 0xfed0f1d6,
	0x1b2096e6, 0x9d4def7e, 0x7c4af4f5, 0xfefe79ff, 0xf87dbf4b, 0x8f96334c,
	0x0c3ce797, 0x384b1ae5, 0x77e8b5c1, 0xce902325, 0x1a01c646, 0x5e57bc60,
	0x2cc63c97, 0x0f6b32c6, 0xf98589ad, 0xa1d6da8c, 0xf6650c19, 0x962d690e,
	0x8ff38323, 0xd1bed0c9, 0x8c79a162, 0xe390486e, 0xbb065d90, 0x2493fafe,
	0x78849402, 0x94f0211a, 0xd2657b51, 0x0cf72860, 0x830f2f76, 0xfb9211f6,
	0x6d65e222, 0x3b1cc9f0, 0xc686abc1, 0xf5996a69, 0x0eb4fdf1, 0xe701ac67,
	0xd6b7a85d, 0x9cb87d23, 0x97674875, 0x4dd669ed, 0xce05abc8, 0x97bf1067,
	0x4dd651ed, 0xe35fbed0, 0xfb05b90c, 0x3ad2d69f, 0x51f1df5f, 0xa1ea0e88,
	0x84663a8d, 0x9eecf2f6, 0x3e5fec3c, 0xbbf0c2d4, 0x33b85f43, 0xd153e11f,
	0xe34754d8, 0x09560c38, 0x5d3715fa, 0x448b8d6d, 0x29acc281, 0xbc8d5f48,
	0x9b64d8fe, 0x16a58655, 0xebcd7dd7, 0x2f54056d, 0x5a099d90, 0x60d8bfec,
	0x9f7187ad, 0x406631d6, 0x9167b4fc, 0xb59222fc, 0x18f5f178, 0xd6fb6334,
	0x156c6704, 0x6c43fbac, 0xcfb199ba, 0x415fd987, 0xf3d588fe, 0xdd26dbf7,
	0x99704f1f, 0xf8a3f110, 0x69e71942, 0xe11a733d, 0x0e386dfd, 0xe41eb1e0,
	0x8c07d205, 0xfc7c8cdf, 0x9c5f98bc, 0xc236652c, 0x0e9ee3ba, 0xfcb5aeb0,
	0x0dcceff8, 0x1db070dd, 0x4ceb77fa, 0xcfa0251b, 0xe210c0ca, 0x05d8b5bf,
	0x64d47fde, 0xb1d71b7f, 0xd207a504, 0x5192d681, 0xd2be7400, 0xdf8a3b64,
	0xe27a1877, 0xb5101af5, 0xd83bfb46, 0x0fb642af, 0x977e828b, 0x8787da87,
	0x85359ca2, 0x346e3ad3, 0xdb266d8f, 0x8fde3887, 0xe6291fed, 0x9e621ff9,
	0x90489644, 0x06cda2ac, 0x93b28f74, 0xeaa442dd, 0x06fac0d1, 0x2ff5e61d,
	0xeb35955c, 0x25f63086, 0x8220f9d2, 0x3017c11f, 0x284f50cf, 0x70c783cf,
	0x1bb7083a, 0x41d032ac, 0x76554474, 0x335d0f95, 0xc23467ad, 0xca7fd361,
	0xe5be091e, 0x17263ffc, 0x7cff8bd2, 0x1a241313, 0x7312e7ef, 0xaeae906a,
	0x8b5fa9e8, 0x3f95fdae, 0x252d7bc2, 0x7c275619, 0x10ca3f72, 0xda04271c,
	0x825b6e81, 0xa5f91399, 0xcb944665, 0x0f7c8099, 0xf30fc8ed, 0x4646fbc4,
	0xde65ba72, 0x83879260, 0xb8300003, 0xfc01b5e6, 0xbbd55d7d, 0xeafe3899,
	0x6b1fd238, 0x44c6d725, 0x32d7ff7c, 0x425397e9, 0x7986d51e, 0x79e197ee,
	0x865495ed, 0x3cc539df, 0xafd89571, 0xaef89038, 0x8b16cc36, 0x7fff75f2,
	0x6af724ca, 0x226ea1b3, 0x0dd734b9, 0xd8676bcf, 0x7ea0c362, 0x6d47c09f,
	0x29feab9d, 0x1a466f1c, 0xccb06bad, 0x025fa8aa, 0x3aafe71f, 0xeefd9efe,
	0x450b2d20, 0x1162da78, 0xa516cf7e, 0xc3039430, 0x490d2613, 0x79ab2640,
	0xae6df89a, 0xf8ca3790, 0xf40182f8, 0x31fc3de6, 0xdea4b79b, 0x4f757c88,
	0x3403b1b1, 0xbc553b07, 0xe302d826, 0x3d9763df, 0xccb76801, 0xd9f5b5ce,
	0xbe388905, 0xe202486d, 0xe88228af, 0x18b8f00c, 0x8f56f6e1, 0x01dca181,
	0x748d1972, 0x529e9d70, 0xfbb5fbfa, 0x699fcbf7, 0xfeb049b0, 0xb200c6de,
	0x9c4a168b, 0x3c032b3e, 0x667f9073, 0xf0a3ed1a, 0x17a595fb, 0xb1f340b3,
	0xa16999c8, 0x77eefdf8, 0x76748664, 0x34e5e05a, 0x87a45c0a, 0x37c260aa,
	0xaffb7513, 0x4f345c22, 0xfb17a72d, 0x6ea92313, 0x9762dbd7, 0x0f2d7d20,
	0x369efc22, 0x8ed3f6f3, 0xf98fa230, 0xc7bd944f, 0x0ba73e00, 0xa74744f4,
	0x4817645b, 0x4ad9f674, 0x3807a3d9, 0xf6bccd75, 0xd7bc2a54, 0x718beab5,
	0x5f6ca15b, 0xd478b7f3, 0x94d7f31f, 0xe6f7c74f, 0x1bbaae97, 0x7c40ebe5,
	0x2011df39, 0x5fdb9098, 0xa6d827f7, 0x67231e20, 0xb943cb5e, 0xf1ccb83a,
	0xfe7812cc, 0xddfb04ab, 0x7d0afeb8, 0xa3c2057b, 0xe3cfcde2, 0x39fca257,
	0x56ded2f0, 0xed83cb28, 0x8abdf133, 0xac267735, 0x3db4c1c7, 0x0aef08a9,
	0xc027c82d, 0x7d82577f, 0xb26fc10e, 0xbbdf1527, 0x43cb6ba4, 0x8355b1b8,
	0xb8dc947e, 0x5fbf52d8, 0x0b283a02, 0x52a0a96c, 0x3ce16576, 0x884f253a,
	0x04708494, 0xbeeb0f7d, 0x8484f664, 0xb86a9d21, 0xa5db2ffe, 0x0d4d1f5e,
	0xff0cb3e8, 0xb995ef01, 0xec919b65, 0xe71e9764, 0x0cbfdfeb, 0x1fbf539e,
	0xb994bcf9, 0xe6b0f3f9, 0xf1cadedf, 0x3e00f1ed, 0xd94eee2f, 0xdcbef88e,
	0x22ea52f4, 0xbdebc0d3, 0xfd7cbe7e, 0x00be9097, 0x89e0978e, 0x81abe90e,
	0x03fa0bcb, 0x1ddae8ba, 0xaeafa2ab, 0x9b5dc3dd, 0x975ae47c, 0x75667be0,
	0x89919b8f, 0x871ee8dc, 0xe7c29176, 0x42cee0cc, 0xb9a5883b, 0x7a6666b3,
	0x702b04e5, 0x9773d2a7, 0xeffb153b, 0x6e62b0d7, 0x96eff157, 0x475712be,
	0xe4018076, 0x8fac18e4, 0x65758edc, 0x6fad1bdc, 0xaabd56f8, 0xd752ee9e,
	0x0c39479f, 0xcbf2f374, 0x03cb9cf0, 0xcc01f859, 0xc2d1e0a2, 0xcb822ded,
	0xb815e87f, 0xf207183c, 0x96e70ca6, 0x72e6f348, 0xda8965f8, 0xe3db67f7,
	0xe1761e50, 0x864e507a, 0xf5033d41, 0x52b79f20, 0x3fe0e057, 0xb1ff35ef,
	0xde1dae34, 0x868273ff, 0xdabe77e6, 0x6016731a, 0xeee8291f, 0x5448ebbc,
	0x76179421, 0x7c42891c, 0x9e2eac5f, 0xbd8eed85, 0xf728e1f5, 0x848fbb1c,
	0xb79cb0d8, 0x2f68b7f3, 0x6ecb7639, 0x8f3c075c, 0xdc97e7c2, 0x87ee4347,
	0x4477e7e7, 0x0e1f20e4, 0xae252f44, 0x3eb398ec, 0x4bb91af3, 0xb74cbf0d,
	0x59aa3eba, 0x6108ff5d, 0x7f5ff635, 0xaea3db2f, 0xaea63e8f, 0x0797f57f,
	0x159920e7, 0xcadfcecb, 0x2dfdcf68, 0xf9ca18ef, 0x0f5ffbf3, 0x7d947c41,
	0x768ad45e, 0x6aadb2ea, 0x249e02b8, 0x9dcedfd4, 0x12b1e912, 0xf43f3f97,
	0xad8ca7cf, 0xa81dfae6, 0x4a2e97c4, 0x9b55b399, 0x4eff7d70, 0x03639ee6,
	0x5cac723a, 0x68eceb3e, 0xbb37b8ef, 0x3fd1e8b7, 0x40eefff1, 0x364cc97c,
	0x8583fa0b, 0x2ddb79e3, 0x2fb1272b, 0xcdb0e540, 0xbd21e51f, 0x91263e15,
	0x37dc2c7e, 0xc3946dfc, 0x4de77b1d, 0x3e4e72a5, 0xb0b163c1, 0x48b596cf,
	0x9ba8609e, 0x5d3a73c7, 0x317255b2, 0x75a2f798, 0xd3dd0a01, 0xab368b77,
	0x56b4b1e7, 0xf9acbedd, 0x8c12b7d0, 0x41786c5f, 0x78aa7a8f, 0xd61dba9b,
	0xe6ed0479, 0xfc8cf3d2, 0xdf1dd2e2, 0xf9dba807, 0xeb2896ba, 0x70cede70,
	0xf324dc7d, 0xb1676fda, 0xb9fb7202, 0x227302d0, 0xda96fdc0, 0x56e1193a,
	0x990fecce, 0xf42fc893, 0x963cc104, 0xf6837d82, 0x5a57e82f, 0xa1add5d7,
	0x7a0480ae, 0xfcf08cce, 0x871b6b2a, 0x636af77a, 0x7c49d5b0, 0x0cce36db,
	0x475065f5, 0x1ab315b8, 0xe5038f82, 0xc5e9ccad, 0xc45f33e6, 0xd59d6f93,
	0xa1d9fb70, 0x38421cf5, 0x7a76b194, 0xdbe7f10f, 0x3aeb01cf, 0xb963f605,
	0x667defdb, 0xb3f28b9d, 0xbc27a4d2, 0x1f7f3655, 0xd8aedbe0, 0xb11f8aed,
	0xf7db902d, 0x2fbd287f, 0xbd7ae910, 0x20c67b64, 0xdbdae963, 0x625c748a,
	0x5f7ebd22, 0xb5df971d, 0xf1811c18, 0x93a4b76b, 0x649f787d, 0xb2f5c54b,
	0x5bf2462d, 0x584b6ec0, 0x876bc63f, 0x34e6fd81, 0x24a7bd42, 0xdb1db5d0,
	0x5d3fb9b3, 0xec952f3b, 0xb7253783, 0xf3aee507, 0x6a5f9cf7, 0xa9fa7067,
	0xda963c7d, 0x8d538aff, 0xdb8efb45, 0x865bb521, 0xe653bb73, 0x044f60f3,
	0x4dac3c93, 0x641af310, 0xf62979a1, 0x7ed98a75, 0x3acfa277, 0xdd80d68b,
	0xfd17e307, 0x57186646, 0x3f11c560, 0x0bd77f4a, 0xc5b3d4bd, 0xef0edae8,
	0x5a0a959d, 0x7ede0935, 0xbdb9130b, 0x6d926e3d, 0xc567e8a7, 0x199a457e,
	0xdf827e9b, 0x59634a7b, 0x7f03e09b, 0xed152d9b, 0x8c5bb3f2, 0xd3a78839,
	0x8f4e5cd9, 0x7cfdc49b, 0xdb6c23f0, 0xe44e2ca1, 0x4ef959f2, 0x27d72271,
	0xe85a260f, 0x3d73677b, 0xe0afa43a, 0x4f140531, 0x2c2d5c01, 0x3d6f47e8,
	0xa457e628, 0x5b7e382f, 0xe051f33f, 0xfc7326c3, 0x22407d9c, 0x49eb083d,
	0xdc7d4335, 0x87148cef, 0x89f42b39, 0xa3a01782, 0x855fa4b1, 0xe90a7afc,
	0xa04b0927, 0xd1fd319f, 0xee3e9a8f, 0x88c4ff03, 0x41f403f4, 0xebe85478,
	0x23c24cf1, 0x43d10fd0, 0x01c6e3cf, 0x0fed47e8, 0xadadeb28, 0xbf82fee3,
	0xf0f4001f, 0x9f20e244, 0xc13d617e, 0x1d2f0ce6, 0x2c6bad30, 0xd10357fa,
	0x4a6cae41, 0x42bef943, 0x9da2b40a, 0xf4e242bd, 0xa30962ba, 0x2ab1c6f9,
	0x8635f909, 0x5bf22479, 0xc7119b59, 0x6007adbb, 0x3f87c3ee, 0x456066b9,
	0x2270723e, 0xefd5530b, 0xfaaac430, 0x54139ae7, 0xa4c677ed, 0x58a7daab,
	0x69f555b2, 0xfaab3769, 0xa89d65df, 0xfc74ffaa, 0x19ff5514, 0xbaaa19b6,
	0x38b5998d, 0xfcea96ff, 0xc1936759, 0x202ea94f, 0x970feffd, 0xf7870109,
	0x1d8cac59, 0xd0cfb449, 0x8426fc02, 0x00915e1e, 0x971377f5, 0x7d02d0cc,
	0x7c3b884c, 0xd8ccc135, 0x794b89fb, 0xabe1e47d, 0x30ff5089, 0xdfaf1971,
	0xfe7fc8ca, 0x8678b128, 0x7be28333, 0xe75f9027, 0x8a3aab5c, 0xab27da6e,
	0x40492e67, 0x90a4775e, 0xd71cb65f, 0x6cb37400, 0xe218fd98, 0xfa576951,
	0x9c162777, 0x57dde7c0, 0x04ff9cb8, 0xdff633f1, 0x22efc12f, 0x838931fd,
	0x98324d86, 0xdbda323c, 0xbea5dd06, 0x4dc83038, 0xc618c6c9, 0x01aa5ad3,
	0x97845acf, 0xb54f4a81, 0xd5c3ca99, 0x5dbe5431, 0x0045616d, 0x34ead6cf,
	0x5b558f2a, 0xeaf1f9e9, 0x57be54f1, 0x83f2a36d, 0xdb2a7cea, 0x94a80baa,
	0x3e6c912c, 0xd69d8dca, 0x87843a8d, 0x0e761b53, 0xecff8fbe, 0xe9796e4f,
	0x29cecb56, 0x0fce8578, 0x13976d1a, 0xc4349829, 0xfbc82e7c, 0xe001827c,
	0xedcc0005, 0x5ca0b369, 0xc18c6dba, 0x36ee7a8a, 0x20c59b53, 0x3bdf48ea,
	0x4d1e66be, 0xf5a7ef16, 0xcee917ed, 0x9b703d46, 0x92fd44c3, 0x217e81bf,
	0xab13cfd8, 0xadbd7e05, 0xf2fc4f4a, 0xc1cb90b4, 0x94648f9a, 0x30dfc1fb,
	0x0243c392, 0x0689fcb8, 0x95db0c33, 0x6f8ed7f8, 0x8686f7f8, 0x7c803d57,
	0x8981743f, 0xbfa290e4, 0xb13c22e2, 0xad3f8c06, 0x60f3d3d0, 0xc60b09cd,
	0x3daaba4b, 0x276e9153, 0x593f7d0b, 0x1e70d2cf, 0x7a48134c, 0xaefe572a,
	0xcbea0e35, 0x01d9480f, 0x0a02f628, 0xa85f91b6, 0x22ccfce5, 0xd70edc8d,
	0x04bc95b6, 0xc5444efd, 0xd4213759, 0x64b3f662, 0x2b72b7b0, 0x5f5033f3,
	0xc435609e, 0xd88477e7, 0xae0092e3, 0xff8032b3, 0x60588235, 0x20fc989c,
	0x07dda392, 0xbf458f87, 0xa5806676, 0x247f0189, 0x7e216d26, 0x196a1999,
	0xfeb1992b, 0x5b47af34, 0xee2b249a, 0x31996c7a, 0xbef51639, 0x1f6becd1,
	0x54c3bb97, 0x58e6caf5, 0xbe1f59f3, 0xe511bb25, 0x8b4904f2, 0x5310eb74,
	0x67b244f9, 0xf3cafce1, 0xfcf9eb2f, 0x1c5ec87a, 0x3821649d, 0x48cc3a0e,
	0x094cf70f, 0x718b3926, 0x1728e5a7, 0xb1632c33, 0x27aebc5f, 0xed700cc4,
	0xef9b4efe, 0x27a9ff22, 0x3c4fb664, 0x991685e2, 0xdfd3fb9e, 0xef5c4917,
	0x369b2654, 0x622a1e23, 0x5b2a060c, 0xbda1e4ae, 0xc905b4c5, 0x1581afe8,
	0xfadeafd9, 0xef434924, 0x8bd06c27, 0x26881b38, 0x902db298, 0x03277529,
	0xa1eeb39b, 0xb3c8c540, 0x3e993801, 0xfbea2345, 0x564e4cb6, 0x7f61b7f5,
	0x21b33b6f, 0x17f79538, 0xcb6bb8bd, 0x1ef8ad3a, 0xe652cbd2, 0x97ae914a,
	0xe1c9b5eb, 0xe1023eca, 0x2348f9f9, 0x32c991f9, 0x71d037d0, 0xe29b905c,
	0x9c8c3b76, 0xbc3593de, 0xede1a1dc, 0x2bb040fa, 0xea143ea1, 0x2fb45fb8,
	0x3c9c5ed9, 0x6667de96, 0x4bde5f7c, 0x3732c7ef, 0x8f694f7d, 0xf433a8c6,
	0x057a0219, 0xa6b209cb, 0x9b7db85f, 0xe23d7134, 0xc9e40bbb, 0xbb723e97,
	0xa564282b, 0xf02a9e2f, 0x7bef937d, 0xe53de893, 0x1a95f2fd, 0xc90465f6,
	0xf297a241, 0xc5cd8d64, 0x25b7ccfd, 0x9b5817b4, 0xf29bf51e, 0x7b9049de,
	0xffbc025f, 0xcb107202, 0xf0ff2053, 0xf9057ffb, 0x2067e587, 0x69f9f0ff,
	0xb6587f90, 0xe7c3fc83, 0x61fe4067, 0xe0fee739, 0x9527c831, 0x97d913cd,
	0xd9d7ba2a, 0x4eddf77d, 0x5e9fec4e, 0xedc490fe, 0xfd0993a5, 0xf417efb7,
	0x8e76f274, 0xdbd06eb7, 0xfd01a768, 0x0f8733ad, 0x83bbbfac, 0x9eccfef9,
	0xeafedce1, 0x67f5e58e, 0x9e347493, 0xe2b6c34d, 0xeb867bfb, 0x6b0c5ea9,
	0xc45bb2c3, 0x68fe811d, 0x671e657c, 0x4a38f9d3, 0x26b2573f, 0x7ccfd5df,
	0xfde249bf, 0x1ed13e88, 0xf04c7a47, 0x0b0acfa1, 0x5d3fa7d1, 0x387326d4,
	0xba700724, 0x8f59438b, 0x48da3272, 0x5f30a2fb, 0xedfc031b, 0x5e3d3890,
	0xee1a9f47, 0x9f475cf7, 0x09c10e30, 0xf2825ce8, 0x51fa3f36, 0xbe093fca,
	0xfe0a8b6f, 0x45b9c139, 0xdfb8c667, 0x1600326d, 0x7ef4d7df, 0xb881f180,
	0xc60b60a8, 0x311f73fc, 0x3f27f555, 0xd757feae, 0xea8fc7df, 0x6eb75ff5,
	0x63f1dfb1, 0x04f24dd7, 0x4fd225e5, 0x4ce1f23f, 0x381f2292, 0x649b7cfd,
	0xe9092cfb, 0x716a3246, 0xc8dba3bf, 0xbd7fc2e9, 0x79f3867b, 0x2b51f42b,
	0xd70e23e8, 0x4f5de495, 0xfd03fcdf, 0xb98cb7d6, 0xe3fa0f50, 0x3e2b9151,
	0xfc82baeb, 0x318dc0aa, 0xfef0dfd0, 0x18dfd010, 0x364e2b87, 0xf41f3a73,
	0xd02d82d5, 0x13d0b8fa, 0x3c7869cf, 0x7ddb915e, 0xe17925cf, 0x3c950c8c,
	0xf40f6867, 0xfe200c1c, 0xf15868f2, 0xe09fe86b, 0xadfc7ca7, 0x8fce64ac,
	0x345373bd, 0x7d753f68, 0x7ea27263, 0x73dc1ae8, 0xaeb4fd1a, 0xfdc63aad,
	0x0974db6a, 0x1825bfec, 0x3ee0b05f, 0x5bf681b7, 0xb0a3562f, 0x2bee7e87,
	0xac3fd1a7, 0x0666467c, 0xccfc9d00, 0x5e9073d7, 0x99d41e96, 0xbb593ed1,
	0x4863c9f5, 0x251ae76f, 0xaefbea0b, 0xf4365846, 0x760daf2f, 0x1e7fa119,
	0x32ffb1d4, 0xe165de93, 0xd37b23df, 0xa5f7be21, 0xe31122b1, 0xa33c77d1,
	0xdd2f3823, 0x8e0ff3cd, 0xfb415d6c, 0x125ce7cf, 0xf2f7868b, 0xb1ad55e4,
	0x5e7c4718, 0x7bc006b2, 0x05de530e, 0x774be3f4, 0xe307ab33, 0x69837b16,
	0xad69645f, 0xd8a06f3a, 0xf68f45b5, 0xf536f144, 0xea1dd2f3, 0xe489e03a,
	0x9d41a3ad, 0x1c9e9087, 0x5cf6491c, 0xf8a6cb3a, 0xd9386d62, 0x1d3c8a01,
	0x2db19fc8, 0xb19272e7, 0x7c6147bf, 0x75f83e54, 0xaf1319fc, 0x0ef510cf,
	0x9afe5fa8, 0x4b8145e3, 0x1e6fb285, 0x61b8c6cb, 0x8d0715bd, 0x2ae7f466,
	0xc2117c0e, 0xaf3f7132, 0xcfe26efd, 0xda336437, 0xcb368f51, 0x796f844e,
	0x0d45f18b, 0xe9a2adc0, 0x1825bd23, 0xd900fee1, 0xe7327701, 0x3cc3f406,
	0x236b0d1a, 0x38a36a3a, 0x2cf5b316, 0x01f078a5, 0x6bf519a3, 0xb69f1bc5,
	0x26f58fde, 0x8f111989, 0x4e89db43, 0xd3233e96, 0x4dfc2c7e, 0xe979c697,
	0x22bc4644, 0x84a1dd9e, 0x778865af, 0x1de033c4, 0x3e232cf1, 0xbd60fdf1,
	0xf709d38b, 0xe2edcf37, 0x9ef055f8, 0x53d66f27, 0xe38eb8bc, 0xea678ef9,
	0x3a240a9f, 0x074131d0, 0xdb73f784, 0x07f5de38, 0x2307ebd7, 0xd1f9d6fd,
	0x3e8081c1, 0x5df9c03a, 0xf87e0747, 0x78f1112f, 0xc7f03a7f, 0x4c49f7ff,
	0x8e13a7f8, 0xf2cc7e62, 0x2eeff39f, 0x7f2cef08, 0x4f4e9a00, 0xf9012bb9,
	0x8bfe7e78, 0x4ca11b7b, 0x258d7989, 0x14df5e83, 0x164cab62, 0xf3018c76,
	0xdb871821, 0x36fcbfdb, 0x2777fb15, 0x7af6d8cc, 0x03ade102, 0x161ddfe7,
	0x1ee6f5c4, 0xf3d125c9, 0xfa004f00, 0x913f2003, 0x015bd8ff, 0x3dd46fb4,
	0x3f07dee8, 0xe3f77a82, 0x45a22b26, 0xa8ff71b2, 0xa7cfe5ac, 0x1ac86e30,
	0xff2a6d73, 0x6537f849, 0x7b615fe8, 0x3e57f803, 0xf99267fb, 0x77ef7a7d,
	0x4eb489c9, 0x4add6359, 0x660ed07e, 0x7ae4bb41, 0xce48cf39, 0x01a0712b,
	0x793f30ed, 0xdcf395ef, 0x21ce62fe, 0x8a57c861, 0xa1c8a59f, 0x7a5e2265,
	0xdae3a1f4, 0x0ee75c08, 0xabe23780, 0x244fe405, 0x2e74f5c6, 0x2fc3e48b,
	0x4857ffa2, 0xf3c7004f, 0x1afdaace, 0x44cae919, 0xfa0875f3, 0x813a40ab,
	0x398e9675, 0xba768214, 0xc70dc843, 0x978a6081, 0x3c9ab294, 0xf852aba4,
	0x7a1fa79e, 0x97b5dd29, 0xd11bfbec, 0x55b7628b, 0xbdfbaa34, 0x95f22c96,
	0xd22659d2, 0x9823d3d4, 0x829d83f0, 0xdb4232be, 0x997b3f81, 0x75f91425,
	0x7c367d20, 0xcfb0b02b, 0x032ee9b8, 0xfce2aad3, 0xd33d5566, 0x3feaa31d,
	0x6aa2d9aa, 0xa9a4f6cf, 0xb31f47da, 0xdb63eaaa, 0xdffaabc6, 0xaaa6ca74,
	0xaf9edcdf, 0xf9eb7fea, 0x37bd5502, 0x03f3d603, 0xc6775afb, 0x53feaa48,
	0xf8d5462c, 0x7c10a160, 0xa985a5a6, 0x389af79e, 0xf71a069c, 0x5c7aab2e,
	0xe9fdafc5, 0x33f8f578, 0x7f71ea6c, 0x82761e2c, 0x0d82d47e, 0x25f40bb1,
	0x3d832f96, 0xbb3b05ae, 0xac71ec01, 0x38f60abf, 0xc7b06e96, 0x606bf9f1,
	0x11bd638f, 0xefac71ec, 0xeb01ff07, 0x54f9d5cd, 0x405d51be, 0xaf046fcf,
	0x63ddf156, 0xc5c7bbe2, 0xc2db1977, 0xe00dfdf5, 0xff789ef2, 0x1b7ef103,
	0xa5ec9fbe, 0x14fcf2c3, 0xd3e035cd, 0xf417e189, 0x5b658fb8, 0xfe879ede,
	0x323bcf7c, 0xc27c0edb, 0xd563aeec, 0x228fa891, 0x417afef8, 0xd718bbcf,
	0x324a68a8, 0xa3c1bee3, 0x807f1fcd, 0xb28d5ded, 0x70eef905, 0x382117f3,
	0x606ba5ce, 0x7a168dd8, 0xbeb7f70c, 0x04df5465, 0x4fa816ed, 0x2c060bd9,
	0xe93727e9, 0x4ac94ba7, 0x5067a5dd, 0xd5ec3416, 0xdb7ed3b7, 0xc77f6a5e,
	0xefb753ad, 0x9bb553aa, 0xf3ee3fb1, 0x5fe45d6a, 0xc6566c5f, 0x477f50f3,
	0xbb4364b2, 0x23aee2f8, 0xad2f301b, 0x04616f7c, 0x3595a7ee, 0xf8b5147c,
	0x797fe007, 0xa8192bff, 0xc00fcbf7, 0x78ef2678, 0xa27407e5, 0x48efe7ce,
	0x8e179bde, 0x6241bb72, 0x8974a798, 0x4f9e50d5, 0x03bd7359, 0xda5952e5,
	0xc7dc3afd, 0xc2cb76e9, 0x7379e7ef, 0x76e3330e, 0xc86afb98, 0x4ff71862,
	0x6377a3ee, 0xcb774bfe, 0x6efc1091, 0xf2aca377, 0x70a52667, 0x0a52767b,
	0x352e8ff7, 0x7cc1091e, 0x47dd4789, 0x1eb5dc38, 0x5161ff5a, 0xe09286ef,
	0xfad32cdd, 0x0869ae4b, 0x937c7d0f, 0x5338d322, 0x7182539a, 0xfcdc275d,
	0x58a6f77b, 0xc2e4f3f8, 0xf1ff9c22, 0x65637998, 0xdc78e7b2, 0xb4c47bb8,
	0x7023b47a, 0x7f3fbcdf, 0xdb8c44ab, 0xdef1f22a, 0x8ad7de49, 0x7e78f6f2,
	0x00e93644, 0x8530afd1, 0x7a79addb, 0x89ea327b, 0xc50b2613, 0x27e4d791,
	0x0f7e2305, 0xf3cf8963, 0x7cb8a45f, 0xdeff2369, 0x085b7309, 0xc689ddd2,
	0x2bda32d1, 0xe3f778ca, 0xace47d77, 0xc24e6f17, 0xceabb153, 0xf178e384,
	0x9bdf9fc7, 0xc7fea662, 0x41cd1f5d, 0x5a44e8bb, 0xad15d910, 0x5dcfbe7a,
	0xdaedc0d6, 0x75712d13, 0xc57ecfb2, 0x3fdc29bd, 0x10d34eeb, 0x759abb5e,
	0xf5fddfa2, 0x474fd54c, 0x43b4baf3, 0xabb31f3d, 0x4f68b7e3, 0x19979e3b,
	0xae873dea, 0xffd70a2a, 0xfcf536d5, 0x1d9c058a, 0x94544f3a, 0x0e3abd0f,
	0x898df1f4, 0xc280fce8, 0xa7c21627, 0x6913c782, 0x113b1edc, 0x23794013,
	0x44f5bd8e, 0xdf7d5ed7, 0x47768096, 0x9e782fdc, 0x59fc8de8, 0xf1f01ec5,
	0x73fa1887, 0xb1a4fcba, 0xdeaf449a, 0xf6d932ff, 0xe8b194bb, 0xff901527,
	0x4c1ec407, 0x83b40ff1, 0x7f2a4e31, 0xb77e14f6, 0x3fec11b7, 0xcd0c83b4,
	0x3d82cf53, 0x06056bd5, 0x6ef6f981, 0xdf84b9d3, 0x747b4262, 0xbf47b0a9,
	0xc9c7d8b2, 0x5ab8bfb8, 0x8072eb43, 0x857981bf, 0x5dde425d, 0x53f09bde,
	0xc98e07b2, 0xee63f466, 0xd5fb7370, 0xd1edc0d1, 0x13c2770a, 0x6eded013,
	0x822d59d0, 0x558f29ac, 0x84e717d8, 0x756e7abd, 0x92fc9e8f, 0x127b1283,
	0x2de6b9fd, 0x2e5d5fb4, 0xb9728bec, 0x6584ec81, 0x0176d55b, 0x7aaa2dd8,
	0xbb7f2ed9, 0xdc81c441, 0x5f8ae7ea, 0x9f4a46f7, 0x7e8e90fd, 0xd1a3d808,
	0x221f07c8, 0xc28e113e, 0x6991592f, 0x7f7e468d, 0xaa996b54, 0x5e1007c4,
	0x95f70795, 0x8e5dbce0, 0x09f92b40, 0xb820df2b, 0xfb9dff76, 0x8c31dd1f,
	0x38cdd1e0, 0x399bbb7c, 0x24ea577d, 0x17df0197, 0x06dd6af9, 0xed1ab5c9,
	0x086f6750, 0xf2c625c9, 0xcf961f91, 0x0da67ee3, 0xd650a063, 0xe8a07c2a,
	0xfdf3894f, 0x3976daed, 0x7c3e47cc, 0xf3489296, 0x74f22c9f, 0x495b0456,
	0xf0360d7f, 0xb16e72f8, 0x61e91b3b, 0x01cff830, 0xc1e9f13e, 0xfd849726,
	0x38f09476, 0x679fa2b6, 0x1c3acd68, 0x290f895f, 0xf8ca67fb, 0xfbf84920,
	0x0cdf1a37, 0xe3bc9be3, 0x1143bc03, 0x58c757de, 0xcfc73f49, 0xfc49dd00,
	0xa8fc4558, 0xd012e7ac, 0x7145c61b, 0xc73788f9, 0x7c7943b6, 0x036dbbff,
	0xc21797be, 0xf22791e7, 0x7902f390, 0xebc04d79, 0xcf2e5496, 0x112552ab,
	0xeb72e0e7, 0xb7db5495, 0xa74f37c8, 0x4299ffda, 0xfa26637c, 0xbf97d15c,
	0xdedd119f, 0xfe5ddc8f, 0xbd784cbe, 0xf280fc0a, 0x925567e7, 0x17655925,
	0xe4af3a71, 0xe1ff308f, 0x838404e4, 0x1696d6d3, 0x9cecfb85, 0x34ae16bf,
	0xe37d925a, 0xc2efc2e3, 0x878c4b34, 0x8bf78897, 0xbe7425cd, 0xca32bec0,
	0x4afcf182, 0x1bc487e4, 0xdd3fbfd3, 0xa436dfc3, 0x60160ab7, 0xfeedfbe5,
	0xda2d56ed, 0xfb5343d9, 0x8be273fc, 0x75a74178, 0x31f68976, 0xf2d3beeb,
	0x897cd6f8, 0xc0f759e2, 0x2d9f9e43, 0xa44f15fa, 0xa07ba87c, 0xb540fb4a,
	0x35ff6291, 0x66a7f692, 0x23dff58b, 0xea8e06f2, 0x7f1809dc, 0xb06e5a39,
	0x98f3f8e2, 0xe789f69b, 0x4f2a36b3, 0x79345506, 0x50e77068, 0xb53f9ff4,
	0xa7dc5007, 0x60f6dd6e, 0x6c59af94, 0x8df7199d, 0x7d764d80, 0x3b607a3f,
	0x497f7fc3, 0xf05553c9, 0xc16a74fc, 0x8ba05484, 0x98a380f3, 0x2fdfeb9c,
	0xf289a4fb, 0xdc1f3a69, 0x865ee737, 0xe50f4dfe, 0x6556943b, 0x0839d0c7,
	0x1b4b6b27, 0x82afc5e7, 0xf07f054f, 0x2bc2a2cc, 0xc00865ac, 0x19eb2e67,
	0x8c6e91e7, 0xf1ce054f, 0x08599eba, 0x245fd04a, 0xacf1fc87, 0x5582bdc0,
	0xacbc78e9, 0xd07983ea, 0x1a75beff, 0xd793da0b, 0xf806fde1, 0x937918f1,
	0x3f225827, 0x297c2075, 0xe319fa78, 0xc2a7fcfb, 0x7ea77bf8, 0xef9c5326,
	0xaf5f1bbf, 0x4c1fdaa4, 0xf7367e25, 0x7cfeb7cb, 0x2e5f103a, 0xbfc7e95c,
	0xc7da7c7e, 0xcff85697, 0x95f67f07, 0x0a8fc421, 0xf0161d7e, 0xb5ff517f,
	0xec5d5b04, 0x1fa27c7a, 0x6d29f38b, 0xd2b3d894, 0x76d7e18f, 0xf1fd7bf2,
	0x4362b405, 0x54bbf07d, 0xf052feb5, 0x52dc9038, 0x3d49dee4, 0x87cee7d7,
	0xfc37da64, 0x351cf25c, 0x3f4b1ca3, 0x51488291, 0xbabe7ffa, 0x3003e86d,
	0x7913e7ce, 0xf3cf5279, 0x2dba94f7, 0x3ee3c790, 0xe2700d8f, 0xd2973ffa,
	0xff3ea127, 0xddc5fa5c, 0xb7ad1ebc, 0xf45e7d60, 0x4fd43324, 0xddf894ea,
	0xba3f611a, 0xde7cfca8, 0x9fa9934d, 0xbe66dec4, 0x2587eaf1, 0x042f578a,
	0x4bf38e91, 0x7e74f498, 0xfd3f3c22, 0xda6ca4cb, 0x1eae5b57, 0x0262f50f,
	0xdfb8fdc5, 0x1eb5fb76, 0xf786615d, 0x6cfa7d3b, 0xbcfe15f2, 0x83fc8528,
	0x5b5b0162, 0x53f73a78, 0xa8a1495d, 0xd37d145f, 0xc99f6c7b, 0x41792e37,
	0xeafb71c4, 0xfbc78fe9, 0x3b43abea, 0x71c54b1f, 0x2ccef58a, 0x5f3f3c2b,
	0xea3c5cf7, 0x8f9de2f5, 0xb99d92a4, 0xf454d1f3, 0x3fb78a17, 0x7aa36a96,
	0x15fc9d90, 0xe7775f2d, 0xdc5f9b9e, 0xded763e4, 0xededc697, 0xb94386f9,
	0x1d4e6f68, 0xc63d7979, 0x297e53bf, 0xb7e26599, 0x07a8f5b6, 0x7a71a417,
	0x9206b567, 0x03cf0ccb, 0xd3eb9e01, 0xf281daef, 0x17da78f8, 0xd7e822ba,
	0xf1a5aa99, 0xe6d73016, 0x1b676868, 0xf33d7325, 0xf6943fed, 0x49d70b07,
	0xd44898fa, 0xe8d9616f, 0x86a675c7, 0x6d175c11, 0xe7c56ecc, 0xe7f1560b,
	0x8d5c0353, 0xa79c7027, 0x033f94f5, 0x37d12c0a, 0x9533bbff, 0x370b51fb,
	0x2b5f644b, 0x2a7949df, 0x9d77ceaa, 0xb34f429d, 0x39239fb7, 0x9b3b9ca4,
	0xb7a3eabe, 0x37dc6063, 0xc82bf6b5, 0xfefc1fef, 0x99ca325c, 0x3217e1c9,
	0xd148cfd0, 0xc12d9fdb, 0xa00f6f75, 0x5931acbc, 0xf4347271, 0xe27079cf,
	0x5c2e5893, 0x096cf855, 0x1ab751c6, 0x2b3a79b2, 0xc972df9f, 0xf1ff41a2,
	0x8bbddd48, 0x7fe76e10, 0x78fb206f, 0x68f0dd79, 0xfefe03f6, 0x4b7f804b,
	0xc1bb632a, 0x15f2c7df, 0x7cf1f7f0, 0x18ea9ed3, 0xdab1ffaa, 0xcb9b2542,
	0x99b96be9, 0xc68191cb, 0xbc7e0d1b, 0x98c8e405, 0xd81e308d, 0x6f4bff8f,
	0x38070d33, 0xdf288ca4, 0x1758a8fe, 0xced9a49a, 0x0e103b84, 0xa07d1e63,
	0x6bcb4d15, 0x79dfdca9, 0x78c6c4f7, 0x75578fb2, 0xed0250bc, 0x182f0c77,
	0xb61bef84, 0xfdff215d, 0x164781c8, 0xb78bbc20, 0x89f5f007, 0x7dff9f75,
	0x30b3f46a, 0x1d1df3be, 0xdb95d3f9, 0x14785e3a, 0x1f9bc5ca, 0xfbd2fbd0,
	0xc46f5d8f, 0x07389d70, 0x357cc3f0, 0x75fe1c10, 0x9e2c7abe, 0xf03b67f8,
	0xcfbfc655, 0x56ab9557, 0x864afc13, 0xb8404c17, 0xe339d79d, 0xa7ce9f91,
	0xee7446df, 0xfc11283c, 0xbcaaf915, 0x0e70cb7f, 0x7b8d32ff, 0x4277d933,
	0x1e0d7ebe, 0xd0f7c21d, 0xd152af81, 0x79bafdbe, 0x7bae0fde, 0x2a7a357f,
	0x5032b718, 0x4e3edfe9, 0xc2b24f6f, 0x7c89c6fa, 0x22f6ff67, 0xc4a70fb1,
	0xe30ff149, 0xa7a10ebe, 0xa16261ca, 0x2497a8e1, 0x53fa204f, 0xd05e77cd,
	0x91bea086, 0x7db519d8, 0xe8f8cec8, 0x7be681db, 0xc702b2a3, 0xeee57ad1,
	0xcc34a74d, 0x6f5fa3e3, 0x1e640f6e, 0xf9f6ef9f, 0x4f4cf011, 0x75b127fb,
	0xe63d7e4a, 0x481d74ed, 0x0bfe7ca7, 0xd74ffce2, 0x7897f07e, 0x3ec9849c,
	0x0e172379, 0x9ca16674, 0xc56f5ff5, 0x1f449d1b, 0xae47e68e, 0x3cd93f90,
	0xeb3682e5, 0xb43febc6, 0xf10b33b3, 0x3ed74177, 0x2ea2fd0e, 0xe2167b7d,
	0x2e4de2a1, 0x3855ffcf, 0x364bcf28, 0x4edc79ea, 0x977f9332, 0xff225f2b,
	0xf718ebbc, 0xbc0e2bcf, 0xb7b4f248, 0x2a47c785, 0xd1796d35, 0xeaa84f18,
	0xd6794568, 0xa5fdc31b, 0x00593c0a, 0x249098f3, 0x27b6a0f4, 0xec1bcf1e,
	0xd587a3e8, 0x9f9e5f22, 0xb8d4acbf, 0x942f941d, 0xdf70c415, 0x33f222e3,
	0x32b05f3c, 0xf9d20361, 0x1ca0d779, 0x66ef8f94, 0xe282a3fd, 0x320a7f69,
	0xca5f64cb, 0xbee6bcaa, 0x9e64b875, 0x7b14c290, 0xdf954835, 0xfcb7a95b,
	0xe3ddfc94, 0x72abbf7c, 0xf627e704, 0xf2a7e706, 0x31f48775, 0x08d5e33e,
	0xbcec527e, 0x07fa7fa9, 0xb26365f1, 0x4be455ed, 0xe386af3a, 0x24ba84c5,
	0xe71bf449, 0xb533dfdd, 0x5f3aff08, 0x66caf6a6, 0x173ee199, 0x7da6098b,
	0x43567cf8, 0x99538279, 0xc5d9027b, 0xdedff6da, 0xfed3ed0a, 0x7cc68f24,
	0x6973b029, 0xd02f38bf, 0x44f98c9e, 0x80923527, 0x0ccc7bab, 0x49767d1f,
	0x904c55e4, 0x3d63d225, 0xa76441b1, 0x3e5b994c, 0xfa7ed7df, 0x4dfdc487,
	0x26ec8718, 0xe7e1eae6, 0x593d3c3e, 0x36f27d33, 0xa829fce7, 0x7322f48a,
	0xf3e3998f, 0xfc8a7f9d, 0xdfb8ab8c, 0x52a4f20c, 0xcae66bec, 0x7e853ddf,
	0x7c83f2d0, 0x26a4ef3f, 0x4bca53e1, 0x12c073c6, 0xe7e5b79e, 0xd99d99ae,
	0x993fc86c, 0x4abce883, 0x61891ee5, 0x81c5595e, 0xaf18ed80, 0x47b5d0a9,
	0xda3f3d21, 0xe91e89fc, 0x39f712b9, 0x5d79f933, 0xd336bf1e, 0x334aebf9,
	0xde55fd23, 0x8c53fc3c, 0xe31f95a3, 0xfb5cb45a, 0x28e9f911, 0x657bf1b7,
	0x2fc97b8d, 0xf90f3077, 0x35068ee5, 0xf4c6f4dd, 0xe7ff471f, 0x3f8a8b70,
	0xfce56ca6, 0x61f30731, 0xc53af44d, 0x44c4a743, 0xb39ef9d7, 0x83c0a7f9,
	0x8f5cee4d, 0xa2774c76, 0xa8609564, 0x3ae740ee, 0xa99c8fb4, 0x7ee9aedc,
	0x4b3195eb, 0xc6b8be49, 0x75f582cc, 0xca763b0b, 0xd95a2dc6, 0x5a533e67,
	0x3baffc78, 0x27ef1590, 0x2087dbbc, 0x0529743e, 0xb8c70fdf, 0x83e7be8b,
	0x234e315b, 0xaff8e5ce, 0x3788bd63, 0x4df8c71c, 0xd3de7786, 0x3cb8e2e2,
	0xa3a22e63, 0x460e7156, 0xde516bc9, 0xa926919f, 0x12e59bfc, 0x240d3b8f,
	0x04bf705f, 0xbf7132f3, 0x4597cb04, 0x97ee26fe, 0x9155fd60, 0x25fb89bf,
	0x4bf71cf8, 0xf228deb0, 0x04bf7137, 0x825fb8eb, 0x7f221be5, 0x154e38f3,
	0x919ccdf3, 0xad1748b5, 0xbd836bc8, 0x7ee193f5, 0xfeeac1f5, 0x7525c327,
	0xfd44b07d, 0xac8aef87, 0x7dd9bcc5, 0x89435f22, 0x5fe77653, 0xb7fb871d,
	0xcde7c393, 0x8dea7e47, 0x7728600c, 0xecf669ec, 0xb1e78034, 0x6f247763,
	0xa4687921, 0xf793e27d, 0x079d548d, 0x7a36989c, 0x4fa818dd, 0xdce24934,
	0x02a8cd71, 0xfdc3cfc5, 0x31c296ef, 0xcc072e5a, 0xd95ca288, 0x59df8451,
	0x8d1c6b1e, 0x8a7cf6f2, 0x477e027d, 0xe0de6b81, 0xff68c965, 0x9f2ceab4,
	0xf9d47c62, 0x9fa18ebe, 0x94d1c4a4, 0x4ca56f7e, 0xeb069a9c, 0xb4969298,
	0x07c7072e, 0x66b942a6, 0x9c06b3d3, 0x24134d9f, 0x2c1d7bf1, 0xa9fbe45a,
	0x2c93bf02, 0xe8f60edc, 0xf470da2d, 0x462703ab, 0xab697ee2, 0x8131e7c0,
	0x9f02e3cf, 0x5934bfb8, 0xb097f7cb, 0x2c25fdc4, 0x8dac7c95, 0xa5660bc3,
	0xe27b3c11, 0x4e229e09, 0x6f395537, 0x68f1dcc6, 0xf4116c17, 0xe5c69419,
	0xc16a734a, 0x3fe4697d, 0x60fce9bb, 0x759f8899, 0x6504fd8a, 0xde7bca9d,
	0x6777f9f7, 0x98f2e28e, 0x60738a85, 0xf3139843, 0x1ebe675b, 0x2e9ff14b,
	0x39a73f17, 0xe5197813, 0xef9d7b15, 0xce18b3b7, 0x45f73317, 0x22b5bf53,
	0xde1e598e, 0xef798a96, 0x947f825d, 0xb6ae72ba, 0x26ea073c, 0xf97d1e6f,
	0xcc54b6cc, 0x8c92efa3, 0x97738c1a, 0x27ede76f, 0x27957f04, 0xfb94f18a,
	0x78ee0c0a, 0xc1f743c4, 0x9cf1e3d7, 0x679326d8, 0x1eef9729, 0x798eee7e,
	0xa81f3152, 0xc69f7253, 0xd2fbd7bc, 0xde63661b, 0xfdcea777, 0xa417d602,
	0xd2ebcabf, 0xdf66d3de, 0x78ee41f6, 0x2fbd8bcc, 0xcc6ccf7d, 0xb41ced8b,
	0xab3085f7, 0xdaf75d4f, 0x6bd76c69, 0x798d9d5e, 0x5c02d3b2, 0x5e91aac7,
	0xcae9c8fe, 0x1ce9a7b8, 0x00eca7c2, 0xed27cfb7, 0x1af4ba69, 0x60a6dfea,
	0x9adfa7da, 0x5ef04096, 0xcda5e07b, 0x7b5d6748, 0x9b07c475, 0xe1793e1a,
	0x002fd457, 0x5c601bb7, 0x850c18f7, 0x4e9f4e2c, 0xe4169ddf, 0x1fd63bfe,
	0xebccdddc, 0x1f6f9c11, 0x6ce6fdde, 0xa6aec3e4, 0xbea10f3d, 0xf8ca169a,
	0x8c57e8b9, 0x7dd29f84, 0x8fd193e9, 0x5b6e0aef, 0xbc57e380, 0xf3f7c01c,
	0x7dd345f7, 0x3c69f50e, 0xa2325cbe, 0xa9f51e26, 0x3bdd8de6, 0xc571857f,
	0xbfb48d97, 0xedce1952, 0x6eb952b9, 0xbf8403dc, 0x873e7717, 0xa46ddef3,
	0x8c12cefd, 0x64bd40a5, 0xb73f0a67, 0x162fcffd, 0xe5721e20, 0xe51e746d,
	0x1a8c3bef, 0xbd09c384, 0x7fcf142d, 0xc8e84f38, 0xf5112caf, 0x7c119392,
	0x79ed413e, 0x9ac8bf84, 0xa5a7d478, 0x8ddf0f11, 0xd7269ef3, 0x0d7e80bc,
	0x6280297b, 0x037617fd, 0x0bbde0dc, 0x02ca3af5, 0x4c1ddaed, 0xa53baae7,
	0xaf78059a, 0xf79eb385, 0x10d634eb, 0xc3f59d3c, 0xe80d3ee9, 0x76df50c7,
	0xcf545b4a, 0x94bfd42f, 0xc5e77e85, 0xff91a797, 0xc2b9d0a9, 0xfc3ba52f,
	0xf3f181cf, 0xdfe2a593, 0x2664eccc, 0xc5d2389f, 0x3d74cffd, 0x5fefbccb,
	0x79d1d06c, 0xb60092e3, 0x156ef30e, 0xbb8d287e, 0x57d71f33, 0x454ba9aa,
	0x7464a4fb, 0x8be402fb, 0x8866460b, 0x0aef7e81, 0xb8da54bd, 0xb9da067a,
	0x2ba7cd03, 0xd7f1f38d, 0x6ebf0f82, 0xf77cba36, 0xcfcbfcf7, 0x3de599aa,
	0xb3feb7ad, 0xb8b9f52a, 0x076ef577, 0xe11563fa, 0x869c7e5c, 0x9b200dfe,
	0xb779092e, 0x7fbaa570, 0x3d385a47, 0xa7b7d0af, 0xc6537ea2, 0xe6669d3f,
	0x3db6a3fe, 0xff95e515, 0x2164d37b, 0xe7e15e6f, 0xa51b4b4a, 0x80df3a0e,
	0xc2f28d20, 0x74e0d4b3, 0x7f4e5e61, 0x27198878, 0xfd6300f0, 0xe6813d32,
	0xa460da51, 0x8165c973, 0x0f6821ed, 0xe9db8239, 0x1bd7683c, 0xd02edb32,
	0x9f8ca917, 0x129efde8, 0xeb712c1f, 0xbefec66c, 0x3f41cb07, 0x1bfe1978,
	0x3a44f140, 0xe6e29be7, 0xda0e7e20, 0x82e74edc, 0xe20dcffd, 0xfc3ecd3a,
	0x62fcd5d8, 0x1e3faf94, 0x2ddde621, 0x74df1075, 0x3c4cf3ff, 0x86a941d2,
	0xc1fdc3ad, 0x973f128b, 0x973a7500, 0x33ec5170, 0x0a637e96, 0xf8b9fa44,
	0xb8f883b5, 0x39276a4b, 0x38fd2877, 0x5d2e87c9, 0xfdb9c93b, 0xb9243fbb,
	0xbed615d6, 0xa1d6e500, 0x3dbceddd, 0x9e017db6, 0xd603f99f, 0x23287db1,
	0xfa61ff3d, 0xa64f2457, 0x816f3cc9, 0xf333a8bd, 0xf7871038, 0xd0270132,
	0xc9ab2754, 0xd059d0cf, 0x574b6a1e, 0xdef463f6, 0x7e5ecbf5, 0x3d9662ea,
	0xc59fc88d, 0xb0171efc, 0x435e1a9f, 0x145e6f3b, 0x0fe343dd, 0x2f5f6537,
	0xa5dbfc32, 0x987fa788, 0x71d3e3ec, 0x9da33a7f, 0x76a008fc, 0xde2bd7b2,
	0xb27f200a, 0x13b3d75b, 0x26c7d7e5, 0x807484fb, 0xb6df43a7, 0xe7848c61,
	0x715bdbe5, 0x72aa6f3f, 0x4e25ef6e, 0x2f195d6f, 0x6208f3f2, 0xc0ba705f,
	0x5633e803, 0x7121f487, 0xde691f3c, 0x9bca1ef7, 0x9224b6ae, 0x74fcfed3,
	0x10c9f9a1, 0x40a71b94, 0xfc7d3baf, 0x2f8553fd, 0x5cfbfed1, 0x5d30bbcc,
	0xf7b51e7f, 0xf7e459bb, 0xcf3ecdb1, 0xd56b1e91, 0x20b87f75, 0x7c547a5d,
	0x3fb824e0, 0x6cadf822, 0x33dd1b52, 0x099f57d0, 0x7ea7d975, 0xd7eeafd8,
	0xa3adcf1f, 0x7e08f0fd, 0xd438e103, 0xf4fc9273, 0x761f3c3d, 0xaa35e82d,
	0xbed10537, 0xe80f66b0, 0xb7ae48ad, 0x85945f50, 0xaa7c51b4, 0xf68029ab,
	0xf81cd633, 0x0fd71e2a, 0x987148f4, 0x47af03b2, 0x35beffa1, 0xa7edc2cd,
	0x94514d3d, 0x2074d287, 0xe50dfd0a, 0x4ee343b9, 0x59f07915, 0xe7943f28,
	0x9527b2e5, 0x6d4aa5ce, 0x56c18f74, 0x87f5379c, 0x46758cba, 0x9c4870eb,
	0x7e01d9ef, 0xde3f929f, 0xce79131e, 0x28b21f20, 0x1e0de27f, 0x41e4501f,
	0x872b9089, 0xe70679f1, 0x1fb2b37f, 0xc83bfb84, 0x09c8fdf7, 0xd859ba63,
	0xbf1455c3, 0xcf9d2479, 0xc69f795b, 0x9e25f1e5, 0x6766f707, 0xbe066256,
	0x61ce5167, 0x9251e57b, 0x1ca0be57, 0xb0392188, 0xeb051746, 0xa2417d2a,
	0xe64a6f7b, 0xee83ceaf, 0x81f6996c, 0x619b8a3c, 0xfae9ab3e, 0x51d3f979,
	0x53873a62, 0xd9fb86a9, 0xda253ba5, 0xe3a8b9d7, 0x6f2065fb, 0xd97e5f28,
	0xc879d5e4, 0xcb224b7f, 0xf0febef5, 0xeebfc68d, 0xead5757c, 0xf87ee8bc,
	0x96e574bc, 0xfaec41d6, 0x75ec4af1, 0xeb965179, 0xbef32b9f, 0x39e65468,
	0x17c83749, 0xe757731e, 0x9972820d, 0x0785dfe1, 0x03c5f75f, 0xbbd41e01,
	0x9fda5f00, 0x955afdbd, 0xa37a8e2a, 0x8b984af1, 0x9a0639f6, 0x90e97fbf,
	0x8f29273c, 0x9eabf815, 0xc6f80cf8, 0x05237be7, 0x1fc5f6bd, 0xd1870b8a,
	0xc2f6147d, 0x07f1be61, 0xe50412ff, 0x68e50d60, 0x3e04a938, 0x07ed605c,
	0x2b727d1e, 0x8d21e79d, 0x783c7414, 0xaf33d95a, 0x7cdb8a31, 0xa077f289,
	0x625d1773, 0xdcfa3f7e, 0xbc411dc5, 0x19a341df, 0x07dd2b43, 0x6ff8a5bf,
	0x5cd37af7, 0x6260afbe, 0x1aded0b1, 0x37ddb993, 0x0471bbce, 0x539e0eff,
	0x69e6f3a6, 0x1f8e1fba, 0xc5f70465, 0xc8dec88f, 0x94fda208, 0xa4abe6ae,
	0xc65bbadf, 0xa3df719a, 0x4265cdab, 0xe7fcab7e, 0x3d428eff, 0x25f2d5dc,
	0x7d7581e5, 0x87e515f7, 0xf4f22a3d, 0xfc8b370e, 0x304b36aa, 0xffcb4b9d,
	0x6dfb0f22, 0x7e37a512, 0x4a5fe3c0, 0xea07c4a9, 0x16fedfcd, 0xfc393cd1,
	0x1fa871db, 0x7ba64fc0, 0x0271bc2d, 0xe50ff44b, 0x209c6227, 0x04e3cb59,
	0x209c6258, 0x09c79939, 0x02718eb0, 0x804e312c, 0x804e31cf, 0x60138c75,
	0x5804e31d, 0x960138c7, 0xe7c02718, 0x20e7177f, 0xf15041ba, 0xe489a638,
	0x0fcc0afc, 0x38ad7806, 0x56a3f7c8, 0x747bf3d4, 0xea041cf0, 0x63f2ebbb,
	0x8c7e451a, 0xefed0b7b, 0x56c93655, 0x979e0944, 0x9e62a670, 0x8c51cf4c,
	0x95ee54ef, 0xf82dabac, 0xe3cd2e7c, 0x9fb196d1, 0xf5e7c7ce, 0x5fde2b3a,
	0xf1c3f405, 0x9e512757, 0x3d4b6952, 0x4726a3c5, 0xf87ca41f, 0x618906ca,
	0x004e751c, 0x65cb8bf7, 0xfb439a78, 0x973764a1, 0xbf91b407, 0xb24bb652,
	0xae3f9ef8, 0xe4857f1c, 0xbc2fb282, 0x72b13794, 0xa452d1b7, 0x9e36abd2,
	0xb4ff84df, 0xc897f378, 0x83b1f0ee, 0x317ee296, 0xa3bf973e, 0xe0e518f3,
	0x374846d0, 0x6d2a6fce, 0xf301bbd9, 0x9e6c7ea2, 0x22119cd3, 0x9f9b238f,
	0x7dffc8b3, 0xf8269ed1, 0x004d6f5e, 0x34f625d9, 0x8c46cffb, 0x1b7cfdc5,
	0x1e8e57c5, 0x755f9234, 0x5570cb76, 0x1e57257c, 0xe58df142, 0xf5f4893a,
	0x62fb14f9, 0xfc8eef7c, 0xb95714c5, 0xf8982623, 0xb7c3a156, 0x60960a52,
	0x0b4cf2fb, 0x0372afc5, 0x3c69cfd8, 0xe0a53791, 0xe4ad7729, 0x0a097bc2,
	0x0dce9599, 0x7bf1b42c, 0xd67b94db, 0xc79e3216, 0xf2d5d0a0, 0x47bf122d,
	0x38210d93, 0x5cf0102f, 0xba67f2d8, 0x80716387, 0xc34de7b8, 0x36e3b7f7,
	0x25857cf1, 0xde116378, 0x27d48167, 0xab7d3e93, 0x83db9e1d, 0x7b73c486,
	0xe38d12de, 0x51d71e17, 0xf46e6dfe, 0xd276a95d, 0x4f2993eb, 0x2fdcf241,
	0x87f23f7f, 0x4f3aa5e4, 0x60aea8e1, 0x15bbae08, 0x39e294e9, 0x578f2a76,
	0xc4a95317, 0xc0bc946d, 0xefaf83ee, 0x56e7efc5, 0xb51ee89a, 0x05bbcf01,
	0x4bee7ff6, 0x45b00739, 0x69c621e4, 0xe0b68c4e, 0x5931bffa, 0xd1b9fd71,
	0x54bce907, 0x31bf1892, 0x1199e0b9, 0xc216cfd0, 0xee1ef89c, 0x3c00d4b3,
	0x120170f3, 0x36ddc1c6, 0x73d2773c, 0x7e533250, 0x727275f2, 0xffcc7acb,
	0xcc964ca8, 0x0bcd6f18, 0x828dc9ac, 0x1312f3f1, 0x2ba728ac, 0xb51c799b,
	0xf78e4a0b, 0xff745d5b, 0x41f7e314, 0xd378154d, 0x461bd8a5, 0x9f3ef58c,
	0xbbaaf826, 0xcbcf2ae5, 0x759c71bd, 0xc707dd07, 0xf41e7df8, 0x369af307,
	0x5bc52872, 0x6de9ba15, 0x748ede88, 0x607a11e3, 0x748ffcfe, 0xa7342768,
	0xefc4dfda, 0xb2ba282f, 0xd9d68a3e, 0xc94c1c7f, 0x838ff75f, 0xffd7caf9,
	0xf7f5bc89, 0xfca8abaa, 0x95257aa0, 0x6a4ed56d, 0xe97881ff, 0x89fa23a7,
	0x25833297, 0xf026f494, 0xfb438f33, 0x8f8147c5, 0x7c7c3e35, 0xa2d84b47,
	0x6a70a88d, 0x241f74f5, 0x30af0de6, 0x8c77df11, 0x7bd389f0, 0x9c0aa4e3,
	0xed57144c, 0x841cc665, 0x24b4a4f7, 0x3bda06ad, 0xf795dc05, 0x3d702f90,
	0x225817c8, 0xe27d685f, 0x81ebcf99, 0x3d70c765, 0x6f3d24ef, 0x586e3c24,
	0xc242f20d, 0x2acc7c7b, 0x4fc97179, 0x7243805e, 0x6a939d1f, 0x657ba009,
	0x49c9fc94, 0xe9cb5c50, 0xb9b87e47, 0xe81a18fc, 0xf6e74dde, 0x3f29022b,
	0xd38ea8f7, 0x7947d1d3, 0x2b115bde, 0x5d07f7e0, 0xfce8472f, 0x9e88e2cb,
	0xff41cfd3, 0xc8998fc5, 0xbb10d95e, 0x457fdc74, 0xe7139c8e, 0x58939c59,
	0xdef9e61a, 0x0fee54a8, 0x404fbbe8, 0x9c53ee2f, 0xa99defca, 0x454df614,
	0x51f89991, 0xa1594f39, 0xc06c7775, 0x3cc1917e, 0xe8cb437f, 0x9a1390de,
	0x51defcc1, 0xa62757c1, 0x36bc5126, 0x83dbad6a, 0x25dcf6e3, 0x93b0fdd1,
	0x047df883, 0xc7029ab9, 0xb6fed04b, 0x7d2b9f86, 0x901bef1e, 0x8489af11,
	0x4df9ef57, 0xe5c5876e, 0xf1e76f07, 0xcf8f7e5f, 0xfbf8495a, 0x6e961ee2,
	0x3e3ddf97, 0x6e951ee2, 0x01ff3056, 0xcab9fbe4, 0xc7968bfd, 0x5b5ffe31,
	0xe3dc4232, 0x67bfe9c3, 0xf28ac186, 0xcf9b36ab, 0x9124b6bf, 0xcb251bc7,
	0xce5bd46a, 0x8efa335f, 0xa19f1ef7, 0x43e0aed4, 0x2da597b9, 0x391b6ed8,
	0x59fbfae8, 0xe60a929e, 0x3271c12d, 0x938b7cf9, 0xa3af842d, 0xbe3c46f3,
	0xc438e113, 0xeced1632, 0xc6c3e345, 0x711f4049, 0x000ce65a, 0x33d8c3fa,
	0xa8f35bdd, 0xbe06b5d6, 0xce2b4437, 0x7c856bd7, 0x73032187, 0x0f4dbfa8,
	0x9727c2f5, 0xa7ea1b31, 0xb5f74638, 0xfef81b26, 0xb0c7bc36, 0x8c8c30c4,
	0xb8f18f7a, 0x1f28614f, 0xb99a30bf, 0x9e3448d6, 0x67e4a34d, 0x36471c82,
	0xef87bd43, 0xfbd0e487, 0xdf7f0d4e, 0x587285a6, 0xa8bfbf12, 0xed007d67,
	0x323e166b, 0xf4e1f494, 0xea73ea49, 0x7df2463b, 0xcd0ca566, 0x7cf8a8b0,
	0xda74bad1, 0x6eb45c1f, 0x1dda395e, 0x3a2086f6, 0xfb39d75f, 0x0d48aec5,
	0xf4b82bdd, 0xc8cf5813, 0xe103bb0c, 0x2cb2517b, 0x8b0e8268, 0xc7a239ee,
	0x7bbb173c, 0xa037e5c6, 0xf7b9dbbc, 0xedb7bc03, 0xbd32d9ee, 0xf7e3377f,
	0xfc75b313, 0x9cbbc71e, 0x3031b457, 0x24135dfe, 0x1877838a, 0xc768f1cd,
	0xfd7c0a15, 0xd7972462, 0xa6861b85, 0x177cdfa2, 0xa3f79bee, 0x7e8b7657,
	0x3bb0fb4a, 0xf96fca98, 0x23ff68a3, 0xc11077ae, 0x368bda89, 0x85247406,
	0x0cf3a960, 0xe654f287, 0x012375a4, 0x5913d30e, 0xe38456de, 0xd88e3cc3,
	0x670b6461, 0x2cb6e066, 0x6506bdb3, 0x3c7344c7, 0xee215bdd, 0xe6625cf1,
	0x2263a8f2, 0xb9b4f71f, 0x833c383d, 0xe7de0bf3, 0xf0a058b9, 0xa459caf4,
	0x32af171f, 0x25c739d0, 0x7e459fbf, 0x995ae2c7, 0xcdb237ce, 0x113cfbea,
	0xa2cf8877, 0xc3d112cd, 0x3d56b5b0, 0x6cf78bee, 0x7d0efd01, 0x649e4c8a,
	0x5645e7d4, 0xd9db15a3, 0x71deb077, 0xa3315f78, 0x86534678, 0x29eb85dd,
	0xfba429ac, 0xec328331, 0x061aa714, 0x29da1a7e, 0x042d231d, 0x1600e98f,
	0xdb4167ba, 0x8a718b1e, 0x3d392345, 0xa7370f4c, 0x8c9e889a, 0x7757cf0c,
	0x38a9cce8, 0x46f58e9f, 0xd327da0d, 0x02ba70d7, 0x7368377a, 0x059ecf30,
	0x4afddf22, 0xb57f3b8c, 0xea0ea0b6, 0x06bd4043, 0xb3be2387, 0x6486ae89,
	0xaf389dd9, 0xe366bff3, 0xde2dee51, 0x4bcf85bc, 0xdb698de0, 0xc779e326,
	0x3909f5f3, 0xe0afbfb8, 0xa4d64871, 0xf8be91e6, 0xde112d9b, 0x50c73d60,
	0x5cca9c4f, 0xc3b616f4, 0xd78843f3, 0x943c93e9, 0x3b2b900f, 0xf7a7ee18,
	0x6bca30c6, 0xcf9c65ef, 0x496a377a, 0xadfc292e, 0xd5e031f0, 0x1554e786,
	0xfcfc29bc, 0x002f653f, 0x281e487c, 0x05c8aefc, 0xf9144e85, 0x0b1f4fe0,
	0xe7b7cc00, 0x8724fbd0, 0xeb83f914, 0xe578e4d0, 0xdd678282, 0x8a1a89c6,
	0xe73c0a83, 0xbcf697ca, 0x3628708e, 0x07d1bd91, 0xe0819317, 0xcd67af12,
	0xdae92f78, 0x8f1d6c07, 0xfbd7c8f8, 0x09e7d58b, 0x3ea5567f, 0xa570b847,
	0xfce11cfa, 0xc51f1f95, 0x10a6d078, 0xe7e22f7b, 0x3dce6ff4, 0xff3c29ff,
	0xa62e6fc3, 0x52f87f70, 0xddf8d3fd, 0x1e628155, 0xab5e7ced, 0x8617a4f4,
	0x837bf205, 0xb2f10ff0, 0x2b7e7188, 0x00fb084c, 0x8422d6f5, 0xffde1653,
	0x9f9e08c1, 0x169cfc09, 0xcf5c29f8, 0x4e1d01e3, 0x8b03e289, 0xdb7e09d6,
	0x7c1f3ea8, 0x07b59626, 0x11cf7925, 0x6a75f99f, 0x72a7f23c, 0x91bed86e,
	0x56962b9f, 0xc3bb231e, 0xe4d3dcae, 0x69a7bbf4, 0x7f3f2b65, 0xd73eaedc,
	0xa6c6341b, 0xe301f8a7, 0xb4a2cefe, 0xa5cf3cc3, 0x0ba33246, 0x179e2450,
	0xe754946d, 0x783362c6, 0x9192dbbe, 0x3ee3c25a, 0xf8a61dcc, 0x05e90d7b,
	0x4e414e85, 0xa2b639d0, 0x52fd6c9a, 0x48b7f91f, 0xa69c5f3c, 0xbe7952a1,
	0xc69ea464, 0x814887dd, 0xa25a5372, 0x2dc9097e, 0x952bc50b, 0x72d28bfe,
	0xbf7fa036, 0x48c4f368, 0x298fc3e6, 0x4b3e7c19, 0x29633e70, 0xf95fab9f,
	0x84cf97dc, 0x867ba4ff, 0x2defc86b, 0x5795f57d, 0xd2f8bef1, 0x7e9005bf,
	0xf6251d28, 0xe35c33bd, 0x2ebed166, 0x2154d73f, 0x95f93df0, 0x9ed043cf,
	0xf7e46caf, 0x81d9431f, 0x62aac565, 0xac2bcbf2, 0xd7e10fc0, 0xfdbf5de7,
	0x7842dfea, 0xa719d7bc, 0xf305d8c1, 0xbfec61c4, 0x8a0bf1a2, 0x1eb2540f,
	0xbffa1b8a, 0x177d2957, 0x334cfdc2, 0x3fc7bdf3, 0xf88ea0f7, 0xf700f2a4,
	0xae9b2b6b, 0xf2bb3c52, 0x7b28fae0, 0xfebfeb3f, 0x954d86bc, 0x36c95ecf,
	0xe8f3a15f, 0xcf8de403, 0xe2f910cd, 0x289bb137, 0x28cb5c5f, 0xa7b947bf,
	0xf295d7ac, 0x958a7983, 0x9794355b, 0x84b5abd3, 0xb7593ee2, 0xdfe4a738,
	0xae0cf9ef, 0x1f032f27, 0xdd17bde1, 0xbbed320d, 0xb8f03774, 0x93c3455a,
	0xb43e78ad, 0xf85c1c02, 0x9e39df6c, 0x1999468a, 0x30c7f37c, 0xe062280f,
	0x12bd9679, 0x94b0f74c, 0x3d5b25b8, 0xfc17a7cc, 0xf33e419c, 0xaba0a5f9,
	0x38f700b2, 0x7f988bc2, 0x3e29da15, 0xcb495bfe, 0x14de7493, 0x5d9175fa,
	0xc620c7f1, 0x3e7aaff7, 0x6e7679c0, 0x4dfb4d1b, 0x15bdee25, 0x086c0f14,
	0x8b923ca2, 0xe5f9f53a, 0x1b7be20d, 0xd07db832, 0xf88af989, 0xd932abfe,
	0xe44f3895, 0x3a928bc7, 0x78b362bf, 0x5b80b36f, 0x03e70676, 0xbb897fa5,
	0xfa192423, 0x31fcd57f, 0x7f614f95, 0x65b5376c, 0xaafcdea1, 0x93ce8831,
	0x5cf8d57e, 0xbdf09bde, 0x9189eecb, 0xed7f0f92, 0x7c71d0ce, 0x62e7136c,
	0xbce2115d, 0xd3d69b87, 0xa12710d9, 0xf22e585f, 0xf71b3aae, 0x7f886885,
	0xff7e1c9d, 0xf95ebdee, 0xf5ebddd7, 0xc7ee3642, 0xf755da18, 0x8d77fd7a,
	0x7f9e215f, 0xef881522, 0x7ec5e8f4, 0x0cfdff2d, 0x113be0b3, 0xca305d37,
	0x439e2f72, 0x38eaef65, 0x9e5887be, 0xc166bf46, 0x37e41187, 0x6066efe2,
	0xf1efeffd, 0xa305ac7d, 0x69895c85, 0xf4718b1f, 0x3f6e048e, 0x27023638,
	0x80cb4802, 0x3f009cbe, 0xecc34b87, 0x8338ff50, 0x0276f7ef, 0xe147ebfd,
	0xc97e7997, 0xf0cbf069, 0x6be7173e, 0x91d77f7c, 0xf3c549e8, 0x9f629d75,
	0x49ee11df, 0x2f71808d, 0xcc713a09, 0xdefaa4f4, 0xeed8e917, 0x4b973ca1,
	0xdb0d8f22, 0xc8e6ee31, 0x123afde1, 0x7e745dcc, 0xa19829a2, 0x3d79aefd,
	0xfcb0e898, 0x00f6e325, 0x2edbfd1f, 0x9e92f4e8, 0xdced27df, 0x1253e7c9,
	0x5ce34352, 0x125df412, 0x3bf34358, 0x96e9ce2d, 0x43bd79e8, 0xf71ee8c7,
	0xdefcdd9e, 0x6db18b9c, 0x173bf1fb, 0xbe53a777, 0x6b824767, 0xf3b53369,
	0x97d28fbc, 0xaf383c03, 0xe983bb0b, 0x6ffe4e3c, 0x5fbed2b6, 0x09008eef,
	0x4185dfe5, 0x5c1bce8c, 0xfa441fa8, 0xa16482fa, 0x7785e438, 0xd2bc6822,
	0xae7495ea, 0x04c414a4, 0xe6509dda, 0xa176bda3, 0xe47899fe, 0xc46fa85f,
	0x2cd59dba, 0xe9f225f8, 0x0ff220ae, 0x8ffcbe2f, 0x187ddf74, 0xcfdff4a5,
	0xa7d9f050, 0x3f39326f, 0x270e4cb2, 0xef99a66d, 0x9fb90627, 0x71f5a44a,
	0x933806fe, 0x44fc049f, 0x769cd2f7, 0x6092881f, 0x83d7d29c, 0x3bdfa86d,
	0xe7d49e74, 0xe2410e08, 0xf91854f7, 0x46761773, 0x560d3f90, 0x61738d34,
	0x69e52667, 0xd31ff92a, 0x3c2356d1, 0x737c1266, 0x74596de5, 0x208eef7f,
	0x7d298fca, 0xe50d26e4, 0xeedcc883, 0xf1757d2e, 0xe1b75174, 0x2fe949fe,
	0x8bc0a57f, 0x3e4a88e2, 0xd1c843a7, 0x0d6e47f2, 0xf657fcc5, 0x6b794ca1,
	0xdf3cb557, 0x332e1fd0, 0x29bcb932, 0xf13cffdb, 0x1ce803ad, 0x4ca74f7f,
	0xbd9763e4, 0x6523e3cc, 0x9a7d6e1b, 0x3a07e3e4, 0x97b6f986, 0xf8864fdc,
	0x3156fdc2, 0x2b7df78e, 0xfe832ff5, 0x4377fdfc, 0x753b3e68, 0x8fec1f94,
	0xfefd1faf, 0xf5bff2cb, 0xec1ba97e, 0x67f67e80, 0x87b6b2af, 0xa07286fe,
	0xd27568c1, 0xd74f9e53, 0xe52f73a9, 0x248c0ae7, 0x38c33a1f, 0xf6257ebf,
	0x4c36cbf5, 0x07f2827b, 0xb3a2cc4e, 0xfd5ccb44, 0x32d99fef, 0x8f2e7cb9,
	0x1f2286b0, 0xe83e0396, 0xb723df5c, 0xf66af9d2, 0xf7de8ea1, 0x267c4f5f,
	0xe3ea27df, 0x0f3c3dc3, 0xc73073b9, 0xc3abe74b, 0x8474ef49, 0xf986ba71,
	0x19d9bf92, 0x5c4a4bc6, 0x33187cc0, 0x89ce87a7, 0x3b9bf26e, 0x7654bda5,
	0xa57bf8e8, 0x44efc52b, 0x873e7878, 0x09366903, 0xdcd9bfef, 0xca06f686,
	0x543971e3, 0xafc2027a, 0xe81bbfbf, 0xadbbfc98, 0xbedf5299, 0xba63ca36,
	0x91e29e2f, 0x53ca3d6e, 0x1cfbb0bb, 0x8effd70d, 0x6f3f9d00, 0xf7ff2890,
	0x8a5f0a17, 0x2e329cbc, 0x539959e1, 0xb2f5fda2, 0x20940f75, 0x6d5597dd,
	0x41f91fb9, 0x96994759, 0xd5ffa3e5, 0x1f34c921, 0xfff71fc5, 0x35df029e,
	0xfed0efde, 0xe019e93a, 0x16990db5, 0x35654ec5, 0x9d639e30, 0x93be99b4,
	0x7c9df8a0, 0x709c0a7d, 0x0bf3067f, 0xa07ebf15, 0x1cf32bf5, 0x0acf3e68,
	0x6091d439, 0xe2026279, 0xe4997dfb, 0x46efd5c9, 0x80ff8687, 0x5d1e86dd,
	0xcc3e9e5f, 0x03dc25ff, 0x946b7dc6, 0xf1dfa867, 0x33cc09d4, 0xc7407e95,
	0x1db4ddfb, 0x0688faea, 0x51a33d75, 0x516acf5d, 0xab6fadd7, 0xef884feb,
	0x3f42702a, 0xec1fcf18, 0xd010e712, 0x4473c60f, 0x1d6307e8, 0xd12c60fd,
	0xe8e7c60f, 0xfd1d6307, 0x1fa3ac60, 0x3f73d16c, 0x83f44b18, 0x4cc9f9f1,
	0xd4728f1e, 0xe021f8f1, 0xe4fb46c1, 0x2bdf94f3, 0xed10bf00, 0x642192d1,
	0x374e61d7, 0xe6fd0de5, 0xa3a452da, 0x7fec987f, 0xf98b1cca, 0x621b6d51,
	0xde5fbfb1, 0x68c72390, 0xfb4378c2, 0xa036affa, 0xc9b1f219, 0x57f636fe,
	0x57ca89f2, 0x45dfa11e, 0xf96d5f6b, 0x4f1c27f0, 0x9760f714, 0x293ec922,
	0x65d67bc5, 0xf8194f8a, 0x23b9afef, 0x14bdfbfa, 0x7f9ffcff, 0xa6c7ef27,
	0x821aa3e2, 0x3d741fcb, 0xbfe728b1, 0x7ba06dd8, 0xe710bf4e, 0xb35cd922,
	0xe2def7c6, 0xc7b77dbe, 0x393fda25, 0xefce1997, 0xf60639c3, 0x54fa3f77,
	0x90631729, 0xef5ce7dd, 0x0692cde2, 0xcf4c33bf, 0xca4ec8e1, 0x84380f22,
	0x989bbeff, 0xcfb470e3, 0xee9fe67d, 0xcfd1540a, 0x7ee15dc8, 0x58309bbf,
	0x73547fd5, 0x26efdfa2, 0xe7df508c, 0x21f57b3f, 0x6d67b3f4, 0x77eaad1e,
	0x0c75f915, 0x9268d5ea, 0xb7054597, 0x860de5fa, 0x6e877ea8, 0xe3a7ae85,
	0xa2bfe811, 0x41f49629, 0x36dbcc11, 0xc0dfe45a, 0xe725e3d2, 0x75db9206,
	0xd78efd12, 0xd86fa162, 0x2dfeb54a, 0x37fdf2d6, 0xed1aabbc, 0x34534741,
	0xd0a103dd, 0xd999b163, 0xcf3072c2, 0x83cb2db6, 0x2f3bc3fe, 0x2aba438e,
	0xf1e2eb97, 0x2507ffde, 0x003c4ed7, 0x6f7c317a, 0xfed0cdd4, 0x951ec6be,
	0xb1dcf685, 0x078c1fb1, 0x906a5f38, 0xbc50fce9, 0x639513ce, 0xbc5fd2f2,
	0xf8881cce, 0xf7e1abaf, 0x4adc60d0, 0x47d2f70e, 0x60444d5d, 0x6ebbc9b2,
	0xe9861e85, 0xe056433d, 0x92335eba, 0x3476055d, 0xc7aba7e9, 0x8adfb264,
	0xb24e4a27, 0x953ac573, 0x7aca8f73, 0x907f0ace, 0x1f71f1a5, 0xd297ed14,
	0x6059650f, 0xe6ea8e1d, 0xb8e51978, 0x2c6761a6, 0xec18b794, 0xf16359d9,
	0x3e52c7f7, 0x4a447bc5, 0xe619913f, 0x7b597c5d, 0x68cdc847, 0x59d1ee67,
	0x91fd43a7, 0x9ce9179a, 0xa5d6a963, 0x78b4bf47, 0x679d1d77, 0x5fdc53b9,
	0x215774b4, 0x58cbe7f9, 0xe799f915, 0x01707c95, 0xd249e28f, 0x7bcc3336,
	0x1b97166b, 0x08fee2c5, 0xabba7ee5, 0xcbbdf8bb, 0xeaf60bb3, 0xa64677f1,
	0xec397165, 0xefbd2fcf, 0x841dcacd, 0x64b726f1, 0x9ef3a1fd, 0x1e3260f7,
	0x6bacc3d0, 0x5f672a16, 0xee7e411b, 0x5aebf827, 0xfc322fa8, 0x78f7ddfc,
	0xb16f451e, 0x8a28f286, 0x59c89ef5, 0x2d528788, 0x81cbbfc5, 0xf0e7c67e,
	0xa05b83bc, 0x3ea0982c, 0x72783377, 0x973eaa90, 0xd011f0f9, 0x0a4c1ccd,
	0x9ecfa9f7, 0x8fe2a49e, 0xf48f677b, 0x6f1c87e3, 0xdce7ed3b, 0x2cdfcaa2,
	0xd0b4e55f, 0x71dc7979, 0xe50e7df3, 0xa9b3a22a, 0xd9cbf7aa, 0xa43f6f4c,
	0x111f1df3, 0x233cf19c, 0x1ac54bfa, 0xd73e4f9e, 0xb79e21de, 0x885873d3,
	0x25872f8a, 0x7ae53f59, 0x76f3c751, 0x2e7b1c45, 0x3fa93bfe, 0x168808bd,
	0x61dfc5df, 0x5d83f8c3, 0xa9b4776d, 0x7c4439f2, 0xc78d3ca8, 0x6d9dca87,
	0x0377dc7a, 0x00e36bf8, 0xfc351524, 0x6fe8067e, 0xf5e70b88, 0xdfd73955,
	0xe1e3875b, 0xc715607d, 0x17e442e4, 0xbc0af6ff, 0x83e70027, 0xba109cf1,
	0x2f8f9be7, 0xd3e855c6, 0x7fc45f3f, 0x2cb2cf9c, 0xd779bf3c, 0x6a17ba5e,
	0xaf3f0156, 0xe0cf70ed, 0xe8fddfe7, 0x57f7914c, 0x9f90ce81, 0x423bdf7b,
	0xac5bd674, 0xddfcf2b5, 0x8547861f, 0xfd3bc78d, 0xac296fe9, 0x5c19ef07,
	0x5d5928da, 0x7087ef12, 0x1c4ba7f1, 0x781fae37, 0x83ea7029, 0xe53b5f9b,
	0xdfc18cd5, 0x285c9163, 0x8b83af27, 0xfe314702, 0xf7e33b52, 0x2e4a3668,
	0x78df8f9a, 0xff3fbc6c, 0xa1fca0ad, 0x33126dde, 0xc386374b, 0x8e3c6bcc,
	0xaf892c32, 0xb249a7bb, 0xe73e5da2, 0xf79e969a, 0xdf014bd1, 0x3d3d9ebf,
	0x7d6fc548, 0xf9c053f4, 0x516b9ee5, 0x7fe8bcfc, 0x88dd1d33, 0x11fd947e,
	0xf97b7e45, 0xd5d10d66, 0x4f112c99, 0x92c6cb1c, 0x74f2101c, 0xc9d43b60,
	0x7efacdf7, 0xa544342f, 0x12de3027, 0xb515f146, 0xa378c1de, 0x8546fdef,
	0xbcf14fa0, 0x843cae7c, 0x22ed80f2, 0x63c8a7ae, 0xc36f18bb, 0x3e5524ba,
	0x8ebd7da4, 0xabf1abe2, 0x342ca823, 0x63fce99a, 0x00b96ae1, 0x4799e0f5,
	0x03c6a3a3, 0xaf599d1d, 0x430e9c8b, 0x4c78799c, 0x7b0fde3c, 0x952e7d66,
	0x98096c5f, 0x56f71beb, 0xae28e34a, 0x737fca37, 0x65d7f48a, 0x73217bcd,
	0x37d6cf91, 0x651a6085, 0xc78ffad9, 0xaf6f4199, 0x4663d8d0, 0x1d673ed1,
	0xae666de9, 0x4fbb42cb, 0xd74a1bb1, 0x7ea346e7, 0x91e7fc77, 0xdbbf5017,
	0x30a2eb57, 0x2fe174fe, 0xf40b0f3c, 0xe70bd916, 0xe72c7dc5, 0xff2883eb,
	0xb7d83cf6, 0x2253afb8, 0xab32ca1f, 0x1ccb68f4, 0x0643fefc, 0x9daebbe5,
	0xab5df831, 0xec5cf293, 0xfb4253ab, 0x65288b8b, 0xc76e56e5, 0xb8e254ed,
	0x4bbbde22, 0xf68c67dc, 0xa1166e3a, 0xb4758ebd, 0x7b44b1d7, 0x8ee79f1d,
	0x865c1334, 0xfba1edad, 0x853c95f9, 0xc4977feb, 0x6c63794a, 0xde0ffa47,
	0xdbfff097, 0xcacc92ef, 0x7feaa79f, 0xaaa1414f, 0x25b9defd, 0xf679f6aa,
	0xfbf55407, 0xf5561f8b, 0x6ad559ff, 0x77f7bb55, 0x0cfdf84f, 0x19fb896f,
	0xa29fbc56, 0xc264afba, 0xfeaa9a1d, 0x050bf4e2, 0xdab5aedd, 0xc0fa43ee,
	0x0e90e5fb, 0x19fe6287, 0x2ca3f1fa, 0xbeef3ee2, 0x9163e5fb, 0xf9fbfc6e,
	0x3a084fb7, 0x3802d57c, 0xfc751d6c, 0x94ddfa5e, 0x4e8f0e9b, 0x463ffa82,
	0xbbf4b9b1, 0xbe1eb72b, 0xac87f58a, 0xf6a5ccb7, 0x084c8c59, 0x5ee9bb9d,
	0xc273cc27, 0x5b37124f, 0xec83dc79, 0xf3e881cc, 0x4bf7ea7f, 0xa5cf544e,
	0x76d52ff2, 0x7564ef7a, 0xaaa79531, 0x5ff9e8ab, 0xf95257ab, 0x9e93b559,
	0x524a323f, 0xb28afefd, 0xdca154cf, 0x77ecdc0f, 0xeb8db03f, 0x703f6549,
	0x0f6b156d, 0xff6cbe42, 0xe5277fb7, 0x4e28a377, 0x949dfea1, 0xdfb6adfb,
	0xe4def3e3, 0x92734305, 0x9e6877e8, 0x393dfac1, 0x8287d78b, 0x77c9f8dc,
	0x93a43a55, 0xb3c8064f, 0xedc51b2b, 0x5b5f655c, 0xf6513bc9, 0xb9f6fbb1,
	0xaf27cff1, 0x5667d944, 0x176e5af2, 0xe4f9c2f7, 0xb27ed0a9, 0xcf0afe4f,
	0xc9df113f, 0xbe48c6bd, 0x4b51b6dd, 0x96b04876, 0xba1f7079, 0xec455f2f,
	0xe066df4b, 0xbf29ccf7, 0xed0d12e3, 0x6fea1cfa, 0xbfbc7393, 0x67eca2ff,
	0x06f98b47, 0x723cf96b, 0x0e29d9af, 0xcfd89b7b, 0xbc0df7c7, 0xe3ef89dd,
	0x2bb44359, 0x50bf24a0, 0x7ec757d9, 0x079fbc41, 0x3f7e51c7, 0xe45f8fa6,
	0x323bf443, 0x0cbcefca, 0x404b6f0d, 0xf8f807b9, 0x93a028f3, 0x3fb76159,
	0x29f80ede, 0x8e7f3008, 0x1f7fc4fb, 0xf10f7f66, 0x4a4a4272, 0x926a0ba1,
	0x7c6106b3, 0x7bb08671, 0x0517846f, 0x15dc0a1f, 0x6de3faf8, 0x840d7c20,
	0xe4fc7f27, 0x1bc2f35e, 0x5e3035e1, 0xb8c3f8bc, 0xbc6bffea, 0xe9bad18c,
	0x1c03b477, 0x1bb2befc, 0x0f6169e1, 0x2e850bcb, 0xad2cd785, 0xb164be58,
	0x16de2197, 0x667989b3, 0xce599984, 0x5ffcfc44, 0xe00cf44a, 0x00008000,
	0x00088b1f, 0x00000000, 0x5bedff00, 0xd755547b, 0x7dceff99, 0x105f7971,
	0x82e05405, 0xef4144a8, 0x363515e5, 0x4d282abd, 0x2979024c, 0x80839094,
	0xc48a088f, 0xd64cd0ce, 0x50980d70, 0xc19253ab, 0x5c9b58c4, 0x3338e26c,
	0xd1aac19a, 0x1373b6b4, 0x69ad211f, 0x3274d36d, 0xb1ae6b4d, 0x22633635,
	0xc9976992, 0x7ef99a64, 0xbdc39f7b, 0x4ed38ae7, 0xfcd6babb, 0x3eb97071,
	0x9efefdbe, 0x3ef7b7fb, 0x8b4c3fdc, 0x8d44dd93, 0x40a7dd57, 0xdaeadd07,
	0x4d4465d9, 0x8bb160b4, 0x2d65c7f8, 0x2fc44eaa, 0x34b6659e, 0x9db721a2,
	0x3f4428b6, 0x459a4d88, 0x25f728c9, 0x1689cb78, 0x3fee57e1, 0x9a36ed44,
	0xf9fbbfc2, 0x9057971f, 0xb85459fc, 0x62cd296a, 0x6efec13e, 0x3ecb29c8,
	0x3f8bffe3, 0xbcc1eead, 0xbcb8d38b, 0xe3ce5c20, 0xba204d12, 0x09771b45,
	0xab7189f5, 0xdddb1b26, 0x58af5b42, 0x1be69893, 0x893cb3cb, 0xf2661769,
	0xfb94b92f, 0xf0eb1599, 0x56d175c8, 0x4b97588b, 0x46c93b8e, 0x9a2628e4,
	0xfcd2b6e2, 0x524aa254, 0x4fedc46d, 0x61f0e87c, 0x2fc84bbd, 0x40502ff8,
	0x28295bd0, 0x428db9c6, 0xc883bf82, 0x39d5be0e, 0x10b0ed9c, 0xefaab3ad,
	0x20ff98b8, 0xcc9e9d4b, 0xeab1a9f5, 0xa278cf6c, 0xd7b7f1e3, 0x16f9e7af,
	0x47ca2c95, 0xdc2a57bf, 0xa642aee9, 0x6ac929ce, 0xcf8758a1, 0x867ff3ce,
	0xbd13cf9f, 0xf94195d6, 0x5de3b6bc, 0x2ec9e824, 0x13e7e527, 0x12e5dabd,
	0x9b052dfc, 0xbb16fd08, 0xc845b215, 0xd5bff7ad, 0x256c90b5, 0xde9a3e61,
	0xc9a5eb3a, 0x31db026a, 0x25057a65, 0x0158de81, 0x92907f79, 0xc634916e,
	0x91d16821, 0xdd13cc7c, 0x166ced7f, 0x7ce47c66, 0xee36c98b, 0xf5d67afa,
	0x5d4fad1a, 0x5e827fcf, 0xd7653ceb, 0x6ced75ea, 0x47cb8f9e, 0x65d7079c,
	0x78b6bf72, 0xf32e53f6, 0x0ca4491d, 0xc38edff6, 0x2e4c40d6, 0xc4b06fd1,
	0xf52f8c4c, 0x62490544, 0xf5b51bbd, 0x9345d7be, 0x9bda6fa1, 0xa4bfca2c,
	0xe74b6cf9, 0xcae7213c, 0xdfa239ce, 0x2b6a3147, 0x38a97bec, 0x71c82d38,
	0xeeaedef1, 0xcf3c79a4, 0x3d582f07, 0xab7db94b, 0xc3d5bdd5, 0xeac0fd3c,
	0xa5c79e79, 0xdf678f4f, 0x8e7a7889, 0xad7b9907, 0x529d5b5e, 0xe820088f,
	0xeaeebbf7, 0x23c7b3b5, 0x64324b0e, 0xb882921c, 0xc5c5a758, 0x272218e4,
	0x872eeffb, 0x099ceba4, 0x93eb2b41, 0x8d2fda8e, 0x511e43c6, 0x63f91c79,
	0xbf7b458b, 0x3f6c3533, 0x49f827ee, 0x29794e3c, 0x05c5afd3, 0x433f59ba,
	0xe81ebec9, 0xc16a0d97, 0x1dba1d7c, 0xdc34ecad, 0xea4d246e, 0xf69a66f1,
	0x2be67cd4, 0xe014ec86, 0x3c0411fa, 0x019c13ea, 0xf2a3eb3f, 0xf11b26b5,
	0xbe5addfc, 0x90b0c988, 0x63fe223b, 0x8ee471dd, 0x82f8dff0, 0xe89f0354,
	0x9f686899, 0x50cf273c, 0x619be29f, 0x55571fa8, 0x57c7e06c, 0x4fb433cf,
	0xc0d0be5f, 0x18b7aa67, 0x7d5a4fda, 0xf3d781a7, 0x445924d0, 0x8675ed59,
	0x2b9d39fe, 0xfd73ed0c, 0xc9ea180f, 0xc0533bef, 0xfeb4abfd, 0x8c3b7a53,
	0x4b5eacf5, 0xfe42e239, 0x6aa93d7c, 0x55fb6148, 0x8a5cac25, 0xf7da9cb8,
	0xd63d7190, 0xfec4ad4f, 0xa1592934, 0x25ffac71, 0xabde636e, 0x15f230cc,
	0x9809ef2e, 0x98cb916e, 0x0a828977, 0xbb5269fc, 0x027e50cd, 0x7f9e3379,
	0x90b34599, 0xfda0ff37, 0xfb0619d5, 0x5aebeb47, 0x0de8387f, 0x3be9bb72,
	0x43707e8c, 0x3307e8c0, 0xa0fd1af7, 0x07e8d068, 0xfd1a8fb3, 0xfa341bc0,
	0xd190c941, 0x18ceca0f, 0xb7c6e0fd, 0xfba07e8c, 0xe6bdb467, 0x41fe8c86,
	0xff2aa2aa, 0xba6ebd8b, 0x689ff468, 0x0b0d10fb, 0x504e2dfb, 0x9fee6768,
	0xf44faf6f, 0xd7b34e7d, 0xdf587da8, 0x9befac31, 0xc1933383, 0x29590e57,
	0x437df3c0, 0xccc97393, 0xce3c84f6, 0x54d84fa7, 0xae71179b, 0xa67755f9,
	0xa191abf4, 0xfbc8b183, 0x1fd1af0e, 0x6354ceee, 0x96379cbd, 0xdb28fb8f,
	0x5618ff01, 0x111757a7, 0x72ef21d5, 0x1c9c4e79, 0xda50bfdf, 0x3590ffdd,
	0x38ebcdd0, 0x9053e96b, 0xa925179f, 0x7f7fe829, 0x9ec2bb61, 0xe82b8505,
	0x31aff0df, 0x721be0d9, 0x45907da8, 0x5950c2a0, 0x2f38624d, 0x72e24c36,
	0x57a64f5e, 0x8790f311, 0x64dfb9eb, 0x89f045af, 0xb883971e, 0xf921635f,
	0x6c8edc02, 0x0450dd94, 0x9d8e9c7d, 0x5bf47d0e, 0x28e29c3c, 0x43277764,
	0x566bff4e, 0xca879e7a, 0xb14b32e2, 0xf20b3ea0, 0x8d3f0d20, 0x41df4e75,
	0x86f57d86, 0x116c9380, 0xd7b99f7a, 0x068be065, 0x67ed0c33, 0xea1b751f,
	0x4302c1bd, 0xc790c97d, 0x999d97c0, 0xe37f6863, 0x3f033e5b, 0x68655437,
	0x6ac5d37f, 0xf0a39f03, 0xbcf6c3ee, 0xf5279bcb, 0x6440e6e3, 0x4b1e1b39,
	0x235e0019, 0x3d09933a, 0xc7f0ce33, 0xf7d4bcb0, 0x7ec9cf94, 0x0c7e6aae,
	0xf960e1fc, 0x963eb8b3, 0x081583a9, 0x6d7a39fb, 0xcc983f62, 0x72e6496b,
	0x39e761f5, 0x37c64925, 0x567f41da, 0x8fea5ed1, 0xc8be95fc, 0xc9fb877d,
	0x6deb85fd, 0x37d0f8da, 0x31c7f7b7, 0x2dd3373d, 0x59ef6bd6, 0x60fe1160,
	0xcfc2650b, 0x1fa4621b, 0x0d8fef44, 0xd7a3bd9a, 0x7a2bafaf, 0x5d3373fe,
	0xee36bdb2, 0xbfba4ef3, 0xa33c2c7a, 0x5e6c55f9, 0xe1e23375, 0xade7bb19,
	0xf7ffb955, 0x7f13ba79, 0x69b88997, 0x5fd72d98, 0x5fdcb16f, 0x5a87211d,
	0xd3afd722, 0xef190ba5, 0xff4fd978, 0x12a7c1f9, 0xd33c0f18, 0xc79f7ac9,
	0xb1c0e438, 0x18948ce5, 0xe30f910f, 0x0828d8e4, 0x585300fb, 0x8a576f59,
	0xf4e702ad, 0x70d0497b, 0x9791265e, 0x7fda4847, 0xf011d3a4, 0xee87218f,
	0x7b3cba07, 0x18da6718, 0x9c65ecef, 0x8c4ffa09, 0xff3c6d33, 0xe0a1c63e,
	0x0b72e85f, 0x2055d83a, 0xe5d5bfca, 0xaea1fc11, 0xb17f8239, 0xa3f827cb,
	0x7e82555d, 0x945aabbb, 0xad137eeb, 0x3f1bf62f, 0x3fb745fc, 0x46fb10c2,
	0x2e3f947e, 0xcbda447d, 0xbd5ec1bd, 0x6a5c459b, 0x38a52aa1, 0xa6bb4fac,
	0xc3d053c7, 0xf10ed978, 0x9576bd7f, 0x50e4c2d6, 0x4ee3f421, 0x07e18d76,
	0xe94bfd3a, 0x64fbd743, 0x708b8c9b, 0xb878c9bc, 0x73e65c5e, 0xdc8f411c,
	0x8f53e84f, 0x8c78e8bb, 0xbd68db8e, 0x4d729f8b, 0xbc7279cf, 0x3db0e2a4,
	0xedd538f4, 0x9db5c7a2, 0x2fc8b542, 0x154b7c81, 0xa258fbf4, 0x8b7e8e31,
	0xdc3f64b8, 0x7a623889, 0x609aedce, 0xe9d0fec1, 0xb5607812, 0x3f74cb96,
	0x156ed96d, 0xb7ef13fb, 0x7908de09, 0xa3ac065b, 0x63767cf5, 0x7d8b56f9,
	0x571f66f5, 0xe8af3fb2, 0xdc030253, 0xdc6fd1af, 0xb24f3f1f, 0x5feb89be,
	0xbd4d7ee6, 0x4fa7fbd1, 0x891563ac, 0x7d2d48dc, 0xda55fac6, 0x74679239,
	0xdaae4f20, 0x4f7fac61, 0xe43d07df, 0x25ca4cf9, 0xb96105ce, 0x4c0abf34,
	0x843ec649, 0x94e22573, 0xe2263069, 0xdc66e75c, 0x3cc2e343, 0x00ae33eb,
	0xcd8f64fb, 0xad7dd533, 0x64faea1f, 0x3af9892b, 0x39fd729c, 0x8f73e18e,
	0x317a3f71, 0x782b9c56, 0xb7a03bfe, 0x0556434b, 0x5dcb4ff1, 0xad549e22,
	0x95bf25fd, 0x4b9facac, 0x5e846287, 0xbe9cb03f, 0x55cb8f37, 0x9fe707ac,
	0x23f8e30c, 0x839a4a36, 0xbc6fb1fc, 0xbac63fc7, 0x4859f346, 0xfd6ebff6,
	0x3849c3a6, 0xb7eeb667, 0xdd6cb88a, 0x7e427c7f, 0x2c4c3e44, 0x7b3f09b6,
	0x15a6a2d0, 0x0eb36d33, 0xf79ce364, 0x598127c0, 0xffd94ba0, 0x7968c7a1,
	0x7cddf346, 0x08d1f845, 0x5df227cb, 0xe3e42295, 0xb388497c, 0xc9ad8937,
	0x3050d4e3, 0x4d71140d, 0xde9c78d3, 0x880ec239, 0xc18df06f, 0x7b8e4239,
	0xe3d957ba, 0xe9e849b8, 0xdce32b87, 0x0411ee32, 0x0e5a2ca1, 0x47f881fc,
	0x283fc47b, 0x77f51fe2, 0xf188f55d, 0x4f3abeee, 0x9c52538c, 0xcf50f12b,
	0x87c00db6, 0x1d92f633, 0xe5d9087a, 0xfa7ad138, 0x9f8cb166, 0x79693160,
	0xb1d7ca4a, 0xbcf91149, 0x7e02b103, 0xb9f2229b, 0xa7d47fce, 0x7f9295f1,
	0x43e4b370, 0x255e84f6, 0xfb8bca59, 0x0a09c802, 0xddae7079, 0x402fdda7,
	0x81c8500e, 0xf031e472, 0x91e063c8, 0x8f23c0c7, 0xa18f2281, 0x6755057c,
	0x9fe5597b, 0x1acc661b, 0x9d578719, 0x4b811154, 0x818a5016, 0x34cce45f,
	0xe574afb4, 0x6497ea1a, 0xffa860dc, 0xe06bdb82, 0x6b982d6f, 0x679b7f68,
	0x63bf8181, 0xed0c17ce, 0x06357c6b, 0x5aaaaefe, 0xaa7bfb43, 0xcbf50d1b,
	0xd431af96, 0x0c1baad7, 0x7f5717fc, 0xbefed0d9, 0xfa864df6, 0x6a153bfb,
	0x7d39e48e, 0x769aefc3, 0xf8ff0aa4, 0x3b754e65, 0xf89dfcfc, 0x9ec97fdf,
	0x5b1f3b07, 0x68edbf03, 0x3b48f38b, 0xbb4955f7, 0x79da485b, 0xf9d856b8,
	0x2be48761, 0x31aee93d, 0xb631d170, 0xe5db0573, 0xd0676c7b, 0xf419db20,
	0xe833b615, 0x0573b609, 0xdb14efdb, 0xed887419, 0xb3eff28c, 0xb34f419d,
	0xc87f419d, 0xc33d0676, 0x49fd0676, 0x7f4172d7, 0x7e8aa5da, 0x2d5aeb3f,
	0xed5d5be8, 0x5de7fca2, 0xa2fe829d, 0xcfca2fcb, 0xf39a3af2, 0x8e02ebc3,
	0xf39c37ce, 0xe70d0fd8, 0x0781973c, 0x0f6c8e8e, 0x0f591d1c, 0x0f591d1c,
	0x03c91d1c, 0x07b64747, 0x5fe48e8e, 0x7c45baf0, 0xf6474f01, 0xe48e9e03,
	0x27fcfa8b, 0xdb744771, 0x804f0fae, 0x67951286, 0x81d11714, 0x6b5ddd6f,
	0x8a169c63, 0x3c53b255, 0x752a2fbc, 0x9c9915b5, 0x8b16ae4f, 0xc3459fb8,
	0xe55bd816, 0x1a9bb0b6, 0x8e6ec0a4, 0x338fa2d5, 0x70257d44, 0x079c9962,
	0x221ef776, 0xb12bcf81, 0xfb8596df, 0x0565c87b, 0xf987dbd5, 0xcf45dbb1,
	0xf913b7af, 0x7c1d6232, 0x313af360, 0xc509c3ef, 0xf69fd85b, 0x4f811458,
	0xbace30f7, 0xf4bc8c73, 0x9b8962eb, 0xbc0e58f6, 0x86fdc712, 0x6ecf151b,
	0x8d9a7a1e, 0xd0c5ec86, 0x70317b53, 0x29c5ebc4, 0xf3ed5c9a, 0xaf0a2cee,
	0xe3cfbf5b, 0xf00be13c, 0xc987f33c, 0x7cf3ccd1, 0xd1c93fee, 0x90e73c02,
	0x70fd0238, 0x57e99b9e, 0xfc23bb7c, 0xe58adffb, 0x37faa7fe, 0xf2e66bcc,
	0xe7dafb99, 0xc5df00b5, 0xf0ff7ec9, 0xe3d0926c, 0x6eca3ded, 0x7f33cb2b,
	0x9006f91f, 0xcf75b567, 0x3472e7dc, 0x8e5d798b, 0x1af90896, 0xdc3b6577,
	0xa8522f38, 0x5482f702, 0x14f3d0aa, 0x77cb1bd6, 0x8a71f202, 0xecbdc21f,
	0xaeb1bdda, 0x47f8455f, 0x818a60db, 0xd3347f5f, 0x3f08abf5, 0xd85f8b5b,
	0x21e1882f, 0xcd56adf6, 0xf2b4ebe4, 0x67ea9537, 0x7368ce70, 0xbfa03b0e,
	0x54a695cf, 0x3f3f61a6, 0xf0a99e46, 0xcdc6d2bb, 0x6a5d79e3, 0xbab1e7c0,
	0x93f6afa1, 0x5aae7f82, 0xca7dc2f0, 0x7ec4fac5, 0x04afdd38, 0xb71559e3,
	0x692c07fb, 0xdfe6dfcc, 0xf6809f64, 0x3803c8fb, 0xdfff9d30, 0xab961c5c,
	0x6258ce90, 0x1d0bf815, 0x7fe1171f, 0x86ee399c, 0x763d78bf, 0xd8d47f82,
	0x9be4765c, 0x8a31bc68, 0xeda45c47, 0x44cb85c7, 0xdbb21a9e, 0xf0d3ae04,
	0xae4ba351, 0xbb1ea3f5, 0x878d1fc0, 0x3ea07f19, 0xe2346f0a, 0xe044a83e,
	0xfb104f0e, 0x3d5ba1f8, 0xdd6aae7e, 0x8bb966f0, 0x6e7ef3f5, 0xfb0a4f60,
	0x0779fbf5, 0x5c039dee, 0xf90579c8, 0xa4c37194, 0xe3775e12, 0x384993e6,
	0x07fc8577, 0xa8f8de05, 0xbc927b67, 0x13ef905f, 0xf49e9acd, 0xcd169bfb,
	0x97c0cd1e, 0x397784ac, 0xc6a6716f, 0xa4b41bbe, 0x5c0af589, 0x89138d11,
	0xcf9b3f5c, 0x9e59abf5, 0xdaadcc2d, 0x0668f8da, 0x75178b5d, 0x9b56b9bc,
	0xbd8f4d77, 0xfb9b31d1, 0x07ec4051, 0xf6c6026b, 0xb9fc356b, 0xbcb1af76,
	0xdfbb44bc, 0x76a771d1, 0x6b507a4e, 0xf1faf8d3, 0x69ee047b, 0x83ade3b7,
	0x1c4937ea, 0x30280744, 0xc8bf0155, 0xfd7ccb12, 0x19479f61, 0xa47e6fc3,
	0x98a5a1e1, 0x7359f594, 0x91e44e35, 0x144eaf3b, 0x3357bdfc, 0xb5765d04,
	0x6ee39640, 0xaa1ced86, 0xf08f0254, 0x38686ff8, 0x33ab9ee8, 0x3f88fd44,
	0x08f1f85d, 0x98a631fb, 0x19a7e5a5, 0xae38e53e, 0xd5da97b5, 0x7eb9e3cd,
	0x5c0900e9, 0x12f01b79, 0x7e072c57, 0xe41c412a, 0x3e7c6256, 0x5cd4d1bd,
	0xcd06c1c4, 0x480e39ef, 0xc89f0de4, 0x01351567, 0x5cbfcf2b, 0xbd81603d,
	0xfd57ff75, 0x6fe06ce7, 0x770e2bf3, 0x885738a1, 0xdfeeb3f3, 0x10d071d1,
	0x2537ddaf, 0xd1a4fbc8, 0x962c067b, 0x43fe4697, 0x6fae3eb5, 0x44e0ddc0,
	0xaaacb0cd, 0xdf5942c4, 0x6d50f07e, 0x7f530e0f, 0xbd447de2, 0x35ec22c5,
	0x376f38cc, 0x54ce9502, 0xb64e23a6, 0xdc5bc52a, 0x292cf5e1, 0x34b3b85b,
	0x42bc9ce2, 0xbb8e2b8b, 0x3a3b9c74, 0x9d3532be, 0x3a05c0c6, 0x233d626d,
	0x43921abe, 0xd558525f, 0x57c84a3b, 0x25ada6c1, 0x7c0e4e4d, 0xa75455ce,
	0x9e0ea7f1, 0x04def7fb, 0xf7c11fa1, 0xf5af1c97, 0x7919fc27, 0xc862a970,
	0xea2a6f83, 0xfbc02513, 0xd862d0ce, 0xd870be35, 0xeb45bb01, 0x83adbee7,
	0x1eb3a6db, 0x45b8954e, 0xcfa3bd79, 0x020e224e, 0x9ad39c76, 0x42bee50a,
	0x17f67736, 0x5b88fbc5, 0x72e9fbdc, 0x3dbc0bbf, 0xa7be5e86, 0x1f0007dd,
	0x1f121dbb, 0xbb1f0283, 0x0c7c49a7, 0x1418f81e, 0xc0e518f8, 0x8f81e0c7,
	0x831f03c1, 0x05063e07, 0x93f9463e, 0xc7b9df16, 0x2d3b9ed8, 0xd8470381,
	0x534fef4f, 0x4eef2107, 0x7eb923ea, 0x7ec7c855, 0x68c4f223, 0x72ff627e,
	0x68fd8796, 0xc3f9e745, 0x3fb0bc96, 0x795ef735, 0x839c79fa, 0x9e220f19,
	0x18255ed5, 0x7efaeb33, 0x7103ecf6, 0x7d9e5e22, 0x6ef221c8, 0x49cce3bd,
	0x9f586e67, 0x613e776f, 0x38327997, 0xd6e3cdd5, 0x907ac7b5, 0x559497f7,
	0x8d5e449f, 0xbb08f42f, 0x724c44ec, 0xf524c6fb, 0xa0af9435, 0xb832a733,
	0xbcdfc35d, 0xf5fa8d9e, 0xc81d72c7, 0xbd478dbf, 0xd1b8668f, 0xe421fd5f,
	0x39704c6d, 0xf5d62f80, 0xb6fd88a4, 0xe3de5d21, 0x778bc7b2, 0x171edd30,
	0xbf3ee44a, 0x73ce4ca3, 0xb1273b59, 0x8635ec82, 0x149cf276, 0xbdfa6f1d,
	0x56bdf462, 0xb9e57ef8, 0x8bdc3cde, 0xdba791a4, 0x46bead7d, 0xde493fef,
	0x7fdf44ab, 0xf02bc68c, 0x94fe18ca, 0xd39daa5e, 0xcb6a73b5, 0x70b539e8,
	0xfcf03a71, 0xf70b8ae3, 0xee09cdcf, 0x6f997365, 0x23d3b21e, 0xb7548b08,
	0xe1f99323, 0xddae28af, 0xaf46f7b0, 0xb0f55bc8, 0xbcd1cb09, 0xdb888e63,
	0x71d300e6, 0x2fef8fd7, 0xeb3c7e3e, 0xf415c825, 0x66ceb039, 0x81138b17,
	0x14fa9a77, 0x7cd12711, 0x47bca94c, 0x03e3e7ac, 0xc6df77f4, 0xdc0ac75c,
	0xe9ec325b, 0x6e5c8428, 0xe3f7af51, 0x5bb44176, 0xe0a7479a, 0x172cc357,
	0x2be616f2, 0x057f188e, 0x9f988fc6, 0x96bc0bdb, 0x7e976a52, 0x73b962e4,
	0x9d625d41, 0xa7a107ac, 0x9e3c6de1, 0xf423cc5b, 0xd80c14de, 0x8d8f583d,
	0xcebe65e7, 0x9e63b015, 0x715e3d15, 0x956eafdf, 0x29bda8f3, 0x39e0228e,
	0x1591cb9b, 0xefd8f389, 0x38f597e0, 0xf589a7d4, 0xccdc1c0a, 0xfe054a7a,
	0x9bdc654c, 0x1abead70, 0xf737f5b5, 0x637118a5, 0xd876e3df, 0x57db56a7,
	0x5950eda2, 0x5791ef2a, 0x10702cf4, 0x0e7cdbfa, 0xe9a7d60f, 0x621bd7fb,
	0xa47de0b7, 0x7b29ffb6, 0xa565f32e, 0x4b2b9fd2, 0xcd2dbfa5, 0xa0554e0b,
	0x1eb10d87, 0xd5d6b3ac, 0xd51de427, 0x0fd676f7, 0x5aab8970, 0xc4fd9be8,
	0xe697ac4f, 0xc37da37e, 0xe31449eb, 0x8a37f736, 0x53695bf8, 0x75c8ae1d,
	0xaa7978ec, 0xe5a97ac2, 0xffb057b8, 0xf86cd4b8, 0xcbed85cf, 0xbc9c85b2,
	0xd139e84e, 0x519c5ee3, 0xf846fc2a, 0x0d3feeb5, 0x479e3225, 0x26d4a3fd,
	0x4ff4a9fd, 0xade6d38b, 0x3dc3e48d, 0x1479065e, 0xa9c70fe5, 0xbc7a9f1e,
	0x94f76ad6, 0x486b5b4d, 0xbc37c88d, 0x6b7fb77f, 0xd4ecfd0c, 0xd9a759d6,
	0x8279f593, 0x7aebee22, 0xcfaeb8b4, 0xc63dc633, 0xf41bb8c3, 0xa9c185fa,
	0xedc30a1b, 0x53eb79f5, 0x3ff83f65, 0x36836cfc, 0x8877da1f, 0xde4316f6,
	0x1bcd1a68, 0x404f36fb, 0x88a038de, 0x6d8eab77, 0xec75d712, 0x5bf7144f,
	0xe471d1ff, 0xbb72f787, 0x681c9ff7, 0xbafabc80, 0x4f32839a, 0x429e30b4,
	0xeda958de, 0x550b33fb, 0xf7c4697f, 0xbf7fcd1a, 0xa2e21a7f, 0xe17bd06e,
	0x0ee424e7, 0x62fcdf22, 0x9cde77ff, 0xafef0ee7, 0x7a2b1cba, 0x4c6f6c7f,
	0x949bd488, 0x0ac14b73, 0x7b4a95f2, 0xd4d5fce1, 0x077788a3, 0xfc0874ea,
	0xda3bdba9, 0x7e391a0f, 0x7ec2129b, 0x7affdba0, 0xb3b749b8, 0xdedd7f6e,
	0xf6e81fba, 0xd844edd6, 0xbf702367, 0x6a6feebe, 0xfcd3aeeb, 0xdf968f77,
	0x3ae756ea, 0xcf788a56, 0xefc13475, 0x66dafab5, 0x9da8f963, 0xfdf9a35c,
	0xc8c5c451, 0xc8d3b4a0, 0x87bcbb56, 0x9d8d77dc, 0xebefb1b2, 0xdda558eb,
	0xf768b637, 0x1c352b86, 0x1c3a76cc, 0xcf55a769, 0xbd353b4a, 0xbf2ffaf0,
	0xc9f216ed, 0x462db63c, 0x8315c5e0, 0x6abd8407, 0xe7b71f7b, 0xa593bb72,
	0x72ef86b9, 0x2ebdda9a, 0xf5d79fdc, 0xff11d80e, 0xa3797527, 0x8fa99dfc,
	0xfd8af422, 0xf7d88947, 0x7bc8f6f4, 0x8d9e7807, 0xf093621b, 0xcf3e8d5d,
	0x371f9a87, 0x62a4a7b5, 0xc6f6a6be, 0x4ab9c3bf, 0x71d1fbcf, 0xc6563e77,
	0x0f1e0ac3, 0x817e7971, 0xf0a3bb27, 0x9d32f7da, 0xabcb5afe, 0xe2f5675f,
	0xf149963b, 0xbe28ff83, 0xe71f5883, 0x7e72fbc1, 0x7980287e, 0xb758c7e1,
	0xbe22f383, 0x0d6fc987, 0x183ac15d, 0x5fef8ba2, 0xe5531340, 0xe604c7fb,
	0xe7b2f377, 0x4ab3cd30, 0xf5265f1a, 0xd4342b83, 0x0ca85a53, 0xade747f2,
	0xdd0ae1eb, 0xa271f53f, 0xe4f5d4f3, 0x71fd96b3, 0xd5cf9df2, 0x3c0a4bee,
	0xb79e4ed9, 0x3dd36be1, 0x43fa3fb8, 0xe4e23a72, 0xbca8d37b, 0x5273acec,
	0x5f3790c7, 0x2fae839e, 0x84e57f6f, 0xe6bde431, 0x938b581d, 0x91f7e8e6,
	0x723ef93e, 0x8b7de15e, 0x21bf3dc7, 0xa66f7c56, 0xcfdfa5cb, 0xfaf2f7eb,
	0xeef5fbfd, 0xa597a7dd, 0xa116f76a, 0xfac9e044, 0x83fe2d38, 0x4d794792,
	0xdfbeb944, 0x1285759f, 0xf3f22353, 0xfdb5daaf, 0x10db4290, 0x8539d4cf,
	0xb671cf70, 0xa5a27cef, 0xd729fe10, 0x68dbf7a7, 0x44ed9cf7, 0xe31cdb9e,
	0xe311bdc1, 0x8f7147a6, 0x114fe2d4, 0x75f733f7, 0xc1d85c96, 0x33d7dce3,
	0xbd7023c9, 0x6a57f386, 0x637e2ff9, 0xa237a3e3, 0x175c8efd, 0x424b7c70,
	0x6ff703b5, 0x8e35fdf1, 0xe57b813c, 0xaf7f4039, 0x3550a8da, 0xf2156fe2,
	0xf2cae223, 0x9bf63e72, 0xfe243b55, 0x5ea16a5f, 0x74e677bc, 0x44ce2f57,
	0xf15a787e, 0x2ed24f00, 0xf9faa3ce, 0xe1c7738c, 0x6505eac2, 0xeca7d7d0,
	0x0cfe3c77, 0xc856b1ec, 0xb9c3e833, 0x405f1893, 0x7a07ac1e, 0x25c35979,
	0x25cffb67, 0xfac30bba, 0x2a9071cc, 0xf751cdce, 0x77761d40, 0x5dda0a7a,
	0x4ee49ef3, 0x9fc8894e, 0x0b59bbfa, 0xc1c67dee, 0xc027ea3f, 0xf7b59a3f,
	0x17fb47b1, 0xe065be09, 0x97f009ae, 0xb9ceb09b, 0xe578ff5c, 0xcff67e93,
	0xcd1f4d6c, 0x076e8b6d, 0x3bbd5a2e, 0x9ae70526, 0x3b3fbb6c, 0x0f368712,
	0xdc4d963c, 0xec40e2fe, 0x0af3e472, 0x0a454d57, 0x5772b9cb, 0xb11ad78a,
	0xe2d7ac2f, 0x45b681ef, 0x6b8fb8e9, 0x67f1fdfd, 0xc2d4fef0, 0xfc78ba63,
	0x8bc60edf, 0xbb5a97ef, 0x795b668e, 0xea9cf389, 0x7edc6503, 0xbdd8e5ad,
	0x95df9173, 0xd14c9ec0, 0xfde63dde, 0x05f9e8fc, 0xdff64de7, 0x4b7dbfb6,
	0xe581f38c, 0xdcb5edf4, 0x60edb5bf, 0xbb59c612, 0xd6728dfd, 0xfeb5ee10,
	0xafbfe30a, 0xe171ec0c, 0x6063b8bc, 0x96e3f616, 0xc79353ed, 0x7e131efa,
	0x7d5cff0d, 0x8bef0c94, 0x059205f7, 0xe483550e, 0xeab77bc0, 0x2f738122,
	0xfb13a95a, 0xf44b8eba, 0x0f4d5ef2, 0xb2fb9317, 0x7b35ff61, 0xbec6ca9e,
	0xc9449bf1, 0xf659efd7, 0xf521e47d, 0xbf8918b9, 0x6df0246d, 0x65e25f93,
	0xcf2694ba, 0xae3834fb, 0x89e4fd81, 0x9f1178b2, 0x1b14766b, 0x5f1909de,
	0xd8dff288, 0xc8eb0aa8, 0xc2f61ee9, 0x05b6df9f, 0xb7cf605b, 0xbde28f19,
	0xf4997d63, 0xacfbb7bf, 0x44f7c58b, 0x15c0081c, 0x4c1df76f, 0x8ea23bc4,
	0xbfad2ac3, 0x978159f0, 0xec5e2b0e, 0x6785f1c3, 0xb48639c4, 0x2e7592fb,
	0x2f1d6fe9, 0x4a4f17d9, 0x944ab813, 0x8e82dab4, 0x80f5ecb1, 0xf9469b86,
	0xb9c40743, 0xc49f75ac, 0xe783ad05, 0x71d02e04, 0xa7169b46, 0x139df76b,
	0xb7ef4138, 0x4bd490ee, 0xde5921db, 0xefd16058, 0x3e4a7c5b, 0xe08acbce,
	0xbb7928df, 0x922d936e, 0xa6dd79ff, 0xcc97507c, 0x8161b66f, 0xfc14b7cb,
	0xda679c44, 0x9971b47a, 0x77cc47b7, 0x5e334e04, 0x40494f96, 0xfce1b77f,
	0x9e4876d6, 0x716d8287, 0xd8bbe2bd, 0xd0360975, 0xb104b6ee, 0xb76aef9f,
	0xb14ad814, 0xe78138b8, 0x73df698e, 0xf7e4837d, 0xbed79f5b, 0xa4945adb,
	0x24791f7e, 0x79150683, 0x4fbf219f, 0xf7ddfcbb, 0xcdfe304a, 0xb883a131,
	0xd971fc01, 0x97bc3a95, 0x2a1c9cdc, 0x7c7fc681, 0xa7c943f8, 0x1ee20e87,
	0x58bfe5ca, 0xcff73157, 0xaf9a57b8, 0x56ffa0d8, 0xa9beaf2d, 0xbac4bfa8,
	0x725eaeda, 0x618d7bc8, 0xaeff9ef1, 0x5fe347e6, 0xce2473e1, 0x88271f51,
	0xb8fa6073, 0x07702f76, 0xd04a8615, 0xb0fa18ee, 0x893ff87f, 0x30fbe00b,
	0x7788b562, 0x0179abe6, 0x53951df1, 0x0c8c37be, 0x107c104f, 0x5fda18fb,
	0xd1f68a71, 0x2e55947e, 0x463aa9e3, 0xa1dec7be, 0x85feb3d8, 0xa3913987,
	0xd554c08e, 0xef22d679, 0x276f7c14, 0xacbf03bf, 0x78eadbbd, 0x5726a179,
	0x73ce7696, 0x4048cc4c, 0x1f3e29fc, 0x3d487275, 0x134af852, 0xb0eaffe6,
	0xa87ef093, 0x70b8c77f, 0xab9e4e38, 0xfd895626, 0xa8db7155, 0x52bfdb9e,
	0x3be20968, 0x5392affe, 0x33932bbc, 0x625b670a, 0xcad8f7c5, 0xc63f57b1,
	0x7ac9333e, 0xcb3278e5, 0x15afe93f, 0x69b7374f, 0x8df0b918, 0xbfad311f,
	0xe400fbba, 0xc6a492d8, 0x187f6397, 0xb2a73aa9, 0x1aeabf8a, 0xfee47a74,
	0x3feb9145, 0x938fe5f6, 0x75e12d52, 0xb0be1e5d, 0xa82948ff, 0x2f4bdc53,
	0xf795663c, 0xb9eb5158, 0xdf16e19c, 0xa13b7385, 0x9609cbf7, 0x0b85ce00,
	0x0b7f1d8f, 0xef885beb, 0x705e719d, 0xee452fda, 0x4acee473, 0x5c39bdc1,
	0xe149b3f3, 0xdb5eb03c, 0xbb74268f, 0xf613747f, 0x84acd7c9, 0xa4b606fb,
	0xfdb47fb0, 0x611e00de, 0x2e50519c, 0xea7f0bef, 0x17282eae, 0x2c8193f7,
	0xeb7cfbf8, 0x55a9dfd8, 0xedd77669, 0xb74bdba9, 0x5d0f6e8f, 0x99fb74cf,
	0xd08ac993, 0xa4d7d16f, 0xd9cbcb5e, 0x7c7ecf8f, 0x2587337a, 0x5baffc4d,
	0xbfff7e84, 0xf2faf5e9, 0x855b01a5, 0xe5887be5, 0x77c835cb, 0xbf9bf0a7,
	0xde227cbc, 0xcef968ff, 0xd09be518, 0x0e9d8c1d, 0x116ed93f, 0x7bfa2a78,
	0x91202a51, 0x71ac1b2f, 0x8d54dee2, 0x906f7f93, 0x2d27c349, 0x5f93a7cc,
	0xaa9cc7e4, 0xc5701150, 0xb067a259, 0xe64590ae, 0x3cf2becd, 0xd3279f91,
	0x77f14c99, 0x1950b613, 0xe2b76b70, 0x0569da7b, 0x823fed0d, 0x4126b2fc,
	0x0e5dbbbc, 0x1e76fc58, 0x66853fbf, 0xfb79e51d, 0xef10ccd7, 0x00219728,
	0x8ee5c7f6, 0xa2b9f3c0, 0xf513bb3e, 0xc5feb2b5, 0x06df9fdf, 0x953c39bc,
	0x5efd1c84, 0xf983b69a, 0x51029afe, 0x7bed1dff, 0x8b1aff12, 0xf3235fec,
	0x2cb6ff60, 0xcec93df1, 0xb01b819d, 0xf80ff64f, 0x766f7132, 0x02dd5126,
	0xcab44dfb, 0x973fb7fd, 0xa93e99cb, 0x60b6d754, 0xdeb9229c, 0x0bdc6d50,
	0xd8a8787b, 0x5c954e7c, 0x5133b67e, 0x71ead3bc, 0xe753dfa2, 0x0d3dcff8,
	0x5217f8fd, 0xff8f3b41, 0xba57e68e, 0x431f15be, 0xdeb0d4f2, 0xd34aff75,
	0x2c3cadf4, 0xbbf46cfd, 0xbe2475e3, 0x4bcc9e3b, 0xef829f88, 0xe86e3d49,
	0x1d592b37, 0x37bbbac0, 0x58ac3db0, 0x59fbd4bf, 0xeb1ead0b, 0x5a7d9cbb,
	0x77f693dc, 0xf3240d17, 0x77fe8347, 0xbfc69d16, 0xe4d0a0b3, 0x26277c14,
	0xbffb87fc, 0x82fd5398, 0x1ff917c8, 0x9c5f2226, 0x98eb6ffe, 0xd11cffdf,
	0x562385f2, 0xd7b4517d, 0xc744eefe, 0xefbda7d5, 0x387f6165, 0x2757e5fb,
	0xac4c5e83, 0xe1f9097e, 0x2ddfdac9, 0x4ef596c6, 0xbdfc4866, 0x9fb53bcc,
	0xf67b8964, 0x7e155f87, 0x53aec7fe, 0xc17fc75f, 0x6a4cca0f, 0xd49a9352,
	0xa93526a4, 0x526a4d49, 0xa4d49a93, 0x49a93526, 0x93526a4d, 0x26a4d49a,
	0x4d49a935, 0x9a93526a, 0x3526a4d4, 0x6a4d49a9, 0xd49a9352, 0xa93526a4,
	0x526a4d49, 0xa4d49a93, 0x49a93526, 0x93526a4d, 0x26a4d49a, 0x4d49a935,
	0x9a93526a, 0x3526a4d4, 0x6a4d49a9, 0xd49a9352, 0xa93526a4, 0x97fa4d49,
	0x1b03ffa2, 0x00ae6180, 0x0000ae61, 0x00088b1f, 0x00000000, 0xc5edff00,
	0x30000131, 0x54a0c00c, 0xeb0bfcd4, 0x87832153, 0xdad5ea9d, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xf1fdb6db, 0x2cf02607,
	0x008000b5, 0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000131,
	0x54a0c00c, 0xeb0bfcd4, 0x87832153, 0xdad5ea9d, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xf1fdb6db, 0x2cf02607, 0x008000b5,
	0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000131, 0x54a0c00c,
	0xeb0bfcd4, 0x87832153, 0xdad5ea9d, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xf1fdb6db, 0x2cf02607, 0x008000b5, 0x00000000,
	0x00088b1f, 0x00000000, 0xc5edff00, 0x30000131, 0x54a0c00c, 0xeb0bfcd4,
	0x87832153, 0xdad5ea9d, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xf1fdb6db, 0x2cf02607, 0x008000b5, 0x00000000, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x00100000, 0x00000000,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x00100000,
	0x00000000, 0xfffffff3, 0x320fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x30efffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6,
	0x305fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c,
	0xcdcdcdcd, 0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014,
	0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xfffffffa,
	0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c,
	0xcdcdcdcd, 0xfffffff7, 0x31efffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x302fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xfffffff3,
	0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c,
	0xcdcdcdcd, 0xfffffff1, 0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffff406,
	0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3, 0x0004cf3c,
	0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xfffffffa, 0x302fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xfffffff7,
	0x30efffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0020cf3c,
	0xcdcdcdcd, 0xfffffff5, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xfffffff3, 0x31efffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xfffffff1,
	0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c,
	0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffff406, 0x1cbfffff, 0x0c30c305,
	0xc30c30c3, 0xcf300014, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xfffffff2,
	0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c,
	0xcdcdcdcd, 0xfffffffa, 0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffff97, 0x056fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xfffffff5,
	0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c,
	0xcdcdcdcd, 0xfffffff3, 0x320fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300,
	0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x310fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6,
	0x305fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c,
	0xcdcdcdcd, 0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014,
	0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffff8a,
	0x042fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3, 0x0010cf3c,
	0xcdcdcdcd, 0xffffff97, 0x05cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cc000,
	0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x310fffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0001cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0008cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0040cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c,
	0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffffff,
	0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c,
	0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc,
	0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0x00100000, 0x00070100, 0x00028170,
	0x000b8198, 0x00020250, 0x00010270, 0x000f0280, 0x00010370, 0x00080000,
	0x00080080, 0x00028100, 0x000b8128, 0x000201e0, 0x00010200, 0x00070210,
	0x00020280, 0x000f0000, 0x000800f0, 0x00028170, 0x000b8198, 0x00020250,
	0x00010270, 0x000b8280, 0x00080338, 0x00100000, 0x00080100, 0x00028180,
	0x000b81a8, 0x00020260, 0x00018280, 0x000e8298, 0x00080380, 0xcccccccc,
	0xcccccccc, 0xcccccccc, 0xcccccccc, 0x00002000, 0xcccccccc, 0xcccccccc,
	0xcccccccc, 0xcccccccc, 0x00002000, 0xcccccccc, 0xcccccccc, 0xcccccccc,
	0xcccccccc, 0x00002000
};

static const u32 init_data_e1h[] = {
	0x00010000, 0x000204c0, 0x00030980, 0x00040e40, 0x00051300, 0x000617c0,
	0x00071c80, 0x00082140, 0x00092600, 0x000a2ac0, 0x000b2f80, 0x000c3440,
	0x000d3900, 0x000e3dc0, 0x000f4280, 0x00104740, 0x00114c00, 0x001250c0,
	0x00135580, 0x00145a40, 0x00155f00, 0x001663c0, 0x00176880, 0x00186d40,
	0x00197200, 0x001a76c0, 0x001b7b80, 0x001c8040, 0x001d8500, 0x001e89c0,
	0x001f8e80, 0x00209340, 0x00002000, 0x00004000, 0x00006000, 0x00008000,
	0x0000a000, 0x0000c000, 0x0000e000, 0x00010000, 0x00012000, 0x00014000,
	0x00016000, 0x00018000, 0x0001a000, 0x0001c000, 0x0001e000, 0x00020000,
	0x00022000, 0x00024000, 0x00026000, 0x00028000, 0x0002a000, 0x0002c000,
	0x0002e000, 0x00030000, 0x00032000, 0x00034000, 0x00036000, 0x00038000,
	0x0003a000, 0x0003c000, 0x0003e000, 0x00040000, 0x00042000, 0x00044000,
	0x00046000, 0x00048000, 0x0004a000, 0x0004c000, 0x0004e000, 0x00050000,
	0x00052000, 0x00054000, 0x00056000, 0x00058000, 0x0005a000, 0x0005c000,
	0x0005e000, 0x00060000, 0x00062000, 0x00064000, 0x00066000, 0x00068000,
	0x0006a000, 0x0006c000, 0x0006e000, 0x00070000, 0x00072000, 0x00074000,
	0x00076000, 0x00078000, 0x0007a000, 0x0007c000, 0x0007e000, 0x00080000,
	0x00082000, 0x00084000, 0x00086000, 0x00088000, 0x0008a000, 0x0008c000,
	0x0008e000, 0x00090000, 0x00092000, 0x00094000, 0x00096000, 0x00098000,
	0x0009a000, 0x0009c000, 0x0009e000, 0x000a0000, 0x000a2000, 0x000a4000,
	0x000a6000, 0x000a8000, 0x000aa000, 0x000ac000, 0x000ae000, 0x000b0000,
	0x000b2000, 0x000b4000, 0x000b6000, 0x000b8000, 0x000ba000, 0x000bc000,
	0x000be000, 0x000c0000, 0x000c2000, 0x000c4000, 0x000c6000, 0x000c8000,
	0x000ca000, 0x000cc000, 0x000ce000, 0x000d0000, 0x000d2000, 0x000d4000,
	0x000d6000, 0x000d8000, 0x000da000, 0x000dc000, 0x000de000, 0x000e0000,
	0x000e2000, 0x000e4000, 0x000e6000, 0x000e8000, 0x000ea000, 0x000ec000,
	0x000ee000, 0x000f0000, 0x000f2000, 0x000f4000, 0x000f6000, 0x000f8000,
	0x000fa000, 0x000fc000, 0x000fe000, 0x00100000, 0x00102000, 0x00104000,
	0x00106000, 0x00108000, 0x0010a000, 0x0010c000, 0x0010e000, 0x00110000,
	0x00112000, 0x00114000, 0x00116000, 0x00118000, 0x0011a000, 0x0011c000,
	0x0011e000, 0x00120000, 0x00122000, 0x00124000, 0x00126000, 0x00128000,
	0x0012a000, 0x0012c000, 0x0012e000, 0x00130000, 0x00132000, 0x00134000,
	0x00136000, 0x00138000, 0x0013a000, 0x0013c000, 0x0013e000, 0x00140000,
	0x00142000, 0x00144000, 0x00146000, 0x00148000, 0x0014a000, 0x0014c000,
	0x0014e000, 0x00150000, 0x00152000, 0x00154000, 0x00156000, 0x00158000,
	0x0015a000, 0x0015c000, 0x0015e000, 0x00160000, 0x00162000, 0x00164000,
	0x00166000, 0x00168000, 0x0016a000, 0x0016c000, 0x0016e000, 0x00170000,
	0x00172000, 0x00174000, 0x00176000, 0x00178000, 0x0017a000, 0x0017c000,
	0x0017e000, 0x00180000, 0x00182000, 0x00184000, 0x00186000, 0x00188000,
	0x0018a000, 0x0018c000, 0x0018e000, 0x00190000, 0x00192000, 0x00194000,
	0x00196000, 0x00198000, 0x0019a000, 0x0019c000, 0x0019e000, 0x001a0000,
	0x001a2000, 0x001a4000, 0x001a6000, 0x001a8000, 0x001aa000, 0x001ac000,
	0x001ae000, 0x001b0000, 0x001b2000, 0x001b4000, 0x001b6000, 0x001b8000,
	0x001ba000, 0x001bc000, 0x001be000, 0x001c0000, 0x001c2000, 0x001c4000,
	0x001c6000, 0x001c8000, 0x001ca000, 0x001cc000, 0x001ce000, 0x001d0000,
	0x001d2000, 0x001d4000, 0x001d6000, 0x001d8000, 0x001da000, 0x001dc000,
	0x001de000, 0x001e0000, 0x001e2000, 0x001e4000, 0x001e6000, 0x001e8000,
	0x001ea000, 0x001ec000, 0x001ee000, 0x001f0000, 0x001f2000, 0x001f4000,
	0x001f6000, 0x001f8000, 0x001fa000, 0x001fc000, 0x001fe000, 0x00200000,
	0x00202000, 0x00204000, 0x00206000, 0x00208000, 0x0020a000, 0x0020c000,
	0x0020e000, 0x00210000, 0x00212000, 0x00214000, 0x00216000, 0x00218000,
	0x0021a000, 0x0021c000, 0x0021e000, 0x00220000, 0x00222000, 0x00224000,
	0x00226000, 0x00228000, 0x0022a000, 0x0022c000, 0x0022e000, 0x00230000,
	0x00232000, 0x00234000, 0x00236000, 0x00238000, 0x0023a000, 0x0023c000,
	0x0023e000, 0x00240000, 0x00242000, 0x00244000, 0x00246000, 0x00248000,
	0x0024a000, 0x0024c000, 0x0024e000, 0x00250000, 0x00252000, 0x00254000,
	0x00256000, 0x00258000, 0x0025a000, 0x0025c000, 0x0025e000, 0x00260000,
	0x00262000, 0x00264000, 0x00266000, 0x00268000, 0x0026a000, 0x0026c000,
	0x0026e000, 0x00270000, 0x00272000, 0x00274000, 0x00276000, 0x00278000,
	0x0027a000, 0x0027c000, 0x0027e000, 0x00280000, 0x00282000, 0x00284000,
	0x00286000, 0x00288000, 0x0028a000, 0x0028c000, 0x0028e000, 0x00290000,
	0x00292000, 0x00294000, 0x00296000, 0x00298000, 0x0029a000, 0x0029c000,
	0x0029e000, 0x002a0000, 0x002a2000, 0x002a4000, 0x002a6000, 0x002a8000,
	0x002aa000, 0x002ac000, 0x002ae000, 0x002b0000, 0x002b2000, 0x002b4000,
	0x002b6000, 0x002b8000, 0x002ba000, 0x002bc000, 0x002be000, 0x002c0000,
	0x002c2000, 0x002c4000, 0x002c6000, 0x002c8000, 0x002ca000, 0x002cc000,
	0x002ce000, 0x002d0000, 0x002d2000, 0x002d4000, 0x002d6000, 0x002d8000,
	0x002da000, 0x002dc000, 0x002de000, 0x002e0000, 0x002e2000, 0x002e4000,
	0x002e6000, 0x002e8000, 0x002ea000, 0x002ec000, 0x002ee000, 0x002f0000,
	0x002f2000, 0x002f4000, 0x002f6000, 0x002f8000, 0x002fa000, 0x002fc000,
	0x002fe000, 0x00300000, 0x00302000, 0x00304000, 0x00306000, 0x00308000,
	0x0030a000, 0x0030c000, 0x0030e000, 0x00310000, 0x00312000, 0x00314000,
	0x00316000, 0x00318000, 0x0031a000, 0x0031c000, 0x0031e000, 0x00320000,
	0x00322000, 0x00324000, 0x00326000, 0x00328000, 0x0032a000, 0x0032c000,
	0x0032e000, 0x00330000, 0x00332000, 0x00334000, 0x00336000, 0x00338000,
	0x0033a000, 0x0033c000, 0x0033e000, 0x00340000, 0x00342000, 0x00344000,
	0x00346000, 0x00348000, 0x0034a000, 0x0034c000, 0x0034e000, 0x00350000,
	0x00352000, 0x00354000, 0x00356000, 0x00358000, 0x0035a000, 0x0035c000,
	0x0035e000, 0x00360000, 0x00362000, 0x00364000, 0x00366000, 0x00368000,
	0x0036a000, 0x0036c000, 0x0036e000, 0x00370000, 0x00372000, 0x00374000,
	0x00376000, 0x00378000, 0x0037a000, 0x0037c000, 0x0037e000, 0x00380000,
	0x00382000, 0x00384000, 0x00386000, 0x00388000, 0x0038a000, 0x0038c000,
	0x0038e000, 0x00390000, 0x00392000, 0x00394000, 0x00396000, 0x00398000,
	0x0039a000, 0x0039c000, 0x0039e000, 0x003a0000, 0x003a2000, 0x003a4000,
	0x003a6000, 0x003a8000, 0x003aa000, 0x003ac000, 0x003ae000, 0x003b0000,
	0x003b2000, 0x003b4000, 0x003b6000, 0x003b8000, 0x003ba000, 0x003bc000,
	0x003be000, 0x003c0000, 0x003c2000, 0x003c4000, 0x003c6000, 0x003c8000,
	0x003ca000, 0x003cc000, 0x003ce000, 0x003d0000, 0x003d2000, 0x003d4000,
	0x003d6000, 0x003d8000, 0x003da000, 0x003dc000, 0x003de000, 0x003e0000,
	0x003e2000, 0x003e4000, 0x003e6000, 0x003e8000, 0x003ea000, 0x003ec000,
	0x003ee000, 0x003f0000, 0x003f2000, 0x003f4000, 0x003f6000, 0x003f8000,
	0x003fa000, 0x003fc000, 0x003fe000, 0x003fe001, 0x00000000, 0x000001ff,
	0x00000200, 0x00000001, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x00088b1f, 0x00000000,
	0x51fbff00, 0x03f0c0cf, 0x33b1d78a, 0x44e36c30, 0x5e0287f0, 0xb0c0ccc5,
	0x01d78806, 0x36203bf1, 0x30606261, 0xbf412265, 0x286d8228, 0x0710c0cc,
	0x190417c4, 0x230bfe18, 0x18c485c4, 0x18447218, 0x2044f418, 0xda405dfc,
	0xee3a944d, 0x26cc681f, 0x54f6298d, 0xc766c102, 0x398c8f22, 0x255de4d0,
	0x049cf951, 0xfe340ff4, 0x57ca88ae, 0x2dd08054, 0x79347130, 0x06bca825,
	0x153f5fd4, 0x39ab9bb1, 0xc30dfdc8, 0xe010e600, 0x000400fa, 0x00000000,
	0x00088b1f, 0x00000000, 0x7dedff00, 0xc5547c0d, 0xbddcf8b5, 0x66eeef77,
	0x21366eef, 0xc23e1259, 0x1a808426, 0x4015f2e2, 0x804375f1, 0x82eb4a86,
	0x2e22a2b5, 0x9b242108, 0x61f5290f, 0x21b2f7db, 0x2fa22204, 0x3e8a47fa,
	0x8b57cba4, 0xae85db16, 0x1b80b634, 0x6dac1828, 0xb62d6d83, 0x51faffd6,
	0xa4490844, 0x953df16a, 0xdccce737, 0xbb37bdec, 0x7fbeda80, 0xe3fdfbdf,
	0xf730dfcf, 0x73399dce, 0x339ce6be, 0x49256667, 0x8411ee21, 0x2fbf845c,
	0x489d7210, 0x28949908, 0x31575de1, 0x19e4b7fd, 0x5c42144c, 0x7d084e24,
	0xecc84e97, 0xb6908132, 0x1aba37bc, 0xe27be80b, 0x7d294813, 0xf4ffa2ee,
	0xba3fffd0, 0x69dd4228, 0x20e7f825, 0xd2464231, 0xded62bef, 0x4ea04a43,
	0xb4990dc8, 0x37908fbd, 0xd08b9b78, 0x8fad0a6e, 0xc4edd449, 0x7678c02b,
	0x211dbeaf, 0x26e22639, 0x9ec5db24, 0xb7891b45, 0xfb211470, 0xb658ad1b,
	0x85bcba37, 0xda7e4266, 0x81e58398, 0x3f3e0f46, 0xcb0638d4, 0xcb17a358,
	0x0737934c, 0x7e3ecae0, 0x4e29064b, 0x3e58c1e0, 0x1fc748d0, 0xa5ffa895,
	0x8a448498, 0xe448bf84, 0xaefd3f2e, 0xe909c5e9, 0x1c6e5a71, 0x3e9f674b,
	0xaceffbf0, 0xc67b85fa, 0xdf064220, 0x633ddc77, 0x90276d02, 0x200511f9,
	0x52e6106f, 0x5998b464, 0x96efc63f, 0x30e90110, 0xe272f0f8, 0x33bf4b19,
	0xe95a86fb, 0x2343cb9c, 0x68d3ad7d, 0x8bb4f9bf, 0x22cc8421, 0x61a143c3,
	0x2e826c84, 0xad7212a7, 0xbe01bfe2, 0x15e3941b, 0x7cce3002, 0x3a5cec8a,
	0x2204995f, 0x33a1c649, 0x48be71c0, 0x11292f08, 0x789909b3, 0xf6ab8d84,
	0x1ccd96a3, 0x0193d2fe, 0x9ec1c8b2, 0x57fbc197, 0x5a22c2bd, 0x7cd8d8b6,
	0x02a4219e, 0x88124dda, 0x89dbca1f, 0x079dfb09, 0xb8c4a4e5, 0x6f71f0b7,
	0x1f100be8, 0x04e7276d, 0xeb8f8048, 0xe3ef862b, 0x81167a62, 0x21767839,
	0x5ed8c3c5, 0xc03a6edb, 0xcc8531e5, 0x576e30e9, 0x4244fa79, 0x02243942,
	0x4c519fed, 0x138bdb15, 0x267854ed, 0x787e4c39, 0x4ff7f6ae, 0xa9fdf417,
	0xfb5a2c7c, 0x45e2faf9, 0x27c0b75a, 0xf4cc6f94, 0x3bc030fb, 0x25b6f88c,
	0xf837ebc1, 0xb11e273c, 0x5f8508f9, 0x5b61cbf6, 0x50dff43e, 0x0b41f506,
	0x24a45788, 0x1b34eebe, 0x778e46f7, 0xba83de75, 0xd969be29, 0xda1dd945,
	0x6c24bc5b, 0xb9cbdfa1, 0xb4657d2b, 0xe2861f6e, 0x08b0c848, 0x829d6911,
	0x4ad90212, 0x47cac7c5, 0x17403c13, 0xae5520f7, 0xef8183bd, 0x875054cd,
	0xbf357c50, 0x3ffec162, 0x808e5470, 0x4eefd4ce, 0x2dc6c637, 0xa67ffca1,
	0xeecb13b1, 0x7b2c2ec6, 0x99624f1a, 0x692a3c6a, 0x5a654226, 0xb3e257fc,
	0xf39af852, 0xda6af0a5, 0x7dc7737f, 0xfe1457c8, 0xdae3a110, 0x00b85315,
	0x45589978, 0x0bf1cdd9, 0xb97c96f8, 0xfc32c6f3, 0xf9cd9e02, 0x2d1b7f92,
	0x841b5b07, 0xcf358a7b, 0xff001d29, 0xd7dc8f13, 0x405e7884, 0x9004d9c6,
	0x9ca7ca17, 0x19688bee, 0xc97ca26d, 0xad3178f9, 0xc0a7894f, 0xcf8c5bfb,
	0xd7ef9f73, 0xe504e97f, 0x0a2c2a95, 0x8429c8df, 0xf20805ff, 0xdca55a87,
	0xc3eb4b9b, 0xe789f854, 0x6dbf30d7, 0x1eb2246b, 0x23d91eea, 0x79c3f7d3,
	0xaa8161eb, 0xc849c439, 0xc739ca8e, 0x4717aa04, 0x50751f8a, 0x37864575,
	0x35c46f48, 0x3e6f2efa, 0x67aa2465, 0x3fd2ac47, 0xebe90fcf, 0x9f930074,
	0xab6467ce, 0xc473f9fe, 0x0eca7591, 0x2838960a, 0xd7980f47, 0x403fa58a,
	0xefd2367e, 0x531246e1, 0x973a9acc, 0xcc2eb57b, 0x86b459ca, 0x28c56fce,
	0xf59a05e2, 0x78a2be81, 0xddfe37fc, 0x428e5083, 0xb1a589fd, 0x62a2717f,
	0x41497d02, 0x55fb69f2, 0x7b28494b, 0x142bfa19, 0x720cbfa6, 0x89852694,
	0x9b4bb68b, 0x49c2fb21, 0x488fade4, 0x8a4dbe38, 0x7d69bed1, 0xa76ef112,
	0x8e615f78, 0x563e4087, 0x86f1e0dc, 0xdc5edd68, 0xb8ba03e6, 0xc2d8e90a,
	0x34e782a7, 0x39e141c0, 0xa309c6cd, 0x455df75c, 0x187cf6c8, 0x62bbf587,
	0x84848794, 0x82fe70d4, 0x3bce1198, 0xa15fc094, 0x2088f7bf, 0xa0931a9d,
	0xc155734f, 0xd5a2cdbf, 0x5abdfc0d, 0x915c59cf, 0x7720fa03, 0x957e9e84,
	0xe03c86d6, 0x647f6a8f, 0x704ff016, 0x2831d77e, 0x5175d3b7, 0x4ceb851a,
	0x3a85f011, 0x301ad3be, 0xf5129309, 0x5dbe0782, 0xd5fefd02, 0x36b842e2,
	0xeb1edb9b, 0x92b1f3a4, 0xeb464406, 0x9455d5b4, 0x3ca5883d, 0xc8337580,
	0x5e203c01, 0x275afd02, 0x8f80ca86, 0x77be852d, 0xfa3d2844, 0xa39cdc75,
	0xfd2e8baf, 0x7f4a9e7a, 0x425cae5c, 0xa36cbad8, 0xf7bc0764, 0xe8184839,
	0x96f44e20, 0x960f3c00, 0x7981e75e, 0x0f4c0815, 0x5852f427, 0xfd571757,
	0x01385dca, 0x73e1b79e, 0xee8bd571, 0x87a041c2, 0x4b5f3842, 0xefa662f9,
	0xbf56f30d, 0x6f357fff, 0x7a51f002, 0x7c7dcf09, 0xf9b0f80a, 0xf407b319,
	0xe633f977, 0xbd6817d8, 0xfa809b76, 0x86c874dc, 0xc2d9e9f8, 0x8c8731ea,
	0x276e7b7c, 0xad3e53ad, 0x743d74b7, 0x19efe03d, 0xf4476c91, 0x5e8137cc,
	0x2561c53b, 0x695eaced, 0x6ddad563, 0xfbe10b1d, 0x810b76aa, 0xd9f6acf5,
	0x9eb95f65, 0x9a7597d6, 0xdda93409, 0xa10f24d5, 0x2161e5f5, 0xe9def502,
	0xfda13e8c, 0x6d177862, 0x72ecebdf, 0x7ac0a2df, 0xd19e2562, 0x97476e14,
	0x4e94abfb, 0xb3bde1d5, 0x3deabbe0, 0x8c529782, 0xb1d763ce, 0xed5dfa5c,
	0x70178293, 0x4edbb35b, 0x9e7c1a3c, 0x2fb18a8a, 0x79d1bc80, 0x32efda12,
	0xe80b36d2, 0x61ebbb55, 0xe048e3d9, 0x18e34ceb, 0xea24b1e2, 0x71d24fb5,
	0x3f7577e8, 0xc530bc14, 0x8bb3133a, 0xcdb59e7a, 0xfcc0a1df, 0x0722e49a,
	0x0c9d6bcc, 0x178596ed, 0x0079b7ed, 0x2cf26dbe, 0xcb7abefa, 0x2352b936,
	0xafbb35d7, 0x5d0d1e21, 0x391e6d4f, 0x7b097038, 0x27b50cf2, 0x7354f0b5,
	0xb0a4437d, 0x57c3573c, 0xa40ca605, 0x516ecd6f, 0xf74abfd7, 0xda08efd0,
	0x0e83a105, 0xb74aabc4, 0xd6c22e15, 0xf3b74e1f, 0xa9474e2e, 0xbfdb54af,
	0x74043e5a, 0x35b4f0a0, 0xa47cb0ba, 0x8dcb0731, 0xcfa41e8d, 0x2d1fc026,
	0x9db87037, 0x449948d3, 0x88fa75c7, 0xc90fb28b, 0x332be39c, 0x9fa67ad3,
	0x020bddd5, 0xf312e782, 0xe64dcb57, 0x54ea22c0, 0x17842790, 0x5bb5127c,
	0x7b81c937, 0x479168a8, 0x66f8dfa4, 0x428bfad0, 0x9d023be0, 0x540a68a7,
	0x923645b1, 0x5974a7e3, 0x7fa1d7cb, 0x87883c13, 0xea32b9b5, 0x96774ddd,
	0x8e7d00ee, 0xaf50597f, 0x7cfadefc, 0xfa0c27ec, 0x3f69944e, 0x8fdf2f23,
	0x5d14e17b, 0x5585ee3f, 0x624f3f6a, 0xd657693f, 0xd785a6cf, 0x5859e1e9,
	0x0fb3f6ad, 0xd95e71fb, 0x4d77dcbc, 0x5773c3d3, 0xbc19fb10, 0x4ec04bc0,
	0xba2bd751, 0x0ed0f82a, 0x7e3193dc, 0xd1f2d13d, 0x9e3043f4, 0x96954a83,
	0xa4a7d28f, 0xc329e4e9, 0x0faba997, 0x6ba218aa, 0xd02fed9f, 0xff3c1fbd,
	0x2a5f036a, 0xf0d753ae, 0x0e05003a, 0x1e5f8520, 0x29dea322, 0xf845621b,
	0xa0a21def, 0xbaf7b9de, 0xcf5868c0, 0x4ff05601, 0xd70395ee, 0x27fa92ba,
	0x81c9025d, 0xd28263d2, 0x999d7ef8, 0xd0fa6de1, 0xa75e8a8f, 0xfa9bd7df,
	0xbd68328a, 0x1af654cb, 0x5c5bcff0, 0xa489a7ff, 0x59a5da01, 0x75bfea08,
	0x423ba5f9, 0x0eb6bc1a, 0xb1a2fca7, 0x81cd5a07, 0xd3c7e01c, 0x2485ef4d,
	0xe1dadf0a, 0xef5bfa32, 0x42c5ef08, 0x375876d4, 0xf00732bc, 0x4abf016f,
	0xc74cbe3b, 0x7bf1c62f, 0x04f7fc60, 0xc718f7e6, 0xd14c14b7, 0xabcd6f8d,
	0x956f8dd2, 0x3e54f8e9, 0xc47d342e, 0xbbf8a7c7, 0x850f908e, 0x4b7c708f,
	0xbf8e155e, 0xba55264e, 0xc7fad3f1, 0x2ee804ff, 0xbf8f9299, 0xfd3ae0ae,
	0xf5aaf3fc, 0xfcd997f3, 0x26a5abad, 0xce1a7e36, 0x3a9266df, 0xd579fe70,
	0xd616fe6c, 0xcef8ff6f, 0x4d3bfc7e, 0x532cfc74, 0x465bfc72, 0x7fcfd34e,
	0x7f3f5044, 0x673f1b0b, 0x57c7c2b5, 0x935cfc70, 0x465be382, 0xd97c7104,
	0x1f02f012, 0x1ad343c9, 0x06a2dec0, 0x460c87b8, 0x72c3e81d, 0xc5fa264c,
	0x100a11bf, 0x18d37b8e, 0x46907ddf, 0xe8494df9, 0x8b5e1253, 0xce3a8c71,
	0xca7b35d3, 0x7f3140e4, 0xa5feed4f, 0xed25d41c, 0xd935f222, 0xa28f0968,
	0x8bb4f6f0, 0xd92cc7e8, 0xc4584378, 0xbff994f5, 0xc18d1cd4, 0x3a3f3ff3,
	0x5e76bb76, 0x9b6972c6, 0x235c54f9, 0x7dfafd57, 0x40d3193a, 0xb8255be1,
	0x7eb56e10, 0x7069ea8a, 0xfaa0de92, 0xcdb7ca18, 0x8b79afcc, 0x7a3271ea,
	0xbb4f5fa0, 0x9d316dfb, 0xfc38d7d7, 0xef8624a7, 0x30852b53, 0x8783ffe0,
	0x9f4191ef, 0x83b36d2d, 0x470fd7d1, 0xdf53a73d, 0x76f096b3, 0x01e9f101,
	0xa28adcfc, 0x0e9fc848, 0x4098f97d, 0x9b659eed, 0x5bbee907, 0x392dc240,
	0x1bddfdb4, 0xd1770d16, 0xdf31dff9, 0xff445e32, 0x84d437ce, 0x9a864c72,
	0x3f350fa8, 0x2879b0fa, 0xdf3adcad, 0x6e57f3ac, 0x77ebe80b, 0x3debe954,
	0x04d9b0e6, 0x8172ccf6, 0xdefda36c, 0xf83660d9, 0xbf1c6c41, 0x95d19329,
	0x4a35f78f, 0xe8fa5cc3, 0xc3c7284e, 0x75d21763, 0xab7d8ba1, 0x2dff53c2,
	0x80587533, 0xf06cf17e, 0x1b28498f, 0x8b80bcfd, 0xef08dbcd, 0xe7d5b342,
	0xbc2cf0a7, 0x1a7c444f, 0xb21f8fe1, 0xbfd44cfb, 0x8bfe6f8b, 0xe374ec19,
	0xdff08c7c, 0x1f38cab5, 0xc3eb0c97, 0x39f190a2, 0x3f2313e3, 0xed97b7d5,
	0x4fc34b78, 0x3bd991b5, 0x577cd2de, 0xaeae7bb3, 0x9b7c3cbe, 0xcdb2fdae,
	0x97ef748b, 0xbdd72db6, 0x1ef5bbbf, 0xe8517d5d, 0xbbfb5d3e, 0xdee93556,
	0xbf70d9df, 0x551dfdee, 0xb7eaeb0f, 0xb5d31e05, 0x36fe75bf, 0xd0e17bdd,
	0xd47111f2, 0xb91181ab, 0x62beb760, 0x2a8fc021, 0x70f2abbf, 0x502dda9a,
	0x0b76a19e, 0xa7204d94, 0xcf4dfe54, 0xfb7eb2b2, 0x8d2e11a2, 0xb9b6f75f,
	0xc9e40f21, 0x7c46f7c8, 0xfe9bf91a, 0x0eb64d0d, 0xc79065a9, 0xfe0d7a97,
	0x87ae64f2, 0x728d5909, 0xdc999419, 0x4ee5f706, 0x28257f07, 0x921a8ac7,
	0xf2fd9df8, 0x1e70111c, 0x6cf4ac04, 0x56e51ba0, 0x766ade0d, 0xd9c1d48f,
	0xf8e221dd, 0x54bb2075, 0xfc154dff, 0x24c7d031, 0xe6ef2476, 0xaf8f00b1,
	0xb4f004c3, 0xdbfae367, 0xe3b158dd, 0xcfe0332d, 0xc6e9e58f, 0x6a9e58f9,
	0x56f9600c, 0x6f961563, 0x19603634, 0xe5855c6f, 0x2c218d6b, 0xc56c6d5f,
	0x6d8d0ff2, 0xdc6c9e58, 0x8dcbe58c, 0x1a7b2c61, 0x7caa587d, 0xfd27afdb,
	0xfee56edc, 0x66449505, 0x88b9f2b7, 0x50bb4654, 0x2039bd1e, 0x0f95e78f,
	0x3f2ec08a, 0x3912927f, 0x8cbe353f, 0xaf1290fc, 0x457687c4, 0x79d29865,
	0xb6f7c0d0, 0x9b274634, 0xaa105489, 0xf51fee37, 0x8fc42f3d, 0x99225d68,
	0x3bd87df0, 0x5fa491d7, 0xbd0146ba, 0xe227472e, 0x38812beb, 0xffc7a9d7,
	0x9dfa14b3, 0x54eb626c, 0xd71111da, 0xe1db124b, 0x5a7d7a05, 0xfdcf09bc,
	0xe6e40f29, 0xbf8ab65c, 0x17883cae, 0x617267dc, 0x16a3e73f, 0x0f1e0122,
	0xba10c3d8, 0xc3b9df39, 0x8addeb09, 0xd6fc311c, 0xaaf8d484, 0x1587e48d,
	0xdbea7ccd, 0x6df3f5f5, 0xd7044542, 0x57fa4f4d, 0xb95f02c7, 0xbc616fc2,
	0xb54b0730, 0x3239159f, 0xe3faa38e, 0xf2064f64, 0xb10bf529, 0x8e1adfdd,
	0xe024fd54, 0x29379288, 0x2e5c40ee, 0x5d878926, 0x7bd224ae, 0xc805c432,
	0xb007f301, 0xffe85b9e, 0x2591c117, 0x7ed5d612, 0xc86223eb, 0xdf3c2d72,
	0x7e8f1ba3, 0xee7d51e7, 0xe297058b, 0x529c8957, 0xdb5549e7, 0x535fbe54,
	0xd616dbb3, 0x5d0cfdeb, 0x373dbebd, 0xe0075bac, 0x36c0b91f, 0x60eb0482,
	0xaf517390, 0x140ab4a4, 0xc3d12cbe, 0xed604df8, 0x3971ad6a, 0x69be01e0,
	0x1ef5dafe, 0xfb26d968, 0x4cf5e093, 0xba4ba763, 0x46b85c44, 0xb26f7f3c,
	0x22858efd, 0x9a08efdb, 0xac4d3d98, 0xabf82721, 0x9ce42724, 0x94d040e7,
	0xdfa0fc7e, 0xd4d1c744, 0x87967ed5, 0xd6c97dcd, 0xb3136ec9, 0xd6e38d93,
	0xb3f7028b, 0xbabf8d2f, 0xc166273d, 0xac788dbc, 0xc6577f6b, 0xfe89167d,
	0xa3c09a57, 0xd12cdf8a, 0x79d22f5f, 0x1d7eef55, 0xe6d3c9ed, 0x2eb7d150,
	0xc206b7a1, 0xfc60e4af, 0xc573cf96, 0xdfb40e33, 0xe2cc3c56, 0x5d7a741e,
	0x3562ee30, 0x2df7cd2e, 0x0ae83854, 0x7eb44c48, 0xf1a9af37, 0x1ad1c587,
	0x99ff3f8c, 0x22706484, 0x4adb11df, 0x8eac0ec1, 0x0e21936c, 0x70988e7e,
	0x791ce6ff, 0x434139c9, 0x8ca28daf, 0x55bbbaf8, 0x3b508f6f, 0xb65f5756,
	0x24af5f59, 0x6fa0dcf3, 0x499a372a, 0xea79c058, 0x0081afde, 0x71c43659,
	0x3ac2d61a, 0xc27466fd, 0x3a07aed7, 0x5289e4fc, 0xfa62efc0, 0xe026687a,
	0xf1e204f1, 0x1cbf8ed3, 0x703f1fbe, 0x1adf04dc, 0x0f1c32e2, 0xdc05bbb5,
	0x69d23067, 0x9557e71b, 0xfc38fabf, 0x91fe9daa, 0xc88cfea1, 0x1122bce3,
	0x5ce78e81, 0x1d2990d6, 0x10637bdf, 0xf167db1f, 0xfafe5336, 0x567fe8a2,
	0xa07b46cc, 0x7dda6884, 0xf3e00c51, 0x4ac5e16e, 0x148923b0, 0x90bb012b,
	0x77c825ae, 0x98afa732, 0xd7212ce6, 0x01b93842, 0x36cd0383, 0xafa876e7,
	0x81cd5475, 0x907ad7fd, 0x83dfda6f, 0xb09d59ce, 0x6d2560ef, 0x23e51f31,
	0xdf7e8e4b, 0xd7d1e6c0, 0x41a7a0ed, 0xd803c17f, 0x8c12f38f, 0xe8c7d93b,
	0xfabc39db, 0xf1fa6ffa, 0xc2fb6314, 0xc40f4ff0, 0x489895a1, 0xa45327c7,
	0xa7ff7eee, 0x062ffc00, 0x717bb53f, 0x62e95b3d, 0xce20ebed, 0xf2b1e941,
	0x3383e9d1, 0xd527612f, 0x8730c85f, 0xbd78eb35, 0x3f0327d4, 0xc2c85fd5,
	0x4f599fe7, 0xa9eae87a, 0x312693d1, 0x01e81670, 0x13e0117a, 0x0d0138e8,
	0x7511d45c, 0x2ad6e569, 0x33e1f9e9, 0x744591c3, 0x0c4b3afa, 0xc5fa047c,
	0xee67c708, 0xff40673f, 0xd96fe956, 0xfe80e17f, 0x7824a4b3, 0xd3c9fdac,
	0xff5443fb, 0x51e8ff57, 0xbc0d2427, 0xbdb9b523, 0x5dc1fe94, 0xcb904e2d,
	0x09c852d3, 0x2c277d74, 0x67db2456, 0x702492f9, 0x08a7db7b, 0xc83fc8a5,
	0x7a9e6747, 0x97e02be0, 0xeccbb07f, 0xb77d7f42, 0x4ca16625, 0xce5d1759,
	0xe5b763e4, 0xf75f5675, 0x7d67f02e, 0x545f5ebb, 0xb751ff7f, 0x10a3d707,
	0xe86367f7, 0xfcedd40f, 0xafb02cf3, 0xea1f49ea, 0x3077e32f, 0x5c4c85fe,
	0xe9c917ff, 0xfbabdf03, 0x2f1cf58b, 0xde07d1f5, 0xe2585115, 0xdb19ffe8,
	0xfebb7157, 0x8591c97a, 0x64c9b771, 0x8a99f032, 0x7666120f, 0x2793f8bd,
	0xd32e204a, 0x4e17f3bd, 0x9fcb58a1, 0x1f390fcc, 0x3fbbfbb9, 0xa796a4f5,
	0xb517aa1e, 0xaf6ab3f6, 0x3fb9da79, 0x41958072, 0xfb09cc73, 0x666dc100,
	0x0e3e886f, 0x7be3bd3e, 0xe49c438f, 0x14778b15, 0xe9e6bfed, 0x475f2fa3,
	0xcd7b35eb, 0x34d87359, 0xa09dc114, 0x7ffd3d4b, 0x1d04f8d5, 0x547c7faa,
	0x78627d86, 0x04ccedfe, 0x76f66a3d, 0x40ec64c8, 0x3a47947c, 0x8492b8e4,
	0x67d7912e, 0xfe20df81, 0xe81963e4, 0x8121cefe, 0x824fce0c, 0xd1476dcf,
	0x213c05fe, 0xfa9d391d, 0x5f6866e9, 0xfa82e94f, 0xf8c9d390, 0xfbc8387e,
	0xc41fd624, 0xff3f29c3, 0x6fb0a7f0, 0x178b07f2, 0xc3f55fe6, 0x1e613baf,
	0x8c0d4b6f, 0x71689faf, 0x9543fe43, 0x6176e439, 0x6d579ec9, 0xdbf206fd,
	0x70df13b2, 0xf8823c63, 0xd6b84d72, 0x7e617287, 0x82dcb74b, 0x0124abf3,
	0x27aabbe4, 0x784bcc44, 0x7b15225f, 0x4c45c893, 0xedf8fa62, 0xe64c16ed,
	0x0e161b79, 0x497847d8, 0x78c2ef0c, 0xef183ddc, 0xffba86f8, 0xfd605643,
	0xd3a32b7d, 0x8fd52477, 0x96874ba5, 0xebae775f, 0x199cfa02, 0x710c1bee,
	0x85227adc, 0x8b843e38, 0xc4f15fb4, 0x3e8cc1cc, 0xf29523c4, 0x2fbea8ef,
	0xbed0e787, 0x95b3eccb, 0x1723bee8, 0xafe313f3, 0xb853e3e4, 0x7d3ec0d3,
	0xb9ed4ddb, 0xeeebf324, 0x176a7b97, 0x234bf869, 0x77de4cdf, 0x5be4cfde,
	0xdcf0f795, 0xdeff780a, 0xc0fc996f, 0x502f6077, 0xf18362b8, 0x0557c77d,
	0x121607d4, 0x3bd7264b, 0xf5ae5ccd, 0xa13e55ef, 0xeeb04b70, 0x610bf3f6,
	0x3cdbccf6, 0x91b95b7e, 0x9fd5a77e, 0x60739e30, 0x2edcaa7f, 0x33fff2e3,
	0x73efef89, 0x985b27f9, 0x1ff6a7dc, 0xa09f8842, 0xc7bdfc39, 0x7ca95e41,
	0xf078bec2, 0xe61fb369, 0x91cf767d, 0x72a76f97, 0xcaa23672, 0x1a7f5ea9,
	0xdf6ab4e5, 0x4e4c9224, 0x925e2acf, 0xf3e94e54, 0xc4aa72a4, 0xbbff8f91,
	0xbf8aa7f4, 0x53fa0d37, 0xf0a987d5, 0x2187d468, 0x34f883c9, 0xf7fa43ea,
	0x903a525b, 0x53be54ff, 0x07faadf9, 0xef4023b5, 0xcaa5f3f4, 0xa97cfd77,
	0xf880ddf2, 0xc67f0e9f, 0x9c434ff7, 0xff89f297, 0x1acddfd9, 0x3c19e94a,
	0xe951f6c0, 0x4ea0c777, 0x6e63e4f1, 0xa1b1db55, 0xd87ada59, 0xda188f50,
	0xbf750cfb, 0x50c07da1, 0x0fb4306f, 0xfdaf3f33, 0x6af2cc88, 0xe6f6ba62,
	0x80e424d5, 0x1141f3b8, 0x14bdcee3, 0xfbf4b5e6, 0xe1f93dde, 0xbf227e50,
	0x5e5b2fac, 0xd7abfa0b, 0x84cce7d5, 0xdbc58dba, 0xce7dfd7a, 0xf61d8d0c,
	0xf51101fa, 0xf2cc3c6f, 0x43ca06d1, 0x4e2fd233, 0x7167bd52, 0x92a299f4,
	0x25e20ab7, 0xbbe6226d, 0xd5ba692c, 0xbd5e2909, 0x34de4607, 0x7a5f3e9f,
	0xbcedc45c, 0xd3bfb05e, 0x293ecd01, 0x9d77e357, 0xd34da126, 0x807e2e20,
	0x364b5df9, 0x6523fc18, 0x90fa0ca5, 0xe86f47fa, 0x5f1803f7, 0xaa7ef357,
	0x57dfe8b6, 0x4fc80d93, 0xbd5e3faa, 0xc03eff53, 0x999f77fd, 0x647189eb,
	0x099ff31c, 0xe0ae51e6, 0x58a6757a, 0x8a7cd37c, 0x114edef7, 0x1fce1973,
	0xe7ef1110, 0x667ea8f7, 0x1d4bca36, 0xf9b593e9, 0x0f20dd42, 0x9beb53a3,
	0x54fe67ee, 0x24da2dfa, 0x258fffb8, 0xeecb4eff, 0xfd14affd, 0xf93fea0c,
	0xc91fde7d, 0x87e5f6c0, 0xd0efb86c, 0xfb81c87b, 0x7f07bd84, 0xa82df799,
	0x02f16b3f, 0xfe87bd9c, 0xd37c025a, 0x0552dabb, 0x3877aafa, 0x3e6af3cb,
	0x3892d7f8, 0x586b8fae, 0xfcccc43c, 0xfe07f3d4, 0x0b2135f3, 0x582b3a4a,
	0x71d90ff7, 0xa7fea6ff, 0xf57b8c36, 0xa96bfc1e, 0xbcff6ed6, 0xfbe3a9f3,
	0x320ebd81, 0x97c01f7f, 0xea51f6c1, 0x4775367f, 0x444be413, 0xe9bbe43b,
	0x3ee7f2fb, 0xd83d012e, 0x33d98fbb, 0x56f8e63d, 0xb7baefd8, 0x336af765,
	0x080f57a5, 0x324210c3, 0x3d33bed7, 0x2f0c9c54, 0xef3c631f, 0x20f1f14a,
	0xffd263e0, 0xb8087c04, 0xe03c1def, 0x98055b08, 0xfdaf87f7, 0x90ffe411,
	0x9d52f905, 0x1348d9ef, 0x9b971bda, 0x75ff9ef7, 0x576216f3, 0xfc5fef32,
	0x5cfff383, 0x34e107b3, 0x3e40c1ca, 0xd62f783f, 0x1178769f, 0xf7e42bde,
	0xe8dbffb3, 0xddd28fbe, 0xa779f979, 0xf3d8ffc9, 0xe3f74d4e, 0x5ddd390b,
	0xff522f90, 0xdf08c7dc, 0x5773d5a7, 0xf933ffcb, 0xd7cbb55e, 0x906dbc9b,
	0xab076d0f, 0x8ad3ae9f, 0x842b5e63, 0x998fd6fb, 0x513b02e7, 0x468bfbe4,
	0x9990eef8, 0xe30a275f, 0x3e20064f, 0xeef15c37, 0xfa006662, 0xc20e6041,
	0x952929fa, 0xca4a8768, 0xc31f665a, 0xf5978a0b, 0xe4308179, 0x9657ad15,
	0xc8465fa0, 0x77db2b76, 0x6b83fbd2, 0xa813e204, 0xfd5d2a7d, 0x4ff04ea5,
	0x314c63cc, 0xaf96094b, 0x9f516943, 0xdf9d64bb, 0xebeb14a2, 0xbebe8f36,
	0x391e3fae, 0xf200adbe, 0x15c91441, 0x652af0a6, 0x429fe86d, 0x269b710e,
	0xa392c28f, 0xf8327eff, 0x3c09d9b1, 0xa31e9d82, 0x7bf3da86, 0xe05c6076,
	0x7faf53dc, 0xf9a9fa05, 0x74ac4899, 0x1c7b3d9e, 0x237c0624, 0x3bf06585,
	0xe622a3aa, 0x562912eb, 0x3f66b37a, 0x6b0fb54f, 0xeee2c47e, 0xe12cfbd5,
	0xeafbf439, 0xe0966ffd, 0x0fbabdba, 0x53d0d7ed, 0x2877c302, 0xab78025e,
	0xeb9f9296, 0xf2cc86f8, 0xb59fba61, 0x5d3f07cf, 0x29f2cdd8, 0x9ab723ab,
	0x05f99a2d, 0x0edab365, 0xa4f428f9, 0x0026f980, 0x4f8f369f, 0x9fbb4fb5,
	0xed7c1814, 0x50673c66, 0x0f6f7bbd, 0x4faa1bc4, 0xf660bc5a, 0x177eefd5,
	0x3fe5d9e3, 0x4719da7a, 0xf9d44aff, 0xbcfc039b, 0xb5d222dd, 0xf68b5a2e,
	0x7d23ad2a, 0xe3c922eb, 0x47f3971d, 0x70747e6a, 0xa8501c3f, 0x9df7f1f9,
	0xd338cf10, 0xfe89cbb5, 0xc74beede, 0x75f80659, 0xe92ffb91, 0x7f819dd7,
	0xab69fb50, 0x778bf06c, 0x95fb420f, 0x6c9a57c2, 0x9be54adf, 0xdfdfa79a,
	0xeec7710a, 0x02b7677d, 0xfe4fc1bc, 0x4fec15b2, 0xdae6c872, 0xea797805,
	0x51b71877, 0x59976bbf, 0xc9e7a1bc, 0xabbc63ef, 0xd0d3fa87, 0xb7c1cf5b,
	0xe8efc0f3, 0x1ba1fbd9, 0x0795e3fc, 0x8b79e267, 0x0f94cf95, 0x57e44926,
	0xc36f812d, 0x336f1057, 0xf448ebd2, 0xe7c9da08, 0x3fc1bd28, 0x23d3f7e9,
	0xe1ee2cb5, 0x9ef9fee1, 0x01cd71e4, 0xe6f478fe, 0x3c806e9b, 0xebd9a8d9,
	0x97e05721, 0xf1d296ff, 0xdfa02bda, 0xbfb9fb9e, 0xe77e9c92, 0x4e941fe0,
	0xf7e81b2f, 0x77e9747e, 0xd177871f, 0xf2fd2941, 0x4de015d8, 0x90ee9b8d,
	0xb0cbaf7d, 0x07efb29f, 0xba010718, 0xed13a1cd, 0x3cfdfa79, 0x369f3788,
	0xbcc42df7, 0x171683f2, 0x07d5a1f8, 0xd3f28f7f, 0x8c09ccf3, 0xbf1e124b,
	0x7ffd21ec, 0x73c4de2c, 0x3a77eada, 0xf1cf3f98, 0xc7befe0f, 0x5fb9cf89,
	0xf558f8cf, 0xf9f953f7, 0x0f9616b9, 0x6b73c6a0, 0xfb91fe77, 0x097a09cd,
	0xaf4e8053, 0xacfe325f, 0x7805c1e2, 0x5b8dac98, 0xf4a78f25, 0xbd3937c7,
	0x7f5578d4, 0x87d68a5c, 0x2c229c41, 0xfaf09efc, 0xdbf224f0, 0xbdc58db3,
	0x7cfacc7a, 0x589d0498, 0x62cb2b3c, 0x95f0d790, 0x372eb1c5, 0x278b4f8f,
	0xecae8c09, 0xfeeaf881, 0x9f3eb928, 0xfdb2b96c, 0x21fb94e3, 0xfb8c155f,
	0xd816a521, 0x2ebe890f, 0xe81fcc13, 0xea057963, 0xdfcf363e, 0xc44a7eeb,
	0xc8dac878, 0x46e7d411, 0x97eea1bd, 0xcd9de119, 0x676bade1, 0x3ef745eb,
	0xfda15847, 0x167e1f74, 0xcf6ebaf9, 0xf68872eb, 0x8ff76c77, 0x31576665,
	0x22f58239, 0xf74f99ac, 0x584a3b0f, 0x79f92ebc, 0x38f95b99, 0x8f9207f5,
	0x5de7bf53, 0xa13538dd, 0x31f2cc88, 0x19de3d2f, 0xf42b77c9, 0x8ccba677,
	0x44ce6ce7, 0xfb648ac4, 0xcc59d7b3, 0x63681edc, 0x4dd743f2, 0xc13eb3cc,
	0x7c4c3fce, 0x92f30d29, 0xf8a89e57, 0x5c2f9c23, 0xec1ac549, 0xe31368c2,
	0xf8bfe8d3, 0xa3bd0286, 0x61176e27, 0xf80fdabd, 0xa587d8d5, 0x77286dbf,
	0xfa50fd50, 0xb0227faa, 0x4cef51ab, 0xc1d2693e, 0x0c19c74f, 0xda1ac1eb,
	0x43d3e40f, 0x23c0133e, 0x0055673a, 0xe4cba23c, 0x13c925b2, 0xcc7e2b35,
	0x35fb56f3, 0xdc79f4bb, 0xd1f5ce04, 0xa9467a7e, 0x74fe3e79, 0x5dfbd3c0,
	0xea5fa4b7, 0xae69eb5c, 0xbd1bbb2f, 0x9d9a3624, 0x3d7a80c7, 0x3aadd3cf,
	0xe8166470, 0x4088aabf, 0xcb4f143c, 0xcbca1b49, 0x840c9623, 0x6f587963,
	0xf81f543f, 0x8eafb60d, 0x2435f6b2, 0xdce1ed82, 0xab4ed686, 0xd8304c8d,
	0x7baf8c1d, 0xf0467e79, 0x69892942, 0x73b76ff6, 0x746eea3e, 0x107bf4e9,
	0x6beda3e0, 0x538e1749, 0x1ba4191b, 0x7b576d47, 0x7f5d7ae1, 0xf21752b5,
	0x7f85ed59, 0x72fde7c2, 0x788398d5, 0x50ffdd48, 0xfe89dc1d, 0x84d892a7,
	0xc34ffd64, 0x39ff6ae7, 0x305c58f3, 0xccb566f7, 0x0cde830b, 0x2a63e7a9,
	0x14cdc2d3, 0xc094736f, 0x1cff907e, 0xa3fcc6c7, 0x4d7dce04, 0x83e73cc1,
	0xe03f9e16, 0x3f964e24, 0x744c84a0, 0xd95c7dbd, 0x8234f0fe, 0x961d01f9,
	0x00fc9a49, 0xbd012b12, 0xf01bb6a1, 0x303f90de, 0xaaa13e0c, 0x8e70e44f,
	0xaa7bbc84, 0x3ae79bff, 0x8b7d43b7, 0xcc579d83, 0x901d7d23, 0xdb83b02f,
	0x4710f9eb, 0xdcf0391c, 0xaf3d67e2, 0x765e5598, 0x852f08cf, 0x0cd075a7,
	0xbacefbc8, 0x50ef6cb5, 0x433b2117, 0x39c066e3, 0x97efac91, 0xf5a5cb8d,
	0x63dfad75, 0x365d7fef, 0x97d68f2e, 0xf7b1f6d8, 0xc9e60235, 0x6eb2c9ff,
	0x1cf94846, 0xf6cfd97a, 0xf97a34b7, 0x39dfc01d, 0x5b5fabff, 0x853c81ea,
	0x99e1993e, 0x9d7384b6, 0x86fe1853, 0x05eeaf29, 0x29846dbf, 0xe4fa04de,
	0x9aff07bb, 0x03dc7a01, 0x0e700cf9, 0x4171ac9e, 0x347d131e, 0xf225e2e5,
	0x5e798cdb, 0xad3d1f2a, 0xe003fe04, 0x063c5968, 0x5e3e05cf, 0x7e0ade35,
	0xde7e66e1, 0x7cfeb1f5, 0x503e763f, 0x237f32b1, 0x9d55e787, 0xbf4fcaaf,
	0xce44fe64, 0x069209a2, 0x0fa95eae, 0x3f7bd9f7, 0xe4217d7a, 0xe33d4241,
	0x3ea57a12, 0x6f7e0967, 0xae207fcc, 0x25b3e42c, 0x6f00cf9c, 0xfd5e4d56,
	0x21e59132, 0x426c71a9, 0xfe60b866, 0x5e282842, 0xe3d3e6bc, 0x30250ee9,
	0xb8eb0ad2, 0xd00dca95, 0x4af9e077, 0x5f3c6f7c, 0x3fc58ef9, 0x95f14aca,
	0x0f21795b, 0x5cffaee4, 0x0b96d0a4, 0xbf9e33f4, 0x299f5224, 0x9db13f99,
	0x054cbf9f, 0xc0d67bf7, 0xe0a71844, 0x4ebecf39, 0x2ed7ff2a, 0xca90bd91,
	0x89aaed79, 0x12f5095e, 0xe7a893cb, 0xc0c7057c, 0xbdc1dcf1, 0x7b69f704,
	0x07cf822d, 0xbbafa271, 0xb6180ed0, 0xddfa0e64, 0x08fcf6bd, 0x7ef513e4,
	0xa5779d8b, 0x720083f6, 0x7a40fc3e, 0x3944e6cc, 0xa720c0fd, 0x52e5e81f,
	0x45ef6e3f, 0xfb1c7b4f, 0xa8fef173, 0x9c4eef41, 0xd915ee63, 0xe8dbdefa,
	0x93863841, 0x8bd80750, 0xcdde3a57, 0x64f9fd56, 0x805bff8a, 0x29fe2a2e,
	0x9e00171d, 0x3ca6b36e, 0x8def8b27, 0x8b9e3474, 0x8b035a75, 0x95dbdda0,
	0x0842d6c7, 0x434176a6, 0x4aa10811, 0x7285225f, 0xfa464f01, 0x8f6d4bd6,
	0xdd14e999, 0xbb45de07, 0xb5dfa545, 0x9d21c6ab, 0x85acf434, 0xf03daffe,
	0x56e009ae, 0x211df8e9, 0xcffbddb9, 0x31af1656, 0x1f9ee78e, 0xb4920537,
	0x8a55592f, 0xdcfc51fd, 0x8a4fe5a7, 0xebe0109f, 0x27e3525f, 0x93cf8c94,
	0x4ae5a7e0, 0x73faa3f0, 0x6b8e5c35, 0xf209ff60, 0xdcf33d08, 0x59dc7405,
	0xba7c82a2, 0xf188977c, 0x4e7eda5b, 0xf7213bae, 0x7436a7cb, 0xe5c179c0,
	0x4fc8084f, 0xf839f84b, 0xbc1cfcb3, 0x72af8f31, 0xecf5087e, 0xb0be7c80,
	0xa30fced1, 0xadd9a8de, 0x04ddfe7f, 0x9e61e57f, 0x443fbf2d, 0xc46fb73d,
	0xcb8579ff, 0x499b12f5, 0x48dfbe7b, 0x260de18f, 0x6e775e5d, 0x94befeb9,
	0xf7e7931c, 0x82f72798, 0xc85c4099, 0x8c4d6527, 0x0a263e01, 0x32dfa033,
	0x7f6a5f2e, 0xede95623, 0xfe90fcba, 0x56c8de7c, 0x51bcf9fd, 0x79f3fa6d,
	0xcfeb37a3, 0xd6155de7, 0x66bbcf9f, 0x7d5d78f7, 0x5d3ae46c, 0xa7db6bfb,
	0x62e3eaeb, 0x9fb5d25f, 0x574f39d0, 0xbb75d49f, 0x93e4fdae, 0xa7ef758b,
	0xef75abc6, 0x42bd3faf, 0xefa1bf57, 0xb1f6ba9b, 0x1d7f4ca5, 0x0530bc6e,
	0x78a809ce, 0x6c8f7c39, 0x7bf3c172, 0x12ae4c8a, 0xcfb773ed, 0xa9650253,
	0x54eafc0f, 0xfadcb67a, 0xfaed14e1, 0x3acc465e, 0xd56e53fd, 0xe56cffd7,
	0x947900f9, 0xcff1285f, 0x2a0fd618, 0x4e40e76f, 0x6b4c3686, 0x878fa22d,
	0x074c2f2c, 0x9fc0da79, 0x9d9c815f, 0x8bab3947, 0x51ba85ad, 0xdb9b36ce,
	0x81f3915e, 0x6f9842ef, 0x271e4229, 0x46640196, 0x501b9a91, 0xc214244a,
	0x1e7e71e4, 0xabeeb8dd, 0x1f11bdeb, 0x07b31b16, 0x04c09e2c, 0xcc3f2f49,
	0x9aa9c8bf, 0x24e86920, 0xed741aba, 0x696f1e2c, 0x94a6eff2, 0xe9f3bfea,
	0x3cf0e5da, 0x3b02f223, 0x3c5bee07, 0x13d026e6, 0x0a2e3f5f, 0xd8b84f4c,
	0x805a3b39, 0x747d2c5c, 0x8fbb5b9e, 0xebb1a5bf, 0x17c3496a, 0xb7f852c3,
	0x57a63645, 0xaffa36b7, 0x2608025e, 0xe8b9dd56, 0x1f2878bc, 0xa32bb5f6,
	0x97c42f76, 0xe30b3849, 0xd61cb5db, 0x4503167f, 0xc5cb8a36, 0x3e6176d7,
	0x8f9e08f4, 0x9f853c3c, 0xfcc6d53b, 0x56e2df13, 0xda3df7ec, 0xf859e62f,
	0x03e6e8c6, 0xf984cff3, 0x567967ef, 0x9891474b, 0xde97d689, 0xcdd71c3f,
	0xd5db6370, 0x4bc0926b, 0x836a99e1, 0xe19c5638, 0x08ea32af, 0x3e74fe43,
	0xfc8c55c0, 0x37f783e8, 0x7fea52d8, 0xcbe46f7c, 0xbb2bbc9c, 0x89f44247,
	0x0dcf665e, 0x46e247b8, 0x8bad57e8, 0x247b86e9, 0xf54bd852, 0x28b5b792,
	0x29ebf2ff, 0xefb0a3ac, 0x74a3aead, 0x78c2779e, 0xf2f4dbb7, 0x3bbf91a8,
	0x8933cd93, 0xfa062dfc, 0x2c7b7dbe, 0xf7073ae9, 0x9f7ac05f, 0x9f97272d,
	0x53f2e77f, 0xe60992ef, 0xf388a573, 0xc2f9c43f, 0x7a54ff38, 0x62f672ea,
	0x3f7d60c1, 0xbb417d74, 0xb8ca5491, 0x6abe70ef, 0x9045fddb, 0x6014a1af,
	0x7eaa65fe, 0x7bbaae86, 0x3ae7c702, 0xbf8a83c0, 0x6ebc0635, 0xe007efe0,
	0x69f14833, 0x0373e1d2, 0x7632f3e2, 0xc3f667c3, 0x55cfe896, 0x53bc70f4,
	0xc616ac7f, 0x6bf3773d, 0xd727e0a5, 0xc601f2dd, 0x1c7b3ecb, 0x9a7bfa8e,
	0x8f3f5471, 0xe305538e, 0x09fcdcf4, 0x31c5c78f, 0xccfcd48e, 0xabf7bc68,
	0x77aaba76, 0x3e78ac1b, 0xd201586d, 0x8b7edce7, 0x973ce00f, 0xe71ae2c9,
	0x063e4ff6, 0xc6d9f47e, 0x9d2d4cce, 0x44f0fdcf, 0x77f699a9, 0x5289df6e,
	0xa7d091c9, 0x8bdafbea, 0xbf0529bf, 0xef1bcd4b, 0x726b3be7, 0xce0bf7fd,
	0x0f169f9f, 0xfdc54710, 0x063c8901, 0x5e3f70eb, 0x3ff8f4aa, 0x14ad7f67,
	0xf2f140f0, 0x870bc40b, 0x8a538d47, 0x790cdfd6, 0x23d7f28b, 0x68471636,
	0x0acd3c16, 0x13e55fec, 0xb89fec2f, 0x0a24ac6f, 0x98c92394, 0x51fefa7c,
	0xed95c79e, 0x79043d36, 0xb79f96ff, 0x699d00c5, 0x07cc115d, 0xc5764e53,
	0xfbc674a0, 0x33edb07c, 0x11fc0947, 0x769d75c6, 0xb85d4075, 0x25b1f8a3,
	0x4e4dffb4, 0xa43df719, 0x07a76f72, 0x4b66c7f2, 0xf9cfff78, 0x66f5114e,
	0x76eb6cd6, 0x1b0a3ded, 0x0ed9ecbf, 0x34969dfb, 0x2fb09cf5, 0x49e1ce1f,
	0xe82deca4, 0xf02db77f, 0xa6599436, 0xa51defae, 0x7f5d6ced, 0xfff883c8,
	0xa21f23c4, 0x79968ade, 0xadaf203b, 0xb3c159ef, 0xb78c0c9d, 0x3ad8d25a,
	0x0a8f96a4, 0xbf2057fe, 0x9c5eb2c7, 0x478a7109, 0xffbc7e6d, 0xe6b60602,
	0xbe6cfed0, 0x1d06483b, 0xa6b8b847, 0x375a06e2, 0xe0e3f7d3, 0x86b2d27b,
	0xf8668fb6, 0x2095c286, 0x35e3e10e, 0x4ea1c39d, 0x4961ce30, 0xdc0d78fb,
	0x734a66ff, 0xe2a738b1, 0xecfe07cb, 0x7d68bbaf, 0x356ea6ac, 0x575625d4,
	0xe47b55e7, 0xabd7cc43, 0x6feec03b, 0x1c607419, 0x7dab17bb, 0xe647de1c,
	0x8cebe348, 0xe7b5d89d, 0x0628be58, 0x7c58d232, 0x89c988a9, 0xf14a7f1a,
	0x0a9fc79e, 0x22e31f89, 0x3bbbb039, 0x229e5212, 0xf1e30e58, 0xbfea3ca7,
	0x4fc6a942, 0xcb17880a, 0xe580d222, 0xe586d218, 0x658224d5, 0xb2c2e931,
	0xe961f484, 0xca112e25, 0xee7f934c, 0x2f97d04c, 0x165f5198, 0x787b9eee,
	0x9f23c108, 0x29a5ba3a, 0xaed9bf2c, 0xa7663d94, 0x7fd23ef0, 0x8f3b1f5f,
	0x519a0412, 0x73bb22be, 0xe6e88fd1, 0xcdb67432, 0x07fd8214, 0xdaca1ae2,
	0xc19973f1, 0x21bb0f47, 0x97d672de, 0x0bf0bf3c, 0xdbe7d269, 0xcfe8083f,
	0x646fd453, 0x9f2a3ef1, 0xd77c005f, 0x6eb45c01, 0xb9e176b2, 0xc8eaf329,
	0xd63f7843, 0xd7dc66d3, 0x76f7c9aa, 0x9aacb9c0, 0x4dbdf367, 0x6abf2124,
	0x464d659e, 0xc29e3dc4, 0x4be3ccdd, 0x24a71f50, 0xfdaebdf8, 0x27d83ce1,
	0x15e3a77d, 0xf6899fe4, 0xdaabe47c, 0xe03909e8, 0x1916fdc0, 0xc9dfdaf2,
	0x0e77bfee, 0x362dd2e3, 0x179c3a6f, 0xbb25fbe8, 0xdfc54877, 0xcd975213,
	0xb1d3c1a5, 0xa8e8aa46, 0x98d0bf60, 0x09a37c43, 0x83d1b179, 0x1746cef5,
	0xc7379fd6, 0xf9878c36, 0x40ba1764, 0xdabacfde, 0x05911c5e, 0x9e05c7f9,
	0xe6bf3a26, 0x132b9fac, 0x118cff40, 0x12ed54bd, 0x44f163b3, 0xce690bc8,
	0xfa044799, 0xde329d7e, 0x4f0a67fa, 0x66b5e4b3, 0x2b8f71d3, 0x68a3288f,
	0xc9e3fb39, 0xc7bbd056, 0x1e2a36b3, 0xeab9ce5a, 0xb4941716, 0xb19bacbf,
	0x6fef333f, 0xdfda15bc, 0x8928fd0f, 0x7d783a7e, 0x2c91e3b6, 0x46f3ff78,
	0xcecf7082, 0xfd0598de, 0x399c2d1c, 0x3b36e007, 0x8e6f784c, 0x5f662f91,
	0x4a3e22c8, 0xc85d2f87, 0x74d772c3, 0xff20d5ff, 0x6f4da60f, 0x97f952b1,
	0xa0d5fdf2, 0xdda5361f, 0x4d87f588, 0xbce34d91, 0x5ca99f58, 0x4198e145,
	0x90907f30, 0x80ca5b1b, 0x415d94ee, 0xbc3fd05f, 0x8cf9e376, 0xc319fbc4,
	0xad323ef8, 0x3e3da457, 0x2ba6e213, 0x40124ef7, 0x11d9534e, 0x9a861755,
	0xe1389ac3, 0xf907bb44, 0x610a4ab8, 0x42eabbfc, 0x7cbfbe1e, 0xf3bab93f,
	0x19fb035a, 0x158fef86, 0x0faceba9, 0x7b95ebfd, 0xa3fa7ed9, 0xcbcea266,
	0xa5aae707, 0x245e757c, 0xfabd5124, 0xa1ebccbc, 0x5dcf3885, 0x10fb7f72,
	0x2d984fdc, 0x81f7b7f7, 0x9a7cf2ff, 0x32d65f5a, 0xf6925a63, 0x05f68669,
	0xd8f5ff6a, 0xa3cf08de, 0x4add44b6, 0x5b1f4bdb, 0x00e7df12, 0xb1ef12dd,
	0xffb54cbf, 0x4d6f0855, 0x87dec8ae, 0x927d4742, 0xb7f7ae96, 0xa99bbdc0,
	0xfeb15ae8, 0xf43596e1, 0xde6de7fb, 0xbea75c32, 0x029d704c, 0xf46af2f9,
	0xb31a455d, 0x5c2eab53, 0x4cf4b443, 0xf744bfe0, 0x7f2a6dfc, 0x65b07dda,
	0x798ebe7b, 0x9c6915fb, 0xcec4246e, 0xa9196ca1, 0xfffaffdb, 0x38567c70,
	0x31c052ca, 0x8e19bfe3, 0x4e5688ab, 0xeb147013, 0xe1fdff9e, 0xc7014f28,
	0x7055ffac, 0xb512ed18, 0x24bb7374, 0xc8afe4cb, 0x9be67b07, 0x7a67b426,
	0xf2192433, 0x0532884c, 0xd21cf5ed, 0x2cfb87ff, 0xfc602a60, 0x116580e3,
	0xa449e3ee, 0x7d04ca55, 0xbe42b215, 0x84d6a85d, 0xde7d39f6, 0x7ea78d29,
	0xed158662, 0xfe05bc88, 0xafef6c1a, 0xd5d2c5ac, 0xc7449370, 0x35d85619,
	0x77faf40e, 0x6aaef795, 0x5ef4e8f1, 0x6177d708, 0x67b022ee, 0xd53fb16f,
	0xd974fb02, 0xc0c7fe69, 0x53c815de, 0xc9b99d2d, 0xf5bd33de, 0x9a9e07d5,
	0xd6ff7e09, 0xc0abf1e9, 0x0b6ad9df, 0x3d030e47, 0x7b4145fe, 0xe103c47e,
	0x975a02d6, 0xaf684c9a, 0xdde11948, 0x52dea1db, 0xefa26de4, 0x83fe82b7,
	0x9e122df6, 0x48db591f, 0xb13c42a6, 0x41d98db9, 0x71cf6fe1, 0xce6ffac1,
	0xf787b3a0, 0x006dff66, 0x740fc3d7, 0xc2a758b6, 0x1d6de07a, 0x1cf565e4,
	0x82aed70a, 0x8335be78, 0xeceba7bf, 0xae78a6d6, 0x13cf534b, 0x7e99113e,
	0x4df16cee, 0x5e7cf583, 0x1fdf6135, 0xaefbb885, 0xfe178e4c, 0x87534f3e,
	0x526a44f5, 0x96ce8fd7, 0xdbde7419, 0xfefa609e, 0xd0ffb41b, 0xde0f9c34,
	0x5637da5f, 0xed2dfbc2, 0xad276c74, 0xe015c7db, 0x6d5b437d, 0x8e37deac,
	0xbf8d57cd, 0x309ac75b, 0xf8e76efe, 0x6017e7b0, 0x65fac99c, 0x9adcde76,
	0x1cfdb0ab, 0xf20337c9, 0x3f9c1c98, 0xccbef8d4, 0x44cad3e3, 0xda6cfefd,
	0xfcc11fb7, 0xfd62b4d0, 0xbea16b73, 0xc5ae216e, 0xc3cb7760, 0xb31fcff4,
	0x267c78f3, 0x7c7885c9, 0x826029be, 0x1268e678, 0x196a92c2, 0xfb81af2c,
	0x11c24783, 0xafd638b2, 0x48e7a885, 0x61e2be38, 0x57886d07, 0x0ee2ff04,
	0x79061025, 0xe3cec278, 0x5fb4b917, 0x14557f88, 0x1824cfa6, 0x6af7c0c7,
	0xb3d991fd, 0x4a918e30, 0x930accbe, 0x0a5becef, 0x638f792f, 0x890a05d9,
	0x4907ce46, 0x5b9da2ef, 0x4bdd873f, 0xf9807f5c, 0x83fbea4b, 0xd607e676,
	0x522388a7, 0xf3883eb9, 0x7063f120, 0xfdaeb184, 0x53f06cc4, 0x089a576b,
	0xc6d4cde4, 0x2d7bc15e, 0xaa75768d, 0x9da89f3c, 0xfdfa01c5, 0xa0afee17,
	0xe674010f, 0x9b12ca7e, 0x79fd774a, 0x7d9cf57b, 0xde9b972f, 0x179e3285,
	0xcacc1fad, 0x78027341, 0xcf92bb4e, 0x997372a7, 0x2580fc1b, 0x9c21b71d,
	0x95ce374b, 0xcae57ee1, 0x6f308b8d, 0x12ebc54e, 0x97f01f83, 0x8c9709b6,
	0xb376a98b, 0x76a807ea, 0x481fd1bf, 0x67857df5, 0x8661d21b, 0xd5f71f2b,
	0x338d6666, 0x89ab7d41, 0x84f8fa32, 0x99bcf39f, 0xf40f35dc, 0xf9eecc8d,
	0xbe7f0ef9, 0xa1fdee15, 0x472c7b32, 0x67ef84cc, 0x55d3fd0d, 0xb6b71e50,
	0x8fb7a029, 0x2be2747f, 0x6d4827e8, 0x9f8bec0a, 0xa79f9893, 0x20b909d6,
	0xc7137ee2, 0x4bc76cfb, 0xecdba04e, 0x79e13fdc, 0x4bc75ade, 0x5cf7ee78,
	0x4c798cd4, 0x596d6db3, 0xce7a1a99, 0xeb227dce, 0xaa3c7952, 0x873cf09f,
	0xb390d8f7, 0x971c0179, 0xff939fef, 0xfd9a7c23, 0xa65a6ff3, 0x1a53b71f,
	0xfafce71d, 0x2ab012b4, 0xa5f06f90, 0xcc9f9422, 0xacad13d9, 0xfefefd7f,
	0xeceff063, 0xf2a47c81, 0x6defe5df, 0x27f3a418, 0xb836f712, 0x8f0f79f1,
	0x272afc23, 0x2a7af1be, 0xbf11370f, 0xf845f719, 0x3dea177d, 0x314d3717,
	0xf3c29fdc, 0x17c2be5b, 0xde41dfc3, 0x27be138a, 0x655cfdf8, 0xf6cbde22,
	0xc63f7e2b, 0x8333e23c, 0x47c2317e, 0xb1e9d5fb, 0xfd7d3eb9, 0xfd7d0ae6,
	0xfbf27f16, 0xf6370eda, 0x83ded14d, 0x3e853d34, 0x8871e328, 0x08171ccf,
	0x0167b80e, 0x90b575e3, 0x93fa89d7, 0xadcaebc5, 0xcc5f7c6c, 0x282bcec6,
	0x5d0836f2, 0xfb82fe83, 0xa615cbfc, 0x040e205f, 0x4b97a8f7, 0x61a37dea,
	0xc107af7e, 0x2a832bf3, 0xc7adb672, 0x0e6f74fc, 0xc813dbde, 0x9c18fb65,
	0xc1f8d5ef, 0x7a4f42f9, 0xc0f825c6, 0xa70299be, 0xa40783e1, 0xe0f81588,
	0xe7966281, 0xb0dbe092, 0xdf6a4e2e, 0x33beeb2c, 0x0e3bf096, 0x02d76e70,
	0xee9468fb, 0xcb9f241b, 0x6ecfe9a5, 0xecdd63f6, 0xa1e5de98, 0xdcacdbbc,
	0x70f40b3c, 0xd25be433, 0x86d978f5, 0x7ac2d6eb, 0x9dbd98ac, 0x1c513f10,
	0xa7ac0f26, 0xf1098a4d, 0xc5639cd6, 0x10ad76f5, 0x5dfd6974, 0x5c212e25,
	0x4b8295e7, 0x17c9e3e6, 0x78ced89c, 0x6fdfcfdf, 0x4117053c, 0xc8e478e3,
	0x5a9f8c54, 0x47cc26bc, 0xe4298791, 0x6f7924cd, 0x966de3fd, 0x0a9dc292,
	0x6ee929ff, 0x519e638e, 0x7a4a628f, 0xe52ec79f, 0xced9e673, 0x33b1c437,
	0xc18a2e5e, 0x39dc42f7, 0xd8f94052, 0x6eae7a05, 0x4d5ff9ec, 0xb87ca0f7,
	0x9303be59, 0x30e566db, 0x7bfa7bd7, 0xa3f152a8, 0x7854978a, 0x9d7f8e90,
	0xe809b39f, 0x845713ee, 0x49f71f88, 0x57644ac7, 0xffd07c92, 0x6e5e9854,
	0xc02ebc96, 0x1f837897, 0x594d54e3, 0x0790add3, 0xd27922dc, 0x3be82fc1,
	0x97b0122e, 0x72f4b8d7, 0xfcad96a3, 0x735fc4fe, 0x6f7c633d, 0xbdff2535,
	0x1d380f90, 0x76a63b5a, 0x2a51fe41, 0x8624213e, 0x978eb0f3, 0x4417a05c,
	0x96d78333, 0xed5a5f62, 0xdc7f1537, 0xbf6361df, 0xc5685183, 0xf1c62df3,
	0x845e48d6, 0x27850d67, 0x7461f504, 0x184bac7c, 0xd279b4e7, 0x5ed35588,
	0xf08898ca, 0xf0b2579d, 0xa4d60077, 0x4f153be0, 0xb6cf9587, 0x7fcfd2af,
	0xf8faf40b, 0x301ff65c, 0xbfe1ae0e, 0xdff193f7, 0xd9b5d061, 0xbded7e0c,
	0xdb065281, 0xabc233b7, 0xc52b3be6, 0x5294fcfa, 0xdf98bbaa, 0xf4d8feb1,
	0xab064242, 0x3a706075, 0x1cf4145e, 0xacc54b8b, 0xf97b44d6, 0xd6b3f5c1,
	0xcf1d6214, 0x7cefd147, 0x511c3bf0, 0x2d48bf7e, 0xbc114f3f, 0xba2e2155,
	0x9570ef3e, 0x7e3a0e29, 0x7661d769, 0x8d9a214e, 0xeff20ff3, 0x768ef08d,
	0xed1e7e32, 0x7e996174, 0xb803f7d2, 0x95da3ebf, 0x6cf881e6, 0xbfdd9334,
	0x5feefc68, 0x7f5f021d, 0x463ef8da, 0xb21bf71c, 0xd47ad9cb, 0xfd1dacf7,
	0x69f881a1, 0x180ff762, 0x7bfe8dec, 0xda18a409, 0x776e411d, 0x28fc6e5c,
	0x68f21fbf, 0x8eb5691a, 0x01989827, 0xcfd3757c, 0x7f7bc1ae, 0x6a0df3d5,
	0x880ba53f, 0xfda6bb6f, 0xedc08714, 0x7ef847a6, 0x067bf1a9, 0x641951d7,
	0x9909fa89, 0xe46112f1, 0x9dc3e0e7, 0x558f7744, 0x045e35ad, 0x0624c87a,
	0xf8e83a66, 0x6ee327f5, 0x3a5f47a8, 0x95e47683, 0xb47f33e2, 0xf0c7d76a,
	0xbdcadd3c, 0xe73c9765, 0x89f88414, 0xbc09ff06, 0xc9e7c2cf, 0xf9fc83fa,
	0x24a185e0, 0xe5ba4974, 0x33c07be1, 0x2f17cf3b, 0xe903fb81, 0x079aee3c,
	0xfdba70fd, 0x359fc3a3, 0x59f3d988, 0x0cb9f912, 0x2ba90331, 0xad19ee0f,
	0xc152f2e0, 0x1ffa25e5, 0x7d0237e5, 0x5c992fa2, 0xfd3afbf0, 0x424692fc,
	0x4dddfa56, 0xc10ff896, 0xeaeb53de, 0x1ae89bfb, 0xd5f80534, 0x9546e4ca,
	0xe482e0d7, 0x70ed9a72, 0x3e0e7f22, 0xfec27319, 0xc3d38145, 0x89bc8fc6,
	0xdb453ef7, 0xd7570245, 0x10105e0f, 0xff024a03, 0xeb61fb03, 0xd4ef2a8d,
	0xc1c6bc7c, 0xddf81de5, 0xcff98abe, 0xbf515eaa, 0x3e50e1db, 0x19effadf,
	0x0766ce70, 0xffe53bf0, 0xcf821063, 0x1deec55b, 0x9fef56eb, 0x69318df3,
	0xe6ea1def, 0xf90483f7, 0x857bf57e, 0x0ea3cc3e, 0xd61f88da, 0xbe5cf7c9,
	0xe9efe674, 0x3bf51ffd, 0x6969ffd5, 0x0eb7f7e2, 0x22d97c63, 0x05cd7708,
	0xc718593d, 0x6edd607b, 0x7aaaeeb6, 0x4bc4e483, 0x7ce69ed0, 0x4c9c7c0a,
	0x7ce31d1f, 0x66eea41d, 0xca5f2928, 0xd06fe7ba, 0xb1a42d75, 0x2e9f16c7,
	0x770ef3c4, 0x23c62f13, 0x93b56eef, 0xd1af0690, 0xe8dc6c4d, 0xbff8fd6a,
	0x935ee3e6, 0xe51ae8ce, 0x25471af7, 0x58fc1d9f, 0x8451ef55, 0xd2be61da,
	0x057fcfc7, 0xf361efe7, 0x748be7ef, 0xecfebeb6, 0x9fdf9113, 0x48ede74e,
	0xc3acf7cc, 0xdb9237f4, 0x367c5d32, 0xf8199f81, 0x66dcb53c, 0xb36e465c,
	0x3e5d3df0, 0x3f6eb09d, 0x48f76115, 0x7ec9d53d, 0xc708cc7f, 0xab9f3e50,
	0x77bc25b3, 0x5b189ae9, 0x73b55357, 0x517bf267, 0x788c5e39, 0x3c991ac8,
	0xf1c9c90f, 0xeece9c1a, 0xa67b8575, 0xcb4d9e21, 0xfbf02f3c, 0xcf842574,
	0x1af629ff, 0x7dc119f8, 0x91e80f16, 0x2ab67dee, 0x7deec390, 0xcaedaa96,
	0x770c7a40, 0xf1e8adfe, 0x7c075ef7, 0xf6097e13, 0xf788bb74, 0x5fc719d0,
	0x77e070ed, 0x852ffafd, 0xc289f29d, 0x9d964ff4, 0xc05cd9e1, 0x8b2c93d6,
	0x5ca5ef1e, 0x7089673f, 0xd8ea9d94, 0x1367d300, 0x1e40be38, 0xba862cee,
	0x4777b3a2, 0xd5403b71, 0x2aad8f9b, 0x804e6f27, 0xb10b29df, 0x43fb2fdf,
	0xe9c60f2c, 0xb47e632e, 0xb8abbe11, 0x6f44255e, 0xe19e4e67, 0x833f6011,
	0xec170444, 0x27edab57, 0xa6bdd847, 0xfbd872df, 0xd13ba7ed, 0xc19079df,
	0x33d72729, 0x463f380b, 0x5d01af41, 0x8c9fa614, 0x6feaa07c, 0x7aea3e75,
	0x9bbbb6a6, 0x2f18e3e3, 0x78d99bb3, 0x96150a74, 0xb12eb64c, 0x1e997f7b,
	0x1643cfa4, 0x4048af58, 0x59e94b1c, 0xedff1777, 0xd8c71e10, 0xe9dc0ae1,
	0xec13e0d4, 0xdce3d451, 0xfcf28cfe, 0x018ed553, 0xd15e34fd, 0x71621dc2,
	0xfa60515f, 0xa7ebd24a, 0x83aa73fe, 0x045dff08, 0x5893f607, 0xfa7ad967,
	0x36cf9f10, 0xa8ed9e7e, 0x75c1ac89, 0x9549e397, 0xdea7169f, 0x9547faef,
	0xbb326d9f, 0x91e80f67, 0x09dcef4c, 0xedf00076, 0x8138df49, 0xbf28d9f2,
	0x586bbf82, 0xb0ef35da, 0x0e8bd699, 0x24580fc0, 0xf388abe4, 0x40b7f41d,
	0x3bef8f83, 0xf023ff1d, 0xf4927451, 0x46a77fc3, 0xf2073e1f, 0x112a7c0c,
	0x3feff21f, 0xc3fefc2c, 0x4822fe70, 0xaa2202e9, 0x591a2fd2, 0x7606dab4,
	0x05e249d8, 0xb227ae3b, 0xee1634c8, 0xecccd833, 0xb8fd7e98, 0xea9fcd91,
	0xb7e808b7, 0xf67d2751, 0xe2ef5a62, 0x80b51bf4, 0x22567bb0, 0x6ff8308e,
	0x7f665caa, 0xe78e5e35, 0x4d0dede0, 0xfef3cd36, 0x7db4edf6, 0x83be427e,
	0xdc74df20, 0x3dec15c9, 0x4784b769, 0x3ff327e5, 0x654abe98, 0xb4e9be6f,
	0xafa05c23, 0xed334e81, 0x70a36ac4, 0x890fcd1f, 0x74766fb0, 0xb878fe54,
	0x5a58f977, 0xfd0578a0, 0x1ee3cdde, 0xebff9e6e, 0xe4e5634e, 0x7fd7a674,
	0x8bb34bca, 0xf2676e95, 0x1708c938, 0x89d7e7d3, 0x97d7ce4c, 0x3f9f5f25,
	0xb8ce7e71, 0x8ba0a156, 0xf6bb516b, 0x7e24e713, 0xa129ae9f, 0x3d3e551f,
	0xca33bfc5, 0x020bb2d9, 0xbfba87f2, 0xfbea4cb3, 0x3f14addd, 0xb8880ecb,
	0x4b4df84f, 0xed8e96c0, 0x6bd76c24, 0x04ec2f8a, 0xc7df8206, 0x9f9a9a98,
	0xe51abd55, 0x04450d74, 0x41ccfb02, 0x9e8307ee, 0x57a743bd, 0x3e78401e,
	0x097fdd01, 0xcbb3f77b, 0xec2935d7, 0x89bf92bf, 0xa1f2a7fd, 0xe3512f1a,
	0x129f2a12, 0x31f101b2, 0x23930679, 0x01ec7eba, 0x1fae9ebf, 0x6f5053c5,
	0xc75b3bfc, 0x6a2f0cad, 0x8eedc37c, 0x4fdf81d7, 0x53bf01e5, 0xff23d77f,
	0x77984bcc, 0xfe674c17, 0x6f9702d9, 0x0369d01a, 0x60ddbfcf, 0x278ce763,
	0xf064c457, 0xfbdfd4db, 0xffee60d8, 0xa3cc0d5d, 0xfd64121a, 0x08748b0e,
	0x954f8692, 0x096f8255, 0x2ab0cbc5, 0xa72f9f36, 0xdf76759b, 0x2ed3a83c,
	0xe0f74a6f, 0x315561f3, 0xdbfa10a1, 0x689053b2, 0x77e0437f, 0x0efca84b,
	0xed612069, 0xf10c75ef, 0x6f14f1b2, 0x38bbb858, 0xd3569f31, 0xe51762dc,
	0xddb75693, 0xb59f4cdb, 0x61f302bb, 0x6357c13e, 0xf93c0798, 0xfc092ed5,
	0xbe5c17b4, 0x3ab9e0db, 0x1ae88f1f, 0xfb7d7102, 0xb6ce0cab, 0x9e23bf7e,
	0x0fb8e2c7, 0xe76ffc70, 0xc4e93ceb, 0x9850efdf, 0x3d5ee05d, 0x4d3bf746,
	0xdb4dbdaa, 0x93f412b5, 0xaf721e99, 0x61bcc22e, 0x4733fe95, 0xf3c277fa,
	0x1aaf8399, 0x47b7e70f, 0x8b49886e, 0xdd3f77e9, 0x2f7a4a62, 0x7f5cbdc1,
	0xd1eff850, 0xf9397fc2, 0xd399db51, 0x760f2d2e, 0xdf031fce, 0xcbef843f,
	0x1dbac89e, 0x235b1bef, 0x503fd813, 0xcb82fef1, 0x1b3d26bf, 0x004db5e8,
	0xf7c1bc9c, 0xdf71d4d5, 0x547ca348, 0x3c83dec2, 0x7feb21bc, 0xbca53847,
	0x4b7d12ad, 0x1ad9ebb4, 0xaaa8bbf6, 0x8f80915d, 0xe5df57d9, 0x2e87e47e,
	0xa78026ff, 0xf461fdae, 0x64ef97cb, 0x12909fbf, 0x4788574f, 0xf826ff3a,
	0x6a1ac2fd, 0x1d39c30f, 0x4023da81, 0xb67ce0ff, 0xc3dc129f, 0x91ac95f8,
	0x60a5bef1, 0xd39e2f64, 0x9f6dfa19, 0x6a47b617, 0x9615ecf6, 0x343bf06a,
	0xe5fdc618, 0x9e550ed1, 0x1218de98, 0xbe441459, 0x817bb1cf, 0x677e21ef,
	0x1b647d83, 0xcbbb17b3, 0x6dd5df98, 0xd0f18d0e, 0x69f9dd76, 0x79dfd85e,
	0x7117ef7e, 0xcfb1d27f, 0x099c1312, 0xe4df5b3e, 0x5e8ddfc1, 0x80b8933f,
	0xb63ae8cf, 0x9b33ea02, 0xee4df815, 0xc2a0bd7e, 0x4cdbf935, 0x7a0cfe0e,
	0x8c9ef901, 0x31783907, 0x74d3ad9d, 0xf57b439d, 0xb3c19998, 0x983e308f,
	0x0a3fee9c, 0x6294cf78, 0x8cc4fc04, 0x1bd3088a, 0xdf88999d, 0x9c512d9a,
	0xcc3dd0df, 0xb3d9ab8e, 0xd557e50d, 0xf80f8053, 0xf0c9cc7d, 0xb86b2d1d,
	0x627b28de, 0x06a6f0a7, 0x22e993be, 0xd96fa78b, 0xfbbf01d9, 0x0b88aa49,
	0xaeda33fc, 0x7e167663, 0x7f3e4127, 0xf180bebf, 0x4b78d98a, 0x8542fa35,
	0xf8de893f, 0xca5f20bf, 0x673f5dab, 0x7ec6237a, 0x89f383a7, 0xa0d38f4a,
	0x7413b2b7, 0x7a532639, 0x158e7ed0, 0xaa3f61a4, 0xcddc831c, 0xa4cd7ae3,
	0x1540fc24, 0x05ce150e, 0x30dde9ae, 0x2e8ae4ee, 0x16ed7f9c, 0x299ee109,
	0xd1ef0bfb, 0x707feff0, 0xeb7c3f3e, 0xc9ff786b, 0x409c9fc6, 0x09b6d6bc,
	0xedb57f6c, 0xac0b7c84, 0x3127a11b, 0xbe46e07f, 0xf7e26fbe, 0x6518dd0f,
	0xee8daff8, 0x395ee095, 0xcff29f95, 0x8b7bc61c, 0x0216236a, 0xae0bd676,
	0x1a4d7100, 0x05ff57c8, 0x2765d76f, 0x00008000, 0x00088b1f, 0x00000000,
	0x7dd5ff00, 0xd5947809, 0xe6f9f0b9, 0x4cc92d9b, 0x327bec98, 0x42512c21,
	0x20824098, 0x00849320, 0x5004c28a, 0x1101b640, 0x69436482, 0x67fb5a2f,
	0xa5c88830, 0x8aadac6d, 0xe8dc075b, 0xa08096ad, 0xb20e8341, 0x94d6aa14,
	0xed16820b, 0xc9ac82e0, 0xfdc2d688, 0xf7dffd69, 0xe664e73d, 0x7a0092fb,
	0x1bfe7dbd, 0xf9c39f1f, 0xefbefece, 0xce73d779, 0xc62496b0, 0x05fc18d2,
	0xc6763db3, 0xd1bfc5be, 0x1f3194e1, 0x66255063, 0x18b3fc3c, 0xdf7f66b3,
	0xcdeefc5c, 0x9bf50c9d, 0x8f5cd9e2, 0x7a6bb18d, 0x812b1819, 0x3dfe36cf,
	0x76a061d3, 0x1b7c0ab5, 0x1d1fd8ce, 0x940738de, 0xdebb4457, 0x153f42b2,
	0x23571583, 0x3a9ee514, 0x640e7660, 0xfa1cb12c, 0x110f8029, 0xd81ca9f3,
	0xd0567cdd, 0x7c094938, 0x660c665c, 0xf98c78e3, 0xad9577f9, 0xedc38366,
	0x9a4e1c73, 0xf00f7c07, 0x67b7acef, 0x72de7860, 0x09ffb27e, 0x59fa850e,
	0x702ca86d, 0x1c9a4224, 0x4f846ae3, 0x3e6f0e2d, 0x68fabfce, 0x5dc38020,
	0xe8cdb473, 0xffe785b5, 0xf18693da, 0xf0bfc87e, 0xd95291a4, 0x330e35df,
	0xc38d77f5, 0xa478f348, 0x7a53e6d4, 0x4e826a41, 0x5647ffa0, 0x803efd58,
	0x8c661fe7, 0x3214a7dd, 0x1cd5bf66, 0x618f74c0, 0xef96357e, 0xafe3e749,
	0xc4ee1836, 0x6cfbeafc, 0x747ff30c, 0x7ce187b8, 0x4b169ade, 0x6e9ea978,
	0x9fa05bf6, 0xf0acbd5f, 0x67e6cfbc, 0xef6acff0, 0x8ed805d4, 0x9eb94625,
	0x7779bc43, 0x05c66f9b, 0xb2ab7ef8, 0xe32f5864, 0x3b2dce7f, 0x3ef84ecd,
	0xfb7159a1, 0xdd50f023, 0x1b78d9bc, 0x2d14c7ac, 0x1ae02de0, 0xfb872786,
	0x45f33358, 0x71f187c5, 0xa7072f4d, 0x8413a007, 0x518d92f7, 0xf9f2cffe,
	0xffc2df58, 0x9a71cd35, 0x9a4b5d7c, 0x386b33ff, 0x91ff04bf, 0xd8dbdd46,
	0x98879850, 0xcef541a7, 0x58d775c0, 0x804d7b83, 0x4247a1da, 0x67adaf66,
	0xfcb25dba, 0x12cff4ed, 0x7523bb18, 0x3189a53f, 0xbd4cce9c, 0xfd647af9,
	0x37ef0285, 0xd046b489, 0x66e292cd, 0x4bfa8333, 0x3b37ab3e, 0x678db521,
	0x51db1f04, 0xe3916d48, 0x77ac4cfd, 0x88abb52d, 0x02ab1e69, 0xa37e2bdc,
	0xf5ce9038, 0x22e993f3, 0xa19a7985, 0xdc9e2fbf, 0xe10f3b15, 0x955bf17b,
	0xd7c51bd6, 0x7c1c7ffb, 0x08d99d5f, 0xaf7a2700, 0xd66eb337, 0xb1fda57b,
	0xf10541c0, 0xfac044be, 0xc3e58bcc, 0xf17a073f, 0xeae5ec6d, 0xfd3e4b0b,
	0x3fbb94e2, 0x799f7987, 0x454bb476, 0x10f469b2, 0xa29284fd, 0x7e801b5c,
	0x5e365512, 0x68afbc01, 0x023b15de, 0xddfc9dda, 0x6816c1a0, 0xcf316bf7,
	0xcbab2f53, 0xbdf72e11, 0x2c3ae9b0, 0x1257e25f, 0xc6ce382c, 0x1d33fcdf,
	0xb67aa9fa, 0x1acc210e, 0x39a6f77f, 0xfe0cf508, 0xc6fbfcf5, 0x77ac0e5e,
	0xae8799f2, 0x36377843, 0xa9f95237, 0xfe53d667, 0xbd3617ad, 0xaf505ff1,
	0xc2eb13da, 0xde5ea77a, 0xf6a97849, 0xdeb8dd1a, 0x91fae89e, 0x7f693bcd,
	0x7ed35d02, 0xff39d363, 0xe92d7492, 0x730be4f7, 0x751d2387, 0xc9eabdd2,
	0x8a7eb054, 0x341cf5c5, 0x6df403dd, 0x13defa05, 0x44518cc5, 0x9e39ebf7,
	0x4d3ba5d5, 0xce3ce788, 0xa3c210cf, 0x74693f21, 0x3035facc, 0xa70c524e,
	0xa5676833, 0x0150c676, 0x66ad8fee, 0xa8515df1, 0x03519efe, 0x96bee036,
	0xdcf891f3, 0x2e6654a3, 0x5f7f082d, 0x3ab1e62d, 0x6fdc319a, 0x593f05a7,
	0x8d5b6652, 0xa297e9e9, 0x6bfc23a6, 0x717ec1cd, 0x4e029f08, 0x3f04dba7,
	0x6a5e6eae, 0x7b51b5aa, 0xe07de7ea, 0x840e9843, 0xf61c72fd, 0xf67ad423,
	0xde3821db, 0xd43ea9ef, 0x9ef3861b, 0x8298eb36, 0xa82989f0, 0xb8212d37,
	0x03978efd, 0x87cb2216, 0x43fbe32e, 0x39ef974f, 0xee5f546c, 0x95adf4cb,
	0x4be24e99, 0x27971716, 0x55e97d7c, 0x7c3b46de, 0xd79961bf, 0xbd5d02a5,
	0xd8c0e276, 0x90bfc80c, 0x7a210caf, 0xbfda1554, 0x8d1b3eb5, 0x9cbcb353,
	0xfafb0a7d, 0x936fb163, 0x6d78cc1d, 0xcc8c7e24, 0x2770e368, 0xbab355be,
	0xcd71f68d, 0xcc9e7cb3, 0x629eca1a, 0x6bb676a7, 0x80f3c3e3, 0xe51b3676,
	0x0cb7d943, 0x9be7f944, 0x69cff24e, 0x929ef9a6, 0x0af989fc, 0xef0c0f67,
	0xf30364ff, 0x9b263d22, 0xfe71b521, 0x5ffd0957, 0xed7e9470, 0xc9a70a48,
	0x0f5cbcd1, 0x2838c2a7, 0xc7a67e87, 0x1b6529b9, 0xa9f23413, 0x2b573e27,
	0x1288fff0, 0xee74885c, 0x40e51edb, 0x2ebdadba, 0xcf922fd8, 0xe1c71d5d,
	0xa6e82ed4, 0x97a73b7d, 0x0f83063d, 0xc367b7d7, 0x8748f580, 0xffdb797a,
	0x4615c4a9, 0x45bd37e8, 0xd25e2071, 0xc1ac9c9f, 0xcf53e95f, 0xbe4330ae,
	0x8a195f26, 0x596940fc, 0x20abc7fa, 0xc3780b5f, 0xcad6ed7c, 0x903f0405,
	0x5e717d43, 0x715b952d, 0x3789199e, 0x945cd4b9, 0xcd8f1f63, 0x6adaf280,
	0xfbfb8256, 0xf6f72c91, 0xc2875a0c, 0xbca2739e, 0xdea2a7f4, 0xfd55c8f0,
	0xef6c3e5c, 0x91f2405d, 0xfed0c6a5, 0xf995de64, 0xbcef6c4e, 0xe946b5d5,
	0x576c0f86, 0xdd027e48, 0x6f1828b0, 0xa6e28b42, 0xe218fef6, 0xb92db507,
	0x09bf38a5, 0x150e5c63, 0xf0959fda, 0x6da9a991, 0xdf6fd60e, 0x88be6166,
	0xed87fa7d, 0x7edcb8e3, 0xfb7242c5, 0x7d9b8374, 0x87e017da, 0x1f6223f2,
	0xd731792f, 0xace3fb80, 0x673fc728, 0x507390b2, 0x804166b5, 0x45fab2e8,
	0xa26bf685, 0x57745dc5, 0x7ea4de04, 0x4dffc7a4, 0xc424cf88, 0x47c254cf,
	0xe103e03a, 0xe1a4fe99, 0xcf9f5a56, 0x377d70cc, 0x1d40b154, 0x2786efcc,
	0x85d1810d, 0xdf49fd61, 0xe71c655f, 0x9e0915e3, 0x157fe422, 0x48ae6cd3,
	0xed1154be, 0xe8454436, 0x8a798c6f, 0x44ef500d, 0x3ee09db2, 0xf529ce3d,
	0xd5be8d30, 0xf3cf3ed9, 0x22b9c22c, 0x08d5ca25, 0xc9b1baf3, 0x437ac857,
	0xe9e88ae9, 0xcf811fb8, 0xced8acda, 0x5ea1ed01, 0xcf1186f2, 0xd0fe21ac,
	0x8f2ceb48, 0x15f9c873, 0xc94b23d7, 0xf2e32cf3, 0xa0daeec9, 0x05cf5d74,
	0x9ade9721, 0x80c8a736, 0xe6d531f4, 0x5fbd40b2, 0xc7ccaebd, 0x207d6bfe,
	0x969e8908, 0xe11eb81d, 0x485cc555, 0x4de84c6f, 0x5c3389b5, 0x7a177e34,
	0x4ae5c63a, 0x6d57c70b, 0x3127970b, 0x45bf39e3, 0xbfa910be, 0xf7247dca,
	0x5767f229, 0xe4be9841, 0xfdd2bd3e, 0xd0f26ed8, 0x758769fe, 0xd2763d23,
	0x0e9c6be1, 0x9670acd7, 0x0a9af962, 0xe08c68e6, 0xbecd7baf, 0xbd93a47c,
	0xaf09a3bd, 0x906cdc4e, 0xe3133e77, 0x5f247ec7, 0xee78716b, 0x6ef9c38f,
	0xc8cabfd8, 0xf6a87cc2, 0x5dfb07b5, 0x1ab2df4a, 0xd8567f79, 0x63749157,
	0x07db3005, 0x7e43ea53, 0xab5cb31c, 0x37f4c93f, 0xffaa3671, 0xa745f5bd,
	0x493c4462, 0xf551317d, 0xe84e26fe, 0x2c09408b, 0x17d7397b, 0x23b79193,
	0xe310da3f, 0x3938bd47, 0x74b77999, 0x82359f33, 0x4abc4a5f, 0x963921bb,
	0xec4d7fd7, 0x7a8bdf97, 0x8c7ec4bb, 0x1f6847b0, 0x63de0d38, 0xef99ed4c,
	0x2f3076cb, 0x63b4ef2a, 0xc99e7cac, 0xb0dbf5f7, 0xe18f0226, 0x60d5747d,
	0xdade6fc4, 0x2dbe7180, 0x3b94bfdc, 0x79c1ba7a, 0x75c27ca3, 0x5cf41654,
	0xb0a769af, 0xfc7474c7, 0xee23d0b9, 0x2f54638b, 0x179bc13a, 0x5eace90f,
	0x78009dcc, 0x85a6f59f, 0x87e588e8, 0xb93da1fa, 0x967cc8c4, 0xc9a7c478,
	0xd7c08c1f, 0xe87f0843, 0xf56ec3a7, 0x99ff40a9, 0x7143de09, 0x3195f790,
	0xd1f50057, 0xe03f807b, 0x1281643e, 0x2c751fe4, 0x7bf08b18, 0x80fdeed8,
	0xcb6d52e8, 0x23d83cc6, 0xa3ce3885, 0x0a0edc31, 0xfdfd57ed, 0xace71e01,
	0x808f9fc1, 0x965b9cf9, 0x3f41f2e7, 0x97f6bd1f, 0xda817f6d, 0x917db767,
	0xa3e08de5, 0x63d556b5, 0xdbe7084c, 0xb9bd3615, 0x5e7b3e1b, 0x3fb737e0,
	0x17086d63, 0xcff48863, 0x534a3b65, 0xd78fa52e, 0xfe672f9d, 0x68791121,
	0xdd50aa87, 0xbdf4b1f9, 0x0e50febb, 0x60cf9dd4, 0x4f7688be, 0x5e093bc6,
	0x54d9f6e1, 0x558191fe, 0x1bdf3775, 0x6e5d39e2, 0x777c6c65, 0xf9e293e5,
	0xe6f6b67a, 0x4eb435fb, 0xbf7ea3f1, 0xa03d9970, 0xc2172802, 0x1687d467,
	0x43017c3a, 0xe01bf22c, 0x7d08835b, 0x4f60ad53, 0x0b7213cc, 0x224719ea,
	0xb41cfa9d, 0xdf62bcef, 0xc3f96bcd, 0x31fb0505, 0xe848eb32, 0xb5d5be67,
	0x7fbe0337, 0x8b131b6e, 0x8fc160e2, 0xb2a324a6, 0xdeab3299, 0x1b3a25ec,
	0x53fd40e3, 0x6fd52361, 0xefa52e63, 0x254f4918, 0xfbfc023a, 0x92193de3,
	0xb3ff10fe, 0x4c7ce2ee, 0x8e277fd6, 0xfe9eabd3, 0xcf01ee3e, 0xed97c4df,
	0x143c3a43, 0x9f1be9eb, 0xd59dfd84, 0x2576bbf0, 0x4813fcf8, 0xaeed4b9f,
	0xf6d758e7, 0x1dee02c5, 0x96666d45, 0x7fd2e907, 0xd9be9364, 0xc82387fa,
	0xb6ac6b97, 0xdb290a80, 0x94133a6a, 0xb41c00eb, 0xe307bac7, 0x4607be78,
	0x001f1dc6, 0x3be0531f, 0x012a17ad, 0x72b4efbc, 0xef137f78, 0x05eb8e1d,
	0xf68b9f7a, 0xb3ab39d1, 0x8bd23c57, 0x1e3f13b9, 0x3f18726b, 0xc5aed32c,
	0xc27eeb4b, 0xdbab7ccb, 0xcdbff08c, 0xce79a1ed, 0x712815ea, 0xa050f068,
	0xcae03b7e, 0x9e2030f1, 0xcc8f83f3, 0xecdd8f40, 0x2e024987, 0xe97aca4f,
	0xca3f6e9c, 0x305b5566, 0xb42907ed, 0xc8b7a8fb, 0x7ae96b27, 0x8fe73c56,
	0x3e39e3cb, 0x4f7789bf, 0x67fce78f, 0x17a9e116, 0xf245c40b, 0x3fe0629f,
	0x251d6840, 0xdf980780, 0xf650d29a, 0x3b0fe461, 0xce0d8e2c, 0x5ea3e3cb,
	0x2def8fec, 0x1c80fa87, 0x4391aa1a, 0x904f38f5, 0x98770443, 0x45eb9989,
	0x84de087d, 0xe1caf56f, 0x87146afd, 0x3dffd023, 0x026f24f1, 0x7c113d03,
	0xde0217fa, 0x147c3f92, 0x8e4bc5ad, 0xa8a35f58, 0xc1de2037, 0x942b96e5,
	0x147cfd8d, 0xf31e3ddf, 0xff807d44, 0x25bb826a, 0xe8012734, 0xfb9016e7,
	0x8f84c1e6, 0x8bbdf801, 0xf810593d, 0xbacfee1b, 0xe50ced3b, 0xbc712fd8,
	0xf913c212, 0x645e411d, 0x99b47873, 0xfc397f31, 0xa7e980ac, 0x2a292d01,
	0xdb4f140c, 0xb0fd49c4, 0x3fda0e91, 0xe1fc9d51, 0xe8f848e9, 0xf02a3dc7,
	0x315e31b5, 0xcc5d7c12, 0xfce6ed85, 0x6cfb2bf9, 0x0eb393a0, 0xf200cfab,
	0x7dea9c69, 0xccede911, 0x5f49fbdd, 0xf40e6a3d, 0x5375b26b, 0xfd3c0e6e,
	0x9f2e12a8, 0x67d55bfb, 0xb5b97d86, 0xa7afcced, 0x6dbdfac1, 0xa5f70baa,
	0xbdbfdef7, 0x1fea0d7b, 0x9a17266d, 0xd7272003, 0xf51d711a, 0x6a3acf5c,
	0xf4ffc2d0, 0xfffab58f, 0x003ec51f, 0x4ce880fd, 0x51a3efee, 0xe60c85b1,
	0x883988b3, 0xc74567ee, 0x707cc06e, 0x191ba2e9, 0xdae67bee, 0x7ff806eb,
	0xfbf5e771, 0xcedc0f90, 0xe7ffb4dc, 0x449f4cf9, 0x56dbc7f2, 0x37b7f36b,
	0x2230f369, 0xc7a2efd1, 0x7f85dff4, 0xfb7bbcb6, 0xc7d8ace2, 0x97ddcda7,
	0xdfe5131f, 0x600ece5d, 0x1e3908fe, 0xf4859396, 0xe7dfdf5d, 0xf2c20e82,
	0xbdd4cd36, 0xefa4ce9c, 0x3f7617a7, 0x8fb10edf, 0x69c7ceea, 0x7db875e4,
	0x8d077d22, 0x3c49ea8a, 0x97cc78c2, 0xbd4bce10, 0x2a5c622e, 0xf1fa4f47,
	0x97bef098, 0xb749587e, 0x4d6614c7, 0x21eb3b23, 0x0a3a77a1, 0x8e5e0327,
	0xfc06bca1, 0x37b1c77a, 0x79c53082, 0x67eb493f, 0x6ba61dec, 0xff003afd,
	0x7c1182a7, 0x4f6094cd, 0xb10771a4, 0xa4ae3841, 0x577739cb, 0xfd7942f4,
	0x53cb7bd7, 0x4ea8f522, 0xdb99843f, 0x34d98c37, 0xe4e98772, 0x9016bcd2,
	0x17a48543, 0xf12643f4, 0xc4198ee9, 0x57301717, 0xc76dd232, 0xf9364b0e,
	0x3ca7bee3, 0xe299f392, 0x7ae2679b, 0xd1c92262, 0x29fc62c9, 0x313f5cad,
	0xd226dd58, 0xe9ccdc3f, 0x90532648, 0x22104dcb, 0x928fc846, 0xc81a2479,
	0x518b148f, 0x7fcc3db0, 0x7cd94894, 0x23ee2a6f, 0x22ab8e0b, 0x62a7f1fb,
	0xe5dc38da, 0xe2b474c4, 0x7079f231, 0xf5658f3c, 0x60df5899, 0xff5caa0d,
	0x63241981, 0xcf1e397b, 0xe57e45db, 0x6e7373d4, 0x3b36efc7, 0x98b377ed,
	0xe004d8c7, 0xacffb85b, 0xb6eb8acc, 0x712702d8, 0xfa91765d, 0x47649cca,
	0xb2337afa, 0x3359a3d7, 0xb66d71c3, 0xac5c3eb3, 0xcc143983, 0x05ce3947,
	0x9f90c27e, 0x41867cd9, 0x486ecfc4, 0xbca67e40, 0x1df910b3, 0xdc42cff0,
	0x1b963def, 0x4b87a403, 0xe62f147e, 0x51f828d7, 0xb829731a, 0xa3f0557e,
	0x1217da5f, 0x9e644a3f, 0xd68fc89d, 0x7e278ec5, 0x34bcc294, 0x46f1849f,
	0xf2495f0d, 0xd329f368, 0xe3be3a8d, 0x697e7053, 0x2b77ed5e, 0x40f24a3b,
	0xbf527809, 0x22fb204d, 0xed06fd1f, 0xc7582f38, 0xbf3e68b4, 0x13cfd2c3,
	0x8067ed95, 0x3de3a9cf, 0xf7804615, 0x5dec052d, 0x2777a437, 0xbd70ab79,
	0xd7d5f633, 0xfa7e4354, 0x00606c3b, 0x8ed1a2d2, 0x7c022f25, 0xbbb6cd57,
	0x2afc83ee, 0x5f35273b, 0x7e4fc592, 0x508b9429, 0xea90debe, 0x1d48ff47,
	0x1f812bfa, 0x8df942ac, 0xc8cbe978, 0x607d04fe, 0xadda1595, 0xac70e35f,
	0x27bfa271, 0x69fd1634, 0x6399dba1, 0x3e86eb03, 0x03dd022f, 0x3cc19f9c,
	0xf81155c0, 0xc59fdf96, 0x3f3c79ef, 0x4fda287a, 0x15af2ffc, 0x39fa0618,
	0xf47ecdf2, 0x96b5d5c3, 0x9f20929a, 0xfe45c637, 0xaf4fb956, 0x1183edd1,
	0xf2a4ba61, 0xd3ef9122, 0x724550fa, 0x970f6d22, 0xe9856b70, 0x80eb2718,
	0x19b9430f, 0xae8fb91b, 0xec3fe165, 0x3fdc3caf, 0xa2318df1, 0x71eccf6c,
	0x18d71744, 0x9f713b03, 0x9169108d, 0x2a7aa748, 0x992fd08b, 0x42e6d53d,
	0x712b9dbf, 0x3b8e2360, 0x1504d664, 0x7984b2e9, 0x0e0087d5, 0x6a4dacc3,
	0x4a3ff412, 0x2af95009, 0xa55ab5c5, 0x5ee5f8fd, 0x0faa3bf4, 0xf70821b3,
	0x13949376, 0x26cc5eee, 0xa9f30526, 0x75353414, 0x62a4e97a, 0xca9b6f5c,
	0xca3dbd70, 0x5b2ae5a3, 0x560f2919, 0xf17e359a, 0xe7ee048e, 0x76309438,
	0x9c44424b, 0xe84125ac, 0x1f2cf921, 0x7ec473f7, 0x56fda56b, 0xfb4f76fa,
	0xf62e5b51, 0x21eecde3, 0xc537d226, 0xcffc94be, 0x7fe9cd13, 0x909b7306,
	0x60a2da4e, 0x40fe425f, 0x97da62e9, 0xbe9798d3, 0xe1c6507f, 0xc260840f,
	0xd78ca6fe, 0x3d9bfbca, 0xe9b4fcda, 0x46007d7a, 0x3b8f0e4f, 0x9f2dabc3,
	0xf1bbf52c, 0xd66efd5a, 0x238c5dbf, 0x7cf293f9, 0xe839b7cd, 0x4a6a9e5f,
	0xab5d7f42, 0x72ff20e2, 0xdbfe42ab, 0x3f56e9ba, 0x5aeaf3fa, 0xad93dc78,
	0xef3d7494, 0x8ceba47e, 0xc714dd7b, 0xacd96daa, 0xbf211edc, 0x0afdaa33,
	0xb0feddf2, 0xb3c436a6, 0x9b0e0bd0, 0x1e913bfc, 0x15862f0e, 0xccbb38c3,
	0x3bb2ce3c, 0x2fd0f98a, 0x3ed1e929, 0x76d9fb87, 0xea0d3fa3, 0x5a7f46ef,
	0x3ca67f84, 0xcbabfb86, 0xfbe99807, 0xff232354, 0x46cf9c73, 0x0b34ebba,
	0x9e7e17ab, 0x6d2cc4dd, 0x17e30fdc, 0x0496e976, 0x568ffa45, 0xb7481f92,
	0x1812938f, 0x99a4f5f1, 0x9b67e4f9, 0x8c545ade, 0x0f904dfe, 0x92df8fe4,
	0xd3f6a4e0, 0x27e445bd, 0x8336c1ba, 0xeb5d47f6, 0x5b02e37a, 0x89cc6e98,
	0xb0c47e42, 0x4eb7a418, 0x0b16cbff, 0xa9c65ff9, 0xe844e89e, 0x281cdaa7,
	0xa47a5a64, 0xfff13def, 0xa6df0245, 0xdb8ccf32, 0xef1ddd61, 0x77685d9a,
	0x3c278081, 0x8e3dbcbd, 0x3271a1f8, 0xb2bbfe23, 0xecdf1194, 0x10fdcf58,
	0xdd55c45f, 0x65787c88, 0xd1792325, 0xe0963f1e, 0xf7f998be, 0xd55da1ba,
	0x11474093, 0xcf1dcafa, 0xacd5f36a, 0xeadaf499, 0x23d0bb17, 0xbfc927f1,
	0x3553986a, 0xab7fffa1, 0xc3eb3db6, 0xc04bace5, 0xd7f048bb, 0x698f3721,
	0x10f3b8c4, 0xfe254783, 0x3195c0ba, 0x5996ec99, 0xc851e38e, 0x2e579ef2,
	0xd874a7a5, 0xff7ca84f, 0x225a3e72, 0xf7f3d7fa, 0x5c9fa112, 0x7d050467,
	0x80df5870, 0x6ddf94fa, 0x0d535568, 0x8b1679e1, 0x91cf5276, 0xabe255fc,
	0x40f01874, 0x8949b3a0, 0x66f4bf82, 0xd0df11bd, 0x82b7d13f, 0xea788291,
	0xc87687df, 0xd01e3108, 0xcae90f83, 0x91fab067, 0xf529578e, 0xa8ac5724,
	0x46ba42cf, 0x7d3f12f1, 0x22a7cab5, 0xf5670c7d, 0x7a846e53, 0x316dad23,
	0x4e8077c8, 0x4fd244a6, 0x6f640b23, 0x44743456, 0xdee267e5, 0xa48e96ee,
	0xc07c081c, 0x0604f4e5, 0xeb8c147a, 0x11eb90fe, 0x444595bb, 0xed4fa027,
	0x6de23d46, 0xae6bb703, 0xbd606587, 0xff16870a, 0xf9b552e3, 0xe85d9deb,
	0xeee5e283, 0x8dfa784e, 0xf9099f38, 0xc96e7ada, 0x6f9698b7, 0xdc8bb2e5,
	0xef707cfe, 0x8deed08f, 0x51f2ce59, 0x45e6813e, 0x3d3d2f71, 0x07f134fc,
	0x34ff77f7, 0x777f1bb1, 0xe5e84987, 0xddab3a3a, 0x5ace6a7b, 0xb947a616,
	0xf565ae2f, 0x4fc02a6a, 0x15c79379, 0x8c3a45ae, 0x960a3947, 0x98a5c23c,
	0xfee495fb, 0x54377490, 0x74929ee4, 0x9072c396, 0x44b546ce, 0x5af15f91,
	0xdfa037a4, 0x94afd122, 0x6e7f52eb, 0xbe85d61c, 0x07481572, 0x48795d5b,
	0xef8cc54f, 0xeb8a21bb, 0xa2e49f89, 0xfd23ecfe, 0xd69e8239, 0x5f212627,
	0x3f227a02, 0xa939174b, 0x9bd1d72d, 0xa141fbc4, 0x7ab2961f, 0x46a7dbd2,
	0xa818f973, 0xb03476e4, 0x3fb7a249, 0x56f4e64c, 0x6f44dcc1, 0x274b4ca5,
	0x5e6d56e5, 0xa2308f4f, 0x5e6f4b41, 0x9d3d37a2, 0x396f44f6, 0x4e526f48,
	0xde9e5c26, 0x09b44ede, 0x460fe87f, 0x26276f6f, 0x49bd395d, 0xca39b63e,
	0xf9436e51, 0x5c90a55d, 0x9f6ef218, 0xaff7cc46, 0x743d25c9, 0x176b9c73,
	0xf2f3d795, 0x8ab736e2, 0x96f202e7, 0x4f5cf289, 0x96ebe639, 0x5d743943,
	0x1b9f9072, 0x2f2f73e8, 0x7eafba2f, 0x4dfd1d97, 0xb5fede3e, 0x58d4ab93,
	0x12aff728, 0xca9b4bed, 0x9ab75f31, 0xe302ffb7, 0x3cf08310, 0xbf11bf91,
	0xd736b55f, 0xae48cdc5, 0xeb168eff, 0xd96cacdd, 0x789aed45, 0xad7b45bb,
	0x5dec8cd1, 0x275ed7ae, 0x49fa39d6, 0x4fc4cebe, 0x44ef186f, 0x47c84b3f,
	0x4371d87a, 0x73e250f5, 0xa58bd83d, 0xa626534a, 0xa97f90e3, 0x53d07788,
	0xd3f8f37b, 0x9cc21806, 0x1902f5c4, 0x70b8c1bf, 0x635e8465, 0x39fee24e,
	0x9e392f59, 0xe3f738f1, 0x0247b276, 0xe505328f, 0xeb0dae3d, 0x1a6714f7,
	0x7a4f5797, 0x191cb8c3, 0xe71a0a5f, 0xdf4578c3, 0x3bb6357e, 0x893d883f,
	0xc84e6dfb, 0x5ef8b7f8, 0xef71e7e5, 0xe91c48cd, 0xfd9fcf08, 0x66ebf711,
	0x21711f8c, 0x10c363e5, 0xf19f3c9f, 0xacd707eb, 0x917b2306, 0x43e8dea1,
	0x50ad96a1, 0xfc227f7c, 0xaee0fcf3, 0x64671ff3, 0xef9d3301, 0xd85ff3e0,
	0xf140de68, 0x6ecfc17f, 0x23637816, 0x9efed2fb, 0x9f93f02a, 0x10d3f824,
	0xd3f90436, 0xb75f02cd, 0x5c4deb58, 0x7499373e, 0x0920a37c, 0x1ebad4e5,
	0xb96d6ff5, 0x8954af8e, 0xbd0a1771, 0x910b317b, 0xd0b8ee7f, 0xe3ac4fbb,
	0xac1df77a, 0x1d73fc99, 0xb33d738f, 0x74879606, 0xe5afd8b2, 0x6a364b07,
	0xdacd35f3, 0xfe062d7c, 0x3ac7dc55, 0xfdc0537e, 0x6aeb1d9e, 0xabdfa286,
	0xc977b1ea, 0xf9255acf, 0x5fcb5f8b, 0xf397bb18, 0x26af4797, 0x6ede8bff,
	0xd832f696, 0x512537c7, 0xb331cefc, 0x3985f51a, 0x807cfc31, 0xfc481b6a,
	0x7b256ec0, 0xa07e27b9, 0x3ea47bb7, 0x7eeeaec2, 0xb1e4809f, 0xe0223ae2,
	0x2ff1c5ef, 0xcb691f61, 0xf691f875, 0x3f02adc9, 0x38ff0053, 0x2ed287ce,
	0x33f1cc5a, 0x20f67995, 0x83b83e7e, 0x49da47e3, 0x722edddf, 0x917691ab,
	0xd4aeafb4, 0xb9fbd23e, 0xcf6b7ee5, 0x93abf692, 0x043ad7ec, 0x9aedf034,
	0x5d3f0ed7, 0x0ef5c2c1, 0xd1973034, 0xd52f9114, 0x4f2737fa, 0x9e2868f8,
	0x5518dc1f, 0x8dc23f76, 0xff9126b5, 0xda4526af, 0x69ffbc4b, 0xb9d3bce2,
	0xf15edcaa, 0xa6cff297, 0x8c621bce, 0x8c3b87b0, 0x73f458a1, 0x68545c76,
	0x75c7cc5c, 0xb70b8f13, 0xbbed405f, 0xe3f6df8e, 0x7b7f20bf, 0x71e2863a,
	0x6ee2aae7, 0x77f40b5b, 0x28abc9ee, 0x9245fbee, 0x3bf88ad5, 0x1297e22d,
	0xdf970b1e, 0xbee30436, 0xa0de62a7, 0x731de438, 0x643f275f, 0x1cfbd5ac,
	0xf19ab7ae, 0xa617ddf8, 0x82a6ecfa, 0xf67bfaf0, 0xff88fa3f, 0xf2e2df99,
	0xd344a437, 0xdef84979, 0xf32e322f, 0xdbf73252, 0x9498bf4b, 0xbe448793,
	0x2c53f711, 0xdc9d72a6, 0xe099910f, 0x75e7057e, 0xfe8fe708, 0x889b3fa5,
	0x728b2f9f, 0x0ffc60a7, 0x88cb32a4, 0x8c2f3aef, 0x057b3f6f, 0x425dedf1,
	0x5c445c5e, 0x88bfffc3, 0x7e46ef73, 0xf3c44276, 0xd1f8884e, 0x4f1e5889,
	0xf7e093fa, 0xa0bb4517, 0xc43dffe4, 0xcfbd65a3, 0x959eac1a, 0x349f7740,
	0x904acf30, 0x2d47ce13, 0x665e74f5, 0xc7575f16, 0x373a38f6, 0x4e9ddb29,
	0xf388bd2a, 0x39e1df78, 0xd05feb8c, 0xe91ccc74, 0xf5c0ee77, 0xd7c1be90,
	0x53c511d5, 0xa4e9de39, 0xaed88bca, 0xf8904663, 0xb87e6761, 0xffa87bcc,
	0xc241518e, 0x8afe1337, 0x7b2fb11a, 0x2e5d3f8a, 0xc78fa4ee, 0x5cfb96ce,
	0xf16763c4, 0x116cd8ae, 0x65639d8f, 0x7ca032ab, 0xf90a6b6e, 0x7d62abc1,
	0x58f134fd, 0x8a77cc5f, 0xec7a4b8b, 0x3fc70ac8, 0xf10eff1f, 0xf2b2474f,
	0xbb13d3df, 0xc91d3fc6, 0x9fe35d25, 0x2bf778fa, 0xc2983fa8, 0xc1d3b878,
	0x56a156e1, 0xf43fa397, 0xe74602dc, 0xef588b84, 0x1ea24747, 0xfcc4cfb6,
	0x1eb93fc4, 0x25bc397d, 0xa9cc0c79, 0x334723f1, 0xd27ac467, 0x3c9af1bc,
	0xe711e669, 0xd2aa32f4, 0xeab3ed35, 0xe7ea6b7b, 0x535abf2c, 0xac1beb9e,
	0xbeade7c9, 0x6fbf5356, 0xdf269953, 0x341bb1ff, 0x4ff2aff5, 0xe1cfe4d6,
	0xa9bf883f, 0xc0606f74, 0xed355bc6, 0x797fed17, 0x2d970068, 0x90a374e4,
	0x6ee7cc5f, 0xddca182b, 0x818eb82f, 0xfd35f3cd, 0x501280b2, 0x903c6286,
	0xe58e9dff, 0xb41611f7, 0xa0fd3f71, 0xe3343b96, 0x3a078d74, 0x5abfd255,
	0xd2b8f614, 0xd5582e35, 0x3c2ad0fa, 0x63d7a1ff, 0x58df2fe0, 0x344f7a8c,
	0xebd41f9d, 0x8b24b735, 0x4b3a5438, 0xa7ad74e7, 0x3c275b0b, 0x1143fef0,
	0xc8e8f7eb, 0x685d0d62, 0x23f007f0, 0x17b9d6ff, 0x161f24ed, 0xe88dbfed,
	0xa5aa92d1, 0x96a7288b, 0xb5f2622e, 0x69776174, 0x30d7a0e9, 0xe1e81d2d,
	0xd2d6e71d, 0x7fc20b05, 0xc2778097, 0xe8dd2d78, 0x85983de1, 0xeb5d6fc8,
	0x6f885c57, 0xb717bc3d, 0x5d75a7ac, 0x4fbc6f4e, 0xbb21df07, 0x82368ddd,
	0x23e73f1b, 0x611601fd, 0xad44b377, 0x57ea4c5f, 0x7e164cbf, 0xf48fd144,
	0x7c52afcf, 0xc677c764, 0xb20586c3, 0xcf68b903, 0x1fee33d7, 0x9c923cf2,
	0x917fadd4, 0x5fe4f7be, 0x2a9d7094, 0x8c25d0f4, 0x1839639f, 0x9f42fdc5,
	0xbf262e55, 0x4f5642d0, 0xc9e9f4fa, 0xd0ff84e3, 0xf0f4f547, 0x3d3f02ec,
	0xcade829d, 0x77affc22, 0xc86ca680, 0xa54f0aeb, 0x0bd80955, 0x52ad0c11,
	0x79f9781e, 0x057fad7a, 0xf922543a, 0x658bd495, 0x927e12ff, 0x2d7ec98f,
	0x7dc197e8, 0x2c6be3a0, 0xbd178b5f, 0x81b7063f, 0xdc646875, 0xe322c9c5,
	0x4c3f7a34, 0xe3c2ffd8, 0x6e4e6a24, 0x0e380323, 0xcfc9b871, 0x66dac257,
	0x7fe977e2, 0x55c43f21, 0xd10fd3ac, 0x4cba9ca3, 0x4f8a759c, 0xdb913e09,
	0xe32abe35, 0x4f8600b5, 0x478d02ff, 0x9c2cce2a, 0xfad7e4c7, 0x751d2127,
	0x8eba4bf5, 0xa8fd0ebc, 0xd6025086, 0x4d5e60ab, 0x4a0ff5fc, 0x0b73d690,
	0x22cfdf73, 0xd65a8df4, 0xf926763c, 0xc63e4183, 0x56fdca62, 0x7faf45ac,
	0x6c5fc91b, 0xbd209580, 0x7111612f, 0x3970dcc7, 0xf9aed5e5, 0x32bf3d2b,
	0xe221c537, 0x253cfcfa, 0xda4ffc13, 0x6ddb3d93, 0x66ddf9da, 0xc0ab905b,
	0xe722dbf7, 0x94f30571, 0x98f616e7, 0x6760b601, 0x634e40bb, 0x93b258fe,
	0x3e8a93df, 0xab1bbefa, 0x4765b715, 0x6675b9ea, 0x7ed07030, 0xe3c2c57f,
	0xfd5acd9b, 0xeb852339, 0x41c33dc1, 0xd9d28b9c, 0x7bd39737, 0x63a8b9e4,
	0xfccd0ec9, 0x727ac50e, 0xacbc6052, 0x8ae3c123, 0x42bedc21, 0xf9e7433d,
	0x74a8b5ce, 0x1476a8af, 0xdbb50fe7, 0xed42da55, 0x82bf16ad, 0x5d9686f1,
	0x699d2fa4, 0xfa040600, 0x1806a9c9, 0xe025efb9, 0x4f6f5baf, 0x3f3c82f6,
	0xb08a4d74, 0x61590b7f, 0xe023f9e4, 0x92522383, 0x77c38bba, 0x96d23b9e,
	0xa1593e0b, 0x160af416, 0x312f9c44, 0x4727b286, 0x0ebf47e0, 0x1bf70a4b,
	0x633c9825, 0x6d63bfb0, 0x7f608f99, 0xdeeb6a15, 0x32cf8474, 0xb77185c5,
	0xcf7e16d1, 0x752ea2cf, 0x7bd847d5, 0x7aa47ffd, 0xd1f9be30, 0x6fe2bbb2,
	0xdbf7082b, 0x7dd0315f, 0x7cb6c634, 0xc6314f7c, 0xd6b966db, 0x85b66e40,
	0x3fb99bdb, 0xc1e4098e, 0xccd37afe, 0xa65f48ac, 0x0e74f5de, 0x92a7143f,
	0x65512edf, 0xe42e9063, 0x3dfde57c, 0xa9f4bdf9, 0x073c1567, 0x6e8fbf29,
	0x13b90d0c, 0x2714acd2, 0x6fce57c1, 0x48687974, 0xf70c2dbd, 0x1b972b76,
	0x7a4f9dcc, 0xdf2b32e3, 0xbce2ed4f, 0x79926d6c, 0x5f4dea15, 0x5d9371f7,
	0x3cc51b5b, 0xed7c6768, 0xa38af770, 0x3b7838f5, 0xb2ddb687, 0x60a5975f,
	0x3fce9efd, 0xedc293dd, 0xaaf3ea92, 0xb550bce6, 0x7ee74031, 0x359bcfaa,
	0x75813fdf, 0xfce12cfb, 0xc67d13fc, 0x1b783da2, 0xfac2ad73, 0x618eadb7,
	0x43bd08be, 0xe3d5f79e, 0xb7ec5a3b, 0x332338da, 0xaf7ba20e, 0x7bd54b9e,
	0xb76a9ffd, 0x169e4df7, 0xa3eb0274, 0x4f60b6f3, 0x5f4ebc50, 0x7f453a2f,
	0xf7482b8e, 0x2f6d9716, 0xb097614d, 0x97cf6bf3, 0xd74bce6a, 0x675c3b42,
	0xba31f9ed, 0xfee1d2f3, 0x471e549c, 0xe3c2a5e7, 0xdb87fc73, 0x54f38a27,
	0x3fdc58c1, 0xd2a2d1ff, 0xd8ffdd3d, 0xa1bf1867, 0xc0587b3b, 0x2324eae1,
	0x0080f5d1, 0x06efaf73, 0x3c9eb29f, 0x99ef2fb7, 0xb5b0e1e9, 0xee87382c,
	0x7ee18f49, 0xaf3f7d5c, 0xf390ba08, 0xe1cf1ade, 0xc006fb5b, 0x8491ce97,
	0x787c61fa, 0x21707c6b, 0x168767ed, 0x7324df6f, 0x21bd6cbc, 0x48f74d98,
	0x7076e7ae, 0xc67df84f, 0x3ee335e1, 0xc3669eaf, 0xa86c5e33, 0x44715eb1,
	0xc52b8fec, 0x04f9ed6f, 0x7092ff93, 0xd972a64f, 0x4fd7d4af, 0xdc52a63e,
	0xb101e4fe, 0xa6db990f, 0x3f2b9c44, 0xfeffb8c9, 0x7a429364, 0x632f7cfa,
	0xcc3f81cb, 0xd709767b, 0x421b9eeb, 0xfbf06d47, 0xe607c0bd, 0x1d7632a5,
	0x6a57f3a4, 0xd60bb8e3, 0xb1bbf176, 0x3b79f948, 0xbf7e27ab, 0x76da57f0,
	0x97ed6c55, 0x71f5f728, 0x8269f266, 0x45327b7d, 0xd943cde8, 0x77d7e450,
	0x3995f73e, 0x5d33d9d6, 0xd87e009f, 0x45f22fa7, 0x1a67a52b, 0x23fe941c,
	0xe225fdc5, 0xfbd52621, 0x21fa0a75, 0x71e1ccfe, 0xe71cfaae, 0x710978e7,
	0x855bf238, 0x266591e4, 0x803ec38f, 0x1e01adf7, 0xcb970b16, 0x277baf6a,
	0xfa59a44f, 0xa0f37df9, 0xc91c4e63, 0xd22a570b, 0xc6efe27b, 0x22bb478d,
	0x6e3177e9, 0x529adf84, 0x0fe8f3ff, 0x9a22b358, 0x0b56b4fc, 0xbde7038f,
	0x3b406a58, 0xcaadaaed, 0xd447f44e, 0xc7c8aeb5, 0x6736f07b, 0xe81f9d34,
	0x972f3ad5, 0x4e3e21cb, 0x3367a362, 0xef1133e2, 0xd6bcc189, 0x3953fae4,
	0x4a7ae59f, 0x877d80ad, 0xde05fce2, 0x57edf607, 0x39df3ee9, 0x7eb73f23,
	0x9578e335, 0xec7096e7, 0x0cec7d48, 0x0ff58dc0, 0x566eafe7, 0x8bf42602,
	0x714cdd6f, 0x02fbea85, 0x5e5133c9, 0xf148d6fc, 0xbd79ce98, 0x71865699,
	0x66272917, 0xdfee0e2a, 0x0ce6fa11, 0xdc78ff26, 0x87a0ba66, 0x9ccf4219,
	0x3be1c319, 0xb1b2b99f, 0x1656addd, 0x33ad806b, 0x84b9bcb3, 0x14c4b7d6,
	0xc65af287, 0xf3967a21, 0x6a65fbdd, 0xf3f3b79f, 0x1fa84a66, 0x7d0a7276,
	0x6fd8971e, 0xbf62a9a5, 0x56fee3f5, 0x31b987d6, 0x46fb55de, 0x3768f5ff,
	0x5c79a25b, 0x7590f815, 0xd7d260d8, 0x77af78ac, 0x0151ebf1, 0xc3877e7e,
	0x45dc3985, 0x6eaf5f78, 0xba60e672, 0x4424744f, 0x4ddbf5f7, 0xafda6cc1,
	0x90145fc0, 0xfb533369, 0x3a0468df, 0x7d074daf, 0xa60ff209, 0xef7cf096,
	0xe40342e0, 0xe24ea4b7, 0xc783abf9, 0x7a9adf31, 0x0e0fcf2b, 0x7f21542e,
	0xe78ab538, 0x0748e0d1, 0xeeb52c7b, 0x7ff41f46, 0x23e84e2a, 0xa7dd20ae,
	0xbfad7dac, 0xd7dfd221, 0xd8f9ca96, 0xef5e28a9, 0x3b9b2e54, 0xdf9de119,
	0xa9adfd7d, 0x371fa106, 0x5eb93b51, 0x76a59ed9, 0xd10eeedf, 0x57b8b16e,
	0xad863a39, 0x99b3f7e6, 0xf3cf162f, 0x38a7f6b4, 0x78d4c4d8, 0xa7e83701,
	0xfe8fdc38, 0xf71cb69e, 0x09eb850e, 0x97ee26ed, 0x26ffe594, 0xace307f0,
	0xb8fa71a4, 0xc9c47df9, 0x3f884599, 0xe0519bc0, 0x937888cd, 0xdfb197f7,
	0xf7e242b8, 0xbcafd043, 0xcfd422fb, 0x4f5bcf0d, 0x38c52b27, 0xdc791b8b,
	0x4797142f, 0x463a34f4, 0xac50cfbc, 0x0161c75d, 0x38d4b687, 0xc25ffe71,
	0x71a1452b, 0x331c051a, 0x0f26fd83, 0x7eebeefc, 0xdd687fe4, 0xe372f811,
	0x5bbb0b3b, 0xd7c0daae, 0x47ee2f13, 0x49e3b306, 0xd3487b4f, 0xba15a9df,
	0x4360c3f6, 0xf3e37ae2, 0xf203fda8, 0xd0db3e9e, 0x90b72ed9, 0x57a88feb,
	0xcce6fbca, 0xf48b1d77, 0x2bde766f, 0x41f7e66f, 0xb1bcebc3, 0x21d3ac58,
	0xebe0e9d6, 0x95e86bf4, 0x4f650c1d, 0xe3a577b5, 0xf677f84e, 0xf4583057,
	0xdde7d9a7, 0xbafb87f5, 0xffecbc27, 0xe722f1a1, 0x276783a9, 0x93f3759c,
	0x4dfdc4f0, 0x74b40aed, 0x2ad9e729, 0xfd9741f8, 0xc73dfb9d, 0x6aede52b,
	0x70e7e6ee, 0xd74b5399, 0x0d735b35, 0xed96e718, 0x97679112, 0x6752fd84,
	0x969d8552, 0x387b32c9, 0x2d4a172f, 0x459fd6e9, 0x5a76f5df, 0xf1999c47,
	0x7b5af2f3, 0xd5c923bd, 0xcf38c6e6, 0x791f7e59, 0x80bfce84, 0xb62d8ef1,
	0x7cb0bb70, 0x4bafe6d1, 0xabbbfbe3, 0xf744247f, 0x652d8b27, 0xa05d3b2f,
	0x7fdda5b7, 0x8cf411a3, 0x77655ee2, 0xb1de42e5, 0xdfe201ee, 0x5f6519c5,
	0x8f3f02e5, 0x979ab75f, 0xaafb280f, 0x1ed3e637, 0xeed1f9e4, 0x83df9197,
	0xcc71b884, 0x911eb0f0, 0x71a4e690, 0x430372d5, 0x5fd4ea3a, 0xfe90b4de,
	0x53dae122, 0xd4316c5a, 0xca471777, 0x9efc934c, 0xe187fbfb, 0x2e789d3f,
	0x41e1d849, 0xef0ec6a3, 0x4bf7e588, 0x9dfc763b, 0xd3fd7be2, 0xd069b9bc,
	0x99cc5d7f, 0xbf90b939, 0x8a63e62f, 0xbc6e2927, 0xd3a9065b, 0x7cc166c1,
	0x3c6b3395, 0x3bb12fa8, 0xc123565c, 0x0065f855, 0xfc02df26, 0xb7e37f5e,
	0xc3e0c93f, 0xc31e7078, 0x7ba81f05, 0x1837c2e3, 0x653bac8f, 0x387aa173,
	0x5ddd75bc, 0x6f0d6fa8, 0x9702fb7d, 0x845efcc3, 0xf470f79c, 0x61f7c1bb,
	0xff9a162d, 0x6eabd6f0, 0xfe23fac7, 0xe90f35b3, 0x40d1d464, 0x8e85b223,
	0x6866af1d, 0x717e49ef, 0x3d8673c9, 0x3c2483c6, 0xd433373e, 0xe51e0133,
	0x8f084969, 0xaa1e748b, 0xaac0e93d, 0xb4e73920, 0x6f404ef7, 0x39e6b8a7,
	0x3f42ed16, 0xabb7bcbb, 0xa91de7f7, 0xf7c1f584, 0x41982151, 0xfa3cde84,
	0x11efd83c, 0x8b29787a, 0xadcbe4d3, 0x15fa9a69, 0xf94d5c8e, 0x34abd4b8,
	0x8b3bd7e5, 0xf909f934, 0x6ff535c3, 0xf26a9572, 0xaf5d8693, 0xaee95fa9,
	0x028be4d4, 0x43fa9acd, 0xcb68b5f6, 0xf115320f, 0x6b88f830, 0x9f25a617,
	0x382dc9b9, 0x2efd44f4, 0xcd7f874c, 0x67f7a1c1, 0x79be7b5e, 0xfe977e17,
	0x123dfd4c, 0xa69cdfe9, 0xeee6fcda, 0x46a998fd, 0x412acf48, 0x81aa27e2,
	0xd87923df, 0xf107bdee, 0x8c91ef26, 0x20267f46, 0x59ee62a1, 0x1679ef7e,
	0x411d67f7, 0x9a7f20c4, 0xdc3f2761, 0x4bfd5311, 0xe971e17f, 0xa37be42c,
	0xeb35d342, 0xabde7d1e, 0x5b297759, 0x52d3c3ac, 0x71c2be4d, 0xb8fea6b7,
	0xf29a15d4, 0xea0f9deb, 0x2690f4f0, 0x9d6b937f, 0x75eb4f0e, 0xa6adfa78,
	0x082e53bc, 0xe81bd2ff, 0x64748217, 0xf11cadb0, 0x1089dd70, 0x5b5863e1,
	0xe9e23953, 0x84cd23da, 0xa780e2af, 0xd0e5d91c, 0x30bbf57d, 0x85fd800d,
	0x486adeed, 0x837774a5, 0x7b4bfc93, 0xdd29f21b, 0xefa2e0d7, 0x46186c7f,
	0x6e0d3be9, 0x30d4ff4a, 0x06b6d29e, 0x0dcda50f, 0x4b7f54cd, 0x4ff70b43,
	0x9bde7425, 0x403f42cf, 0x8b5821bb, 0xd39a2077, 0xda7e243e, 0xc76c1d1e,
	0x23be7dfc, 0xe0b72fc4, 0x47f42899, 0xba40f489, 0xd21d34bb, 0x5a863137,
	0xd01f3e12, 0xa117706c, 0xbaf6fe1e, 0xb31ad7cf, 0x857fbb18, 0xc711d527,
	0x13c856f3, 0xd57ce9b2, 0x40dd6be7, 0x28a12f5c, 0x37f296b9, 0x8a23be62,
	0xeeb9bf97, 0xbfc3d273, 0xd5d75c77, 0x76fbae25, 0xdd71375a, 0xed384e97,
	0x703997e8, 0xe11dbfb1, 0xa5f84071, 0x34c8acdc, 0x6352d20f, 0xece50991,
	0x225e9d11, 0xd2d56bd3, 0xcddf4883, 0x74cdd706, 0x1306f8fe, 0xac9dfa43,
	0xd6577b70, 0xf5ce9cdb, 0x2c9b8e83, 0x341d4f64, 0xfba76fb8, 0x69e84a63,
	0xeb57f384, 0xea9c902e, 0x11b287b0, 0x3bae5f7e, 0xa149f3cf, 0x445715a7,
	0xf3e1c4de, 0xffbfbae9, 0xe8e9f0d0, 0xa75f3e0e, 0x0b1cb839, 0x0f50b3b8,
	0x9583f990, 0x638a1aee, 0xe2fbba95, 0x2c780e3a, 0xec7aff7c, 0x1981af74,
	0x473725dd, 0xd3ea73f8, 0xa9feb44d, 0xfd0c2178, 0xb4aab7ed, 0xfcf0f5cf,
	0x2ff73a79, 0x9da09d11, 0xec862339, 0x7e068382, 0xff5f5aef, 0x672e74a5,
	0xef77474f, 0x28bdfcc7, 0xf3529b2f, 0xafe836d2, 0x75145963, 0x4fe9e1dd,
	0xbd4758fa, 0x3b5cf742, 0xe59fd44e, 0x009716e5, 0x6715c509, 0xfca0bfe2,
	0xfebbd6a5, 0x7fea0876, 0x45c62cbc, 0x3571c432, 0x455bc7c9, 0x5609d9e5,
	0x4f669fd2, 0xb9432ace, 0xa9c45338, 0xc98dd8e6, 0xc632ae14, 0x9da9f199,
	0x55a2b605, 0x30b64100, 0x4f8cd2b1, 0x2e6554d0, 0x1de9855d, 0xe3321e7d,
	0x05d509d3, 0x1aa1579b, 0xb85b035b, 0xf05ff884, 0xd79806dd, 0x93aae5dc,
	0xae4273db, 0xa77c97ba, 0x7e921673, 0x2f738a0f, 0x57b20400, 0xcb780937,
	0x9d049b76, 0x388ba716, 0x903640e9, 0xf4e9efdf, 0x474b0fe3, 0xbbf670fd,
	0xf3f07afd, 0xfe85cb6b, 0x8f99bef8, 0x40df7fab, 0xce9cdb8e, 0x6683fcf5,
	0x7cf7c6e6, 0x3972b77c, 0xabfd3850, 0xfd604afb, 0x030ead85, 0xd6e7d1c5,
	0x9c3c436c, 0x3478116b, 0x4fdc16b1, 0x3ef37c53, 0xba4733a6, 0x939793fb,
	0x4736ae97, 0x2cbca479, 0x23ca7a0e, 0x50b0e5e5, 0x45ca3953, 0x0d031f29,
	0xd71f8255, 0xdddd1f13, 0x7bf29cb0, 0xee947c1b, 0xf82d586b, 0xbf951371,
	0xe098f0d3, 0x8fc17ec7, 0xd6f7d237, 0xbe94e986, 0xf4a5e0d1, 0x2e77ac50,
	0x3f1953f2, 0xd2f56a9c, 0xeb3dcef9, 0x53e30c2c, 0x742d5ae7, 0xc476006e,
	0xe2244fd3, 0xdd0b18b9, 0x8f9fd3bf, 0x4ef9f3d1, 0x8efae87a, 0x53c412c3,
	0xd416b9e7, 0xa67a7317, 0x69cc03a7, 0x98d4be47, 0xc84ddd7e, 0x9d380e87,
	0x57a7d476, 0x6ef22e3e, 0xf904dda7, 0xdf47d3fb, 0x80e3f284, 0x40b769d7,
	0xa3e3d57e, 0x69cfb979, 0x03fc828f, 0xee5e6ee9, 0x5de41467, 0x13715e9b,
	0xa652b1f2, 0x51fdc6ec, 0x031dcd6e, 0x75e402e2, 0x17dc6ee9, 0x8de752e3,
	0x01717dc1, 0x9412f4f5, 0x63762bd3, 0x7afe427e, 0x721d5e23, 0x62568adb,
	0x4ac4b2bb, 0x931bb623, 0xb62574b9, 0x21e7db1b, 0xf1bb6463, 0x62579b05,
	0x7ad746fe, 0x17a7ea23, 0x84958f90, 0x597991fb, 0x3cb4f92e, 0xd5a835af,
	0xb0a0f243, 0x40f243c5, 0x6a6ca5c2, 0x77e8fde5, 0x1c516bac, 0xaa63ce0a,
	0xc6bc19d2, 0xf8b56eb3, 0xebf021ae, 0x629f1e27, 0xaceb015f, 0x94b5fcc3,
	0x828ad9ff, 0xbf7f941f, 0xff0dde90, 0x3bf62c3e, 0x7f3c7bca, 0xdfccd87d,
	0xb0a7f8ad, 0xe75aea7b, 0x45fde9d9, 0x9ea3b5e6, 0x0cd94465, 0x3a4558fd,
	0x44a3a44c, 0xdeeaad7a, 0xa4b4e38c, 0x2bb2fb0b, 0xfb15687f, 0xa1af775f,
	0x1fc17287, 0x687748de, 0x61a83bde, 0xbd07e44d, 0xfd2ff9dc, 0x79fd65b9,
	0x594e7908, 0x9e41fe7f, 0x1e7aec9b, 0xbbdf4439, 0x7696479c, 0xa7e73455,
	0x00d791d3, 0x33d07f5d, 0xf708fc9f, 0xa0e025f3, 0x1ce1ef2d, 0xa7e662f6,
	0xce5d7173, 0x120ed8c7, 0x62ebf59e, 0x2efe24de, 0xbb760b24, 0x5d17493e,
	0xe1c4d7d7, 0x07f0e46f, 0xf103aefd, 0xced73154, 0xc9156fd0, 0x825d0e7f,
	0xdaf9e8ff, 0xa72fc50f, 0xf7e1adcd, 0x31f2bbec, 0x57524663, 0x4fef263e,
	0xa7a953eb, 0x3c317de2, 0x237be7a7, 0x3ffcec8a, 0x657b7b25, 0x16567ea0,
	0x7680c6fa, 0x677f2268, 0xde7117f8, 0x315fec78, 0x3cbff8f3, 0xe0c27b27,
	0x6dea3dfb, 0xc44d1939, 0x5851dadf, 0x86491ec0, 0xf7b3f23c, 0xec549e1d,
	0xcd07e58f, 0xf715ef91, 0x99d40e74, 0xd770e5c1, 0x47ce6994, 0x70bfac76,
	0xf4f4ef45, 0x750a8f04, 0x2bef1064, 0x43161b9c, 0xc28cf3f2, 0xea4ef802,
	0xd264d299, 0x9964ce5b, 0xd0fe988d, 0xac99f176, 0xdebfd47e, 0x36933e3e,
	0x1dc7cacc, 0x16d31e3b, 0x79b1f7b3, 0x6e1e0fe8, 0x7bc938a1, 0xc4e07ce2,
	0xa2262e4f, 0x06a89c3c, 0xae950b92, 0xfd99f576, 0x859ccab3, 0x586bed5d,
	0xdf5c18df, 0x8f6cece5, 0xc11e2db5, 0xabb7b7a8, 0xf0c37f97, 0xe588f5fc,
	0xeb9e1917, 0xdfdbeffe, 0x17a4d96d, 0xd17ce65d, 0x11bf90b0, 0x17d18df5,
	0x11c3b9f9, 0x94b5c78c, 0xf3f36f61, 0xdbd52246, 0x600c73e9, 0x6aeef79f,
	0x8352cf97, 0xcedf3143, 0x0bcf3ec0, 0x2ed2e7db, 0x9e7e30b7, 0x7af5ec0a,
	0xc2b3dba4, 0x244c074e, 0x7b8d39d0, 0x13f3983e, 0x745103e2, 0x96a5e2be,
	0xae70934f, 0xfa4b6d7f, 0x30ceebf5, 0xbe39d77d, 0xe7e79161, 0xc57f97ab,
	0x3b2ddf22, 0x4ddafc23, 0xa82f7e26, 0xc92a9ffa, 0xab639025, 0xecd54f11,
	0x119df32d, 0x7f3595f2, 0x41ef09d9, 0x712aefc0, 0x955f244e, 0x57686e89,
	0xd021ec29, 0xd85e7834, 0xec77cc8f, 0xc927ca26, 0xba2633fa, 0x2ccadfa1,
	0x9e56ff59, 0xa2e5934f, 0xf7915f7d, 0xb9f3c03d, 0xbc8dbfb2, 0x3f979dbe,
	0x278fc4fc, 0xfcc20afa, 0x90865d7c, 0x1e5de203, 0x214fefe0, 0x79c4b8df,
	0xe0b96d18, 0x9e1df2ff, 0x8fae7b8a, 0x69f71779, 0xdf6742b3, 0x9135efaa,
	0x7c74febf, 0x7be46173, 0x8cdcf29b, 0xe74edca7, 0xe95e6a98, 0x44e901bf,
	0x464c1fb5, 0x8898e53d, 0x36a857b7, 0x5b9cb38a, 0x4f78f9cb, 0xe5c2de7a,
	0xd5f06baf, 0x6bbc5ca5, 0x1848814b, 0x52cfecef, 0xeb3c1ce8, 0xff7146d3,
	0x791433d7, 0xf1ee80ce, 0x8958f3ca, 0xf68dcc79, 0x51abe271, 0xcfc5bdfc,
	0x2ebf88da, 0xaffb957c, 0x22edd66b, 0x755f3679, 0xc3e8ff92, 0xa44eef5c,
	0x5b7b76c3, 0x2f7b8a3f, 0xd5e6837f, 0xf6e0e390, 0x105423a8, 0x5dfdcf09,
	0x65eeffe1, 0xbfeeffe0, 0x415bfe12, 0xd738a06f, 0x67b228b6, 0xb3418c53,
	0x4798e30b, 0x218d7bf8, 0x6da1b701, 0x7efdd09f, 0x7be79325, 0x8d38f0b5,
	0xc725273c, 0x1ced3255, 0x521e220e, 0x919df933, 0xf8910f18, 0x9ac31d1b,
	0x780dbfd1, 0xb83c0970, 0xde120f10, 0xb408b8e1, 0xd7ec8dcb, 0x248f39a9,
	0x3ed3dee1, 0x9c87d3d6, 0x704e3eb7, 0x09776d87, 0x8ef95fdd, 0xc9eefae7,
	0x24bd0872, 0x1af6e748, 0x73889872, 0x335a3c70, 0x96dde0bb, 0x6bbc6979,
	0xf187ffcb, 0x3e9b87ae, 0x2f7116ad, 0x33abf7fd, 0x70a3ff0d, 0x4fe6dffc,
	0x53bf5d9d, 0xf9773e53, 0xb7f22bfe, 0xbfe83f4a, 0x93daefca, 0x2c93f5bf,
	0xbba44aef, 0x322f2f89, 0xd266bc60, 0x3828ff6b, 0xba0f938c, 0x97743e28,
	0xa67bcb58, 0x6728c7d0, 0x742d4b7d, 0xcee8ec4f, 0xcf9093e1, 0x554779ce,
	0xb7c12ea2, 0x99579f67, 0x66ce823b, 0x09b3ff2f, 0xd06cd7e5, 0x4f8bba34,
	0x8be8283d, 0x5f0093ce, 0xa6656e98, 0xfa771844, 0xf25efe74, 0xc4c40c74,
	0x42f01a53, 0x0b2344f9, 0x95a8fbe0, 0x42c06336, 0xbded21f1, 0x3f788b55,
	0xcd4d0c15, 0xadd555fd, 0x9ba779d2, 0xd2b8f187, 0xba66b6ad, 0xdf633887,
	0x027f677d, 0xafa56ce5, 0x95a39f84, 0x343e87f7, 0xd178977c, 0xfb8c9983,
	0x87111555, 0x38a26a5c, 0x4cddbea4, 0xaa89deb1, 0x6c1bcfc2, 0xe4d5e7e7,
	0xedf584fe, 0xe7e60cb3, 0xd13df1da, 0xa0537aca, 0x23ea217f, 0xa91f493b,
	0x10a2b61b, 0x463756f1, 0x0c296639, 0xcb7585eb, 0x477d26bf, 0xe9f59fcf,
	0x3ea1fa95, 0xf447d86e, 0xa3c7f523, 0xebca010d, 0x46b352fd, 0x71c53bff,
	0xf5cd7f86, 0xdd1711c4, 0x7e71af87, 0xda4b7b7f, 0xd2eed259, 0x7f9271db,
	0xb6d577c8, 0xbbc43a65, 0xefe67f7e, 0xfa791a22, 0x7df6a67a, 0x8167c942,
	0x8999beef, 0x8fc747fc, 0x9532f823, 0x72f8abff, 0x5debee98, 0x9e99bfe8,
	0xd70fdfc9, 0x2a757dd3, 0x7a7aa797, 0xd255cb57, 0x2ef4f46f, 0xf716fce9,
	0xcddff27a, 0x8f30b6c2, 0xdd0a7559, 0xcaf23a83, 0xc2b23f03, 0x3f34ce14,
	0x1bbcd26c, 0xbee91df7, 0x8cf85cab, 0x2def8aec, 0x345b5817, 0xf1cca7bf,
	0x8f0e95f1, 0x6bbf9f80, 0xae55d3f0, 0x895ffdfe, 0x3fd66ebf, 0x45c9fbe7,
	0x711c7446, 0x6a8e604f, 0x6d79e3e0, 0x9e281cfc, 0xf3f0eb43, 0xb9555b7b,
	0x33bef44d, 0xc8b16818, 0x50ef1647, 0xef1e1ad9, 0xbc45a630, 0x05867427,
	0xdf011fde, 0xefe48d17, 0x07797470, 0x4cd5b6c8, 0x07bdd2f8, 0xd67dcf24,
	0xeff47e8a, 0xf38ad502, 0x51fdf29e, 0xfd407bfd, 0x6489ecb3, 0x83660ff7,
	0xd2fc3c79, 0xe51da97c, 0xb89f8465, 0xd90362fd, 0xda9e833b, 0xc8df73f8,
	0xb24b7e30, 0xc359e8ba, 0x0f4d2eb3, 0x317ff2da, 0x67f6a83d, 0xef8f7de9,
	0x4e310f4a, 0xa4acc4f7, 0xdce8bef0, 0x685bafbf, 0x7a77caff, 0x44be963b,
	0x5c746fef, 0xba0f1460, 0xf4663f9c, 0x673d7e19, 0x46fe67d4, 0xc475e03b,
	0x09f91f51, 0xd2f41f86, 0xde6bb63d, 0x6389e371, 0xa3dbb456, 0xdea5bce2,
	0x3088f520, 0x4df7101f, 0x2b8ef9c4, 0xbfff17e5, 0xbde439c4, 0xa0537697,
	0xebca30e4, 0xbedd51ed, 0x167f7d4f, 0xef4f6bc7, 0xf58a1e62, 0x9a788fde,
	0x7cadf822, 0xe542b31f, 0x6b9ed7ef, 0xb14fc953, 0xf9ffa7ec, 0x5d9c27fb,
	0x67ebd7fb, 0x48af8e75, 0xafa4f78e, 0xb9f819d7, 0x4ee5c1f9, 0xf6859f3a,
	0xa42dfa0f, 0x7f5f431f, 0xa3d94e7f, 0x8f776459, 0x7ce3736c, 0xe9f3e31e,
	0xcb755f09, 0x4df8d4bf, 0x6ebf1a7a, 0x7e638947, 0x9238fec4, 0x396f69d5,
	0xf8c35b8e, 0xf8ba52be, 0x4c0766df, 0x014f9954, 0xf1503bb9, 0x71923d73,
	0x6b16727d, 0x0b0e74a3, 0xfc65ea51, 0xe67cf51c, 0xb88174a2, 0xc7393977,
	0xa5e20efb, 0xf7a214c3, 0xf2becf5b, 0x5de80b7f, 0x3446eba6, 0x1fa8d9e1,
	0xd7ad7fca, 0x428a3aa7, 0xff21a687, 0xb37ff6d8, 0xaff7249d, 0xf6e8fdec,
	0xab307758, 0x9ff6ff1b, 0x6f7e554a, 0x7f2771c2, 0xdbc1d1f7, 0xfc4931b0,
	0x5ce4ddbd, 0xdf308ba2, 0xf92f594c, 0x06b1c626, 0x38f0331e, 0x7e8562fc,
	0x6825a657, 0xf0362da0, 0xfe3f5cf6, 0x56cb4b2e, 0x26b03e5e, 0x7e40afce,
	0x5e28f0e0, 0x8fce34be, 0xb367dee7, 0xb9cbed20, 0x8aabc4f8, 0x949c21f7,
	0x69de26de, 0xb7bb0d06, 0x6f6fed02, 0xdbf3f2b5, 0xd707d82c, 0x48f6885b,
	0x88eef637, 0x07dfbe6c, 0x7efce6f5, 0xbfd69950, 0x75e51060, 0xb3b36539,
	0xed945d21, 0x141d3156, 0x61e6b6df, 0xcdb0273c, 0xd61ef0c0, 0xa6efc317,
	0xf76c8a78, 0x35994e68, 0x49b0e01b, 0x7d8ce7e1, 0x1df22c3b, 0xbf48e4d3,
	0xf29ce4fc, 0x292fec58, 0x52ff099b, 0xdfc570f7, 0x3fbc8a59, 0x3e57de18,
	0x7508376a, 0x322ff242, 0x93682f7a, 0x9efdf3c2, 0x595a4db6, 0x1f4c3e40,
	0xe68f9dea, 0x5e707378, 0xd98ccc83, 0x894ffe70, 0x3eac33fb, 0x8bdfe31b,
	0x5018b69e, 0xc400f8af, 0xf82bde31, 0x98b3d80b, 0x2976047e, 0xbb057fa6,
	0x6063d314, 0x29fa6297, 0xde98a5d8, 0xdf08be7e, 0xb33b620a, 0xff60d7dd,
	0x9fa0ce32, 0xdb9b2baf, 0x5e397543, 0x3ce76782, 0x1e699876, 0x7edae29b,
	0x63cc30f9, 0x063eb6d3, 0x13d2d7bc, 0xfc763a3c, 0xbf52fb3d, 0x1de322b3,
	0x62fef2fa, 0x46adc2fc, 0x2d85fb92, 0x1185d8c1, 0xcdb22af5, 0xdb703e54,
	0x7fd8b167, 0xae13a3bb, 0x3a96056e, 0x15f3c0d1, 0xad27bdd9, 0xe398be44,
	0x85eb8d9e, 0xa63d7dfd, 0xf9ff2d85, 0x01c7bc4b, 0xb65c53fd, 0x823d0943,
	0x1d7e98fa, 0x75cb75fa, 0x60d7fac1, 0x7adb4dfb, 0xdf804ae3, 0x765fbe30,
	0xbb72f7f0, 0xd10577ae, 0xa84b24e7, 0x4c27ef18, 0xf6ed56fa, 0x4e5d685c,
	0x02fbc129, 0xb7a49dea, 0xd3948934, 0xf7d7c495, 0xfefad7dd, 0x00877c98,
	0xe513a879, 0xd458c5d1, 0xfc452b07, 0x9f6b65b2, 0xcbbee8f7, 0xefe1953e,
	0xd78a0dea, 0x8126bbee, 0xdc0e9927, 0xbe20f661, 0xde38ed36, 0x04e7df07,
	0x1db9f4fc, 0xfbb2fbea, 0x0c91ce6a, 0x71e17e1c, 0x4fa81fa4, 0x8337a3bf,
	0x38c0afad, 0xceeb4cfd, 0xd9a4b83d, 0x1815638e, 0xaa9b9fa7, 0x9e74c5ec,
	0xc62c7733, 0xe6f9e5e7, 0xf74bf2db, 0xd1ba56e2, 0x5c7a4955, 0x08973229,
	0x8d6e50b9, 0x4af58f11, 0xc9a09439, 0xd0cd4b8f, 0x99debfd4, 0x909f29a7,
	0xde53403f, 0x35c4ef79, 0x37bdfc24, 0x1bd423c2, 0x0eb066e3, 0xcf7cbbfe,
	0x69be74a9, 0x3783b6e0, 0xc4fc800c, 0xf7a66fe7, 0xf28936d7, 0xfdca5b89,
	0x800e8f88, 0xa91419a7, 0x7c1ec313, 0x4cec61e4, 0xef541f67, 0xbe2f6678,
	0x7da3dcd7, 0x60bb1970, 0x687ae309, 0xde81f64f, 0xf93e002e, 0x8393e44b,
	0xc0ea995e, 0x869bdff3, 0x3947485f, 0xb8b652f4, 0x85ec261f, 0x73a5e89e,
	0xf7ce285f, 0xe947ef22, 0xfbb185e9, 0x74f1fd04, 0x0f7e01e2, 0xb1f2bbe8,
	0x918f91cf, 0xfcd3eddd, 0x7f575f1e, 0x5f2fe719, 0xdf745d19, 0x9c599075,
	0xb4f7146b, 0x35256216, 0xc2b5ef4c, 0x5b32764f, 0xb05923dc, 0x44b4fefe,
	0x3723e7aa, 0xfbcef554, 0xf2238ad3, 0xcb698ecb, 0x695655ef, 0xb5732bf2,
	0xaba5b5f9, 0xa4f7db22, 0x6c7c2d87, 0x103bd99e, 0xdd29f3ef, 0xc9e10efe,
	0x65ff1e6c, 0xec2f8289, 0xf67c4458, 0xf4c5cef8, 0xfafaa7fb, 0xfa1fd0b5,
	0x20f616fb, 0x9a7f255f, 0x7cf7f2a1, 0x977fe5f5, 0xd87eb9e3, 0xd8003ef1,
	0x57ae79d3, 0xa0fddcb9, 0x91acd797, 0x7f5c39eb, 0xa1eebb3d, 0xf1837e9f,
	0x9edceda4, 0xf1c71b3a, 0x0bf5b85a, 0x41d20183, 0x85af1cd1, 0xef01a08e,
	0xc55474cb, 0x76fcf0f8, 0x9d3b62dd, 0x3bd41bbb, 0x4815bef4, 0xdfe73a26,
	0x3a05617f, 0xc12f10fd, 0x0ee1c845, 0x3e30b9d4, 0x24359bff, 0x97df3b87,
	0x99d681fb, 0xe9193a0c, 0x5f9c652f, 0x13fa41cc, 0xfec18af2, 0x759fbbaa,
	0x43e42fca, 0x7bcc1708, 0xdefe7e72, 0xed7e50af, 0xfd02fce7, 0x0f493306,
	0xfeb4db70, 0xefda6684, 0xe4676ff0, 0xf91e90f9, 0x3326eec7, 0x343f95da,
	0x7392191f, 0x60717e59, 0x6eb1e002, 0x7dd73f3b, 0x2f6fb5ae, 0xba3fc116,
	0x54c7c3c8, 0xdf32e7da, 0xc78eaade, 0x9fbfa0fd, 0xdccce12c, 0x77cbff7c,
	0x8533de75, 0xd3b9d326, 0x773a461d, 0x99c9a77b, 0xf1a97712, 0x19ccab56,
	0x1da0de31, 0x72679216, 0xbe0e1d1d, 0xfe3b41d6, 0xc05a5f16, 0xc8dd15d3,
	0x4c07d055, 0x540fa889, 0x1ebf642a, 0x865291da, 0xb0a43878, 0x75307380,
	0xa747e741, 0xbbf0eef0, 0x488dde8d, 0xbe4637cd, 0xd7ed27a7, 0xdcdc779b,
	0xf7d6f517, 0x043fceb7, 0x728b6218, 0x4c5f68f2, 0xb3d23e63, 0xb279c50f,
	0x51322fd0, 0xc50f5fc4, 0x7ea0ce85, 0x8c54687d, 0xe84b7e82, 0x2ff6257f,
	0xe4c875d7, 0xf48faac9, 0xfeafba2f, 0x7572ef5e, 0xbdea63ea, 0xbce813a5,
	0xcd77a33e, 0x9f5ca927, 0x7df26f66, 0x9d6bf92d, 0xef4f16d2, 0xbe4ce49d,
	0xa7da0727, 0xf0b9ff2c, 0xce69369f, 0x3ea95d17, 0x6f3f69dd, 0x17bbf854,
	0xb5af4e2e, 0x7aff4f23, 0x02a7de1a, 0xbbf51f3b, 0xf49d969a, 0xaede8a0e,
	0xf4abb4ef, 0xfaefc2fe, 0xbb1748be, 0x5c2bf3cc, 0x7e9fb2df, 0xeb1a6875,
	0xe5859f6a, 0x0ef34b96, 0x862bc814, 0x9efac5ef, 0x77e7bfe3, 0x7da9a9a7,
	0xcbde3149, 0xb0f870ce, 0x97d797ba, 0x37bc35ef, 0xbbf6d1ea, 0x85fabca1,
	0x559a0718, 0x0f9972cb, 0xf5b2cde5, 0x351fc9fd, 0x1dfcecc8, 0xe843aefe,
	0x877a26b7, 0x18d224e2, 0xb96e4fe4, 0x6a5f7e8a, 0x0bf9c191, 0x3d8c7f7c,
	0x7e9d12af, 0xf48594f1, 0xf387c594, 0xfdc14f48, 0xe79504e7, 0x1d47d00b,
	0xcbf16ed0, 0xfaafd419, 0xdbd79d82, 0xdff74294, 0x3c4f7e25, 0xb2f74515,
	0xfb9b0aab, 0x5fdbe005, 0x7357decd, 0xb2a7af00, 0x01a7cffc, 0xf85fca9c,
	0x3f509fc7, 0x8929bc58, 0x73c615f0, 0xb9c57af7, 0x1fce3cd6, 0xf7bebc04,
	0x5da9c879, 0x81ddfbde, 0xfc61a9f8, 0xee793cfd, 0x7fc6306d, 0xeb3f5e10,
	0xa1f2fefe, 0x56e7ae1c, 0x024f7f4b, 0x7ee2a6b3, 0xeefe32f6, 0xd3facfdf,
	0x7367adbb, 0xbbdf3be2, 0x24f2f7e1, 0x7dad1ebd, 0x163dfc9d, 0xaa2abe7e,
	0xb1f938fb, 0x2c7fae1c, 0xf1ad7eb4, 0xbf2ed537, 0xd503f1a0, 0xffdff016,
	0x1ce8dc1d, 0x7cafbf82, 0xa0c3c097, 0x0867cf54, 0x1f9a3bf7, 0x821de57a,
	0xfe3f93e7, 0x67ddc710, 0x7b133f23, 0x3a67d847, 0xf5a16bfb, 0xd71fb14b,
	0xf1f7f66b, 0xd10b8775, 0xdb7c720f, 0xa8ddfa00, 0x71db6af9, 0xdda8df7c,
	0xbe31f6de, 0xdf65bd5f, 0xeb87f201, 0x5ce5dbe7, 0x53f9c280, 0x0123ae35,
	0xfe7871cf, 0x3df6872b, 0xac9f17e7, 0x93f04819, 0x938ee97e, 0x7287dbdd,
	0xffffb29e, 0x6874a507, 0x008000e7, 0x00000000, 0x00088b1f, 0x00000000,
	0x98edff00, 0xe5556c7d, 0x739fc019, 0xbd2afdcf, 0xa4fdbdbd, 0xdb9e1fa5,
	0x694ab56e, 0xa5296d8f, 0x52d8e32d, 0x05e64344, 0xe30a2331, 0x50a20a6c,
	0x42d9477b, 0xdea7099c, 0xacb8af8c, 0xc49512cb, 0x1a64772d, 0x74d9d0ff,
	0xd8f8eac8, 0x9ba54675, 0x83246bc3, 0x458e4361, 0x6e5b163b, 0xb2634e65,
	0x7bcf3d84, 0x53dee5ce, 0x5bff3a0a, 0xafc8d4f2, 0x9ebf79ef, 0x3b7df7ef,
	0xa34cf079, 0x253000de, 0xc8229b49, 0x1cb3f42b, 0x00b8afc0, 0xbda6004a,
	0xfc42c6c9, 0x029574fe, 0x3fd338b0, 0x16364c1d, 0x487be804, 0xc42e9f7c,
	0x30038e36, 0xf4f5bcc4, 0x0fd2336b, 0xe462e29e, 0x818d497a, 0xa1406ef8,
	0xfec74260, 0xc14765ed, 0x2183445d, 0xb8052fe2, 0xe29fec17, 0x01b43722,
	0x71dfa3ac, 0xffdb7beb, 0x041485f2, 0x3d860fb8, 0xd6700b50, 0x3f43f835,
	0x17f86a72, 0x83403d1e, 0xeb268456, 0x9ce32401, 0x8cc2caeb, 0xe009b39c,
	0x3f471a06, 0xbc8ce457, 0x47d43746, 0x50e99d71, 0x013570c0, 0xee48a2dc,
	0x57763f49, 0xc38d1541, 0x8ad1357e, 0x31a9f11c, 0x390ee794, 0x79c148b2,
	0x4689bddb, 0xeef33390, 0x7df17590, 0x0b7b7a4a, 0x8976d0d4, 0x401e48c6,
	0x520bc0aa, 0x4d44b23e, 0xe30f686a, 0xa73ea0df, 0x4c267908, 0x9205c794,
	0x81e52790, 0xc72823f5, 0xb7eefa32, 0xb4030ce5, 0x23a2b8f6, 0x8cf8cc81,
	0x1bf6cefc, 0x47f437e4, 0x3a2b916b, 0xfead70dc, 0xc6bf6d1b, 0x31065860,
	0xd1f9d61f, 0x9db69dce, 0xd0193401, 0xedda8f0f, 0x8481fd47, 0x057288dc,
	0xf28c86fd, 0x3f431e77, 0x9dd3bb60, 0x69288d78, 0x9fd0bb00, 0xd6b0901d,
	0x5d4cf51b, 0x97f50795, 0xd80d8d70, 0xdd0b650f, 0xed876eb4, 0x14523dde,
	0x187e8fc8, 0x25203c12, 0x60b7e265, 0x90835046, 0x1766889b, 0xc111015c,
	0x5c151095, 0x77824305, 0x6ae0b0c1, 0xadc20a48, 0x69841889, 0x9343c787,
	0x1f3b88b9, 0xb6415d72, 0xc3a2077e, 0x61ed6b81, 0x0c3da97c, 0xebf0e289,
	0xe82563da, 0xebae4265, 0x5eb2a5d9, 0x2eda79c4, 0x9c478a3e, 0x32f10397,
	0xc53032e2, 0x7029cb3a, 0x41db9d71, 0x07bb5371, 0xfdeed134, 0x3768f68a,
	0x30deb775, 0xe67a5d87, 0xb6fd938e, 0x96c88a5d, 0x1d7f1925, 0x903aac55,
	0x9ca01bf6, 0xf9734591, 0xce49aa13, 0x7feedcd6, 0x7e225829, 0x7119dca3,
	0x4b76c52f, 0xb62d40f7, 0x45f7288f, 0xeed8e5dc, 0xa8f16eec, 0xf7838300,
	0x5b605647, 0x023609cf, 0x87df91e6, 0xc8fb4036, 0x17b432b5, 0x38eaf7d2,
	0xf27d7da0, 0x53ca540f, 0xd920073d, 0x14b9d220, 0xaae22f28, 0x676be28b,
	0x9d53f2c8, 0x8295ff4f, 0x13f9f672, 0xbded0541, 0x3e77b073, 0x5ebdf8e0,
	0x4a0fdd6b, 0x51478594, 0xe3ee1f37, 0x85e8ce6f, 0xb60e46fd, 0xd819494d,
	0x93c8ce15, 0xec2bffde, 0xf68dd2fb, 0x1f5f353d, 0x50507ea1, 0xe1579c69,
	0x8c8de6b7, 0x12b8aa74, 0x721211ca, 0x03757998, 0x94fca8bb, 0x3d528e45,
	0xf159e549, 0xfcb15476, 0xa2a4e691, 0x5c94aabd, 0xf8353dfb, 0xfe0491f9,
	0x3708fa9e, 0x28ef79c6, 0xedf6827a, 0x2dd59977, 0x722797e8, 0x1e297bcf,
	0xe12af1d2, 0xef501bbe, 0xaf710698, 0xd0ae83c8, 0x4051d624, 0xcda95c9f,
	0x336a7bc4, 0x68f687ae, 0x3c7a448d, 0x3eb6ddd8, 0x5db13afa, 0x1ec1ea1f,
	0x24afe7da, 0xb33cbf4f, 0xa97ffc85, 0x47ef3de0, 0xad2b1f22, 0xd4ebb3b8,
	0x3f6313f1, 0x119ab0ae, 0xfeb7cac8, 0xf67c5f13, 0xfec7d63e, 0x869501cb,
	0x383b1e77, 0x9e4cc100, 0x751c0401, 0x1d779d24, 0x2c84bea3, 0x99b2ddc6,
	0x6f7b2fc6, 0xefea96bc, 0x863371f2, 0xc75217e5, 0xf15854cf, 0xda139f6f,
	0x39d7d2e7, 0x74657a27, 0x3b039e3a, 0x3ee3915e, 0x04876bd4, 0xb606db57,
	0x78c7e1ff, 0x5af1a7c9, 0xdaf51ca0, 0x37d5eb6a, 0x8b1786f6, 0x90632d3c,
	0xf2db0fbe, 0x81f67d6f, 0x0f5714d5, 0x7a993dc7, 0x1b6fff8f, 0xb921ef8f,
	0xfce0bdb7, 0xf491954e, 0x6fe7b7ef, 0xf94bd307, 0x1cec37d6, 0x7e4f0fd7,
	0x7faa7542, 0x70fcd674, 0xabf0b15e, 0x1d01ae7d, 0x43deb83d, 0x2fd218f6,
	0xf71cfa40, 0xdba87dc6, 0xa80e5f8e, 0x05576a21, 0x3f575154, 0xfe48027c,
	0xb67878f4, 0x3a48c448, 0x27de1f4f, 0xb192d281, 0x3ef3d363, 0xf4d1fc8d,
	0xf48d7cfc, 0xb882f26c, 0x88e26067, 0x9b426f38, 0x2f771848, 0xb8d4cc17,
	0x8f979f70, 0x7158abd7, 0x35bb0fe1, 0xc8c9e0b8, 0xafcec3b7, 0x1ec5f95e,
	0xe5c7c62f, 0xa3e42107, 0xa7fa83f8, 0xe2de70bb, 0x63881e93, 0xfcb065ff,
	0x2ba2f971, 0x8c74eb4e, 0xbb264efd, 0x3cacf3cb, 0x40b995f6, 0x8e47b2c9,
	0xfa940f32, 0x5f6d3b4c, 0xdcb7ed9f, 0x7f4742fa, 0x31c0ba9e, 0xc6bdbf3f,
	0x09cb1fd1, 0xc07da21e, 0x6d0d92d0, 0x75adbf54, 0x1d5bb40a, 0xffc4c0f3,
	0x36cbbfb0, 0xcae0dee3, 0xcbc71493, 0x93575b02, 0x35568abd, 0x8fcbc73b,
	0xef97a4cb, 0x5ea1f602, 0x1dba9f5d, 0x7298ed7e, 0x1e9f17b6, 0x9bee2082,
	0x7eeb3a73, 0x8035fe20, 0xc53e23ee, 0xe287bdf9, 0x12ae1282, 0x22e3b32a,
	0x55c0f763, 0xb45c52bb, 0x761c37c1, 0xf4376d9f, 0x5d2fb883, 0x86a80cae,
	0x4943f192, 0xf9ff69c4, 0x2ff69deb, 0xaef69dd7, 0x77b4ead8, 0xef69d455,
	0xed39769b, 0x769c361a, 0xe1d7ddab, 0xa1cdff18, 0xe6fb476e, 0x8c72ee67,
	0xd6be25bf, 0xc2f85ed1, 0x8bf18e7d, 0xe8efbf86, 0xc47d1a6f, 0xb38e9fd1,
	0x6dc1c5eb, 0xe2b31d89, 0x1bae05cd, 0xc9cb41c4, 0xcdfb1cc7, 0x8812fbf6,
	0x9da1e4f4, 0xbda34fdb, 0x20e36b95, 0xea8034c7, 0x9838ece0, 0x2cd8ffed,
	0x7c84ffff, 0x2a79f98a, 0x4a49f178, 0x5ae76fd7, 0xee57ad75, 0xd7e46a4a,
	0xbe4a8f2e, 0xea29477e, 0x60baa3c9, 0xfb11679f, 0x7bc3833c, 0x6ac876ac,
	0x75f549ab, 0x67cd67aa, 0x97143d23, 0x75f466ad, 0x2eda0f54, 0xd3e4f50e,
	0x10940d78, 0x3b6c978e, 0x812edddd, 0x984edb3b, 0x8cd2eecc, 0x0631ef1d,
	0xdc1c7ce5, 0x4c789ff9, 0x16285b94, 0xddad6975, 0xe75bb52f, 0x072d1ac5,
	0x58f659dc, 0x473e9ed6, 0x697c841a, 0xbf63dfbb, 0x0f9ef02f, 0xbbe7ba5e,
	0x7858f1fc, 0xfa8d7bae, 0x5dee2c8c, 0xbd87b8ba, 0xe21ee925, 0x9ab27f3a,
	0x52d3fbe2, 0x9e30a5fd, 0xaa5c9713, 0x926dee22, 0x52a52319, 0xb43898a4,
	0x0d688fde, 0x5fc01ef4, 0xd8a7e017, 0x101188d9, 0x944c87e2, 0x79e5b75f,
	0x091fac35, 0xa427fda3, 0x9c169ed0, 0xe3e3aa7b, 0x2ebf3a6a, 0xd3dfb505,
	0x576f6377, 0xf3e3a881, 0xb3ac2f51, 0xc8314ba6, 0x9263c604, 0x4c7c5778,
	0xcacd2c8b, 0x711e7ddb, 0xcefd815e, 0x29db68da, 0x60dacefd, 0x4b813bef,
	0xbe3ac56c, 0x612df471, 0x53656d8f, 0xaa2cfbf6, 0x07fd7086, 0x07cd032a,
	0x45ad1748, 0xbe88bb5d, 0x155ddfa7, 0x9e72fff2, 0xf90dcaf6, 0xcef71ce6,
	0xfd95b734, 0x757bec53, 0x39d68bfe, 0x0df5fd73, 0xf4673e71, 0xd89fd6b6,
	0x9fce2b9f, 0xdd55fd89, 0x97faccc4, 0xd4e78dc0, 0x8ebbe8c6, 0xebb4d8f8,
	0xfbb88eef, 0xa381f19e, 0xf19e2cdf, 0xe6fea054, 0xf795f291, 0x5fa6fda3,
	0xfbd1b5f1, 0x1535fd13, 0x9b1f7ace, 0x0579bd3f, 0x7ae5f7ed, 0x18e42c7e,
	0xb7049ddf, 0xf9e7a327, 0xdb4567dd, 0xce0a6ddc, 0x5efd33d6, 0x27fbd34d,
	0x7fa377a8, 0xea79a466, 0xfbb5f0a1, 0xef58d5f4, 0x4bdbf1c2, 0x1e1ce9bb,
	0x2dbaf2af, 0xf2ed59d6, 0x5ed5bf76, 0xf2988ab9, 0x7bd1f604, 0x4d025c75,
	0x589878c2, 0x5ef3d9f0, 0xa954e25c, 0xeb83539e, 0x3e67baa4, 0x5139d173,
	0x79d3566c, 0x3d02b3f2, 0x49728350, 0x2f2c0978, 0xd1d67214, 0xcba2e0bb,
	0x0d602df8, 0xaca35258, 0xa5fffba1, 0xa1f715a0, 0x1435ca9a, 0x450b7ff7,
	0xd03d690a, 0x4f8d2f4c, 0xb2f98bcb, 0xf46bde9e, 0x49f7a61e, 0x82e2c72a,
	0x51e8491a, 0x70c92c41, 0xaf558d61, 0x95ecd956, 0xe893ac9f, 0x0f8cf09e,
	0x5c27ee28, 0x0bf746b2, 0xfe2f84e3, 0xa981e51c, 0xfec2e6dd, 0x2a9535e9,
	0xca2973c5, 0xbc17f74c, 0x40f789a5, 0x097d1ff3, 0xfc5b13aa, 0xec388a9f,
	0x4f389b1b, 0xa3c17df9, 0x9f5e51b4, 0x93b7eb0b, 0xd7c17dbe, 0x083bd6bc,
	0x131baa34, 0x0e877c47, 0x96dee984, 0x2b30ff13, 0x0b86fa8e, 0xd1feed1c,
	0xd987f8f2, 0x05fa3df7, 0x24eb0efd, 0x6eddbf71, 0xacb163e7, 0xf8fb112f,
	0x08feeb4d, 0xd74ec233, 0x737a73d3, 0xe406a9f2, 0xbbf53ca5, 0xcb84e724,
	0x7d55ef29, 0xeb33b96c, 0xb74e38dc, 0xe4713ff8, 0xbdc1e4e3, 0x68f71475,
	0xd4fc9d37, 0xd69b4b2c, 0x41ff31ce, 0x654d5fdb, 0xcfc9bb91, 0x7e7f448f,
	0xdb256de4, 0x3a3f43cf, 0x2c6b7547, 0xf5d6ea20, 0xb3d6cfe6, 0xb098c4ef,
	0x6e7a1cc7, 0x7ad27da4, 0xf33f1f4e, 0xf5f28354, 0x25554bf5, 0xea6eb4bd,
	0x2b545fd7, 0xd8efbf38, 0x2e29675b, 0x03bfecfa, 0xbbe761c0, 0xdf0f37de,
	0xf559858f, 0x4dd66a99, 0xbeca5ba2, 0xf3d2f91f, 0xf9cedd2b, 0xbca63178,
	0xc3fca51a, 0xf4e1c3fb, 0x47cf027b, 0xf3e9d3aa, 0xdf1fb0f1, 0x924b98a3,
	0xd3a8a6f9, 0xedc52fb4, 0xe710c91e, 0x07effa54, 0x21cf0931, 0x407d4f8a,
	0xa6f96fd4, 0x79f14a80, 0x492f6318, 0xcb5b8ee7, 0xf670a3a5, 0x4f93763b,
	0xdc7643df, 0x7cf76ef9, 0xfc8ee77a, 0xfdfb2ef9, 0x8b1f9d64, 0x4c5cf8ed,
	0x0d1e93fb, 0x691ce2f9, 0xf36be5b5, 0x77ba6547, 0xb643052c, 0xbbfec3f2,
	0x1d37fec3, 0xd90eaeef, 0x93263f8a, 0x993264c9, 0xc993264c, 0x4c993264,
	0x64c99326, 0x264c9932, 0x3264c993, 0x93264c99, 0x993264c9, 0xc993264c,
	0x4c993264, 0x64c99326, 0x264c9932, 0x3264c993, 0x93264c99, 0x993264c9,
	0xc993264c, 0x4c993264, 0x64c99326, 0x264c9932, 0x3264c993, 0x93264c99,
	0x993264c9, 0xfff3264c, 0xd205ff81, 0x00fc9234, 0x0000fc92, 0x00088b1f,
	0x00000000, 0xc5edff00, 0x30000d31, 0x48b0c00c, 0xfca7b4c5, 0xecc81581,
	0xabd53bc7, 0xb6db6db5, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xfb6db6db, 0x1c6a0fe3, 0x8000549d, 0x00008000, 0x00088b1f, 0x00000000,
	0xc5edff00, 0x30000d31, 0x48b0c00c, 0xfca7b4c5, 0xecc81581, 0xabd53bc7,
	0xb6db6db5, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xfb6db6db,
	0x1c6a0fe3, 0x8000549d, 0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00,
	0x30000d31, 0x48b0c00c, 0xfca7b4c5, 0xecc81581, 0xabd53bc7, 0xb6db6db5,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xfb6db6db, 0x1c6a0fe3,
	0x8000549d, 0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d31,
	0x48b0c00c, 0xfca7b4c5, 0xecc81581, 0xabd53bc7, 0xb6db6db5, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xfb6db6db, 0x1c6a0fe3, 0x8000549d,
	0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d31, 0x48b0c00c,
	0xfca7b4c5, 0xecc81581, 0xabd53bc7, 0xb6db6db5, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xfb6db6db, 0x1c6a0fe3, 0x8000549d, 0x00008000,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0x00000003, 0x00bebc20, 0x00000003, 0x00bebc20,
	0x00000003, 0x00bebc20, 0x00000003, 0x00bebc20, 0x00000003, 0x00bebc20,
	0x00000003, 0x00bebc20, 0x00002000, 0x000040c0, 0x00006180, 0x00008240,
	0x0000a300, 0x0000c3c0, 0x0000e480, 0x00010540, 0x00012600, 0x000146c0,
	0x00016780, 0x00018840, 0x0001a900, 0x0001c9c0, 0x0001ea80, 0x00020b40,
	0x00022c00, 0x00024cc0, 0x00026d80, 0x00028e40, 0x0002af00, 0x0002cfc0,
	0x0002f080, 0x00031140, 0x00033200, 0x000352c0, 0x00037380, 0x00039440,
	0x0003b500, 0x0003d5c0, 0x0003f680, 0x00041740, 0x00043800, 0x000458c0,
	0x00047980, 0x00049a40, 0x00008000, 0x00010380, 0x00018700, 0x00020a80,
	0x00028e00, 0x00031180, 0x00039500, 0x00041880, 0x00049c00, 0x00051f80,
	0x0005a300, 0x00062680, 0x0006aa00, 0x00072d80, 0x0007b100, 0x00083480,
	0x0008b800, 0x00093b80, 0x0009bf00, 0x000a4280, 0x000ac600, 0x000b4980,
	0x000bcd00, 0x000c5080, 0x000cd400, 0x000d5780, 0x000ddb00, 0x00000028,
	0x00000000, 0x00100000, 0x00000000, 0x00000000, 0xffffffff, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x00088b1f, 0x00000000, 0x51fbff00, 0x03f0c0cf, 0x33a80f8a,
	0x32ead430, 0x31e90430, 0x43d61c30, 0xf712d388, 0x9fa65171, 0x81818597,
	0x8105881f, 0xbf881858, 0x7c303231, 0x3f5e2467, 0x5d82089b, 0xc0c0c02f,
	0x0107e40e, 0x0c825fe9, 0x19846f0c, 0xfc803818, 0x46fe40a9, 0xc40bde20,
	0xcbb140fe, 0x101dfa40, 0x4e6202df, 0x73e6fc11, 0x293f9011, 0x8affca84,
	0x882c7fc6, 0x308ebf5f, 0x0223797e, 0x6af0d8f2, 0x87c66e02, 0x77a0503f,
	0x350df020, 0x2ababe54, 0x50218303, 0xc21d49ac, 0x3f2489bf, 0xa1a62805,
	0xcab3610a, 0x00c83033, 0xb0d4b7f9, 0x9406cb9b, 0x2fca0597, 0x3f781f50,
	0x4200c3e2, 0x003cdb36, 0x00003cdb, 0x00088b1f, 0x00000000, 0x7dedff00,
	0xd5547c09, 0x73b9f8b9, 0x9264cee7, 0x2124c999, 0x8093ec21, 0xb0e21a80,
	0x27518085, 0x4482f084, 0x1411151c, 0x42122271, 0x1b5a26c8, 0x6e7fdf6b,
	0xb5282258, 0xfa8f2eb1, 0x36080ea2, 0x0201a8a5, 0x60e21946, 0x1b62a900,
	0x975a155a, 0x2422fb0e, 0x8b6a2a01, 0x3bef9df5, 0x7bdccee7, 0xfcb89133,
	0xfbebebde, 0x277f3f8f, 0xdbfd9ee7, 0x73be77cf, 0xc4ad1a30, 0xaf908831,
	0x211d77e1, 0x90848acf, 0x31da48e4, 0xe918f3b1, 0x55bc8845, 0x0813ae72,
	0x05b0de11, 0xc8431baf, 0xdf82d5de, 0x96c1f34c, 0xfe684238, 0x7e4dfd4c,
	0x8fcd1a73, 0xbf31bb34, 0x79f31736, 0x1bb7de5b, 0x8b7cbe69, 0xa1bc8468,
	0x643da4e5, 0xdcd2a425, 0xf4d5d8f6, 0x9116e77b, 0x1143a1ac, 0xc90354e7,
	0x0c58e422, 0x34e5bf61, 0xb148429f, 0x57cb6585, 0xf30398ef, 0x13366928,
	0xfca7ed0b, 0xaed3f9b5, 0x7bf9f9a6, 0xca550224, 0xfa98d5d7, 0xbf02fcd2,
	0xc5f908d0, 0x38e21f2d, 0x4949131d, 0xa7210663, 0x39c4317c, 0x6dede68c,
	0xefd2b729, 0x938dfea5, 0x06e97ea1, 0xf5a065c1, 0x7c77eb4b, 0x3697fd04,
	0xda444349, 0x3886c2ff, 0xc6ce1ce2, 0x3ac09afe, 0xf9834de6, 0x2256ff96,
	0xb92f9a66, 0x00899f78, 0x26758c8c, 0x7fc60d8f, 0xc1b4e4dc, 0x8e380d38,
	0x5ff2cf02, 0xbb6871d3, 0x1705978a, 0x40c2ad2c, 0xf69f30bc, 0x5f332cd7,
	0x6abac2b0, 0xfda1434c, 0xa09b0f6b, 0xd17f7cde, 0xe6138b56, 0x1934dab7,
	0xdabf59e6, 0xe9119c54, 0x6fc3616f, 0xb63af334, 0xaf6f706a, 0x9e9f5caa,
	0x9ad051f2, 0x4252f923, 0x98568ddc, 0xd374dfb7, 0x23f7c888, 0x7be20242,
	0x9c488361, 0x29fe9131, 0xfcbbf1e6, 0xe813fd3e, 0xbfcdbb60, 0xaf822d2e,
	0x3bf80e45, 0x0e73af82, 0x67633f8e, 0x257fba96, 0x40f00c7d, 0x73e753e7,
	0x5f0bfa60, 0xfa4fa62a, 0xa7b7089c, 0x5d31c37d, 0xf7e173e5, 0x98d97c67,
	0x98dcfbd6, 0xc02be73e, 0x60f3efd4, 0x99be35bd, 0x79f5ae98, 0xbe8bfbf1,
	0x7c1b4c12, 0xbd7df855, 0x0dd31aaf, 0xbfbf193e, 0x698e5bec, 0xd30eafa3,
	0x9855be4d, 0x58fcf936, 0x5fc72b6f, 0xbf11afb3, 0xc66beebf, 0x620be034,
	0x83dbe2da, 0x570e4ae9, 0x35c90e7b, 0xddd8b852, 0x81d941c4, 0x73ba1624,
	0xf44f9a25, 0x6cca7cb0, 0xf344d739, 0xa79a5e29, 0x165bea70, 0x7cd335cc,
	0x3e562adf, 0x6264a7f0, 0x940fcd0c, 0x4afa7959, 0xcd0b44f7, 0xf2b1d7a7,
	0xc4f2f5a1, 0xea1f9a58, 0x6c57e567, 0xa38c4e08, 0x591a2bf9, 0xe4806679,
	0x333e6959, 0xf6a3f2c8, 0x346cf3ba, 0xe58daa3f, 0xf3923eb3, 0x159f34ec,
	0x9c27ed62, 0xd3c5e60e, 0x564e84fc, 0x90c5ed7e, 0x3f428ce8, 0x5cef255b,
	0x97e97142, 0x7d8dbaa7, 0xbde4de68, 0xbc28b88f, 0xe36ee9e4, 0x491f0a78,
	0xf29df2c6, 0x6cde589d, 0x03fcb192, 0x5fcb18b9, 0x7e58fc97, 0xf2c4ae42,
	0x2c7e4dd7, 0x8d5c9bff, 0xc41480f9, 0x0d4d6b72, 0x82980fd6, 0xe6b03e58,
	0x916f2c11, 0xaaee5842, 0x5bcb0279, 0xff2c214c, 0xf77ad2c5, 0x547f9a24,
	0x74033ef0, 0x96f044b9, 0x6f40c190, 0x4a1ea98d, 0x9902b56f, 0x18bdf409,
	0xd7969288, 0x3ca131f6, 0xd671fada, 0x69c0a20b, 0x8be417b3, 0x0d247c5f,
	0xfb0179fb, 0xe23f6891, 0xfac9fba5, 0x4fd35b24, 0x4a2527d6, 0x1fb01b3f,
	0xd9facf4b, 0xed04c9fa, 0x55293e7c, 0xc642d9fa, 0x3d6c7ed2, 0x5fd6575b,
	0xf9f3b472, 0x4fd2994b, 0xa127ce0b, 0x3e69f367, 0xf34f85aa, 0xde7c30d1,
	0xf724f9c2, 0xc7d93e6c, 0x3ec9f0b4, 0x1b4f8616, 0x67a7d3f6, 0xd31f34fd,
	0x58f9a7c2, 0xc27f3e18, 0x6cf4067e, 0xb5c7d95d, 0x1e3ec9f0, 0x8421cf86,
	0xfacf5a4f, 0x168cfd79, 0x099faf3e, 0xec53e7c3, 0xad9eb2e7, 0x16bb426b,
	0xc3da133e, 0xae2bf9f0, 0xf59ef2eb, 0x16bb7af3, 0x87b7af3e, 0xf615f3e1,
	0xeb67a233, 0x85a1d09a, 0x308e84cf, 0xf4024c7c, 0xf367b233, 0x85a67c09,
	0x30b3e04f, 0x9fb1e27c, 0x4f9b3db1, 0x7c2d05ce, 0xe1842e72, 0x8cfd8a93,
	0x813f59ef, 0x04f85a0b, 0x93e1842e, 0xd35cfd86, 0x7ce575b3, 0xce4f85ae,
	0x5cf861e7, 0x73de0021, 0xed087cf9, 0x3f7dd6c7, 0xe1695f2d, 0x1855f2d3,
	0x3e71a33e, 0x973e7cf9, 0x7fdae7e8, 0xed73e168, 0xc9f0c23f, 0xf4a67ec1,
	0x7f969fac, 0xf2d3e168, 0xf27c308f, 0xf4375d71, 0x7ed75d6c, 0xb5cf85ad,
	0x8cf8335f, 0x1798d23b, 0x6ea9cb4f, 0xc9b48974, 0x6edd1775, 0x0745e681,
	0x170e8bcb, 0x5445bb01, 0xe6d211ec, 0xeb7b6916, 0x8f518486, 0x325db510,
	0x975856f1, 0x6a695a8d, 0x3b3e24bb, 0x25076356, 0xf93513b8, 0x9abe82a4,
	0x749ec9fa, 0x99ef794d, 0xfbca6857, 0xf2694778, 0x68264afd, 0x9aa80fea,
	0xaa0fc9a8, 0x3f535ebe, 0x9359be4d, 0x76fcbc1f, 0xeacbfd4d, 0x0f94d6ee,
	0x29aa555b, 0x48bfdcbf, 0xe1b2bf93, 0x23fa9a27, 0xca6b171a, 0x447e6aaf,
	0xf8323e53, 0xf47e4d0b, 0xf534679e, 0xd1adb6c7, 0xb03b8f94, 0x3e3e535e,
	0xbf9349b4, 0x9aebc4fa, 0xbe74d7fa, 0xf75fc9a9, 0xfa9adbc5, 0x638e7314,
	0x08bcf257, 0x5f70417c, 0xa131f720, 0x99b418bd, 0x6bea6f30, 0x5b04fb65,
	0xc508f3b1, 0x75e0c9bb, 0xe029a2f6, 0x9fbd509c, 0x5864b7db, 0x03c5d288,
	0x1cc3bc13, 0x2603fbf4, 0x288e55ef, 0x17a509f6, 0xea42a481, 0x2faa4034,
	0xf462587f, 0xc5dfb13a, 0xfb6907a1, 0xd0e7434a, 0xbbff9a04, 0xf40fd721,
	0xad40a2fd, 0xb1574a7e, 0x7a82a922, 0x06e266b1, 0x2d387dfa, 0x455905eb,
	0x5007cbcf, 0xfd22153e, 0xa9bc972e, 0xafac8760, 0x3b065f79, 0x5d0076a5,
	0x7e425f57, 0x941fbc23, 0x03f6d087, 0xb4bd538a, 0xda89b33f, 0x4df1eaf9,
	0x1c0cfc74, 0x79e811bf, 0xdc9f8c2b, 0x7a737c75, 0x98fc66b6, 0xf19a2581,
	0x7c744c63, 0x35f79507, 0x29f1f31f, 0xb2102652, 0xc718f84d, 0xc12c0f37,
	0xd1361ff1, 0xfc7a8f7d, 0x41f8f0d8, 0xeeeeff58, 0x413e9fd6, 0xa581febb,
	0xd89bf5da, 0x39aedffa, 0xc58fc7ca, 0x1c23bff5, 0x581feb65, 0x666fd6ca,
	0xb7c786fd, 0x06dfe187, 0xbba0ffeb, 0xd1ce0ff5, 0x99507fae, 0x3666fd76,
	0xce6b9ffe, 0x38adf1f0, 0x19c287fe, 0x6541feb6, 0xecc9be38, 0x98fd0175,
	0xf956c5fa, 0x3fa4f8e9, 0x81bd5c15, 0x9038e85c, 0x44a44f0e, 0x4253c84f,
	0x81e3ce3a, 0x176f4658, 0xa1bd2962, 0x3bf1923c, 0x47c953f1, 0x9c1539f7,
	0xc86e17f6, 0xc2dc8135, 0x99dfba72, 0x4f7aa7c7, 0x4df488b3, 0x2ffb349e,
	0x6f6df3a3, 0xdfc86516, 0x7e35e4f3, 0x66958f90, 0xda079772, 0xbe104919,
	0xc46a7d1f, 0xf4baf51a, 0xe93abce9, 0x5fc34858, 0x44f23e6c, 0xce8abc32,
	0x60881f2f, 0x8c7f246c, 0x6360a7ee, 0x4bee887a, 0xd12e3d20, 0x23f7e8f1,
	0x8645bf74, 0x06a6f9a9, 0xfdd911db, 0xff3a10fe, 0xb9f94419, 0x22779d71,
	0x8cfed14b, 0xeac7fe0c, 0x63e03f05, 0xe7dd1d5e, 0xd2bff8ab, 0xb3bbf8cc,
	0x11aff048, 0xfb695c38, 0x027b78db, 0xcffda3f3, 0x1f36b071, 0x5bb0dcb7,
	0xedfdd3b0, 0x3f4d24aa, 0x597f88b3, 0xc77f6d2a, 0x31121dca, 0x0d145d00,
	0xf2f40458, 0xb8824490, 0x93250d4f, 0xb40c4e0c, 0xf583af7f, 0xe94cdb7f,
	0xcfd54848, 0xedc6291c, 0xf399f3a1, 0x9df388a0, 0x8796d5e5, 0x86dce25a,
	0x3aae9a4c, 0xf28a112f, 0xe5b44a3b, 0xf3695677, 0xf36b5577, 0xcfb83d74,
	0xdff5922f, 0x3ae872e9, 0x9baf0eef, 0xe7e69c2e, 0xcbb9b2f2, 0x47835925,
	0x6535cdba, 0x0074f2f1, 0x6138413b, 0xeb5dc1fb, 0xe4d03a53, 0xf5d2afe7,
	0xffe2e9c7, 0x36ffffe3, 0x739b2bfe, 0xcd511c97, 0xca71bcab, 0x7aaa2392,
	0xd26e1b0b, 0x67f817e4, 0x5fcfea69, 0x9f29a455, 0x5340b757, 0xbdf9773e,
	0xfc917c9a, 0x5dfea6a0, 0xf29a35d5, 0x6856ab3b, 0x7928efca, 0xe59f935c,
	0xfea6a5fd, 0x6b57336d, 0x059685ca, 0x37a84283, 0x50fa83bd, 0x93f99fd4,
	0x299d0099, 0xfbd0acf4, 0xa62a5f09, 0x4c4e7ca7, 0x530e406b, 0x8d786ef9,
	0x8a6b95a5, 0x573c8106, 0x54b8ffe8, 0xa5e41035, 0xf2f59e9e, 0xf4a74f57,
	0x9d9a2fd7, 0x0265a4a1, 0xeb1e80f1, 0xf2b276e0, 0x67ae4bfd, 0xb48672c1,
	0xb2f8c4cc, 0x899f536c, 0xe0f90ec4, 0xf76b2ad0, 0x014692fd, 0x4bc041d7,
	0xeb780c9a, 0x1a977547, 0xf33583af, 0xc443bd3c, 0x27802bf1, 0xf1ba83c7,
	0xfc6018b4, 0x5bc0eb60, 0xdc7cc046, 0x39be606f, 0xd3aded19, 0x472582be,
	0x79f8032e, 0x9be13d30, 0x9f31e989, 0xbe23d317, 0xf90f4c12, 0xf90d30aa,
	0xc4fd31aa, 0x91fa6327, 0x7fa6396f, 0x7a61d5f6, 0xd30ab7c0, 0x4c7e7c0f,
	0x4c6e7ddb, 0x57fd3a15, 0xc378ebc1, 0xbf5e38ff, 0xbc75e354, 0xc3e6c1c1,
	0xcc28faf1, 0x3cdd8a37, 0xb1918c14, 0x3dc47b2a, 0x8bb6fd05, 0x909d9fb8,
	0xe5c7e602, 0xdda12f63, 0xe2dda1b5, 0xf8720e1f, 0x0dbff0dc, 0xb9f53f05,
	0x69291403, 0x8f4fafdd, 0x40e16ebf, 0x17bf68dc, 0x925e29fb, 0x625b96ba,
	0x062d5c19, 0x11464052, 0x17b2e2b2, 0x6067775d, 0xa11248de, 0x9375dfbd,
	0xd4bf4a2d, 0x5ef80416, 0x6c4bae0a, 0xbfa13217, 0x3dfccf63, 0x06f1d20b,
	0xb6c60f66, 0x9297688a, 0x802e0be0, 0x9ace586f, 0xefe0a95d, 0xe4ccbced,
	0x76d7bd40, 0xf27e16bd, 0xadf81af5, 0x2eafc308, 0xe437e115, 0xfc14bfc2,
	0xf333bb88, 0xf81111e6, 0x337c297d, 0x18f394fc, 0x887778fd, 0x97456fc6,
	0x5c0a291d, 0x3a1206db, 0xfe80efce, 0x9ae7ff69, 0x9c03c586, 0x025cfdc3,
	0x1f1bc23f, 0x7479040f, 0x8d64f006, 0xaea0f7f4, 0x5e7b73bf, 0xbfdd83b0,
	0x8f945528, 0x92b38144, 0xc9a63796, 0xd49db556, 0xab9fcdac, 0xd11a0a13,
	0x4fc6719e, 0xd7f2011f, 0x40911f21, 0xaa62a64e, 0xd528b3f4, 0xfc50e384,
	0x90debe30, 0xca7f7c80, 0x7ef58317, 0xd77479e8, 0x4d1e644f, 0x0f6d30e4,
	0xe0f5ff24, 0x4b77ebee, 0x9abfc6a7, 0x0246cfc0, 0x5fb005d2, 0x5fffe862,
	0x311bc1c3, 0xb7e95e62, 0xcd9451b2, 0x0df7c157, 0x3b68f19a, 0xf83672a7,
	0xf137fa75, 0x531c9183, 0x8aaa95e8, 0x8d61f07a, 0xc8b5ba05, 0x4128fb5a,
	0xee6caf93, 0x25ec6b23, 0x51ca83f8, 0x02305332, 0xf27194bd, 0x975a30e9,
	0x3f7e740b, 0xc8162706, 0x2bd58103, 0xbc99098f, 0x2597a04e, 0x4276ae33,
	0xaf5c3acd, 0x7f147e7e, 0xfba94669, 0xcf142ff9, 0xc289e03d, 0xdcb83b1f,
	0xbf30332e, 0xed918902, 0x5246be70, 0x36cdfb65, 0x0c359a9c, 0xd1dbf41f,
	0x50705471, 0x97e059fa, 0x2bf6b53a, 0x06d3cbe3, 0x8fd02fe6, 0x371807fb,
	0xabf0d2f9, 0x326fb0d8, 0xc70f5bac, 0x26b3e68a, 0xfd15f22f, 0x47022b2f,
	0x163fbe05, 0xe9107f3d, 0x0e1b4aba, 0x84fabee2, 0xe87d0f24, 0xd762e41b,
	0x8f535bf9, 0xb9d645c5, 0xb70d8b68, 0x171e8b0a, 0xe95f20fc, 0xdc60daf2,
	0xc0f9b3bb, 0xd52d6917, 0x4145a83c, 0x7b11590c, 0xbd2f395d, 0x216169bb,
	0x44a3f1e8, 0x93de73c6, 0xd8165d62, 0xab8da5e7, 0x17906e4d, 0xf00050c4,
	0x60fe433a, 0xd7c2ad1f, 0xe109a2e7, 0x43f8ed45, 0x3b5279ea, 0x76a7935e,
	0x4c5f26bc, 0x73814e6e, 0x2527e2f2, 0x9d7017e2, 0xa2e3f29a, 0x4f9dfb03,
	0xeec16aaa, 0x7a34dc39, 0x8780d5c6, 0x02cd9f57, 0x8b4ddef8, 0x1c0225fb,
	0xbf1c21f7, 0xa00bf8ed, 0xe3aea8fd, 0x7756e846, 0x50e1cc8e, 0xfdb820de,
	0x68c6e851, 0xd0a37464, 0xa1d1b257, 0x41a45ff1, 0x18bfe55e, 0xd78fcba1,
	0xff33bfe5, 0xfe1a22f6, 0x4de8b1fd, 0x7e332633, 0x609afd85, 0xfcfa44ec,
	0x76a7fdce, 0x0fc47fe9, 0x2d7f7fda, 0xc7fed0df, 0x0ffda0ff, 0x7cff32e9,
	0xfdaed8e3, 0xd2fabf97, 0x9bca9956, 0xb29e57d2, 0x2762ca13, 0x2e29758d,
	0x75b2ff8a, 0x0740eccb, 0x1db28c27, 0x5fa4f2e8, 0x9147f02c, 0x05190f5f,
	0xadbb2f6e, 0xe0d3f802, 0xa9ffda4f, 0x034e8ff5, 0x7585c23f, 0x64fd0392,
	0x99a0e60d, 0xd3455df2, 0x89924282, 0xff2c83f9, 0xf21159f0, 0x2cfa5acd,
	0x2953d5fd, 0x727f944e, 0x83fa033f, 0x57cf6883, 0x193a3dac, 0xe92578f4,
	0xb7d17e44, 0x48bff183, 0x64537d44, 0x8e5aef8a, 0x6814f31b, 0x4d957ecf,
	0xed159e8f, 0xfd0857f0, 0x25fafa00, 0x332f2edc, 0x3ca17ada, 0x81c6471a,
	0x41e0523c, 0x172eccfc, 0x13367d5f, 0xd7a7a1fc, 0x541763be, 0x11f65270,
	0x3ee71ae7, 0x7bb3baff, 0xf94ed7f9, 0x2a0f6d50, 0x99b381f6, 0x2c0227ef,
	0x7682932d, 0x5b298f88, 0xfa64b92d, 0x17a5ecb9, 0xfc067c5e, 0xbb327f93,
	0x2ffda32e, 0x07d7697c, 0xe17e6813, 0x2157a946, 0x4855865b, 0x92a5e089,
	0x2a3d5ffe, 0xcdd28782, 0x11ce4cbb, 0x134ffbec, 0xb858f823, 0x8c898771,
	0xbc8f0ae8, 0x90a61dc6, 0x1a5e0a35, 0x7b064e0f, 0x2bf57c4a, 0x64fde013,
	0xa77a408b, 0xeae78145, 0x016f685d, 0x1c8f109c, 0xe9bc614f, 0xbc5257ea,
	0xf0567c80, 0xc69f2fa4, 0x07f409e5, 0x9e940ef1, 0xe21d7e5f, 0x766cfe89,
	0x5e4bfac1, 0xeb0ecfbe, 0x62ac6e38, 0xb2ecfd74, 0xb71d3714, 0x1c539244,
	0x25efb298, 0xe908fdcf, 0x1fbefe6d, 0x94bf30a5, 0x75018fbb, 0xd607dc8b,
	0x56feaf37, 0xf1315f5c, 0x3c95dd22, 0x3e407a2b, 0x0524667e, 0xc5f0a31b,
	0x8f272e59, 0xa548a1af, 0xd54e3beb, 0xfcd9c607, 0x43aff441, 0xe8bdf83f,
	0x5f11faf7, 0x986cd50b, 0xe1862cff, 0xc0d18f69, 0xcab52ce5, 0xf6baf4d5,
	0xcfc036e1, 0xdeee01a9, 0x49527e70, 0x8787328c, 0x57ed35f0, 0x9bdf97dc,
	0x8d3887e1, 0xb51dbc59, 0x3be0f2ab, 0xdc936fd4, 0x3b4d4c96, 0x645a75f2,
	0xf8f9fbfc, 0x60b1de74, 0x894f1d0f, 0x900fd76e, 0xf5403d14, 0x54be8ab0,
	0x7df8cdfc, 0xdfc60aed, 0x6ffbbf0a, 0xbff2802a, 0x07f8c7be, 0xa27e81da,
	0xc6f60af3, 0x05d31df2, 0x12660794, 0x6bd7c68c, 0xdad7ce25, 0xe84e8572,
	0xbc428dbc, 0xd3085e8a, 0xb9f9c79f, 0xb493f149, 0x565e4a9d, 0xaef678c2,
	0x3b7c29fd, 0x69fff39f, 0x232bffe0, 0x19ea4ffc, 0xaf6f77df, 0x329f08ca,
	0x33e2ffc9, 0x3f94afc0, 0xabf02765, 0x7f7581e4, 0x83f5a1ba, 0x7c9f29db,
	0xa9f0a8da, 0xf9ea7e56, 0x8fd364b4, 0x9ea7d008, 0x5fed3f4f, 0x29f2a245,
	0x4f951efd, 0x5bfe87fb, 0xbf02a7e5, 0x7e16925e, 0x0eec3c8a, 0xb8797a8e,
	0x2a8ce8d1, 0x3defe90f, 0xfe95d592, 0xe853ba14, 0xe537f4ad, 0x84ee4083,
	0xbba152e9, 0x742a5d30, 0x16af5fa7, 0x4ff2fa7e, 0x974e9fc0, 0xfded79e0,
	0x3e28fdc9, 0xcb8202cb, 0xbb76c4ec, 0xe4e14f21, 0xdd7c6666, 0xd4bd7eee,
	0xdf2ebf79, 0xd6efaba8, 0xfaba3de5, 0x4abe5d5e, 0xf6cfdf57, 0x26adcd15,
	0xd4107482, 0x131697d4, 0x3ac9e219, 0xe7e88bb7, 0xae73a0ef, 0x363beda5,
	0x2a65f9a4, 0xd859960f, 0xd933bb3e, 0xabf20b54, 0x4f69d1c3, 0xf985bc84,
	0x9d3c3acb, 0x7d9504f6, 0xa2203078, 0x49f90dfc, 0x06fdb441, 0x4e104b21,
	0x395dd221, 0x17c8bf3b, 0xc1ab03ad, 0xba27528f, 0x9ee228e0, 0x70ecdb9a,
	0x1811d07e, 0xfa4ce37c, 0x456fde7d, 0x88e85f0c, 0xbcc267b5, 0xf636ec88,
	0x27f9d951, 0x0e74fc88, 0x00dccf5d, 0x59eff3b3, 0xadc7b3a9, 0x1e409bf7,
	0x90fc7b52, 0xe8cedfd6, 0x53f794ba, 0x2f2daf52, 0x9e912b25, 0xe95ffd94,
	0x97b96d5a, 0x55ef17ef, 0x19247ce8, 0x846bf6c9, 0x5cb829f9, 0x6e3317cd,
	0xdee1499c, 0x402447b1, 0x2202e727, 0x06dcfdc2, 0x8c935f65, 0x3a4152fc,
	0xf0299e51, 0x30fc0d39, 0x73797bac, 0x59c7cb7a, 0x652ad10f, 0xfccc3f5b,
	0xde9e9a4f, 0xdba1a7fa, 0xfeeaff20, 0xae921f81, 0x2c5af3f5, 0xd1db2e78,
	0xdf78c362, 0x0eefed8e, 0xaff2087c, 0xcf305d99, 0x33cf968e, 0x163a6e81,
	0x5e404b9b, 0x7e600c75, 0x3fdb25c7, 0x7ea10ccf, 0xaaf88a5c, 0xbecc4c97,
	0x13fdfc09, 0x74a417a1, 0x79f7a055, 0xebe570fc, 0xfec13f16, 0xccfdc73f,
	0x0a9eb50f, 0x61df0e7e, 0xc1373323, 0x39d812fc, 0xf1b6e573, 0xf1d0d42f,
	0x98769bcb, 0xbcf2d2e6, 0xc4cabe37, 0xcc4de178, 0x4297699e, 0xf339c1cf,
	0x8b1da4af, 0x76e70a25, 0xb4be8660, 0x2790c99e, 0xe5c1a35b, 0xf51bf42b,
	0xff2d1e14, 0x6021e06b, 0xc0594f9c, 0x60118fe6, 0xf27e5fdd, 0x8b7ff021,
	0x5952e919, 0x358da7ef, 0x6a5c6f68, 0xcbff1fdd, 0xf6085bad, 0xff17dd64,
	0x58bdd7c9, 0xd5dca272, 0x3a5741f3, 0xe600fedf, 0x70b9b25f, 0xf7a43dbe,
	0x17e626fe, 0xff5d67f9, 0x26fbc6b7, 0xa5fb778a, 0x3ff57dd7, 0xc7bbbaf9,
	0x70e76ffb, 0x5e203bbc, 0xaf8df2ab, 0x56df7e70, 0xbff1ddce, 0x5d8afd74,
	0xda78366e, 0x66fce972, 0x181b3a92, 0xcf92b314, 0x36d085ed, 0xf6bf80f3,
	0xfc4af982, 0xbf3f507c, 0xefe62695, 0x07518490, 0x725c74bc, 0xceb5cdab,
	0xf71e7a89, 0xfdb8d341, 0x317fad30, 0xdcd3a1da, 0x60274ecc, 0x98b85227,
	0x21f91467, 0x3c9cc83e, 0xe015e309, 0x682dc5a6, 0x83f769b0, 0x5b8813bf,
	0xb4f876a0, 0xc07b0581, 0xbfb1bd2e, 0xe9666831, 0x556f4841, 0xf76b67be,
	0xdabcb32d, 0xb5336dfc, 0xacedf7f9, 0x73720cdd, 0xff9d2e5b, 0x87465e8c,
	0x56e5da1f, 0x59bf3049, 0x4ea40a77, 0xd5bda7e5, 0x025f6da3, 0xff9558fb,
	0xd14c416f, 0x88473842, 0xfee02e19, 0x2295c6f6, 0x0c9893ca, 0xc9ebd701,
	0xf02e3096, 0x0593c1a8, 0x3d1c2e70, 0xac27e2ae, 0x77ac173b, 0x31578701,
	0x877b42a9, 0xebfafc5c, 0x04bdfa1c, 0x2eb8523e, 0x03721370, 0x738bd3b5,
	0xc42c6084, 0x1c891899, 0x9cfc0a3f, 0xf6a43902, 0x79b5fa73, 0x129b5df8,
	0xf552e7e9, 0x1fc7a3bb, 0xa50bfd3a, 0xb51243ff, 0xf3c52197, 0x53a7e673,
	0x057753f6, 0xcb2b1c18, 0xfa3a7f04, 0xfa928209, 0x199881bc, 0xa7e5fdfd,
	0x72af91a3, 0x9e223e7f, 0xe0c6f3ed, 0x6e4a9dbd, 0x9d939e67, 0x38d7e0f1,
	0xcfcc1817, 0xdeecf2b9, 0x8fbcf428, 0x08feb3ef, 0xed34f4e7, 0x89d42498,
	0x4e93ef60, 0x93c9dff4, 0x945d642c, 0x4990b678, 0xc2af2739, 0xc4fc1f7d,
	0xfb23c02c, 0xe34da7cd, 0x5b785513, 0x6349c379, 0xc03c5766, 0xf39450ef,
	0xc29aef8c, 0xbae00ebe, 0xec9a12cf, 0x73deb289, 0xdf0b7f9c, 0x75ef12fc,
	0x93481cdd, 0x4f372e00, 0x9fe73512, 0xdfdc4ca7, 0x868c9a37, 0x39be1579,
	0xf01e3ec5, 0xc17447b2, 0xc0caae3d, 0xca379359, 0x9e1e9039, 0x51f83fd0,
	0x62ae4b0f, 0x9fe1e780, 0xafec0859, 0x32e7e5de, 0x9d271019, 0x37785b81,
	0xcefe91f8, 0x3b31eae1, 0x30a5bd30, 0xe3a64a57, 0x46393466, 0x5f54d1c2,
	0x4a03df5e, 0x39042c6b, 0xbd4a76b0, 0xdeac65be, 0x22a39341, 0xc797fada,
	0x27cff5b0, 0x85b207ae, 0xe5bc3e7f, 0x9c16dcfe, 0x1264fa08, 0x95d887bb,
	0xc7f209ae, 0x0fc102b9, 0x4ff61ef2, 0x50142f98, 0x606bbcdf, 0x02cdf2e5,
	0xba14d9fa, 0xb879c3d7, 0x1959c199, 0x47e780bf, 0xe052fe70, 0x3f57c0ac,
	0x953ea55f, 0xfda9d757, 0x8f36370f, 0x61f4197c, 0x18704045, 0xc6155768,
	0xb0f80990, 0x0971f9b2, 0x9cb3ebfc, 0xf4625fac, 0x67cfaa64, 0x4e76663d,
	0xeaea3ade, 0xe7274039, 0xd5919a57, 0xb59cf7dd, 0xd77dde83, 0xdc3dfae0,
	0x277f9453, 0x20df7592, 0x39f43eaf, 0xea49274a, 0x4e50d37e, 0x2b9652df,
	0x8ee4bb81, 0x6f521db2, 0xcc793d15, 0x7cae5889, 0x1ce65bef, 0x78e9df05,
	0x31f90f38, 0xef388133, 0xbc36c68c, 0x5547769f, 0x92c3a302, 0xcc261dc6,
	0x657d61a7, 0x3d1c653c, 0xd42f4d3f, 0xcdccefc6, 0xb807f50b, 0xf7839a14,
	0xe9d0a2bb, 0xae72b379, 0x84f52df0, 0xe66dd29b, 0x713d21ff, 0x4227a2bf,
	0xef154792, 0x9eabadb1, 0x4f4d1de8, 0xf671aa2c, 0xda2c3c06, 0x3037b83e,
	0xe6dfa2c9, 0x13d344a7, 0x39d8fbef, 0xcf7e7ee1, 0xd53a63b3, 0xf4a95713,
	0xd20b74c4, 0x3addbe89, 0x84f50f73, 0x66ffb782, 0xe83ef379, 0xddfc2889,
	0x89ead66c, 0xd4228119, 0x8ba63313, 0xaf11fb9a, 0x27a52f98, 0x61665372,
	0x45c5725e, 0xb9f79fa1, 0xc79fbc3d, 0xa038c1c9, 0xfcb9da2f, 0xee8debd7,
	0x3193fae4, 0xbe473f02, 0x1fff5c84, 0xd722b382, 0xa02add17, 0x0e95d83d,
	0x9fdf3b09, 0x00bae545, 0xfae4c8f4, 0x5fb93ba2, 0x3d67274c, 0xa8c76720,
	0x5f6b2ce5, 0xa17a65e1, 0x3fed39b2, 0xdbf2d366, 0x0c5724eb, 0x447b7fad,
	0xe5a966ee, 0x72777b6e, 0xddc984b7, 0x68d181f3, 0xbeb7753f, 0xa5bcb98f,
	0x2b886cf2, 0x9ccc7d0a, 0x5fb9a71d, 0x5be47873, 0x5f819b19, 0xbcf115de,
	0x03b728ee, 0x6b7c8ef6, 0x0ba7f80c, 0xc7888c63, 0xdba7ae54, 0x1274a47d,
	0x3dde5f85, 0xdf2e9ecc, 0x2afc2220, 0x57ff189a, 0x277e0834, 0xf51e4fcd,
	0x0bf209a5, 0x3773b3b7, 0x5cc282ba, 0xbe17fe15, 0xff05aa1b, 0x02d5c2ef,
	0xbc421b9e, 0x3e73c032, 0x6bb16787, 0xf457ee21, 0x622b03f1, 0x55c86bed,
	0x47fa1fd8, 0x42fd79cb, 0x93fa2773, 0xb8257f0b, 0xf1ae9356, 0xae43e505,
	0x8cfb093f, 0xefba0d85, 0xbcfc15ae, 0xd47e8820, 0xf96d46f2, 0x79eebe78,
	0x33633062, 0x2f7eafec, 0xbbe9a2ba, 0x94f87af1, 0xecf84f7c, 0xf319f0a3,
	0x4167c1c3, 0x99fa0760, 0xf45c2dbf, 0x863ab8f0, 0x914793fb, 0x478fc031,
	0x2f946e0d, 0xee22dbf2, 0xfc79ef3b, 0x013bcd32, 0x781cb853, 0x85ade0d7,
	0x42b95c38, 0xebf37ac0, 0xa14aee37, 0x648dd9f9, 0xe7a5b824, 0xe3ead2af,
	0x726ffeb0, 0x5d9f7ea2, 0xb88051b5, 0x1efc79bf, 0x71ff894f, 0xcee1577c,
	0x69efaa6a, 0xcca3b9fd, 0xdcff385e, 0xf944e967, 0x756fd0a9, 0x07a7e30c,
	0xf70e3cf8, 0x7a849ced, 0x207059aa, 0x4c2d065f, 0xc13c516f, 0xe3ad0f7b,
	0xf1cc9f3f, 0xcd11fcc2, 0x14958f0c, 0x93d7c06f, 0xc8df3c03, 0x023bc1ec,
	0x55f9d967, 0xdec48760, 0x1248108d, 0xee173bca, 0x08fd159f, 0x29b969e7,
	0x3f6efc2a, 0x9d7fe8c8, 0x7e0fc2e0, 0xc1f7dffa, 0x5578376f, 0xe29e99ec,
	0x75538157, 0x1c23d70c, 0x6d2cfbcf, 0x7cf1a385, 0x3be17046, 0x3c04811a,
	0xc752385f, 0xe5a885de, 0x017cf4ed, 0x3bf50ffb, 0xc4c13715, 0xc0b41e21,
	0x38777182, 0xcfb33a6e, 0x64fcf7b4, 0xdbfebecd, 0x92549dc6, 0x22cbb436,
	0xa35e5ff1, 0xb67ef419, 0xae8ece36, 0x07fef908, 0x6f8dffe8, 0x500a9fea,
	0x39f72fd4, 0x01d6d7d8, 0x7c832226, 0x1d212e5f, 0x7e7066dd, 0xe5f20390,
	0x7f008911, 0x763bdf9c, 0x505eecff, 0x147d222e, 0x02ba3bbd, 0x588a9dce,
	0x7a2911ac, 0xc3a5e990, 0x533ffc7c, 0xc61eed7d, 0xd83b0487, 0x9d7e8097,
	0xf91daee9, 0x5bff8a4e, 0x065becc7, 0xe4b761e7, 0x00f83e39, 0xbd82b8f0,
	0x79687287, 0xeed3ee1e, 0x3e4057bb, 0x05f1403b, 0x3d3adcfd, 0xe80f83ed,
	0x9e5ceefc, 0xb35be78c, 0xe033c9dd, 0x5ef66bbc, 0xf5a4e5d1, 0xb368dee6,
	0xd4d779c2, 0xaaf122e1, 0x692772e0, 0xb8e7065b, 0xbdeeabb3, 0x84a4f815,
	0xe77843ea, 0x2fb024a4, 0xebe437bf, 0x295f6c05, 0xe9bd4d7b, 0x9d56dafc,
	0xe3a18d35, 0x007ad317, 0x567acaee, 0xe0ad72af, 0xe2da5082, 0x2728e3c0,
	0xf80ad78b, 0xb51b4490, 0xbf58637f, 0x6fda18fe, 0x4f6d3d5b, 0x3da1f3f3,
	0x6136bbf4, 0x55679c06, 0xfb6279d2, 0x873c1aec, 0x68eda62c, 0x7b5b6931,
	0xa0b7f62f, 0x1f70205e, 0xed3b24a8, 0x6fe86cb1, 0xf282e4af, 0x897e3bfd,
	0xe87322f1, 0xff687d78, 0x3e50c573, 0x090f27d4, 0x648f7c0e, 0xbbe410cc,
	0xe477ce0e, 0xfe76748b, 0x5ee5102c, 0x7f1d518e, 0x38b0b4e0, 0x9aeae2e5,
	0x4857585a, 0x20334e4e, 0x81359d3d, 0xe1423f1e, 0xebf6a5ed, 0x6b8b1361,
	0x9b0f9568, 0x79f92a42, 0xca30658d, 0x739a7baf, 0x23ccce51, 0xf7273c1e,
	0xe47b30d6, 0x5f8b32e0, 0x724c3b00, 0xadef840c, 0xbdf8cccb, 0x77a625fd,
	0xd08407da, 0x5ebc7a1f, 0x695f7022, 0xa7e0fd49, 0x37c78f01, 0x2c2e7848,
	0x3ca12b3e, 0xf312ff9b, 0xb3d6b593, 0x30378f7e, 0xecf796f9, 0x6e4193ad,
	0x9ca75fcf, 0x58e56b23, 0xe514b3b1, 0x2616b3d4, 0x4af2f497, 0xea4aa72f,
	0x43d74756, 0xae8e4ff7, 0xf2d7fa87, 0xfae8ce73, 0x155892b9, 0xe20a3539,
	0x07ca8a46, 0xf40559cc, 0xc40b277c, 0xf6be0b6e, 0x77a053d9, 0x7ef86ccb,
	0xf1d1854f, 0x83e8c0b4, 0x1d9ffc80, 0xf019f8d8, 0x0b6cc943, 0x0c73cfbe,
	0xb47c01f0, 0x3dcf0932, 0x0845fd8b, 0x721e2577, 0xbd2d2afe, 0xb3dae72b,
	0xab7122bc, 0x1c4957f5, 0xedeaab71, 0xb74a77ff, 0x9abb9c74, 0x8045bf05,
	0x3fddc1fc, 0x0779831a, 0xdb9aabce, 0x486d2b07, 0x3c1ffbd7, 0x76e80cbb,
	0x02054fce, 0xbd913b76, 0x2b0fa0b5, 0x47ce0956, 0x4ffe7e68, 0xb4f9fb59,
	0xff7bcc3d, 0x517d192f, 0x1f02773a, 0xbe3fd454, 0x15afeb1b, 0xfeffd09c,
	0x4f6845d5, 0xc122c894, 0x7107b5f2, 0x15f5411f, 0xcab517c6, 0x41f00a62,
	0x03b352c5, 0x7a15b9ce, 0x20f3e852, 0x624ce7bf, 0x1fe0995c, 0x249d053e,
	0x714ba577, 0xa7d610a6, 0x32953f40, 0x2f83b7a3, 0x91602e49, 0xbb27d34b,
	0x9fd0aadf, 0x2637f408, 0xf5ad7f42, 0xc7a02679, 0xcf017ee3, 0x7e80f3e3,
	0xad7f3e81, 0x558867f8, 0x8a5d476d, 0xd874f53e, 0xdd28fe85, 0xe8579c81,
	0x3d47a153, 0x92321e1d, 0xfbef3019, 0x1d705996, 0xcdafb579, 0x867c66a8,
	0xb57939e7, 0x5f00a60f, 0x9c591b17, 0x72d70287, 0xea078b23, 0x6b27af32,
	0x327a7d4c, 0x6c3cdd3f, 0x1f845b16, 0x12b71644, 0xb5bce3a4, 0x938c05e1,
	0xe0feb33b, 0xb66fb434, 0xf8003a51, 0x2091b06f, 0x28fc43ee, 0x449b4a8f,
	0x1a11c637, 0xa8b75983, 0xbc4aeff6, 0x5857c2c4, 0x26e973dc, 0xb690bfb3,
	0x387add2f, 0x17b1cf13, 0x5e5bfb33, 0x4c7da02f, 0xdc2650e4, 0xb23528c7,
	0x5dbd0db8, 0xe2c2dcb0, 0x16bf4ec9, 0x36ec1337, 0xbbbd81a1, 0x9b78da55,
	0x77f95664, 0xa949167d, 0x322ae787, 0x7bdc33c5, 0xdfa9f986, 0x35e2527d,
	0xd19aff4e, 0x84b3695f, 0xc3695cf6, 0xbf8876c6, 0xc6603d2b, 0xc3656efd,
	0xce278c59, 0xf625e57b, 0xa8b3583e, 0x12eabf89, 0xe220d4f7, 0x53454739,
	0xd06fc639, 0x54779e3c, 0xff8f4634, 0xce7c54bb, 0x6fb657c2, 0x17082995,
	0x1d95fe6e, 0x5b6af1df, 0x247bc767, 0x771cdf0d, 0xa9ce25d8, 0xc637c571,
	0x3f829d39, 0xb46d0128, 0x1ac4e2e8, 0xf3a35c98, 0x6f768acb, 0xbd6f6c20,
	0x1073d9f4, 0xd37a7b87, 0x7cc1cfa7, 0xfe71fecb, 0x20c78839, 0xd807162d,
	0xdfeb9527, 0xa54638c7, 0xbe163bdd, 0xaff5f9ff, 0xfdb3fe30, 0xf417664f,
	0xf8fdbed6, 0xda3bb040, 0x02997e37, 0x6ff79d71, 0xcebf47cf, 0x7af25bfd,
	0x837e2893, 0xd2983ef0, 0xf107bfad, 0xb57c7aa7, 0xdc62b536, 0x6f8a19c8,
	0xb8e10f90, 0x1672c6b5, 0xf1e4e807, 0xc7a21b6a, 0x4f8976f9, 0xc6e5ba6b,
	0x362e406b, 0x92e0fb31, 0x51ef6a71, 0x03d55e3c, 0xc1586dfc, 0xfc745af5,
	0x283f819d, 0xb45a4e9e, 0x359fbe71, 0x19fe7bcd, 0xea4a6b28, 0xd82d4e36,
	0x7129b803, 0xee2d5bc4, 0xbf805abf, 0xe306fd36, 0x856f0102, 0x9fcf904e,
	0xf0ff040d, 0xfd13a909, 0xcddb9d10, 0x74ad0f78, 0x9fe47efb, 0x30fb2df6,
	0x78f0974e, 0xfe1276de, 0xee4bf8b1, 0x6b5ca9f3, 0x1c6df163, 0xe6ff10fe,
	0x1e77e3b4, 0x58e8c6e7, 0x2eeb7f89, 0x36232dee, 0xc093bf9d, 0xd7caf3e2,
	0xc8e3c87e, 0xb212f822, 0xbf074f01, 0x81509e31, 0x30e00383, 0x19c71d4e,
	0x1c30be3d, 0x05f1cbef, 0x1d7903f8, 0xf9a4d38e, 0xe7b710fe, 0x9e13f617,
	0x7f85101f, 0x38b357db, 0x7b4976d0, 0x278233bf, 0x2c39df16, 0xfeafc756,
	0x5e75c59e, 0x16df1d6a, 0x9d63bd4e, 0x5e1eafd8, 0x97462fa7, 0x0ac7d7e7,
	0xd3feefdf, 0x3f7f4174, 0xdc2c4a60, 0x683a683f, 0x8b7f7822, 0x7b94a3ef,
	0x76bfdc44, 0xf188bd7a, 0xad8db581, 0x72f5cf28, 0x9b9f82a3, 0x3b3be7e8,
	0x2b57ed96, 0x38be999a, 0xb7e6c9bd, 0xbf4e7ed2, 0x75d21af9, 0x268386c5,
	0xdddabf88, 0xe2c4d9b0, 0x811f180c, 0xe6abf0be, 0x1de5fa7f, 0xf9bf2899,
	0x71fa42fb, 0x9538f94a, 0x54e3e881, 0x19ab386e, 0x68dca167, 0x3d2f5872,
	0xfba329de, 0x54efe836, 0x4e9bb31b, 0xd1058a35, 0x10dcc7ee, 0x777f712b,
	0xdea94b1d, 0x6c9677c4, 0xd1255dec, 0xd8768b1e, 0x03ecb6fd, 0xfddf5ef0,
	0x4dc61336, 0x71e1a92c, 0x4aeeff16, 0xb12f7c05, 0xbe604f5d, 0xaabe00cb,
	0xf0e4bcfd, 0xa4dfb012, 0xf518cf54, 0x7f328bb9, 0xf1032f53, 0xbf7ff0ab,
	0xec37a0ad, 0xee518947, 0x9698f30f, 0xf411b9fe, 0xf98f9b60, 0xc3c5c9f3,
	0x9b7be043, 0x892bb1d1, 0x4936dbf6, 0xb62b8170, 0x35fbdd2b, 0xb93765e7,
	0x4249efb5, 0xefac3d4c, 0x7680cb9c, 0x7410cda1, 0x3ed42ad0, 0x0dc54b6a,
	0x8d3893ad, 0x8f0a1829, 0xf88fe8f1, 0x7dc08662, 0x66a13b39, 0x1973d42a,
	0xc41fef35, 0xef751b67, 0x86f79021, 0xe563bd50, 0xe7f8aaf4, 0xda6fec6c,
	0x59df086f, 0x3520c848, 0x6d2bbe40, 0x9e1fb45e, 0x7df1bbb0, 0x0e1bfa0a,
	0x4912b0f7, 0x3efd4bac, 0xf3571d0b, 0x571d03ee, 0x6b704f93, 0xc60549f3,
	0x4cf4d123, 0x64c79f12, 0x48708ad1, 0xfb7037c8, 0x59785dd8, 0x09de644a,
	0x8415c4c9, 0x18ac1bf2, 0x4bd94e0f, 0x6ac3af56, 0xce9bced5, 0xe227234f,
	0x81b24233, 0xddf353cd, 0xae029c41, 0x4efdaddf, 0xefc9abe7, 0x919de452,
	0x59de4118, 0x8708da63, 0xbc0d39ff, 0x495d1a97, 0xc21f8059, 0x8132d9f7,
	0x7cf104fb, 0x4d7c741d, 0x0b78077d, 0x7edaf8d8, 0xfa877f48, 0x5c55df1e,
	0xe7163e0f, 0xd29620f9, 0x2aa0d653, 0x49cde80c, 0x4647dc15, 0x2f40b2d3,
	0xd5e94f94, 0xcd30e479, 0xae8c750b, 0xc824ac86, 0x0d3a4337, 0xa59e3dec,
	0x9a9768b1, 0x196c8863, 0x8899f705, 0x51828d2c, 0x9cff9cfc, 0x2bb40d8b,
	0x6b4a72e3, 0x73a05db4, 0x451e61a2, 0xd1142342, 0xeb18fffe, 0xaef20a3e,
	0xaa6f26f6, 0xef2c2461, 0x733b65c1, 0x072f6b90, 0xa6a1a10f, 0x019ed77a,
	0x1df04228, 0xef572226, 0x53af1a02, 0xc3b054f2, 0xd8bae9fd, 0x431dde70,
	0x3a5d7de5, 0xa47f9fcb, 0xda72d97a, 0xcf788adf, 0xc4871879, 0xf3c0ae38,
	0x9f7b20af, 0x45fa52e8, 0xb5f0e799, 0x63b1c9a1, 0xde14ff98, 0x16ccbcf9,
	0xfa8d1fbe, 0xc9559d78, 0xe13f7107, 0x7287da69, 0x1f71bcad, 0x4f201b96,
	0xa14941d3, 0x2812fdc9, 0xc8adc7fd, 0xe21cbd4f, 0x0d528bf6, 0xe2fd9d74,
	0x6a32ec56, 0x65b3f0e0, 0xe047fb3b, 0xa8fc5c60, 0x7e8f0e0e, 0x7bf4382b,
	0xcb65d1f4, 0xdd7cf7fb, 0xc6fa2e94, 0xae6a74d1, 0x1a53df01, 0xfe8ac077,
	0xa0b3fa16, 0xacfde23e, 0xab5ee6ee, 0xfda12fb2, 0xe8a9c7a4, 0xd0a7694b,
	0x33747755, 0x60ae3898, 0xe969ecef, 0xf73896e7, 0x8caf3095, 0x6b7ef738,
	0xef1fae32, 0x16f54f59, 0x45252679, 0xbd589ae8, 0xeedee1a3, 0x8f777163,
	0xcbc95389, 0xc48bb9a9, 0xb1df3a74, 0x91c90bc0, 0xcb5724f5, 0x9d74a196,
	0xc6036ec9, 0xe7163f5d, 0xeced009d, 0x54833b33, 0xc013523c, 0x23105a3b,
	0x51fc28e3, 0xdbed9dbb, 0xfe0c8b6b, 0x57fcecc5, 0xf422fe80, 0x47d1d211,
	0xe68fa327, 0x151f4883, 0x3e8c8381, 0xc6266b9a, 0xd83473f2, 0xce91d737,
	0x4f778091, 0x91be435c, 0x5c507de2, 0x4a3f6d67, 0x2ebc9217, 0x8472f0bf,
	0x5f9834eb, 0x79f0fc17, 0x0eeaeb29, 0xd27b75bf, 0x7d80cd1f, 0x9e035ee5,
	0x5370297f, 0x8e28fdea, 0xb10ed3c5, 0x7800ef79, 0x76876657, 0xed36fa03,
	0x71c603f9, 0xbcdef7d8, 0xa7dbda03, 0x23390c53, 0x5dedd6e3, 0xd6e9ef8c,
	0x974075d1, 0x0653a4f1, 0x3c3ddebd, 0xe184ff18, 0x064f7601, 0xf220e3c0,
	0x5f7e7acb, 0xde1df288, 0xc7141d83, 0x88a85bde, 0xc5e8fb63, 0x994f2271,
	0xf7bc961d, 0x5df6099c, 0x580d4b95, 0x0cd2193f, 0x6297faf5, 0x4671c5bd,
	0x3c189f2e, 0xf42abc14, 0x1c692544, 0x3e30dbbc, 0x5c50fbc1, 0x127e9ab2,
	0xfd55d2e3, 0xf31eed29, 0x943dcf11, 0xbcedc650, 0xabd03efb, 0x6a667e94,
	0x2c908dda, 0xfd30b700, 0x868cfa50, 0x056eda1f, 0x38c4bbe3, 0xee3617b0,
	0x39c2245c, 0x9af14f43, 0xd1c2ef05, 0xa47159fa, 0x9f6d136a, 0xc8534f15,
	0x6f7cf127, 0xd2c7ef9e, 0x0cb91fc1, 0x9abefd02, 0x735761fb, 0xe3a312b8,
	0x6277780a, 0xe3b31c75, 0x50e35272, 0x6b7c282f, 0x7383e0a4, 0xcf3f236c,
	0x374cef4e, 0x3e14de00, 0x821a7636, 0xd2b4aa36, 0xc4034e8d, 0xf3edbc35,
	0xb07ce07a, 0xfd73b93b, 0x9f1eece5, 0x3e16fbfe, 0x5f6cef9f, 0xbf72ee9f,
	0x4df00b77, 0xb1e84c79, 0xe2be699b, 0x97e8f3f2, 0x71571c5d, 0x4efcfab5,
	0xffe7ea9f, 0x76e3c5f6, 0xbfdb0fb0, 0xb3441730, 0xb8724fb3, 0xc4cdf1ed,
	0x85dd8a76, 0x5378c2a8, 0x33417dd5, 0x5d5768a6, 0xf00f228b, 0x41131b28,
	0xbf31c6bf, 0x7bba75d2, 0xd879ca82, 0xe7e641b5, 0x067902cb, 0xb1a77bf5,
	0x60bfc3f7, 0xfd0c51f6, 0xf299ce0f, 0xdbd8b9f9, 0x1b12ef46, 0x6136f7ad,
	0xf159abe7, 0xff70ad55, 0xf0d39888, 0x6897327c, 0x4acadfdf, 0xf3849baa,
	0x79c34f88, 0xcae8c5e4, 0x0346cb7b, 0xc34e0f94, 0xa27cc4f8, 0x3ce8cbb2,
	0xf41306b2, 0x5761915f, 0xd4d81c60, 0x79fe94e1, 0x662079f9, 0xe238959f,
	0x8a7f7223, 0x92679673, 0x73a96ec6, 0xe77f1c81, 0x68aef12b, 0x56b916f1,
	0x0f1ece05, 0xe1ebff9c, 0x2c29d13c, 0xc2bb39b5, 0x3d4f0f5b, 0xeab815fc,
	0x91fb98e1, 0x1462526b, 0x12e1e938, 0xaff4af39, 0x0fe4bc04, 0x297f5117,
	0x89c3d078, 0x7a842bd6, 0xeb4e5cef, 0xb8ab79c1, 0x2f7a08d2, 0xdc204d2f,
	0x36fb457e, 0xcc1f4c3f, 0x59bd257e, 0xae1eb3dc, 0x2ee8e15d, 0xac894fcc,
	0x0bc0376f, 0xef5c99e3, 0xab58fc41, 0x4971c255, 0x8ea23af0, 0xfc0578ef,
	0x3c38f1c7, 0x1d773fbe, 0x774552eb, 0xc6133b55, 0xbae7e844, 0x6e76b42f,
	0x49f2607e, 0xe2b39fb0, 0x4fc14bbd, 0x8c34c44a, 0x3bf0a39b, 0x4e33a5a4,
	0x486971bf, 0xda9e1427, 0x40e1f072, 0x9e5624fb, 0xeb95d0ef, 0x7ebf4ce8,
	0x815ece85, 0xc2bbe30f, 0x6cb3a14b, 0xf53bf72b, 0x4ec1fd25, 0x4c6d7cce,
	0x126dc83c, 0x8fea8c48, 0x13c07718, 0x2bd387ee, 0xbc40b1d2, 0xc18eefe1,
	0xed7e43df, 0xe551daa4, 0x7a27981f, 0x9146b06f, 0x5c7d0a5f, 0x0d76f1c3,
	0x7f807791, 0xfc621ae9, 0x901f786b, 0xadff5916, 0xe8ffbe56, 0x3ac1fa47,
	0x9939c6b7, 0x0cebe7dc, 0x959a9baf, 0x3e1cf780, 0x158c4e7e, 0x4e9065ef,
	0xfc30e9e3, 0x191df1d3, 0x991894d9, 0x93ebc487, 0xd9845581, 0xfdf1b371,
	0xf2170a5a, 0x1e645c75, 0x88c156a5, 0x79f0aaef, 0x9188699c, 0xbd6d9e21,
	0xfb00ade8, 0x37b0b4ee, 0x0c67d713, 0xa7bd050e, 0xbcdf3f2f, 0x69ca02b3,
	0xc7ac62bd, 0x6450bfe7, 0xedce877e, 0xb49aff66, 0xca53edee, 0x141fa8d6,
	0xfb81c8be, 0x9f01578c, 0xef308a75, 0x693f3f00, 0xfb825b39, 0x2c713741,
	0xb7f692bd, 0x8c64dceb, 0xe2a3cfdf, 0xe9e9ea06, 0x7adf4f5e, 0x3a449e7a,
	0x3d3b40e7, 0x73d77f1d, 0x0b7ec57f, 0x4a5ecdd3, 0xa7bd2a37, 0x9fa50bd0,
	0x3a7e80a7, 0x1a7d1cc6, 0xc777edcc, 0xbd014f9c, 0x11e7d8a7, 0x0abdc43b,
	0x9d9ddbe0, 0xebe7d8ae, 0xa1e7deac, 0x87ac233f, 0xee1f4fb6, 0xf87dc034,
	0xf9a95a3f, 0x76e5f005, 0x1bf6a5cb, 0x0c91a764, 0xc39df3a7, 0x2068d0f1,
	0xbcabbef8, 0x767d4048, 0x6094e927, 0x24ab3bbc, 0x8e76becd, 0x8793f3a5,
	0x66b0bce0, 0x2f33ea18, 0xb114f2dc, 0xae3f8b3d, 0x64c7f165, 0xd850e778,
	0xad55ddf7, 0x82878f6d, 0x34779159, 0xfb75a13f, 0xa1bf4224, 0x5b67b864,
	0xebeb6b24, 0xa1d657c7, 0xaedf57ef, 0x042bbf92, 0x54bb14ef, 0x2b0ec2f6,
	0xcf0ccb8b, 0x2efe6df7, 0xe8378501, 0xcb8173d5, 0xa1448ffd, 0xc6f5255f,
	0xa38db924, 0x76d0f923, 0xef68ccf3, 0x28e32883, 0xda4d9ef0, 0x2dfe7814,
	0x78e5fd1a, 0xf0c01f99, 0x2e735064, 0x3a43a4af, 0x37bda127, 0xfb4051a4,
	0xd731acba, 0xe7635730, 0x17707db3, 0xadde1f3b, 0x3b4dfa80, 0x58df9d98,
	0xb285fb83, 0x59efb626, 0xfa5af70d, 0xa06489f2, 0xcfde1ffd, 0x39549c42,
	0xcac7ebbc, 0x7d157083, 0x2fab1d70, 0xb4ddfed9, 0x47ec0862, 0x8b92a9bd,
	0xb8b67fe6, 0x9bee8636, 0x8588d36a, 0xf8937dd0, 0x5793c5b3, 0xd1387ec2,
	0xcc04902d, 0xf4fb5ad7, 0xfd2cff7c, 0xf616a6ac, 0x75df74cf, 0xe142f811,
	0xa3f8ee97, 0x3844eadd, 0x5d8fb776, 0x6c91ef11, 0x3f987f28, 0x73ff8f42,
	0xa078ce31, 0x7f7c15bf, 0x5cf57d7d, 0x865837dc, 0xf1081c5d, 0xef1c3960,
	0xefb63689, 0xf7638ca9, 0x06e32bb0, 0x4d4e41fa, 0x3689bd13, 0x9bc77e3a,
	0x1f828717, 0x87e1edf9, 0xe016df71, 0xf5ee2cef, 0xf1d47895, 0x8c6c03e9,
	0xbcbfae3e, 0x8efb0ed5, 0x11fec61b, 0x319f91ef, 0x4ecc77b2, 0x76349b67,
	0xfcd6c3ee, 0x257f3001, 0x4113e0a5, 0xd98ce73e, 0x7df40079, 0xa2227a77,
	0xe802dc07, 0x5f717201, 0x35039e0a, 0x3f83b2ed, 0x97bf34e3, 0x35a9a67e,
	0x969a6ee5, 0x1da3fc6f, 0x7c995bf6, 0x6d8c679d, 0xd94e0ef8, 0x6fdf1116,
	0xdca6e3a0, 0xa6e5fe01, 0xb08f59b9, 0x7ad46261, 0x37f7f090, 0x9af07b14,
	0xf5cfd918, 0xc4d7e2a2, 0x6bae3af7, 0x7b16dd12, 0xccf0bb57, 0x0a27f49e,
	0x72442f01, 0x2464b9a1, 0xe44ed13b, 0xb7f43ce7, 0x6df9de13, 0x9a3799e1,
	0x3572dfce, 0x13d51312, 0xde49d802, 0xc779cc5e, 0xbf62b1e4, 0xd685f75d,
	0x27b7a97f, 0x3133bd15, 0x3f697230, 0xde717002, 0xf60ef782, 0x4a4e3118,
	0x77e66f6f, 0xaec6ee4e, 0x70e91c7c, 0x38e0d353, 0x3010e7c0, 0x9a5e8186,
	0x2a3be3ce, 0x03382415, 0x68a9b1de, 0xf2411d12, 0xe97a724d, 0x52eff03b,
	0x27240475, 0x60476fd0, 0xe4264c57, 0x87f4459b, 0x739bbe55, 0x7b59d025,
	0x44f7c240, 0xb51fb72a, 0xf4503c83, 0xbd807b7c, 0x3811d233, 0x7e95df8c,
	0xae939bdb, 0xd1b3fd04, 0x3b9ff6c0, 0x0e2dff77, 0x171bc3e4, 0xbee125cf,
	0x3ad3d157, 0xeff157fb, 0xb0c4d9e6, 0xdf6d577f, 0x3de73112, 0x8fca9788,
	0x44288897, 0x7a2ed5ec, 0xd4b223fa, 0xebeaba46, 0xdb89fc30, 0xd7ae7c08,
	0xeb7861df, 0xe36cb7f4, 0x3200d576, 0x6bd5de0a, 0x10b498be, 0xe20679ef,
	0x3fd18b1c, 0x8e93ecc3, 0x317ea79d, 0x15efbe15, 0x8bff3dd9, 0x9bfdd222,
	0x85070b2d, 0xd7b86aac, 0xf42efe22, 0x8dbedb39, 0x2bb0bfd6, 0x8dabf996,
	0xf7d52bae, 0xfdf5220c, 0xbec15e1c, 0xee4bdcec, 0x7ce7ef0b, 0x48f3fb67,
	0x9eabf797, 0xd9fda1b5, 0xf0c41939, 0x2683fad0, 0x6c431790, 0x1c99e79e,
	0x39038c68, 0xfd899320, 0x24b71d08, 0xfa044c96, 0x0e21acea, 0xb2dbbb88,
	0xbc0060c7, 0x8697598c, 0xf9eb3171, 0xc682e0b9, 0x4a9a533a, 0xe7e02cbe,
	0x7924274a, 0xfbeaa260, 0xdfb67665, 0xf4abb13b, 0x7f979479, 0xa2cb9332,
	0xcec947e8, 0x9366d9e4, 0xd403753c, 0x7dc0643b, 0xafddcec7, 0x41f786ef,
	0x8e701c17, 0x17f37d04, 0x5fda07e0, 0xb5f5def3, 0xfcdb5710, 0x2a0b6811,
	0x8916d7df, 0x36ee3a06, 0xb27e64e2, 0xffb80cf7, 0x8917fb0d, 0xf9d6093b,
	0x67cd8d91, 0xe6831edb, 0x7f1b6a1c, 0x1b5df417, 0xb56a873b, 0xa6d53f31,
	0xee93133d, 0xeef43e46, 0x1e557806, 0x9ddad509, 0x629abf11, 0x6f7f8d2f,
	0xf411d4d3, 0x0da7f1cf, 0xf3b7400e, 0xac2235bd, 0x908279d7, 0xb1748104,
	0x6d7f689f, 0xfe95ef20, 0xfd669db6, 0x09bc79d1, 0x9fc0aa7c, 0x3347e06a,
	0x9b5b7e68, 0xa9e21131, 0xeb2bf814, 0x3677c650, 0x2b6af712, 0xd37b92b2,
	0x9577f837, 0x3b47c877, 0x392ef288, 0x9b0ce5d2, 0x41e8c43b, 0x13f9081e,
	0x2ed162bb, 0x19f5ccd9, 0x041a2d49, 0x24f053f0, 0x479f99d8, 0xe3774f99,
	0x407ae45f, 0x5d2dbf49, 0x329c97af, 0x1616cdd2, 0x8394ed8f, 0x6e218331,
	0xfe3079ab, 0xb8aa29bb, 0x4f008bd6, 0x8ffad212, 0x0306439a, 0xd8aabfdc,
	0xb3e0242e, 0x6fb43d22, 0x6c6674c3, 0x3e6bfa44, 0x4b8f9040, 0xfe65ee1b,
	0xc7ec123d, 0xf3c2b9df, 0x7e1fe06a, 0xa047dd6e, 0xeac0f8e9, 0xbe10fd25,
	0x55f03b41, 0x6f944e04, 0x33aaad20, 0xb82ebd01, 0xf9f3a59f, 0x5582eff9,
	0xe2cfe45e, 0x97cf167a, 0x7a634f62, 0x312bd394, 0x7885f6c4, 0x066dc78f,
	0xb3f31c4d, 0x364f6e9c, 0xe30ad13d, 0x6feafa52, 0x9a13e5a7, 0xa61a7f1f,
	0xc9ebd0ab, 0x53f612b5, 0x1f3dab12, 0xdd78e34f, 0xf7a31ef2, 0x89a56bf1,
	0x78d2cef0, 0x5fc03899, 0x3aed6dbc, 0x36f7e411, 0xc634e7a0, 0x4fd7a0e7,
	0xee247aec, 0x0ee7a027, 0xa5f8081a, 0xc9489b37, 0xec5f1546, 0x86aafd5c,
	0x6a1b4b7f, 0x3bffa2a6, 0x9c802894, 0x8156f857, 0x6b9366fb, 0x34fff20a,
	0x624fff1d, 0x33b36fed, 0xf9c13cbc, 0xca0289ff, 0xc253f4ff, 0xfa0104da,
	0xfe8a6cd9, 0xfd8156ee, 0x1ffb9e7b, 0x0b5722e8, 0x9f74be00, 0xc74c1f66,
	0x1ce1b8af, 0xf3c3ebee, 0xc4f374e3, 0xd26e8524, 0x1d7f8004, 0x8010e0c5,
	0xd02b8517, 0x20afda33, 0xf1d3736f, 0xf4aea13d, 0x973958b8, 0x446df0d3,
	0xebfc29ae, 0xe70eddbd, 0x96aa9336, 0x549d9d80, 0x9e9d2328, 0x1283bc14,
	0x093b5ea9, 0x2e451cfc, 0x7cf97364, 0xde6af241, 0x0f3aef0f, 0xbae817d2,
	0x60d8ee84, 0x705ea45d, 0x72947e00, 0x57db3d67, 0x59c398fc, 0xefe3fef9,
	0x5d13f70b, 0x0663fee0, 0x6c134ef7, 0x99fa8705, 0x44c2233e, 0xb8620be4,
	0xdbf02fbe, 0x6ec7aa02, 0x93b1e957, 0xabd21d52, 0x4e1a8702, 0xd81217ef,
	0x9e7c5dba, 0xa7ed8177, 0x1ba2673a, 0xf8c0a304, 0xbf18145a, 0xc9ffd08b,
	0x20a6135d, 0x9d10dfdd, 0x586e17ee, 0x5099f48d, 0x237bc0e0, 0x965d184f,
	0xf2688c84, 0xcee98fd8, 0xfb81ff75, 0xe063a02c, 0xa0f8eefb, 0x4480f804,
	0xa53f7fa1, 0x14fe157f, 0xf174a03a, 0x27255dac, 0x9ca174f4, 0xd97029ef,
	0xfc1f3bac, 0x5c0b9154, 0x89bb3bde, 0xf3d65153, 0xea1cf19d, 0xd26ff7e2,
	0x5be017f3, 0x04bf1391, 0x3ddb1b3e, 0x678ff59f, 0xbcd2cbe5, 0x70a1ae07,
	0xe4c7d65a, 0xd6e5425c, 0xc7668a32, 0x51b9c8a8, 0x595f1f23, 0x0fce1ec7,
	0x3cfb9ddd, 0x4b7de716, 0x9f384f0d, 0xe8446674, 0xb9db9f25, 0xf199d68b,
	0x61237ddc, 0x8cef2dfc, 0x79efabf5, 0x50d48c3a, 0x0fdfa0a5, 0xb5193df2,
	0xcef21072, 0x4219136a, 0x5690bdc7, 0x6fe213b4, 0x2e4dadfe, 0xb297411c,
	0xbf4f24d1, 0xae07f701, 0x94ffd029, 0xfc038342, 0x876e09bf, 0x2409fe00,
	0xbdcbe059, 0x83d19c6c, 0x3ee2575d, 0x0d1ae9d6, 0xc710e1f2, 0xeeef82a3,
	0x83d7a2e0, 0x7fbbe1dd, 0xe3bf3f3c, 0xf2f97ae5, 0xe3e3871a, 0xb22f963d,
	0x27667c08, 0xac22c5de, 0xc7c98723, 0x21c97cb0, 0xc6283e78, 0xa7bd1a0b,
	0xf9407fe4, 0x558fc622, 0x50ec97c9, 0x7f42f954, 0xf242e551, 0xe76879da,
	0xedd10392, 0xbfba24dc, 0x417ff7c1, 0xc97ad2bf, 0x4777fb32, 0xa67a710f,
	0x8c718994, 0xe8cd6b75, 0x93e457df, 0x1527ba7d, 0x5ef64bfc, 0xcbdc1726,
	0x53274e73, 0xba779a24, 0x539fb80d, 0xf1fb57f0, 0x5c9f1813, 0x604ccebb,
	0xe9cf12ff, 0xf13a7e2f, 0x72a88507, 0x439f808b, 0xe67f73fe, 0xc80317a7,
	0x09f28b4f, 0xeb9ddbea, 0x95bd21c6, 0x400ba614, 0x090da5cf, 0x4e279402,
	0xae401872, 0x571aeb29, 0x52dd222d, 0x5e32b8fe, 0x72719f85, 0x1bf00895,
	0x954de494, 0x123da812, 0xa9bfecff, 0x68e33cfd, 0xc476657e, 0x0ff343cf,
	0xdcf7c75b, 0xe7e133cf, 0xc430f9ff, 0xddda148b, 0xc7b780d9, 0x60133ce2,
	0x55deacfc, 0x69ee0fe8, 0xa577c4fc, 0x4fee4a9f, 0x7eb47b22, 0xe6b72a7f,
	0xff993834, 0xd155e61f, 0xd0d3d8f7, 0x117fbe1d, 0xf3673ed5, 0x45f1c5e8,
	0x8f88223e, 0x112a9e5e, 0x3c8a2afc, 0xb787059a, 0xc02d7f6c, 0x7fc287f9,
	0xeec0cf20, 0xc025e256, 0xff4365bf, 0x43eb1fbe, 0x44547e3e, 0x342cad4e,
	0xb8977d44, 0x83fade32, 0xf81271ca, 0x289fd6fb, 0xe4450bf7, 0x5fc64aaf,
	0x513fae4c, 0x9d852878, 0xfef7b05b, 0x3c63e3ee, 0xfbf5d8bf, 0xef22bd61,
	0x9b348c36, 0x254b8864, 0xa874e26e, 0x808593e2, 0xbc41b410, 0xe204dfeb,
	0xf8e878a6, 0xf3e9889b, 0x9053cfff, 0xb37f7606, 0x282d45c1, 0xf940d388,
	0xf0441ae8, 0x7f234ade, 0xd5b73107, 0xea3e06ea, 0xfdf86210, 0x3cf6b76a,
	0xe073bb24, 0x24be5a06, 0x937fc660, 0xf95723af, 0x785c1177, 0x6f8159bf,
	0x0c4fbbe6, 0x634ff8c7, 0xede40b9d, 0x7feb0b1a, 0xf7f9858d, 0x769458d6,
	0xefd078ce, 0xe7cb9ddd, 0x3f43f754, 0xcc97e2a1, 0x008a0ce9, 0xa74ef49f,
	0xb1c30581, 0x049d8cf1, 0xd79cadd7, 0x6ff87237, 0x0449b3de, 0xa9359fbd,
	0x8fec096e, 0x07fea99a, 0xd1c84f78, 0x046385da, 0x853c8e7e, 0x389877b0,
	0xc885249f, 0x1281300e, 0x20dc840e, 0x709c2692, 0x67fd80ef, 0xd00887bc,
	0xa84e2a9f, 0xbd25fa01, 0xbd0dc2dc, 0xe5d9dfe0, 0xef2166ff, 0x899ef367,
	0xaf7df002, 0x338249b6, 0xaf9d2ba3, 0x18fa7d82, 0xf802cf16, 0x838ff655,
	0x24c5737e, 0xff529780, 0xae67ae2d, 0xc0f37af6, 0xf3d74cb5, 0xf8f7f02a,
	0x7856fe99, 0x895c6aaa, 0xaa726adc, 0x6080b3d6, 0x3242fd7f, 0x01cfa3ae,
	0xfba42e6f, 0xcfd809ad, 0x8c411384, 0x455de983, 0x0c883c20, 0xed0f7b68,
	0x6d5501ad, 0xf373e002, 0xbe71379e, 0xb276dbfd, 0x26d7f394, 0xf3282f6e,
	0xf6656fda, 0x9e7e7ed0, 0x2e667b5d, 0x13be9fc6, 0x2738c5ef, 0xb9b51d65,
	0xda2ad4de, 0xdf882aff, 0xfc7dd319, 0x4de39fce, 0x8fe05f8a, 0x99cad700,
	0x8340dda1, 0xca433f7a, 0x8f8843de, 0x7db66a94, 0x9177b55f, 0xd562f200,
	0x067ee8ec, 0xe2ac6e45, 0x9c555a7e, 0xa72d484c, 0xc62516a7, 0x92e4aba5,
	0x48e9eed2, 0x1e66cc9c, 0xaf16d327, 0x8ea7efb2, 0x7a016658, 0x9f756b9a,
	0x7f94fe80, 0xff3d6817, 0x7d9476f7, 0xb1af02af, 0x77cf860e, 0x0fda6fe2,
	0x27004de7, 0xf5e3a507, 0xe6f1e896, 0xbb143b97, 0x690bd193, 0xeb02f463,
	0x3665db50, 0xd5c3c307, 0x919e6f6e, 0xa445c9d1, 0x2b7f6c93, 0x02b8edd0,
	0x7fe815b9, 0x5274e100, 0x4f44e8c0, 0x7e05ffef, 0x004cac60, 0x00004cac,
	0x00088b1f, 0x00000000, 0x7dedff00, 0xd554780b, 0xb3dae8b9, 0x79332667,
	0x24f2664e, 0xa25e1daf, 0x84243884, 0x093b6287, 0x18040301, 0x824a2a04,
	0x92403bc3, 0x5a968209, 0x188061ef, 0x2c1b5203, 0x1d696a5a, 0xc52af4a8,
	0xa1b52836, 0x55e13a0d, 0x8a83a8b0, 0x41a5a7a0, 0x04854450, 0xa5a0f1e2,
	0xbffffef5, 0xef6666d6, 0xec458a4c, 0x6f73ddf7, 0xdac5d9fa, 0xffb5ed7b,
	0x6b1fbff5, 0xd9b2c9af, 0xec664b19, 0x993b0f96, 0x21b19627, 0xe7377312,
	0xfe25f631, 0xdad43b7d, 0x971a066c, 0x18912c14, 0xc6347b8c, 0x3115b56d,
	0x4ea33436, 0x9d704936, 0x3eb3c6d9, 0x29b5f58c, 0xc2f5c18c, 0x32bdaee1,
	0x6e5ce783, 0x29bde719, 0x37cf46c6, 0x1b8fbae4, 0x364da092, 0x344b573b,
	0xd706c38f, 0x9a4b9259, 0xfe87d700, 0xd0b5b195, 0x44b079dd, 0x7df0f252,
	0xcc65bca5, 0x3cf30cd5, 0x385958cf, 0xae02517c, 0xde8936be, 0x3c7bf3db,
	0x526f08b9, 0xe092e0d0, 0xb1e3b0fa, 0x87d7067e, 0x7193ab2d, 0x282c493d,
	0x5ed80031, 0xc3362b65, 0x9daa33fb, 0x93de0792, 0x6019e317, 0xfc1f308b,
	0x1883dd59, 0x3aef1ddb, 0x2ef30b16, 0x3beac67e, 0xeceba16d, 0xa6aff84b,
	0xf7d35139, 0x4efba4b6, 0x17f5080f, 0xe1d23fe3, 0x616656bf, 0xe6ab1943,
	0x6577d8b7, 0xafbe114f, 0xe8fed2c6, 0x3ed7e82c, 0xc19999fb, 0x3f5c1512,
	0xc1fcf3c0, 0xb1d99882, 0x144ff5a1, 0xe5d5beeb, 0xf1846519, 0xdb9e712d,
	0xc311f9f0, 0x78657bfd, 0x6f995868, 0xba4151af, 0x038dedd6, 0xe658d9f8,
	0x477d0adc, 0x878b6b3b, 0x76f1e26e, 0x8ff43c57, 0x3cd226c5, 0x6ae87cb7,
	0x58c21bcb, 0xf8499b82, 0x76ede03c, 0xf24b1bc4, 0x937ae214, 0x0664cb82,
	0xf480bc70, 0x7d3abd89, 0xfa72c58e, 0x22958b1c, 0x8c4a65d2, 0x7fce326b,
	0xf7c59e0c, 0x80d84afb, 0xbaf7f83a, 0x3f994372, 0xb3ce1f02, 0xd73cd2c5,
	0x6676ef8c, 0x6b37c70c, 0x0f8bdbfd, 0xff8bdf40, 0xf3ff0996, 0xfbe3fe04,
	0x547ffac0, 0xf20a5efe, 0x79d2c1af, 0xd4bc0248, 0x0c8acab4, 0x934c0f70,
	0x190ba75c, 0xdda0fd5b, 0x53fae0c5, 0x0a3392cd, 0x531733c6, 0x118c296c,
	0xfcff408b, 0xd9f2136f, 0x05c2d0cd, 0xa5f38c3b, 0x735bfd9b, 0xc03edee1,
	0x26f38c37, 0xe1ea380a, 0x8747001f, 0x45cc054d, 0xcaec4df7, 0xfb824d9f,
	0x982ff851, 0x6b6e6a4b, 0xab808093, 0x098f3387, 0x0adbdee0, 0x347087ff,
	0x60a3fb44, 0xbf6d5ffe, 0xf4066878, 0xc0683efb, 0xb95fc165, 0x7c1883ed,
	0x097d25d4, 0x196f1cad, 0x4efb8460, 0xc329da39, 0xf8e8e6f8, 0x58c0967c,
	0x06125ef1, 0xcc1fbab6, 0xdd59ef03, 0x5beb4d16, 0x25e40fdd, 0x2d61f897,
	0x9c5f67e2, 0xf5c3a599, 0x1c23902e, 0xbfb58c37, 0x44373231, 0x4f96aea7,
	0xf581ee67, 0xbcf8637b, 0x3f6c98de, 0xf63b7803, 0xfc8fee5c, 0x1cf96e3c,
	0xf803a977, 0x08fcf657, 0x7b9f53e7, 0x78a9c065, 0x996337c4, 0x4fd12f04,
	0x0577c10e, 0x5f8e366f, 0xeb48ce39, 0x4ed160e8, 0xd9b3775c, 0xbe4e90c5,
	0x55cf9c13, 0xde0ad6bc, 0x3a2d68e8, 0x3df581ee, 0x89d33c75, 0x74b477cf,
	0x3ef00d59, 0x69e7826f, 0xab3943e4, 0x879dde33, 0xb1baecf8, 0xd3f48f3d,
	0xd77af12f, 0x4f7653e1, 0xefad35de, 0x7d655f37, 0xa36c635e, 0x7f9dd094,
	0xb5207cf4, 0xe52e7db6, 0xd4309c93, 0xe66cbe63, 0x6eeb0d5f, 0x51b83418,
	0x654f4246, 0x6329ca0a, 0x060fb615, 0x995de886, 0xe1197ee0, 0x9dcbe550,
	0x75c36ee0, 0x0a327be1, 0xb17b9d68, 0x9ceaff9f, 0x9ae19342, 0xf23879d6,
	0xff84033a, 0x1a9eb11a, 0x06406c4b, 0xd34ed9f8, 0x7caaed27, 0x2f0eeef6,
	0x8718e3d0, 0x83dc79d7, 0xd6377cf4, 0x61f11ab9, 0x71dcda0c, 0xa43bff04,
	0x4acf8697, 0x1a3ef5c3, 0xc1c532e3, 0x192b6df8, 0xda2907e7, 0xb71605b9,
	0x1a3d9f63, 0x826565f5, 0xbbe71da7, 0xa67170c9, 0xd05ced1b, 0x764d986d,
	0xaf0a73cc, 0x8cbbbac3, 0x8c9d4704, 0xfac35ff3, 0xba78413f, 0x1d1bbfaf,
	0x7a616d3a, 0x48cfc54e, 0x8891df41, 0x9dcc541f, 0x2dda4fc6, 0xa048fc21,
	0xddec33dc, 0x968503e7, 0xedb6f08d, 0x1dbfd33a, 0xe97dabe6, 0xdf944ccc,
	0x1147dfda, 0x7f7f4b71, 0xf1f20263, 0xbd3662f9, 0x3ebbb639, 0x9d4564fd,
	0xf5cc08db, 0xe937adb9, 0x34166ad5, 0x69af1da3, 0x8636e25e, 0x988053e9,
	0x05361fee, 0xc3fe71cb, 0x095b3245, 0x1ce5d77c, 0xe822ca96, 0x6d7db569,
	0xedcf7305, 0xa8b3d8c7, 0x76bf90e7, 0xbc20490d, 0x1f49dab4, 0x5e1fc7eb,
	0x352ee551, 0xe1df3cf5, 0x7ee9d6c1, 0xe75cbe78, 0xc894dca7, 0x227160ed,
	0x28a033b7, 0xb9e7085d, 0x3efce317, 0xe0ae74b8, 0x3c033c68, 0x66f9db9d,
	0xe5f80fa1, 0xfd2e0b1c, 0xa7cfca03, 0x6a2b6cb1, 0x0b47c1c7, 0xe485c657,
	0x7ce1b6ed, 0xeefdb7ed, 0xc60578d5, 0x9bd8ef97, 0xdfc30be4, 0xe9f8cc6d,
	0xc5cdfe15, 0x31f5f2f7, 0xa47f7b63, 0xd9c3fb07, 0xf2da0514, 0x3893fb5d,
	0xa406281f, 0xb7a132f3, 0x4697837e, 0x5f2be684, 0x2d2eeb5e, 0x2e6bf50c,
	0xbc3f9959, 0xd19a0c6f, 0x8a5cd5f4, 0x89f1eba5, 0x3fa44971, 0xa85eb17a,
	0xde2abe3f, 0xbc55d7f4, 0x367c1e1d, 0x79f8ed1b, 0x993e646b, 0xe5daf020,
	0xfe8a911c, 0xd039b952, 0x1c6116d7, 0x4f9a7e63, 0x5657aebf, 0xfda5dc78,
	0xbc6f867a, 0xf9227999, 0x7c04639d, 0xf32b4e5d, 0xdd2f5c81, 0xf43b226c,
	0x5363e5ea, 0x677e810b, 0xab6c9936, 0x3f559f00, 0x23f99bdb, 0x38355fb8,
	0xff4126ca, 0x8be8128c, 0x67e0bc7c, 0x7dd71bb2, 0x94d2d366, 0x0c7ed039,
	0x700d58fc, 0xa26cd82c, 0xef9b55eb, 0x0567eba3, 0x59f82e9f, 0xf3d440f2,
	0x9b5beeaf, 0xfaaceb82, 0x41dfc3fb, 0x6cc3b17d, 0xda18381b, 0xbb92edea,
	0x162e4c34, 0xf4d56d3d, 0x15581877, 0x375d43ae, 0xee573c93, 0xf7cf002b,
	0xcf5f0d13, 0xff01697f, 0x2fe34525, 0x88b13f7e, 0x538995fc, 0x45b5dd60,
	0xee2fe45d, 0x764d103d, 0x9958e5fc, 0xe0c081fc, 0xcdd3feff, 0x77f51fd0,
	0x087c93a3, 0x85a3e7c1, 0x006c665e, 0x16f9a1e9, 0xcbb51fde, 0xa8c4fe48,
	0x1df09938, 0x4a513d00, 0x3b15c846, 0x4b7dc61a, 0xb91e4e7d, 0x1b8c0461,
	0xe862609d, 0xb02b7e2f, 0x7e819ca8, 0xe325f6ff, 0xeb61ed7b, 0x232e6129,
	0xccc5223a, 0x26beb9a4, 0xfa0b7e3a, 0x11993047, 0x8b28f8f5, 0xbee8fef6,
	0xbda2cee3, 0x5ed36d1b, 0x49e7e557, 0x21818394, 0xe07bd839, 0xc3c6c7a3,
	0x961fe73a, 0x15763fb9, 0xae1af33d, 0xfbd21fab, 0xf0ed8a95, 0x3b02abdc,
	0x533e5eaf, 0x35fc8e9f, 0xa0ab625c, 0x5472e67f, 0x30b92459, 0x0186faab,
	0xe884079d, 0xf0b9c13c, 0x62c51f4a, 0x5725f0d2, 0x57ff08fa, 0x5cff77d7,
	0x9a25a72e, 0xfaf43e49, 0xdf3f2f50, 0x1f2c3e94, 0x17db3fbc, 0xb12fed47,
	0xd70764fd, 0xa8fd7a33, 0x5c2a7fd7, 0x2e6b787a, 0x37bd1ac9, 0x71a15126,
	0xa667fd21, 0xde31d7fb, 0x2118953a, 0x4cfb02de, 0x350df2f8, 0x014e31fa,
	0x1c43e1ff, 0x38ab1797, 0x7aa4018a, 0xd418ef5b, 0x3d6273eb, 0xe5fca31f,
	0x52a6eafc, 0x6e060bf4, 0xfea0326f, 0xbd3890e8, 0x8b4499b6, 0x3c50bcfd,
	0xffac5174, 0x1007d098, 0xd91c5107, 0x7628f97b, 0x6517d60a, 0x016b3e61,
	0xa99f7dd9, 0x9fff3420, 0xc58a2fc0, 0x9198aa38, 0x7224367c, 0x00f7afff,
	0xf98360c5, 0x73615e1f, 0x5e7e069d, 0x5a8d22b3, 0x01806036, 0xe054b7e9,
	0x7c46fd06, 0x9a27b7ce, 0xe4bef5d6, 0x7cb947ce, 0xa7a7c058, 0xe55d9147,
	0xb5d9376f, 0xf5912579, 0x48ddae74, 0xb89f8ae3, 0x8dfd1b2b, 0xceeedbf7,
	0x3ef9fd46, 0xfb4419c0, 0xa0267467, 0xeccf309f, 0x6ec91fee, 0xe1c850fc,
	0xfc4ec223, 0x8245c840, 0x6d812b88, 0x71623b5c, 0xbfba6e7d, 0x6a74c566,
	0x4e58afd7, 0x1e76cce3, 0x788fc6bf, 0xe81bd83e, 0x4c9d7a76, 0xc5b4e076,
	0xa9e8f140, 0x9db2d8ba, 0x7f3b8704, 0x677f985a, 0xb4f77016, 0xb5fb22ae,
	0xd61aebe9, 0xe7f68f1e, 0x0105df0a, 0x7b7a611b, 0xb029ec9e, 0xd2dc6327,
	0xbce3829e, 0x76ffb052, 0xb33bfa72, 0xefaa0f51, 0x2aeb1adf, 0x66cd71c2,
	0xd6f11036, 0x8bedcd1c, 0xecdbce1e, 0x5e1e9f9c, 0x0ffa08a1, 0x9f4256a0,
	0x1f7f9e11, 0xbc0452ed, 0xbefa0897, 0xb12aeb19, 0xb1609ea3, 0x3ad25fe4,
	0xe3ca2f80, 0x3af1a35d, 0x23b707c4, 0x7953431c, 0xac58e7be, 0x4b85f04d,
	0xbbb7fee2, 0xe5d79e9c, 0x13ca7a71, 0x2338e1e8, 0x1fcfacf0, 0x3f9aada8,
	0xe7ac53b8, 0xd68da242, 0x2827cfab, 0x2915cccd, 0xbb5bf06f, 0x734b9e99,
	0xa518e4b9, 0xe21b3967, 0x6327cf79, 0x733a649e, 0x8ea4f8a2, 0xfcc36e6c,
	0x7fa97a49, 0x1a57e625, 0xe772f512, 0xa55e62b3, 0xe290c7b7, 0x41297183,
	0xd619b14f, 0x0a425cf7, 0xeaca97c1, 0x86dd2256, 0xf8b40c78, 0xfda2fb21,
	0xc1dc1a92, 0x0fa14290, 0x28ad2241, 0xf389df5f, 0x1c7887dc, 0xb56eb73a,
	0x943cc159, 0x727d464f, 0xd8e4f256, 0xeece4f81, 0xc7e88e8f, 0x33fa0835,
	0x4b17a4a9, 0x6d3cf783, 0x790c3c22, 0x0899f1fa, 0x6fa790ef, 0xf1614a37,
	0x89bb16f9, 0xff7671f0, 0x978a1ca2, 0xfd6289df, 0xfbcfbb72, 0x078fe0a4,
	0x305fde04, 0x27bfe647, 0xd66bb8c4, 0xf9bbc7cb, 0x8bd84f35, 0xda987942,
	0x97a48b9a, 0xf42bb5ef, 0x9b1a9f9e, 0x7c02f40f, 0x732e74fe, 0x3d17de22,
	0x75f299b3, 0xc79b982f, 0xd4f5c76e, 0xffc6181a, 0xfefc0efb, 0x0bf42f40,
	0xd1832ae7, 0xfcf2b81f, 0x780d6de1, 0x6c55a7fd, 0xdd3fe230, 0x3cc25ebf,
	0x26d667c0, 0x5b67d7c2, 0x584ad8a3, 0xcd23c2d2, 0xfe801f63, 0x43036ac6,
	0x375fa27d, 0x4864c9bc, 0x326036c3, 0x47f4e70c, 0x1dd2a7bd, 0xf48ccb18,
	0xf886e950, 0x6fb63d43, 0x7e08efeb, 0x12e7ae15, 0xa2dfa214, 0x458c7667,
	0x6d55e93e, 0xa32f3097, 0xed75f5c2, 0x97b475c2, 0xae5d0487, 0xc35f2f66,
	0xa97b7a71, 0x627393b7, 0x0f48475d, 0xde5ec55e, 0xb76bf82d, 0x530a13d0,
	0x253cc11e, 0x3ca06c3b, 0x772e9e8f, 0x45e5bbda, 0x7f9e11db, 0xd63a2f35,
	0xb5c7e6ae, 0x666dd179, 0xec9b4fae, 0x11c99eec, 0xc054a1e4, 0x69d0d86b,
	0xd4987b46, 0x4bd4452a, 0xffb962c7, 0x8bb3fa06, 0x64466bf4, 0xbf011afd,
	0x1bf8e05f, 0xe0f607b7, 0xbec482a8, 0x0166e831, 0xeb86ff3e, 0x814f82bc,
	0x2aaf1547, 0x509c7f3e, 0x4db2fc4c, 0x25cf95f8, 0xc531fd68, 0x99738ea1,
	0xf566d01c, 0x1ce3b7a0, 0x7f009d7c, 0x4f9e03ac, 0xf934c65a, 0x9eaf3575,
	0xcc93e754, 0x303cd043, 0x38e5bbca, 0x304d2b3c, 0x730473ae, 0x427e816e,
	0xf518ad85, 0xd9cabd9d, 0x86f7f986, 0xd99f3c73, 0x57f984b0, 0xff8c3cd1,
	0xe537a79f, 0xeeef114f, 0x41f6eed8, 0xadd81f5d, 0x2b87074c, 0xc9eae11b,
	0xb9475d6e, 0x357c73c8, 0x88ec18b9, 0x9833b740, 0x388a2bfb, 0xf1a4587e,
	0x8ee1e740, 0xd9d3abe4, 0x7f03ea2d, 0xfe4c984a, 0x2d9fca25, 0x3d77443f,
	0xf98a6f3d, 0x3bbc7a9a, 0xc245265e, 0xc372bacb, 0x93ae2300, 0xd9233b45,
	0x588ed99d, 0xcc1bfb82, 0x1476cff3, 0xc3f3cf75, 0x7e5fc69f, 0xf5f3956a,
	0xd7ce101b, 0x9e8b8a64, 0x33768ffa, 0x7cd587e6, 0xf7af0ab4, 0x40b9890b,
	0x217c773f, 0xaf5eab53, 0x310a956d, 0x7bde2ace, 0x8ee2fc99, 0x2fc82fb6,
	0xc5f9d0ee, 0x05ef7bea, 0x18f944f6, 0xff12c72d, 0xe3c4dc5f, 0x3f299977,
	0x7870091e, 0x5f989a0f, 0xff25fe21, 0xfd0bd681, 0x03398c8b, 0x1c7b7e38,
	0x8705c3d9, 0x139e10e6, 0x12981b86, 0x5744af86, 0xf0c25334, 0x6bb328e5,
	0x5eeec9fa, 0xd3a9f19a, 0xa7ee6b7b, 0xdcd26e7b, 0xd02aa8cf, 0x6eeab3f4,
	0x59cf8cd1, 0xe7e9a25e, 0xc669c6fa, 0x43bc69f7, 0x74d7efd3, 0x36fc66b7,
	0xca16fc6b, 0xc15cfbfb, 0xb9deb0be, 0x6c37bd62, 0x8e79ad9c, 0xd600a405,
	0x7209e647, 0xcc6dbc7f, 0xcc8fac41, 0x1b88f915, 0xf3348bfd, 0xe6d26bce,
	0xf3ac8c13, 0xafe00640, 0x03392fd6, 0x51b05fd0, 0xcb617f7b, 0x42e7c266,
	0xe2faf6bf, 0xfcfdb467, 0xc40ca757, 0x14671071, 0x6bf73fa2, 0x713f3687,
	0x6efb3a55, 0x473a26b8, 0x6ce969a5, 0xd674b455, 0x80662fe3, 0xfe1f775d,
	0x17f04ff7, 0xc5f2d4e7, 0xb7bf8537, 0xe6bcda1c, 0x639e31a3, 0x2d5da728,
	0xf98664cb, 0x875e32f9, 0x34f96aec, 0x2112b0ff, 0x5bafdf2f, 0x8eaffe5e,
	0xe6a6bb30, 0xdeb03be5, 0x0afb3372, 0x9fbd96f5, 0xc0a21e23, 0xffc098f2,
	0x969dc366, 0x6b15f52b, 0xd7af0f28, 0xfa0b6a5f, 0x7a41d3bb, 0x5a97543d,
	0x4d0f4f0d, 0x708ddb78, 0xf18b75aa, 0xef04599e, 0x08c808cd, 0xaf962ff8,
	0xf0079d53, 0xfdf50970, 0x0c7b62f8, 0xf63b53c6, 0x01714bdd, 0xfae24d6b,
	0x23a3d44e, 0xcfa4a7f8, 0xe99ff19b, 0x74bf1764, 0x4a437f70, 0x2c8bb30a,
	0x15efe760, 0x79a7b176, 0x4f45bad4, 0xa647b4ad, 0xd6274bfa, 0xf5e8225f,
	0x69afa48c, 0x1d7a745f, 0x524678f4, 0x5f709c78, 0xefd401d7, 0x24ecf780,
	0x1c5c4f78, 0x64294dd8, 0x131c7f37, 0x79d6f24f, 0x00dff648, 0x945a2e17,
	0xa85e7b04, 0x7787a2be, 0x32e1c5a4, 0x56f3e986, 0x1b376b49, 0x321fb80a,
	0x3a6bac50, 0xa7805dda, 0x3abdf444, 0xc8dbddbf, 0x869053e3, 0x7f30d6aa,
	0x8e2924b0, 0x2e8a9fc6, 0x37b8412e, 0x21bf388b, 0x35f7a257, 0xf7d91248,
	0x9494276f, 0x382f7ae0, 0xbdb18b8a, 0x04a7bc45, 0x37e8237d, 0x28f0e6f5,
	0x3a80bf62, 0xf8c5dfff, 0xa84a3bbf, 0x09b2492d, 0x1376c83f, 0x68cdfbd2,
	0x966bcd17, 0xa55f8d65, 0x7127b7b6, 0x2c7ce27f, 0x7f3e8f7f, 0x31e8463c,
	0x914717cc, 0x47cab930, 0xc4f268a7, 0x4493996f, 0xc7a2589e, 0x6fc7485d,
	0x94f63a0b, 0xb00d7637, 0xaa7543ed, 0xb3af1bcf, 0x9ab1bcf2, 0x3796ee57,
	0x98898e76, 0xc43a4637, 0x30f243d8, 0xbe8ae93b, 0xd37d44c9, 0xd8fedb90,
	0x578fe478, 0x0416e765, 0x98becffd, 0x715b807c, 0xc8f89c1a, 0x956c4d88,
	0x7c0bfa15, 0x4c97e50a, 0x15c58710, 0x97d7e484, 0x1a784b94, 0xc9603c74,
	0xfec3fb87, 0x3cc36eec, 0xcca9ff72, 0x89bfea8e, 0x478a8d35, 0x8b13627f,
	0x5f7cb718, 0xf17c73d0, 0x3ce5191e, 0x25f813b9, 0x2fbe3d02, 0xfc7201e8,
	0x586dd200, 0xec8ba7a7, 0xa403d08e, 0xda3e30ca, 0x597f2067, 0xf8eefcff,
	0xb3e43e51, 0xf9c8fe41, 0x9fc2f392, 0x6eed14be, 0xed07f9c0, 0xbea3376c,
	0xcdeaa059, 0x046606b9, 0xf4114efa, 0xd789b29b, 0x2fe5d9a5, 0x3f5594bf,
	0x0cfcd18b, 0xa982c1f5, 0x3fcc7e71, 0xf5cd682c, 0x896e5c11, 0xd6de2bf2,
	0x2fec6e23, 0x86c43218, 0x5debaef1, 0x80307d26, 0xf5c6345c, 0xa07d918e,
	0x9fb201ea, 0xb8a75449, 0xf9d5f043, 0x04e08558, 0x062ebcfd, 0xd360b0e8,
	0x2fb83dca, 0x182fe8e1, 0xcb8e23d5, 0xb271439d, 0xe59c8069, 0x591ad805,
	0x9c3e0145, 0x154cf346, 0x80bef8f3, 0xef425af7, 0x887ad69d, 0xc4dc73d6,
	0x97e0167c, 0x2a77dd8e, 0x5933ca46, 0xa2bfc49c, 0xf64275ce, 0xc3c6443c,
	0xa08b59d8, 0x631ad5dd, 0x58eb0b5b, 0xbfdc666d, 0x113b4435, 0xdb6213ff,
	0x492fc48d, 0xe3c4469d, 0xda674119, 0x92e3844b, 0xce49d119, 0xe5ba7030,
	0x489f7c28, 0xf03e6d5f, 0x783ba0b0, 0x7d78998f, 0xcb1bcc42, 0x3dcce014,
	0x19c6b349, 0x484f7f41, 0x2e596378, 0xcd27f7f4, 0xfe04671e, 0xc6f1909e,
	0xea20b9a7, 0xc39a4c7f, 0xf8df03fb, 0x0ff437b4, 0xfde5cd25, 0xd9f7895b,
	0x8de6929f, 0xfce1e5f3, 0xdffccd36, 0x5fbcb995, 0x19472b6b, 0x19c522ea,
	0xbe449347, 0xef82500a, 0xf1feb771, 0xb759da38, 0x9976ff5a, 0xe46ff534,
	0xdbf00b18, 0x2c57c178, 0xc0ec9e29, 0xf1bf4138, 0x87ed00c6, 0x84025831,
	0xbd581bdf, 0xb006f90d, 0xc2cbe1b5, 0xd90fefee, 0x497f2d35, 0x0396c62e,
	0x46c525bd, 0x397ab27c, 0xeed158f3, 0x06eeea87, 0x6e67775e, 0x8f0abf7c,
	0x706efefa, 0xf68d6901, 0xd136b870, 0x1d5c2a3c, 0x287ca383, 0x54fdaa4f,
	0x3a90eae1, 0xef498e7f, 0xa3793fad, 0x11dae91c, 0x412d99d7, 0x41e3f37f,
	0x724773a2, 0x6725cfe7, 0xe9c4df58, 0xffa4b7f8, 0x4cfe3a20, 0xe50dfd76,
	0xf7ccca3b, 0xbc623495, 0x2479ef02, 0x7ac3e3d9, 0x339df01e, 0x65977c80,
	0x3a543d26, 0x309f9b44, 0xb63b7325, 0xdbf39926, 0xbaa6a8e8, 0xde97c023,
	0x095b129d, 0xbb97bde3, 0x262768cc, 0xbb349eb4, 0x79ddada0, 0xaafa8cd2,
	0x4f30fb16, 0x447326ed, 0xb278f5bd, 0xeb4bf82c, 0xeacfef07, 0xee1250ff,
	0x512b985b, 0x5ddeee05, 0x7fb1a389, 0x255c2cef, 0xdc8f7763, 0xab1f1a31,
	0x843db774, 0x7dac3ded, 0x5dd0b23f, 0x97e3591e, 0xd18aa8ce, 0x7595b5f8,
	0x9eff4d0e, 0xc80ea026, 0x33cb3df5, 0x8303f1b4, 0xb9e015b8, 0x50fe858b,
	0x74174dbf, 0x5d6d2bbc, 0xdcadf710, 0xdaf931e5, 0xd09be6c3, 0x4768d2ba,
	0x2724ebb8, 0x531f5fa9, 0x7c19b9f0, 0x7d1ad085, 0xd1b075e1, 0x51993c2d,
	0xfdfdcd5b, 0x5e03ec0a, 0xbf24aa2b, 0xcc1e2122, 0x22dbdf74, 0xcb6f7dd1,
	0x37dc52fa, 0x51265de6, 0x97a524de, 0xfd848788, 0x0ac047bd, 0xf384d47a,
	0x624fb8cc, 0xc21bd40e, 0xbfe157df, 0x59d97a67, 0xe7e14fe2, 0xae9cebab,
	0xeb85dd80, 0x607ce4f7, 0xd61aff42, 0x835dba77, 0xb2bf6d4f, 0x67bfdb4e,
	0x9e5fb6b9, 0x819de22c, 0xd3ca206c, 0x88c964e4, 0x7fed557a, 0x6bf6f592,
	0x9b678001, 0x0c9a9eec, 0x0e6d55fc, 0x9b69fd50, 0x7abea1ec, 0x32d7ae1f,
	0x07f03b92, 0x92258e48, 0x9726d5cf, 0xe8fd18ad, 0x76f8891a, 0x17f30b06,
	0xa9e34372, 0x3fef772f, 0xcef5cc9c, 0x197bab6a, 0x4b76c1d5, 0xa970adb6,
	0xa232e8d4, 0x8a5ab81f, 0x1469179c, 0x831af0f2, 0xeae01e28, 0x768a4c8f,
	0xdf824a7d, 0xffedef07, 0xfa1f2cf2, 0x810bfdf7, 0x7b94140f, 0x0bc66f6e,
	0xfc11337b, 0xfafff44b, 0x49d3cdcb, 0xb66cdfbf, 0x76177e91, 0xae17d548,
	0x6876b567, 0x8a41e67c, 0x5c6e263f, 0x62f50177, 0x82ae3edf, 0x23df00f5,
	0x47fefe56, 0xdc7e4976, 0x779b5387, 0x2a67f480, 0xb7be05b0, 0xd1e84d36,
	0xab3eed16, 0x986bd454, 0xa3cf2fcb, 0x545ba6f7, 0x1e91776e, 0x86250294,
	0xa97e812f, 0x9985bde2, 0x653bad0a, 0xeb84b351, 0x95be62ce, 0x8bbfc768,
	0x6a1c9842, 0x1f9fd9af, 0xfef3e922, 0xaf9864a6, 0x4cddad26, 0x34eb1ef1,
	0x5d3cad7f, 0x2213f9f7, 0xa7cb0fcd, 0x2e2874fa, 0xf98f1cbf, 0xf7777b9a,
	0x9bfba7f9, 0xee368b64, 0x71b4d936, 0x5a01f8f7, 0xa9c133fd, 0x86933bd5,
	0x9fdcd1f7, 0xb9a81aec, 0x50aca53f, 0xbee69fd3, 0xcefe3355, 0xfd34a3e9,
	0xba71b4a8, 0xbf36803c, 0x9b403312, 0x6a73895f, 0x875128f3, 0x025d3b7e,
	0xbe2d98bc, 0xa1e00f76, 0xb8636411, 0x0647643d, 0x28a85bc6, 0x8d685d1b,
	0x7071b6c5, 0xa4f90054, 0xc38f17b1, 0x97dd0ea3, 0x2c798016, 0x582ddb09,
	0xe495f88a, 0x3114c12f, 0xabea89a0, 0xf5a83d37, 0x73a72737, 0x47b6a2fb,
	0xa41f3d93, 0x19e0dd60, 0xb3fb8325, 0x2c4f8a41, 0x45fb8cd1, 0x2fc85a2f,
	0x7564e352, 0xe2cca29e, 0x79ae9177, 0x7ea8ba0f, 0x0d985ac2, 0xcc5b8af3,
	0x22fa9f22, 0xd79b77df, 0x85706ed2, 0x14a2f7c9, 0x771e0fae, 0xf9c58c97,
	0xcac15b6b, 0x7c6d3ca2, 0xcaf58ccf, 0x78b6d6da, 0xeef967b4, 0xb798ccf7,
	0x76175d0b, 0x8d19d8ce, 0x34df95f5, 0x2bf711cb, 0xfcf0a7a7, 0xd7a101fe,
	0xc50bef2b, 0x4343c547, 0x4772b9fa, 0xf7864067, 0xf35e8257, 0x244a6bf1,
	0x59fa0d3d, 0x9e3ccf13, 0x719feeae, 0xddc1ec69, 0xb22603c3, 0xf1da553f,
	0x71e54cf7, 0xed71e811, 0xd206ccf5, 0x9b60102f, 0x7a056f30, 0xa5371b5d,
	0x79ebd15c, 0x381e825f, 0x3fbc8eee, 0xd79d32bb, 0x467b8fd3, 0x071e1d11,
	0xfcbfa27c, 0x71fc3778, 0x6f0d5ebc, 0x840f21cf, 0x6e3f4fd1, 0xdfa73a61,
	0xede83d73, 0x67ee14ba, 0x0582916f, 0xeebd54a8, 0x19dfe268, 0x718b5996,
	0xac81f6ff, 0x5eb01acf, 0x895bf951, 0xcffdbda1, 0x6fb443b6, 0x7f63bccf,
	0xf4a7ee0a, 0x614fef36, 0x26d57fc0, 0xf3fa2565, 0xf44e1fc0, 0x025b6a7f,
	0x734d7f04, 0xaf5e1b61, 0xa89c9169, 0x2f3bbd92, 0xb275a18c, 0xffac06f6,
	0xae01e96d, 0x4f6e14a2, 0xcf0a295c, 0x9de07813, 0x4677f768, 0xf798fdf9,
	0x09fa01df, 0xb125dae1, 0x596fe826, 0xf7588963, 0x7be04fbd, 0xc5331adf,
	0x3cf0d559, 0xd640e3ae, 0xf905b301, 0x4bac0769, 0x991c75c2, 0x2ff38316,
	0x33f43133, 0x65cef854, 0xfae04f05, 0x810b99df, 0x3d5f5c0e, 0xbf7c2657,
	0x23e44cb3, 0x90dfbde7, 0x0d4d7181, 0x77bedfdf, 0xf9e5176e, 0x7ee2a9de,
	0x2679a8da, 0x96bbcb92, 0xcf457f70, 0x3edf2ad7, 0xcf54f829, 0xedbe7abf,
	0xd755afc6, 0x2195afc6, 0xbb47cd7e, 0x9d1ff40f, 0x3df47c8a, 0x9e51bb88,
	0xa535ef2e, 0x1bbddc02, 0xdfdc4e6c, 0x3ff64835, 0x637a8294, 0xb83fbf2f,
	0xf5c4b37a, 0xae37728f, 0xccd1a32f, 0x4fc84ad6, 0x09d54f5c, 0x53ac29ba,
	0x2ff8a18a, 0x54f51bd8, 0x841dfaae, 0x81df4d89, 0xd72339f9, 0x977e833f,
	0x186d79b6, 0xbd0b66ff, 0x81c5eaa3, 0x41d9e666, 0x5ee680f5, 0xe79e6193,
	0x939ebc4c, 0xd7ebe62d, 0x64cc73a7, 0xf78bd768, 0xb55a203f, 0x357483ff,
	0xec9bba9e, 0xc70b04fa, 0x81e5b8ff, 0x0fc75c0a, 0xea1f1ecc, 0xb7ecf2d5,
	0x35eed1ab, 0x8f257ef6, 0x49cc87f2, 0xaf1ab87e, 0x66711def, 0xaf5852d3,
	0xa268c6f5, 0x7af775af, 0xb5b3f21b, 0x4f5490df, 0x5b53fe04, 0xe65ca5ef,
	0x5d5f0071, 0xdaad43ea, 0xace7bc9f, 0xb725f699, 0xf243185e, 0xae9d2972,
	0x14adcfab, 0xfb120f70, 0x267cd53f, 0xf0e36de8, 0x097c3082, 0x8ddc303c,
	0x3cf08457, 0xba5af44d, 0x69e60d84, 0x8784f5f5, 0xa447d519, 0x9dcf3059,
	0x16299726, 0xc276fdf0, 0x0fb8c5f4, 0x8c1595e6, 0xbf70a279, 0x6e79859d,
	0x367f7dc0, 0xa45707ea, 0x158dff51, 0x8b7eb50a, 0x9814e9fb, 0xbabeda67,
	0x328fb47e, 0xe63709eb, 0x9b0e3ad6, 0x0b40cec4, 0x7d6a09f9, 0x6655aba8,
	0xb5dfb816, 0xa77aa253, 0x4bccff0a, 0xfa03cc19, 0x1f7c5de5, 0xfcb3583c,
	0xce7bd24d, 0x30630baa, 0x7d5c1a4e, 0xdefb01b2, 0x0635ffe5, 0x60138bfd,
	0xc0cf904f, 0x126967ef, 0x662393ea, 0x715767dc, 0x3cf341c9, 0x831ce867,
	0x497be772, 0x89d43aa2, 0x54e60b96, 0x8218af6e, 0xe7d609b2, 0x4fdff802,
	0x78fc2449, 0x381b075b, 0xbf70877d, 0xdb43f046, 0x23c45f4d, 0x95cb2c3d,
	0xe7c56fd7, 0xe50cca0f, 0x67496d7a, 0x1e822dbc, 0x5182be3e, 0x81d70572,
	0x74fefead, 0x139fafb3, 0x886e9b9e, 0xa4ea7fbc, 0x698073d0, 0x93fc5392,
	0x042adf80, 0x92c255bf, 0x0714ec12, 0x9e41a205, 0x9d475b2b, 0x275b6235,
	0xf1b4f7b1, 0xcc2f7b19, 0x0f89ef8f, 0x8b5b6abf, 0xf50bf5f3, 0x61648e31,
	0x91c6117e, 0x1f7ef34c, 0xf56533cf, 0x5844f54d, 0x683915e7, 0xe80eff07,
	0x938e0b55, 0x1f7e40e2, 0x5df9ed48, 0x3f282b0f, 0x27cee896, 0xfeb05ed0,
	0x6a3b8a06, 0xe87f5a7c, 0x87971a68, 0x6f1c69a3, 0xfc40a79f, 0x895d8034,
	0xba4e209f, 0x7109fc8c, 0x84163c52, 0xfd27e2c3, 0x2c9f8a75, 0x9f985728,
	0x1f3cfa06, 0x25693e89, 0xca326a52, 0x39f11357, 0xfe473e03, 0x3633afd2,
	0x85b3e455, 0x7285df5c, 0xc2dbfc8d, 0xef3f5ae5, 0xb1c56927, 0xdc1aef38,
	0x6f4115cf, 0xe7c697bc, 0x1128d9ab, 0x1d1bbcbe, 0x6c73a784, 0xf804bba3,
	0x81c01cf2, 0xdc3a02fb, 0xac4498ee, 0x31dc78d7, 0x1e90d8f6, 0x4318dda8,
	0x7be9adcf, 0xf4166387, 0xdf395373, 0x65196f9f, 0xdccf3c41, 0x7d4fe5c8,
	0x5dc089df, 0x22a7940e, 0x09d9a753, 0x4f5b33f7, 0x581fa3c6, 0x038a6bb4,
	0x3827b0e5, 0x6a3d0593, 0x7c5d2f96, 0x01f9c1da, 0x3d6a9bf3, 0x602abbce,
	0x5e2ffc46, 0xdb7f88ce, 0x5acffc5e, 0xadf3e394, 0x87b43631, 0xf8c776e7,
	0xbc77ff50, 0x4837e514, 0x12f88714, 0x339daf40, 0x7f244fb5, 0xc36c9773,
	0xd2fbd1f8, 0x3ca04fc7, 0x428c5f7a, 0x6e2d8fcf, 0xda02f87d, 0xb1d6eabd,
	0xb4f98d67, 0x2adffcef, 0xefcb350f, 0xfdaaf5a7, 0x1458578f, 0x8de7a3d4,
	0x6e2c4f5c, 0xdffc8179, 0xf2bb97c5, 0x6e7e1eb1, 0xa286dff7, 0xdcbef35e,
	0x99f51435, 0x435d0ff7, 0x77f7bef1, 0xfc917531, 0xf3a49f96, 0x2f6a903c,
	0x6a32df73, 0xb0b245f2, 0x4df5b90b, 0xb39fb865, 0x2754c8e8, 0xfbd573e6,
	0xb40cfd45, 0x68e8bf7f, 0xd85e63a9, 0x6341f573, 0x721f5e19, 0x6e6634a4,
	0x4a5e5f18, 0xa779a933, 0xe0f3ca6b, 0xb0d0e35d, 0xe0d04ebc, 0x35b8c2b2,
	0x4fdf2341, 0x31f9255b, 0x45ff00de, 0x53f91cff, 0xfe1d0b1d, 0xb827e4b5,
	0x821a0fc7, 0xb5ce7efd, 0xcb15aa0a, 0xfe61befe, 0x43415dd2, 0x68f80a20,
	0x80546b7a, 0xf1a0fdfc, 0x1f85f524, 0x99c2f335, 0x42295cb8, 0x1bc0669e,
	0xeb8f51a3, 0x17f035f3, 0xfeab7087, 0x3ce9dbd5, 0x6759947f, 0xcd3ee033,
	0x43667a8a, 0xebcb76bc, 0xf29dbf4c, 0x8efcfa45, 0xc160dc12, 0x06be94e7,
	0xfaabc21b, 0x9dc748a5, 0x9c40f411, 0xbe551f90, 0xa20683ea, 0xc4b07d4f,
	0xb35a17d2, 0x6d3b03d0, 0xa3befa06, 0x56ca75be, 0x5fd42fcc, 0x106633be,
	0xadfea7bc, 0xdf7e183b, 0xb12b61d1, 0x2ee7c3f4, 0x96996edf, 0xfd1be217,
	0x72a68efb, 0x17f219bd, 0x03bfdb22, 0xbbfd9f42, 0xd49ee0ec, 0x107619ff,
	0xa943f3e2, 0xc19f3e3c, 0x3e3c27f3, 0x550fdbd7, 0x7ef3ab2f, 0x5dddf021,
	0x3f259f2f, 0xd268e207, 0x2aa45fcb, 0x75b32e34, 0xebe283b2, 0x943aa6b7,
	0xf7f3eed8, 0xf60d3a31, 0xabf3eebc, 0xe7d79cfe, 0xb8c16fda, 0x91f7c5c7,
	0xb44aa779, 0xfff556ef, 0xfc896ebc, 0xc9856f72, 0xb854e38f, 0x3e795382,
	0xe4cb9a76, 0x3f214ab7, 0xaf23f551, 0x744a77dc, 0x552bf55f, 0xe6e831ff,
	0x43a9ddf9, 0xc5bf7df8, 0x75f10173, 0xeba56022, 0x75f82345, 0x31fbdcc6,
	0x3bf3baae, 0x203d2312, 0x4f954afc, 0xc5e77ef5, 0xff093ed6, 0x49b50f2c,
	0x672aa7f0, 0x50f93ad9, 0xc0ae58ed, 0xf1da2d53, 0x9fe3b442, 0xfd73fc6b,
	0x4dc760bc, 0x53a7a869, 0xe43f3d19, 0x291dd1a8, 0x2a71ff5e, 0x4d393f9f,
	0xb83336a1, 0xcde118af, 0x07da4162, 0xb57d93db, 0x4f4fbc88, 0xf95373f7,
	0xb3c9abfd, 0xdfefac4b, 0xd323cf25, 0xfee1d4ae, 0x2be796af, 0xdf0f61fe,
	0x2b4c9ddf, 0x8ff48d1e, 0xc582eb96, 0x327f7f28, 0x275bac45, 0x91a7f1a9,
	0x3fb3e869, 0xf8c06ccb, 0xf3c55bc8, 0xca898d07, 0x1cc714eb, 0xf67f6992,
	0xd1078862, 0x29745b8f, 0xf46ada91, 0xf19da197, 0x47aa11cc, 0xc2d2a8cc,
	0x5d3948df, 0xae497e78, 0x4ae7fd1f, 0xa6794a56, 0x1b44d6ca, 0x4c6e77ee,
	0x72803e6e, 0x2b2adbe5, 0x2fc7c35b, 0x785bc754, 0xba796e1e, 0xa0e39c5f,
	0xeb2a07f1, 0xd6bf7ef4, 0xe455b83f, 0x13f27a8d, 0xe566d0fe, 0x4ca0e57a,
	0xf98b5e72, 0xcec19ba6, 0xe0bd72b5, 0x24f3ce5d, 0xe92badb5, 0x711aabfb,
	0x906343ff, 0x5f5450f2, 0x5b67a183, 0x3ca0a7d7, 0x9eb69732, 0x51f4f354,
	0xbafa97d2, 0xd7277d92, 0x596ade4b, 0x4a8691d4, 0x7881afd8, 0x4bfd1532,
	0x78849945, 0xfb34b807, 0x60bf54ca, 0x5d2ba88b, 0xe28a783c, 0x7abb19d0,
	0x8e3523a8, 0xb12475e3, 0x1d7ba37f, 0x0cfec0e9, 0xa475eae5, 0x262396da,
	0x56ae2f8c, 0x4d227a4f, 0x31cc779b, 0x4e6efcf2, 0x7cc364ab, 0x5f2b4e55,
	0xd135b0f7, 0xf98f5fe4, 0xea075ccb, 0xe74e9503, 0x9efc7327, 0x62d3e77f,
	0x17f03ada, 0xeb0acda3, 0xcb3bc3fa, 0x7de0ccde, 0x73e0a2c5, 0x3be862cb,
	0x1bdcbfe9, 0x03fdf883, 0xdf9f48b4, 0xce46371d, 0xd5f2864f, 0xbca34abf,
	0x1b57c8b3, 0x85c61ec1, 0xe7fa3af2, 0x1ae78b86, 0xbca15c21, 0xf75e2ee6,
	0x8cf74c6f, 0x7a4ffea3, 0x27e4adb3, 0xfd1f28ba, 0xe635f002, 0x62c2068d,
	0xebfd2eb1, 0x758f5668, 0xcf64c6a4, 0x3f47242b, 0x47282831, 0x9fd53cf0,
	0xb2143b7c, 0xac32888f, 0x019be4f3, 0xc0efda16, 0x24dc4df7, 0xf10e98e8,
	0x0099d62c, 0x8758a99a, 0x3dea281e, 0x88ccd1f9, 0xf2623ff3, 0xeb11bdac,
	0xe7466d4b, 0xa702124a, 0xf75c7263, 0xe2e493ba, 0xfeb572f5, 0x7bcdd6a4,
	0xf8493faa, 0x7fce7c9e, 0xfb126f54, 0x133ad4e7, 0x8a9b8efb, 0xd787ab5f,
	0x6f5f8c31, 0x6f5f64ce, 0xfaf7701f, 0x0798a7cf, 0x247fd7d3, 0xcfa46fb4,
	0xb5c6f5b5, 0x3e279e03, 0x8ceb57fd, 0x9d7634ae, 0x8f0a62eb, 0x0f707597,
	0x4298bc49, 0xffdfd771, 0x6cec9e3b, 0xc3d9176b, 0x1628ce8e, 0x3b63fca4,
	0xf2b7bbcf, 0x203a81ef, 0xb30e4b7e, 0x395333b3, 0x8eb4f7de, 0x19dffe22,
	0xf1c18d2c, 0x5b0fc28d, 0x29d4d6f3, 0x82fbefe8, 0xc3afda46, 0x76c78f18,
	0xe8458d06, 0xba475cb7, 0xa045a624, 0xdb9a258b, 0x1d1cbd27, 0x40f7f610,
	0x518fe71a, 0xcc38f0ef, 0x57d78cbb, 0x782f426c, 0xfd5d78eb, 0xa48a5640,
	0x2353d3e6, 0x75765fd5, 0x5ca8dd92, 0xdabed128, 0x797f5aaf, 0x3d723d2c,
	0xc9cb467e, 0xb297f5c8, 0x7b3fa431, 0xf3eb67ca, 0xc5d343d8, 0x3c41b4fe,
	0x9a4cfd8f, 0xaf6bd68d, 0x2c8c5c1b, 0x3affaeab, 0xf4fde1d2, 0x8eb87408,
	0x7c6547f3, 0x37ddf5b3, 0x71fae1be, 0x71fd244c, 0xff4fe71d, 0x911fe786,
	0x67e2cdf2, 0xff0c37fd, 0xfcf0df03, 0xf308d4ee, 0x3fbabfff, 0xd7ff5f40,
	0xefd017ef, 0x343a8803, 0x1ef787cf, 0x0675d696, 0xbfc4b5a0, 0x3d025d38,
	0xda7c4c68, 0x7cb47682, 0xad87af04, 0x37f8b529, 0x037da14b, 0xcf3ebe2a,
	0x2da9f1e0, 0x01cf82ef, 0x0576ce78, 0x2f981d4b, 0x0e28c11b, 0xbaf2b0ee,
	0xd2da3318, 0x7c3ed327, 0xe01dfa5b, 0xf0f63497, 0xc42fd33d, 0x91d93d7c,
	0x93e2cca2, 0xba6cefa8, 0x3b6ad2fd, 0xb635c442, 0x970fbe16, 0x3bf49519,
	0x3a4abde8, 0xfb0943fa, 0x00f8f5f8, 0xb8266d73, 0x283bdc94, 0x1172541e,
	0xfd44c7be, 0x7fae3ed7, 0xeda5e62e, 0x5d6217e0, 0x07d63d70, 0xd1b59e29,
	0x4b7df538, 0x1f78717b, 0xeb093133, 0xf91bbeb9, 0xb9d6273e, 0x5a8bec80,
	0x0a6c3bd7, 0x51259e9c, 0x3a72ef5d, 0x10d57f8c, 0x2b92dbc8, 0x9bf01898,
	0xf546d3b7, 0xfc46d7c6, 0xbbfc01ef, 0x5be75e26, 0xf643e36a, 0x700cdc62,
	0x485ddd2c, 0xcf633bfc, 0x18156388, 0xe7e5f47f, 0x2b8b7483, 0xb8e0be45,
	0xf9a877c8, 0xf5beb502, 0x39279167, 0x6817f981, 0x021f31db, 0xc32f7a6d,
	0x941fdef5, 0x7c822bde, 0xfcf1263e, 0x9e55ef90, 0x3b342a1f, 0xa7ef84fb,
	0x3af02fec, 0x17ebc02b, 0x9b67be6a, 0xf7e14f58, 0xf81440e4, 0x830d85a5,
	0x0be768cc, 0xb1a2b21b, 0x0df977cd, 0x6bbdea58, 0x4a830eee, 0xe47c48bf,
	0x4bf625ec, 0xfaa4ec1e, 0xbaba0bde, 0x7c5ed2ff, 0x1927c33f, 0xf6969f9c,
	0x67edbc62, 0x63ee8d5c, 0x1c9b48c2, 0x0954aea9, 0x39c23171, 0xadc391ab,
	0xa032bbe2, 0x9cf7c28c, 0x80d9dfdc, 0xee55416d, 0x57bbca28, 0xff40685f,
	0xebb97bcd, 0x5f29b7c0, 0x9e305666, 0xcdaed998, 0xca64c5bb, 0x2417fef4,
	0x6fa6bdfe, 0xe3e291ac, 0xe246b1c2, 0x95a57b1f, 0x89bb57e2, 0x9fd8b1c9,
	0x82a2fdcc, 0xd851a4b2, 0xc9135367, 0xa8382c1f, 0x0bcbce24, 0x63ecc1e5,
	0x9e232597, 0x556756ae, 0x8b7e69f3, 0xf3d2326b, 0xd6b3ad5f, 0xf68b7e1c,
	0x52ebaa9b, 0x4bd6a2f1, 0xaab3aa7b, 0x65bc1efb, 0x69f66a9f, 0x639d8d78,
	0xb858ff30, 0xec59a4fb, 0xe5a5b4bf, 0x85b0ea86, 0xfd502ebb, 0x7ab7ad55,
	0x5f902eeb, 0xb9d1cf0d, 0xf0573b24, 0x008bebfa, 0xb02db607, 0xf3c0176e,
	0xb637587b, 0xbc6eb0ad, 0x018ad2fe, 0x385606d4, 0x62b3dda9, 0xc085b538,
	0xac76e93e, 0xbaa05edb, 0xda5ef2ed, 0xd75a9fba, 0xbfbb26db, 0x53592bdf,
	0xbebea3f7, 0xf34727ee, 0xa0f78d7c, 0xf063be89, 0xfe90b61e, 0x959d6e2e,
	0x67c1f183, 0x08393c47, 0xddd62d77, 0xbce2f8c2, 0xc44d69cb, 0xb4edd838,
	0xb0adbd62, 0xf719aced, 0x831ad4c3, 0x0187cc66, 0x65b819e4, 0x02f3bbd1,
	0x5adbf7df, 0x5efc456c, 0xf2d63eb5, 0xff63ebff, 0x352c7d4a, 0x54c7d793,
	0x36e0523d, 0x7b6336b8, 0x179d65d0, 0xb8d627a6, 0x4d653d79, 0x8724dedf,
	0x13bddc1b, 0x57cd86e7, 0x17f3c65f, 0xad7db1f6, 0x6517d7e1, 0x1d987af2,
	0xf08a0dcf, 0xd7f5e0fe, 0x7a48c1db, 0x16abfcfb, 0x6da49efa, 0xf69c82d7,
	0xe1f82e3c, 0x6535b8f9, 0xfbf07373, 0x28f1df7c, 0xebe78fd6, 0xa638f934,
	0x94f5cbab, 0x66519b97, 0xbf695970, 0xda366750, 0x8cfe7d6d, 0xb9b33b19,
	0xf065775d, 0x197c1cf3, 0x56eb386c, 0xf9977b9f, 0xf185f68f, 0xc8199577,
	0xba75a85e, 0x5b233282, 0xb059fc01, 0xfaa7e4dc, 0x24f1995c, 0x637117dd,
	0x0320adbd, 0x61c4fcf9, 0x6af30db3, 0xb398fcfa, 0xdec6e9ec, 0x5ab3bcf0,
	0xaeb2e272, 0xf753c756, 0xb4b65781, 0xdb7cc68d, 0x58d4d660, 0xee0fcf0a,
	0xfee1b06b, 0x3cf5eee9, 0x40bbffbe, 0x3cfa39f8, 0xfa19f21b, 0x7c3cfa25,
	0x6bb70654, 0x8d6ec251, 0x8516da46, 0xd39f51e6, 0xf0854ff3, 0xebca7abb,
	0xeaf98b97, 0xf4d60acb, 0x1b96fa45, 0xfa93da18, 0xdf4b12b2, 0x657af9b0,
	0x63dc6918, 0x0a4c1f58, 0x3af20faf, 0xa82ebea0, 0xb6c2b9ea, 0xbe20c7cf,
	0x46be8037, 0xe34de63b, 0x97c283f5, 0xdea20f8a, 0xf9c9c108, 0x95da437c,
	0x1913b1ef, 0xfdc3175f, 0x12ddbe73, 0xca0ae7e5, 0x0313dd3f, 0xbb06e67d,
	0x70ed7a87, 0xa8b1d5df, 0x458dca8f, 0xd78f5df8, 0x33a95d2d, 0xca693d61,
	0xf0e355eb, 0x69c2833b, 0x5d208f83, 0x689855a6, 0xf76aa07f, 0x7d3ebca6,
	0x79bfbf0c, 0x1fde3455, 0x0aad3920, 0xc12b2f5e, 0x07b7e3eb, 0x26ce9330,
	0xcfa07420, 0x1b4f8783, 0x16fc6e51, 0x3f182dcf, 0x75164e17, 0xa76e0aa6,
	0x364eb5a7, 0xb4f3f231, 0xd66f7376, 0xea0f9467, 0xfaa42d6a, 0x3ff70391,
	0x4dec85e4, 0x63b06ee1, 0x8ecfd771, 0x08d86455, 0x1d83379f, 0x93ec7843,
	0x4f5e9d79, 0xfe825eff, 0x9ea5d93d, 0x1fda30f4, 0xe505673c, 0x6eeb4a53,
	0xfbcc15c7, 0x5d7f430c, 0x7a5843c2, 0x4235bfe4, 0xe0f625bf, 0xf040fdcf,
	0xa7fb8f6f, 0x753dfe5a, 0xff1935a6, 0x6ac6ea33, 0x9bd6a5fc, 0x03ed78d4,
	0x7b6a07c1, 0x6bfde046, 0xc680df7f, 0x0df7e235, 0x37dfc8f6, 0x73a66ccc,
	0x1befd44a, 0xf1599bf6, 0x4fdc248e, 0xf277be2b, 0x693f264f, 0x36ef93ff,
	0xdf849b3c, 0xb278493b, 0x23c3d806, 0xf3d5e764, 0x3f5b6ae9, 0x66d6f9e6,
	0xa6bc3fbe, 0x2fb9f225, 0x5dff847d, 0x37a462ea, 0xdb7ec46a, 0x9d453b31,
	0xf2de4ae8, 0xde78637e, 0x9304abd2, 0x7ebc7dd5, 0x79b4f78a, 0x96f29ecc,
	0xf9f7eab5, 0xed139255, 0xe1f6d5c3, 0xbafd8936, 0x5d31e63d, 0xae5f7cff,
	0x7af98f3e, 0xf38eb686, 0xad1b7497, 0xa247ba7f, 0x062c9b73, 0xdbed3577,
	0x45b2497f, 0xbefde7da, 0xa2f18390, 0x334bf20e, 0xde5f8fe7, 0x37f7d122,
	0xd21e1df8, 0xf12f97fd, 0x597e70ef, 0x51c3bfc0, 0xf7ea1eeb, 0xea863735,
	0x9dfdf41e, 0xfa8e5dfa, 0x5dfa8d9d, 0xd18de4e7, 0x23f14e74, 0xee34e6a6,
	0x2f88faf7, 0xe8c1947f, 0xab14747e, 0x47af248b, 0x947f8a32, 0xaee38451,
	0x2974ffbb, 0x66f4de52, 0x23fe4711, 0x4178c7a3, 0xc4d22cca, 0xc7d7d40b,
	0xeeabd70b, 0xcfc0a8f1, 0x2bb75c75, 0x1d78df92, 0xebd9dfe7, 0x3687cd9b,
	0x6adba247, 0x16f3e46b, 0xed54cbef, 0x707cf68e, 0x497bedd6, 0x251bd76e,
	0x54add8e5, 0x3d51374f, 0x8dabd55d, 0xd2fe7c71, 0xd557ae4c, 0x36d11ef6,
	0xcbe7229a, 0x3ffb8916, 0x90a35d93, 0xa33e064f, 0x6a0e5fcd, 0x6f2fe6d6,
	0x239ed16e, 0x3da03832, 0xa0f0a427, 0xa298fcf6, 0x98fcf6a0, 0xe7b5c761,
	0xd7688cc7, 0xeb731f9e, 0x63f3da87, 0xe6d4eb6e, 0xe97dbf2f, 0x9c77dd0e,
	0x340e7e7e, 0x73f86e70, 0x74732ca3, 0x7418d6e7, 0xeb44d6e7, 0x9dd1adce,
	0xcde6228f, 0x9dd2f5f5, 0x9f5da35f, 0x7971eb1d, 0x0b8f5ed7, 0x3d4452f4,
	0x9f158fae, 0xafacac7b, 0xf536fd15, 0x0abfea7b, 0xe99e3b3e, 0xf8132079,
	0x6c6ab3c4, 0xfb55f22d, 0xcc6ca8ca, 0xa55678bb, 0x0fc049cb, 0xfa25479e,
	0x5564be9e, 0x99efed3a, 0xfc983f53, 0x22e602a4, 0xc1d2a93f, 0xb0f39e22,
	0xadeb9325, 0x662675d9, 0x2997c04e, 0xf15f3c66, 0xd6c4a35c, 0x3b137b72,
	0x8ab0f801, 0x59ac3e71, 0xea9e2473, 0x2ceec2de, 0x5560a8e4, 0x3ce80b75,
	0x2f79fd07, 0x9cd9acd5, 0x5a2cf30e, 0xa0f246d7, 0xb545ff3f, 0x4f315e43,
	0xbef6b34d, 0x40bbad97, 0x76b3c7e7, 0xde43fa33, 0x4dfded16, 0xe65ea299,
	0x1b944e64, 0x1671fdcf, 0x044b2ff4, 0x93ad665e, 0x9c1f586c, 0x7c96df53,
	0x1ce7f427, 0x52de2994, 0x9dbac2f1, 0xe74793cf, 0xd83c5fa7, 0x8be7fc8f,
	0xe38a928a, 0x5e3cf13c, 0x619e8c90, 0xe1d2bd78, 0x9be78619, 0x8713be75,
	0x93b0fcdf, 0x17f26497, 0x27ca07c0, 0xf2c6cdbf, 0xb3bcf3c3, 0xcc14b64c,
	0xbdd8f8b3, 0x8a671469, 0xb75d57b8, 0x6c7102d7, 0x4e21f63c, 0xbe93ebe5,
	0x646e8894, 0x2fc13ad2, 0xff80f7c2, 0x85ac7143, 0xffa25659, 0x4a695673,
	0xfdd7d741, 0x8afc8990, 0xc913dbd9, 0x3f5d98af, 0x22e78cca, 0x4899decc,
	0xcf9968fb, 0xb5c616f5, 0xd64f1d2a, 0x83481e17, 0xe7376779, 0xfd2d653a,
	0xa2e27134, 0xdd2a93c6, 0x6e855f4e, 0x0dd123a7, 0xfeb9a5e8, 0xec5e8e86,
	0xd77d0741, 0x7f64b157, 0x5df7cc3f, 0xefd2b3ac, 0x038f7453, 0xce4f5c7c,
	0xef1345bd, 0x12baf594, 0xddf9d1c7, 0x888aeb5d, 0x957a7a6e, 0x30ce63fd,
	0xbd8adefc, 0xdfd0c71b, 0xeec3eca8, 0x62e303b9, 0xe557cb89, 0xe865b1ea,
	0xf42c7cdf, 0x2e22ebe1, 0x1171823a, 0x626ff1f8, 0xa3fd045c, 0x863a2e22,
	0xefb41171, 0xed045c60, 0xa03e7169, 0x00c0672a, 0x8417afc4, 0xa2b85d7c,
	0x61a597e7, 0x1fecad3e, 0x8019166f, 0xdf7d92e7, 0x8b3a389b, 0xad2e49b1,
	0xaa7d3d3f, 0x376e9fd6, 0xa1a4c6d9, 0xebc35fde, 0xb7ddb303, 0xa333c66a,
	0x073cc662, 0xba18501b, 0x3147f64e, 0xaee39e63, 0xfc668772, 0x34331a77,
	0xc2966b7d, 0xeb2ccbbf, 0x777eb9a3, 0x7f4d40c5, 0xc47025d6, 0x167f15e0,
	0x65312bdf, 0x32cfc938, 0x36312f11, 0xc6c7d39c, 0xe8d4f99f, 0xf2f913bc,
	0x12c9c3d3, 0xba7a6dfa, 0xbb9df4a8, 0xee3ca651, 0xf3128d9c, 0x9ba7a801,
	0x7d7c90e6, 0xce8e3c7c, 0x5ed8698f, 0xe870daf8, 0xa26edc9f, 0xeb27657d,
	0x39e28f1d, 0x27b727d6, 0x7af7e3c7, 0x0599069e, 0x48dadf48, 0x8ef3aadf,
	0xbf495faa, 0x1fcb308f, 0x303d44e5, 0xe7ef9f6b, 0x6dfd1f6a, 0x72832ada,
	0x0fec96f2, 0x17474448, 0x959b79e1, 0x9a1fe3f2, 0x327f0f98, 0x873b4e69,
	0xd58943eb, 0xf5acff63, 0x0bbffdcf, 0xd09b9c70, 0xfe80df34, 0x99387c94,
	0x32f3e6f4, 0x58adfe43, 0x51dfa262, 0xde547859, 0x15267d8c, 0xcbba7064,
	0x6c1e3bf4, 0xcfcd145b, 0x6053813a, 0xa367b2dc, 0xf915acb6, 0x76ffea2e,
	0xe0ad7f90, 0x0fa7e453, 0x912b9913, 0x8779e580, 0x53248e8f, 0x4f8427bd,
	0xfbae3e7f, 0x5bfba329, 0x1fbfc059, 0x93e7f7cd, 0x99307b7e, 0xf78f4be4,
	0xbfae66d3, 0x520f287c, 0xe4866f48, 0x35777f8d, 0x714ce4c7, 0x921ade92,
	0xf4eb7a8e, 0x17e5133a, 0xcf15d199, 0x13cf71eb, 0x39efab3f, 0x20c6546d,
	0x731ba77c, 0xd9c2fbe9, 0x7bb264eb, 0xbc7c87c8, 0xebb7c79f, 0xedc60f65,
	0x83c946be, 0x6f9ebb71, 0x6a5afe54, 0xdea2a672, 0x19b8899c, 0x9c2f5dd1,
	0x8875e74f, 0x6eccfe2b, 0x1b3ffe7e, 0x3a9c6ed2, 0xf53d7c28, 0xe19ebdfc,
	0xabc9739a, 0x04f1ff7b, 0xf174e11e, 0xfc049f60, 0x5bece74e, 0xd9dbf132,
	0xd3434dde, 0x189fae80, 0x2efd0cf6, 0xe09e3ff4, 0xfd08c0fb, 0x754f568b,
	0x86f9fa16, 0xddf8d975, 0xa9eb4774, 0xe7856f47, 0xe4ce7a3e, 0x9e5fb124,
	0xd164fa4c, 0xff3985b6, 0xb421bbec, 0xe8ef3cfc, 0xaf00974a, 0x31e6958b,
	0xc7984f98, 0x712ec2dc, 0x79db293c, 0x81b6c35e, 0x154e39e7, 0x38c5adc5,
	0x8f2e8e6d, 0x6be04a71, 0xf1a49645, 0xfe89f61b, 0x73e7031c, 0xdf38b788,
	0x07b1a631, 0x4077f18b, 0x56de90e4, 0xd83541ed, 0xd6178c5d, 0xe7e6f567,
	0x14a6b307, 0x4f08b71c, 0xf3eb86a8, 0xad7e3c6d, 0x4fca267e, 0x9602a9f1,
	0x782fcc2f, 0x4595e843, 0x409ee7e6, 0x82c05df6, 0x71ba7d7c, 0xf3fc991f,
	0xedddb983, 0xe6db7ccf, 0x6fcd3b7a, 0xc63ee272, 0x6b5e4205, 0x807f249a,
	0x8ec93fd7, 0xccf313ce, 0x6f547613, 0x27d9baaf, 0xa79a5d9d, 0x49acbbb3,
	0x5e01676b, 0x855bcf3a, 0x3ba70f57, 0xb0f08e26, 0xf7ef89a8, 0x1ff1ef9c,
	0x4b704898, 0x3764a04e, 0x77301678, 0xe3ae2269, 0xeb9f1e19, 0xabafd3e1,
	0x9d62bc1b, 0x3be7b87a, 0xe577d02f, 0xc225dbd5, 0x2a1d7e97, 0x9bfef43d,
	0x3ef9974a, 0xadf9df8e, 0xfdf3d112, 0xa3217e2b, 0xbf2aa17d, 0x9ff866b0,
	0x44f779e6, 0x360b6bd4, 0x0dce1e80, 0xf32d4ff1, 0xcc7c9f13, 0x07e80d02,
	0xf14de57a, 0x1f8b6f28, 0xba40f37f, 0xa07c3182, 0x5111219f, 0x65a3d1f7,
	0x59f885b7, 0xd1abdf8f, 0xc5f15af3, 0x9e813d44, 0x7bccfc03, 0x7cefa65a,
	0x3889c6c2, 0xab7847d8, 0x58ccf9f2, 0xf232ae67, 0x06aee3f3, 0x7fc8d7a7,
	0xf0aae96f, 0x7d2fe0f6, 0x45b3b86d, 0xbf9ba61e, 0x92212fd5, 0x79d7527e,
	0x27bdf6ad, 0xd85f3d3d, 0xe76879f5, 0xe360fda1, 0xe32e740b, 0xa05e1bfb,
	0xcfcd5873, 0x09fda3cd, 0xf39c6c1f, 0xc4aefe28, 0x90e7db07, 0xa4f05f5d,
	0xe63dd76a, 0xd4617f70, 0xfd4f59c6, 0x67d3e42f, 0x9e3f54ac, 0xe223cfbf,
	0x309fd01d, 0xf5c8d94e, 0xf5c0db25, 0x7fb402e7, 0x6eff6479, 0xcff771c0,
	0xfc80dcf7, 0xec9d761e, 0x3c73fde2, 0xf30dd9bf, 0x18abffde, 0x6c968fa7,
	0xb3fcf00b, 0xaff6802d, 0x2763dee6, 0xe4a377e8, 0xa7bf47c3, 0x8ee87bda,
	0xb3f27a36, 0x3b08bed1, 0xce6f235f, 0x205fa1b6, 0x1bbfc1ec, 0xdf11b3df,
	0x7c714fe4, 0xf1c8d7bf, 0xc71d6a7c, 0x3ef6c37b, 0xd7bea714, 0xa8fc87d8,
	0x23f7b6f7, 0x0b5dcf7c, 0x5a7f26f8, 0x8d51fad1, 0x178c6f80, 0xd700df10,
	0xc08a7dec, 0xbbe393b7, 0xad99e391, 0x6edcede3, 0x39d1f578, 0x22fff7eb,
	0xc17e89ca, 0xf900d687, 0x90ee1f4b, 0xd5344ce9, 0x9cfd52cf, 0x3f4d62ff,
	0xc54c7f47, 0xc1fec2f7, 0x152bd47c, 0x8f18ffeb, 0x83b85f78, 0xe1ba4927,
	0xd152b99b, 0xffbd0eef, 0x2b345f8a, 0xfa2fdc3b, 0x65a9748a, 0x5c97da6e,
	0xe595e78b, 0x567fed87, 0xbf4cd77f, 0x79e159df, 0xb4e628c9, 0x4c9e1058,
	0x79b3effd, 0xfe7fee18, 0x9985dfac, 0x771c92f7, 0xfdff0ff6, 0x602c89b1,
	0x580b73c2, 0x5afb44b3, 0x892d966a, 0x3e78662f, 0xb1c11d69, 0xf3db9b39,
	0x36676b0e, 0xa3bb65f9, 0x6f4bde38, 0x9f45c4d5, 0x188dda98, 0xcce2f94f,
	0x9771ddf4, 0x7e8099d1, 0x7907c4d4, 0xf0e26f1d, 0xc3f369c1, 0x12ef3be8,
	0xfe78c73f, 0x1cb98925, 0x63803bf8, 0xbcc41f69, 0xf754c9a6, 0xa8ed0f9f,
	0x7c3df1f0, 0x9b39b78f, 0xe04f6de7, 0xfcf00ada, 0x773bf126, 0xaa34fce2,
	0x4e8e02db, 0xbe74dd58, 0x0b6489de, 0xa4cd7dff, 0xdda3ca04, 0x8ce1f42d,
	0x6fb403d8, 0x31f1e61c, 0xff739e3b, 0xad0509a6, 0x1cfed2c2, 0xa4f7c486,
	0x62cfba9d, 0xf5feadc0, 0xdddf9136, 0x3ba3a5f9, 0x6a7a213c, 0x46f37dcf,
	0x6c87ce47, 0x9a71e6cb, 0xdd5172e4, 0x8ee60a21, 0x973ff786, 0xd4bad0ad,
	0x136ceefd, 0xfbae35d0, 0x75ea71f9, 0xc6e7e3e6, 0xbfc09756, 0xa19c616f,
	0x06c87f50, 0xccdabf4d, 0xbecbefef, 0x4c86d27b, 0xb00ccfb0, 0x52fd07de,
	0x59fee3c6, 0xe7dc7e09, 0x97cf0935, 0x246b63b2, 0xc8c3bafe, 0x36de067c,
	0x43fd62c6, 0x51352b9c, 0x70da6fe0, 0x19004816, 0x9ed21c08, 0xc06778af,
	0xf001b810, 0xafcf093a, 0xea73c7cb, 0xde0d9314, 0x0a932ee3, 0x5ea94e30,
	0x3de0d5f5, 0xd26f3d96, 0x37d09186, 0xdf9c3818, 0x1989f9e3, 0x3c07af98,
	0x7db234cc, 0x37a70172, 0x576bc5e2, 0xe747df68, 0xa7f68912, 0x957a79a8,
	0x794383de, 0x0ce3a27a, 0xd3cc1f01, 0x9bcf8f18, 0x94ebd323, 0xc5fc0790,
	0x62fbc414, 0x558ba721, 0x95aedcf9, 0xd047394f, 0xc061fd11, 0xc2d10cdb,
	0x6afe693a, 0x9cf51ef1, 0xe6239675, 0x7d7ce1cf, 0xe38d5b3e, 0x58fbdabf,
	0x51cf3f2c, 0x289ad395, 0xfefabf3e, 0x47fda249, 0x679f9db6, 0xfcfafa21,
	0xab4d99fc, 0xaace3ce9, 0x1f3f317f, 0x0ea877a6, 0xe73b9926, 0x6fa5ea22,
	0x66ee4959, 0xd5fb9b98, 0xa71f76c5, 0xc1584f9e, 0x2f5e2682, 0x61327910,
	0xb1cb4697, 0x8565de74, 0xb3877fc4, 0x67ce38a3, 0x8dfcc048, 0x015b4889,
	0xed1f80fc, 0xf7cad9fe, 0xdc26567b, 0xc1fd113f, 0x91b3788a, 0xc163e3ce,
	0x90dcdcb8, 0x96286dfe, 0xe6433ce9, 0xd6127c7b, 0x3d6356d1, 0xe87ff790,
	0x936ca4ca, 0x3af93fe8, 0x97a9a3ea, 0xffd4fe81, 0xcc1724e9, 0xdc5fb1df,
	0xe1269b67, 0x04878efd, 0x34fcfb1f, 0xeae3c75f, 0xfefcadfd, 0xb3fef51a,
	0xd40ffefc, 0xbd7f45f9, 0xdd4afeee, 0xbef09ffd, 0x2767a9f3, 0x254f10f9,
	0x6e2ba59c, 0x3877e891, 0x00bea096, 0x0aac567a, 0x0c2b7e10, 0xc25b787b,
	0x5f218602, 0x7b8e5c61, 0xfe327649, 0x38e9e9de, 0x728bd7b4, 0x929fd45d,
	0x0735b9e5, 0x64d170f8, 0x388667c9, 0x27e5bd90, 0x07b131fb, 0x9b24bc7d,
	0x28669fe7, 0x08515f30, 0x694f30df, 0x3ebff24e, 0x6e9cd9cf, 0x96b84cf3,
	0x87757679, 0x32d73be7, 0x76ae764f, 0x7a1fd51e, 0x096bb7b9, 0x8bb7a7ce,
	0xdaa59faa, 0xc1ffc5c3, 0xabc5e8e3, 0xb10bb39a, 0xecaef5fd, 0xffb879f9,
	0xe83b2655, 0xe3f0f615, 0xbef877b6, 0xe66d9db8, 0x1fb87931, 0xa1ec8dae,
	0xf75447ea, 0x39fde700, 0xd62fa106, 0xafe0faf3, 0x9e911acf, 0x1fcd0d8b,
	0xfe76893c, 0xf7e22916, 0x73c53395, 0x7df87a27, 0xb87307a4, 0xd7d2da1e,
	0x675c7df5, 0xdfe30e65, 0x7c8eacc5, 0xa17ef39e, 0xdd842abf, 0xce34339b,
	0x8b9e00a2, 0xc6acf2de, 0x37f356fd, 0x9e6016e5, 0xc9567978, 0x3d5fc843,
	0x793b59e7, 0xe795b59e, 0xc1ec2b59, 0x59bca065, 0x0fd0e720, 0x8dbf102d,
	0x672ab1ff, 0x6cf0b220, 0x6fda9459, 0x923a549f, 0xffb0bfe7, 0xf9dea78b,
	0x3f9e0fa1, 0x3e60f088, 0x68a0d87d, 0xb9ed0bd4, 0xc81b0631, 0xb399fdf3,
	0xe5470802, 0xdf68dbb0, 0x5c54714c, 0xa7a459ff, 0xfdc5f118, 0xe29fee99,
	0xf98f1c7d, 0x90398f10, 0xc3ac277c, 0xfb4c8af3, 0x31f93d56, 0xf875489e,
	0x043c089f, 0x1ed46c72, 0x059c0034, 0xf7d43821, 0x2cbfbf83, 0x5e9df308,
	0xbf183e95, 0x599e3a7b, 0x93f132fc, 0x4cf1ff78, 0xf7f0f6cf, 0xfeb0369f,
	0x557c7218, 0x70159e38, 0xe6e82cbc, 0x16fc091e, 0x51ddf716, 0x4fe9a31a,
	0x5730772d, 0x6a76fe78, 0xbd3fa686, 0xfc668fa2, 0x6a0773dd, 0x0a884fee,
	0xe30ba90e, 0x24fd9ed7, 0x25f73f1f, 0xf71a2e2e, 0xf5a5fde9, 0xdfc6debf,
	0x5a78ee95, 0xbb6fa276, 0xb7d6f770, 0x8be108f1, 0xe5075f40, 0x9bca1523,
	0x6650747d, 0x970bbcfc, 0x745ebc31, 0x189f058e, 0x1f5cf529, 0x47db6c5a,
	0xbd7013bf, 0xcd7f42eb, 0x016f7111, 0x783b402b, 0xe528eeb1, 0xf9636aeb,
	0xe2edceba, 0xf9e2d7e7, 0x9f025fd5, 0xa20f8edf, 0x1409785f, 0xa8fbc83d,
	0x47549396, 0xfd70e5f3, 0xc4b99b5c, 0x17b0fe88, 0x63ffd45a, 0x00254f40,
	0xd8db049f, 0x67e89da0, 0x7f71c6e7, 0xca14d2fd, 0xe68c1f8f, 0x29839df9,
	0xc63bf489, 0xd2c71b8b, 0x314bdaf5, 0x72ebff34, 0xf9abf690, 0x3d51277e,
	0xe5464262, 0x71b7dc2a, 0xb797da30, 0xe13bde14, 0x5197b737, 0xdf2764fe,
	0x7e41324f, 0x6812c863, 0xd2c69bab, 0x766413f3, 0x2deb7f10, 0x9a0cd2e1,
	0x7ada0277, 0x8dc5ee3b, 0x56f68b5b, 0xfffa0736, 0x398bf514, 0xf78bf48e,
	0xfb9e9592, 0x3722603f, 0x00800059, 0x00000000, 0x00088b1f, 0x00000000,
	0x7dc5ff00, 0xd554780b, 0x399ef0b5, 0x66491e67, 0x99212726, 0xc9e21024,
	0x7008120b, 0x97861e12, 0xf0c0484c, 0xc1880274, 0x0fde1d06, 0x16888909,
	0x40e7fd2b, 0x6d1a0402, 0x515014b0, 0xad4b0407, 0x4d62a36d, 0xa0098fad,
	0x0d3fa837, 0xaf7b5b6a, 0x08b406e5, 0xdb911a8a, 0xd6d7fe8f, 0xfbdad6bb,
	0x09267324, 0xfdedef68, 0x9dbe3ef9, 0xbd7bdfb5, 0xaf6bdaf6, 0xa946667d,
	0x33c6b75b, 0x8c2d54e6, 0xeb663325, 0x48d8c698, 0xa95ca6c6, 0x631fac60,
	0x49bfe35f, 0x2cd4798c, 0xc37746c6, 0xf283e4b6, 0xb7d61762, 0x57e9fd50,
	0x7d5a5286, 0x6fa52e65, 0x14913de4, 0xcbe4f2c0, 0x028c0753, 0x48a2c938,
	0x8d95fe0c, 0x8c31b2b7, 0xf464e5dd, 0xab1b7def, 0xec602e6c, 0x4f8b594b,
	0x3feee828, 0x915db53a, 0x75fa0f98, 0xda50b15c, 0xab97cb3f, 0x6f667cc2,
	0x499d90ec, 0xa9cb91d0, 0xb804ca1c, 0x1e5d50b8, 0x74748fd1, 0x061d5d81,
	0xb29d77ed, 0x0e3e60fb, 0xca234b48, 0x35f319ab, 0x50ee32f7, 0x65eb4ad5,
	0xb3a5136c, 0x67b41eb1, 0x3865efc7, 0x3e14dbff, 0x9001b67f, 0xaa58c696,
	0x6fb46fa8, 0x9830b407, 0x23bcfe97, 0x94510874, 0xf3889815, 0x95612f6d,
	0x723f62cf, 0xfb85467b, 0xc9ff379f, 0x9afe72df, 0x895bffa8, 0x7efec06d,
	0xbb52693b, 0x7ad5e60f, 0x9291c8df, 0x5cefddda, 0xc27c4ed5, 0x18afce94,
	0x95e6b5d0, 0xac077538, 0x0af0166f, 0x3b2f9dc2, 0x29320742, 0x3092599f,
	0x40b01c75, 0x73a78d79, 0x2fc61f90, 0xcc26357d, 0xafbf4386, 0xc60cc8c6,
	0x604e5df9, 0xf4a5e22e, 0x1665c1d5, 0x25f24c0f, 0x5ea0cc87, 0x79be75d5,
	0x7cd7df98, 0xc013e2fb, 0x6a6fcd38, 0x8f8f4585, 0x8b6fc9ef, 0xbe2e7f04,
	0xbdfc4712, 0x8ec36648, 0x576f3cc0, 0xeb0e9add, 0x42d1bc5c, 0x967960eb,
	0x63ac2e50, 0x9b8580d6, 0x966bcc19, 0x3ba8f6f4, 0x8681be61, 0x966ed469,
	0x892cdac4, 0x681bfcdd, 0x1f06f9e2, 0x4092b9af, 0x4c95f570, 0x95ed6f1a,
	0x5cd7047e, 0xb174a189, 0xf2071790, 0x054bc035, 0x7c86df5f, 0x19b19633,
	0xcaef2e42, 0x1e23d40a, 0x58ddd566, 0x6c08f38e, 0x72851b4e, 0x7637cdd5,
	0xf80bf905, 0xabb97526, 0xad750f1b, 0xfc0a980b, 0x13f248e5, 0xb4852cdf,
	0x997ca234, 0xfc6887e0, 0x483e476d, 0xf37ce6fe, 0x8b37c15d, 0x2b5ce15d,
	0x1b56cde0, 0xf9866da3, 0xa7524a5c, 0x6dd71e22, 0xb0500007, 0x752fe6ce,
	0x3dd77cc3, 0x4280d164, 0xb718c96c, 0xc6fac193, 0x0f6b57bc, 0x82eff044,
	0x0a99c32b, 0x257b9878, 0x030dd287, 0xfd707b03, 0x17ccae8b, 0x294e1b74,
	0xf247dde0, 0x84293bf5, 0x62d4c372, 0xb632f32b, 0xe2ace91e, 0xdd398b04,
	0xcb2f7cc5, 0x9f382dda, 0x5b256fcb, 0x1e7fa874, 0x53045cf1, 0x618fe9f7,
	0xd0e42dbe, 0x8dbe63f6, 0x75d00ae9, 0xe9895ec9, 0x4852ce30, 0xe9692303,
	0x838ecf24, 0xd62b508e, 0x84be604b, 0xac2fc422, 0xf18f8f3f, 0x5eaffc35,
	0x32d387f7, 0x8355caa8, 0xa18787da, 0x3849555e, 0x776816f9, 0xf88da0f1,
	0xdbeb4d6b, 0xff281463, 0xc29252d8, 0x2e3e2140, 0x01539e07, 0x84e7ab95,
	0xf803617e, 0xf39ffb8e, 0xf1bb558c, 0x73872cdb, 0x0cdf6865, 0xce61d578,
	0x79528dcd, 0xc5c345c8, 0x36bb0c55, 0xf8fa1bbf, 0x8269868e, 0x1bdf390f,
	0xf82d5d7c, 0x1ff91abf, 0x25facfea, 0x78a019f0, 0xad0b11ed, 0x43e2b997,
	0xfe6e96b9, 0x9b257d5f, 0xffe6e9fa, 0x00e303d0, 0xb2a7fa7f, 0xf3758876,
	0xac8fb1bf, 0xec617211, 0x53042f27, 0x5fb06901, 0x791ce524, 0x5fc7ea11,
	0x33d50ef9, 0xefd0c2e4, 0xe437be86, 0x1e6e1660, 0xccf1de30, 0x0fc847c0,
	0xb0b67e93, 0x4d8c240c, 0x1e83c397, 0xcf94c249, 0xd3eb9bff, 0x9e9f4233,
	0xb5d3e931, 0x8bd3e87d, 0xfe2e52df, 0x772fd455, 0x05fddbb0, 0x71cfdf5c,
	0x3237f777, 0x71dff26b, 0xdf26521d, 0xf359ff77, 0xddbf3296, 0xf310bfbc,
	0xe03ed6be, 0x40fbe4cd, 0xd067deb4, 0xcffdea1f, 0xe10fce5f, 0xc19a70be,
	0xfa72813e, 0x487a9c52, 0x6fb40bec, 0xae87c6c4, 0xc81c2fb6, 0xeccde259,
	0xc9485f7d, 0x17d81ffc, 0x4beabe0c, 0xa0fc663e, 0xfff12a7d, 0xfa86160b,
	0xb69790d5, 0x98179058, 0x40d65b7f, 0x7937aead, 0xc90df631, 0x159ceb4a,
	0x2ea85d7f, 0xf4dca7b3, 0xe5a283b4, 0x178bf428, 0x39d2fe01, 0x90daf890,
	0x0c7e4323, 0xe4265a79, 0xcdc85aa4, 0xd303324f, 0xbc863f11, 0xc0d9fa4c,
	0xdfa88f51, 0xf218bf88, 0x5aa4b2d7, 0x0d55fc86, 0x397f2469, 0x9bafe0fa,
	0x9d9dbf32, 0x9bf33131, 0xff8b19d9, 0xb8b5fcf9, 0xf25afe0f, 0x832fe1df,
	0xd9bc66af, 0x7c454a3e, 0x70d6ef5f, 0x337cd15e, 0x9fbe6be3, 0xc43b8730,
	0xd402f5cb, 0x8fb2d7af, 0xe835fe0d, 0x611f45db, 0x3e432c47, 0x2cc9f480,
	0x6fccf6df, 0xdd131f66, 0x76ed491d, 0xbfd2015f, 0xf42764dd, 0xf03e5f65,
	0xc6caf52d, 0xc7f7486f, 0xff88ee91, 0xf2fb39ff, 0x5ee4ccf1, 0xeffa1ce9,
	0x295679d0, 0xc11fd9fc, 0x74befdf7, 0x050fe7a0, 0x28fc3acc, 0x8d8bf33f,
	0xf9353ff2, 0xc09f5072, 0x0468e3df, 0x1e12731f, 0x6e9fac38, 0x33fa832f,
	0xae55d47e, 0x0994f963, 0xe63fa2f1, 0xa8c55343, 0x7ffeeaff, 0xfda46f6b,
	0x29e389bf, 0x87fb21d0, 0x00a3c045, 0xc5c04776, 0x5e3ef051, 0x307723df,
	0x5109fa85, 0xa593f23e, 0xfa2fe688, 0x7d7d05d3, 0x3c04bfc7, 0x6c2c56cf,
	0x26a9d007, 0x5f6bff69, 0x5baa1d02, 0x46a2cc2c, 0x447d81e0, 0x92fb5878,
	0xb49fc045, 0x3d6fbae3, 0x9973e1c2, 0xb2e9379f, 0xb4ec17e8, 0xb6dd0235,
	0x824f8b66, 0x5b14d6fe, 0x3d995942, 0x4bae7df1, 0x81f318bf, 0x9edcd4ad,
	0x5dbe93d9, 0xb537a47b, 0x61f6a2cf, 0xff18b7c7, 0x17cc0996, 0xfe6ec5ea,
	0xd943c84a, 0xcb5ef8a8, 0x8f892ce5, 0xc6c015ff, 0x173590f8, 0x45ea1fd6,
	0xbc595cbe, 0x55ab76bf, 0x276e33e0, 0x6eddb7e2, 0xa7763be0, 0x09f0026f,
	0x827c5d63, 0x13e3037c, 0x5b15929c, 0xe5f320d1, 0x75f0a2fa, 0xdc7ef5b5,
	0x28f4be0b, 0x82ae397a, 0xf4bacfef, 0xd57b7742, 0x357c3edc, 0x31ee5d7a,
	0x95dbe0be, 0x4cfb1f06, 0xfb2f1efc, 0x93e33f89, 0xd7da0a2c, 0x8d31fd6b,
	0x96e8ae78, 0xc40ae4cf, 0x198c7b53, 0xe7f2dd4f, 0x202b28ad, 0x4fd449fb,
	0xd07a89dd, 0xcfaaed6f, 0xaf8bb1e5, 0xf00f2f99, 0xb636a68a, 0xb2903c2f,
	0x5f117753, 0x39c13950, 0x968ef311, 0x7828e6c7, 0x0afc9442, 0x81fd23f9,
	0x13c050e7, 0x4935dfda, 0x046aec67, 0x7f05f89f, 0xfbe16a7c, 0x6e64fb43,
	0xf167b667, 0x42cb36b4, 0x716655fd, 0x7e0c067c, 0x43c08d8a, 0xc27f89ba,
	0x58898e78, 0x4169e137, 0xe2eeb192, 0xeeb0998a, 0xbe5e44f6, 0x4ed46b3a,
	0x8e1bbd3d, 0x564d6fee, 0x105e8571, 0x5398ffd9, 0x0205d788, 0xd759b56f,
	0x4372c29f, 0xa313541f, 0xa8e87f10, 0x3f91aa0f, 0xa3f93d2c, 0x7f07ab38,
	0x7ded51ea, 0xbfb4abb6, 0x5f7b67a1, 0x4b667b54, 0x05ed36fa, 0xd14666dd,
	0xae8a3cb5, 0x95705165, 0xfa4c8701, 0x8bcbd0d7, 0xf16e765b, 0x38ee3cc2,
	0x45967a0c, 0xe254f3f2, 0x83143be7, 0x853c6f7f, 0x3f374dfb, 0xa73c1397,
	0x9f4dd059, 0x70f513b6, 0x71e1ea05, 0xd45cf0dd, 0xaf4f0443, 0xee47c5f0,
	0xfa763357, 0x34b7ce80, 0x5267f518, 0x8deb5bfd, 0xb95166fe, 0xcfa64741,
	0x0aba20ae, 0x9bf4c3bd, 0xeaf9614e, 0x27fb7897, 0x5d4ff80e, 0xa29a1e55,
	0x0a2fb2f0, 0xefeaa3d6, 0x56fec6ba, 0x637ed51f, 0x14637954, 0x6e0a37bc,
	0xb45fb730, 0x1683fb94, 0x21203f01, 0x9a32e5a2, 0xeacb9e3f, 0xf6ba73b2,
	0xefee0b73, 0x5c93326f, 0xf0e3a8cd, 0x561607cb, 0xc0441434, 0xe857b759,
	0x416f7cfc, 0xfe31b4be, 0x2eae740f, 0xfad83f01, 0xeb3f9bd0, 0xa2f32f8b,
	0xfe5e7bf7, 0x1a67f8ef, 0x64cccfda, 0xcc931c97, 0xcc64ab70, 0xfad4fabb,
	0xe034cc02, 0xb7e81535, 0xbcc7b199, 0x0aef382e, 0x59457578, 0xafa45da4,
	0xd6313e22, 0xfa9fd469, 0x1c25afb7, 0x55ac9def, 0xbca10715, 0xb738726a,
	0x44b3ed16, 0x297ec29e, 0x235d7ee1, 0x5f533afc, 0x5fb8fc96, 0x7386c556,
	0xac4415d7, 0xc20f3593, 0x27deb675, 0x3af47d11, 0xc45b0e7e, 0xb3ee3b54,
	0xcecf984b, 0x1ad608e0, 0x49e1bf1f, 0x3eec7768, 0xd3ee0369, 0xf3f437a7,
	0x28ad3fa2, 0xc79ddb9b, 0x2ef3afe2, 0xee35b803, 0xadb7d276, 0x7a50a6db,
	0xed6df254, 0x94bb1854, 0x2b856f75, 0x09e3cb1f, 0x581d9f4f, 0xf809b15f,
	0x952c8bfb, 0xc544d9eb, 0xf6f682db, 0xa43b1b0e, 0xf234bce2, 0xdfba2d2f,
	0xe703b851, 0x17a869b3, 0x3fc5cfed, 0x069a98ae, 0xb16f16f5, 0x75476869,
	0x9c0c9558, 0x14c7605f, 0xad2f963b, 0x237ea917, 0xfdfeafa5, 0xd40f3a89,
	0xa2d47cef, 0x13fa801d, 0x39bf372f, 0x0d15e01c, 0xe8921ad9, 0xa6562b95,
	0xf76738c0, 0xc0490e0e, 0xd4c41f97, 0xd79b3ebe, 0xc57f5867, 0xd9c9ea57,
	0xa4beb0a3, 0xe7fa866c, 0xe7ed1f20, 0x03a5db73, 0xc7979c16, 0x25816b1d,
	0xa31bfb9d, 0x2db9c973, 0xf1fa108e, 0xb702bace, 0xf671c5ed, 0x67d2d0da,
	0xc7aa2ce7, 0x7f887802, 0x6a455b62, 0x043be61a, 0x2c25b77d, 0xb22c3c02,
	0xed0ff176, 0x3813cb27, 0xadbd9f1c, 0xe3ac10e2, 0x3d8343dc, 0xd9adef88,
	0xfd1b253e, 0x84be3923, 0x5f38d1ec, 0xfabd6fbe, 0xb476e977, 0x71737fe3,
	0x6bf917b1, 0xebe73640, 0xf62cae57, 0xabb08e2e, 0x132a7f96, 0x576abc1f,
	0x5f7ce3d7, 0x41681d8d, 0x41f018ff, 0x2fabf43f, 0xe016e715, 0xf5cf0de7,
	0x07fd5f62, 0x6fd063da, 0x27920feb, 0xdebe26a8, 0x9d14fb4d, 0x782e0037,
	0x3a9dc1e2, 0x1d0fdbe8, 0x2807d81b, 0x91fb1b8c, 0x1329767f, 0x18e9e07a,
	0x6d4c7fee, 0xdfe9141e, 0x514392e9, 0x9bba4fff, 0xa827faf0, 0x3fd0fe8f,
	0x66e6ffe9, 0x57f59eae, 0x1a3adc78, 0xddb91f17, 0xb4e3d232, 0x2f773c1c,
	0xa8fe5bb4, 0xe581f68d, 0xec6f268f, 0x6f8171c4, 0x75cf5972, 0xf1b6c86d,
	0x725f6873, 0x51513fa9, 0xbcf22136, 0xee0544f2, 0xe5c97d17, 0x540e27d4,
	0x2df5741c, 0xae142b97, 0x6a3ea69f, 0xad3ca3f3, 0xd996ed18, 0x3f26c608,
	0xc421dafa, 0x633b8acf, 0xf1301c8a, 0x883a8f15, 0xb76e1d5e, 0xc07940ae,
	0x201396e3, 0xedcd979d, 0x55b3bb92, 0x26254b4a, 0xad288b3b, 0x25ec3f47,
	0x803f4f98, 0xd1f86c2f, 0x9c61ebee, 0xfe68598f, 0x4bbf80f5, 0x97a7ce3e,
	0xf421488e, 0x27d932e7, 0xb97d02cf, 0x513d7192, 0x7b39e27d, 0xb2b9fc09,
	0x3c4cc576, 0xd90aae0f, 0x338876ce, 0xefbd1e35, 0x89866c38, 0x0d7da003,
	0xb57b02cf, 0x7545f483, 0x0d5eb9b3, 0x8242fc6b, 0xa25a6afe, 0x2776cbfa,
	0xd0ca1b9d, 0x98045ca7, 0x6d6a9761, 0x6d2c1883, 0x0ae40b85, 0x8fba59d6,
	0x6c5687fb, 0x980e4290, 0xee3f696f, 0x0830fe3f, 0xeb4c1f74, 0x578015d5,
	0xcdfbe2ec, 0x3909660a, 0xf71bcfe1, 0x1ca329dd, 0xcbf4207c, 0x23f30b22,
	0xa3107f5f, 0x60bfa065, 0x8431a3f9, 0xad8f15d7, 0xd043fdfa, 0xacd363ae,
	0xf4f3c8a4, 0xd00fc126, 0x7626733f, 0xa6d1f3f7, 0xdf2067ef, 0xe70e3e97,
	0x8acf5862, 0x058bf604, 0xb4a74899, 0x5dd5d50c, 0xfbe6c56f, 0x707af106,
	0xf3f386ae, 0xf712eda2, 0xa0ef3c5b, 0x5c640ffd, 0xd2dbc489, 0x7b7613fa,
	0xf15bff01, 0x455abb0a, 0x2ed8ddfd, 0x50b3fb41, 0x7f08b92e, 0xdf84477a,
	0x2bec76fc, 0x0047f48d, 0xb56557d7, 0xfa873edc, 0x3ca3b4e9, 0xedcd9d3f,
	0xba4427d9, 0x0dbb4328, 0x80fd51e7, 0xc99cdb43, 0x88c691fb, 0xaeb9c079,
	0x1cbedada, 0x57ecc2fd, 0xd5a7f20e, 0x62f8c7d4, 0xf10e743c, 0xd6fd0b3d,
	0x27b64cc8, 0x9d7cbf62, 0x2fae546b, 0x193dff20, 0x5cddabf2, 0x0027561f,
	0xec7ef9be, 0x9fff42b3, 0xbcd95fe3, 0xdde1b4bf, 0xb7c6bbed, 0x0fe79774,
	0x9bf57c47, 0xf8f3895f, 0x0af244b9, 0x18a078c8, 0x4b9fbaed, 0xbd3cf123,
	0xa9b1fb68, 0x78ef5fa8, 0xa6c150a6, 0x0ef17e8b, 0x08770fed, 0x7da0773a,
	0xc005fb8f, 0x9afa40cf, 0x890187d0, 0x6c1336d5, 0x1a3bdd31, 0x6ddbd5e5,
	0xd06aa744, 0xaa38a8e3, 0xfa81fd37, 0x7bb776ad, 0x3f56bf51, 0x7a831b6f,
	0xddc84db8, 0x27034de2, 0xb3fc07bc, 0xe0af16d8, 0x9f46b47e, 0x4d784765,
	0xeee08593, 0xc819c976, 0xbfd49f8f, 0x893e21e0, 0xbee2e709, 0x8c6779d3,
	0xa0170076, 0x27dcff70, 0xd007b9f5, 0x6954b36f, 0x7ca05b77, 0x44ecfae9,
	0x95a7cfd4, 0x4fcb1db0, 0x115a6737, 0x04ca29f6, 0x08f27d84, 0x55013f82,
	0x07f82cd5, 0x0b5acbf5, 0xa79ae7a7, 0x60b3d98f, 0xdcd98bbc, 0xcfe9fe5f,
	0xfe8419df, 0xf68cea9d, 0x006fb841, 0x400d07bd, 0xa1653f3c, 0xd3ed777d,
	0x78662f92, 0x22d7bd37, 0x56be41bd, 0x3daf3a0b, 0x9177c2f2, 0xbd22d7ef,
	0x0bf27a8b, 0xca71edf0, 0x54ff767f, 0x471fdbc6, 0x29f630be, 0x006deb80,
	0xfc39d9b7, 0xc803e0a9, 0x7af9e32f, 0xd049e901, 0x465f6823, 0xf45f7bf3,
	0x0ab1cd8d, 0x9f48387a, 0xf5f0e6c6, 0xde7f6c76, 0xf4fbf483, 0x475ec7e7,
	0xb3f5713f, 0xbdab0bb0, 0x47c0bdf0, 0x43dfae0d, 0xa1fb27f3, 0xe9ebd706,
	0x9f177f5e, 0x61ab790b, 0x7ac67d7c, 0x7eb1646b, 0x8fb45ca3, 0xc2f211cb,
	0x0c8ebe04, 0xe425f2e6, 0xed15e509, 0x817d6330, 0xe0dede44, 0xce1cc2cf,
	0xca45fd9f, 0xe20f6694, 0x7a8be907, 0x67c7f806, 0x06f4231f, 0x19f4f954,
	0xbd047f98, 0xe497f98c, 0xf35e86a8, 0xd3762425, 0x56cac3b1, 0x39af76f6,
	0xc9cb8724, 0x19292d99, 0x4fbf802d, 0xf1455ce0, 0x72afc008, 0xdf0678c4,
	0xfe95e318, 0xae3a62ac, 0x630ffa1b, 0xa7b8c6ff, 0xfb1938f5, 0x7cb8cd39,
	0xe437f318, 0xe16eb4b2, 0xd60f42f4, 0x5d9dd4fb, 0xe3e6eb80, 0xd428e497,
	0x00f687de, 0x58b5f7b4, 0x467d4fc8, 0x6ccfe39c, 0xb8b3c179, 0x27df9ba0,
	0x3fe3fa09, 0x9e73dbd9, 0xf045ff06, 0x74b3cd33, 0x11d32ddb, 0xcd1be636,
	0x0cde0697, 0x931b64fe, 0xe6894ec9, 0x33f49ad3, 0x3a2f1c76, 0x3e57b0df,
	0xca0abf40, 0x212dafff, 0x767aff92, 0x1f62273c, 0xfc3af436, 0xdd31b173,
	0x2fb184fb, 0xe3c3943f, 0xcd663e4a, 0xe3d012f6, 0x4fb7ce6b, 0x76dda8f5,
	0x61cbc4e0, 0x45fd1e29, 0x228b3247, 0x1735b5f7, 0x569f138f, 0x78adf6b3,
	0xfdb459ae, 0x23d7599d, 0xec14fe3f, 0x5babd422, 0xbed1d8a6, 0xc968755e,
	0xd9f3a418, 0x5d6fbe06, 0x24fd1fa8, 0x1b67c7da, 0x525de47e, 0xa74aed80,
	0x45fc838e, 0x8e890b3b, 0xcfb4c41f, 0x6ef3b842, 0x76801d89, 0xde8d0fe3,
	0xe3c02b78, 0xe025d7dd, 0x941f4e7a, 0xd045c6ca, 0x3653297d, 0x98f68ade,
	0x1ca0af1c, 0xabfa169c, 0x52e9c6ce, 0x7bfcf827, 0x83e7295d, 0x41babad2,
	0xb9de5f78, 0xde26f41f, 0xe6d5db13, 0x72fb8e30, 0x35f7d90a, 0x4d491c70,
	0xb26a7ba4, 0x99da5687, 0xf288ad33, 0x7f90699d, 0x377ed6c2, 0xddc4e7ae,
	0x884dc2ee, 0x31abe963, 0x4b1db98b, 0x2bf601f2, 0xcbe06f8d, 0xc166c798,
	0x19fdd14f, 0x7ed0dbed, 0xe6273d47, 0xa7fea17f, 0xba7f71f3, 0x11373870,
	0xcbd1ffd7, 0xcf680d31, 0x7ae3647c, 0xec1fe8cb, 0xeca30fab, 0x760c132b,
	0x7e060994, 0x7f6cd0fa, 0xedf9a66d, 0x2a3b01ca, 0x51d9758e, 0xdd565f06,
	0x191f1b99, 0xcec3d027, 0xe2c7f9ce, 0x01062e8a, 0x2f1b6061, 0x8c051f40,
	0xb7f7165f, 0xded1dae7, 0x0e28726e, 0xc887ef58, 0xf4bf78df, 0x703388bc,
	0xf0ff7e72, 0x3c2191f9, 0x9f7f2dcf, 0x2d9bcbc3, 0x3aa10c21, 0x849b73be,
	0xbd8197f5, 0xb0896297, 0x9ced775f, 0x4970628f, 0x834d6c0b, 0xf30e97fa,
	0x76280838, 0xafadd945, 0x7bffa9a7, 0x07e1ab76, 0xec239638, 0x88698d57,
	0xc6df0377, 0xe055e5f9, 0x08a2e28b, 0x25706f3f, 0x8317add9, 0xb73f4a01,
	0x3c60799c, 0x5e3bb3f2, 0x4df9b943, 0x01a48fcb, 0x8523f748, 0x7439e15f,
	0x415e2b9c, 0xb82cfdf9, 0x2f132e81, 0x35296b06, 0xc1f86ee8, 0xa5691e26,
	0x8cb59f76, 0xb43c697c, 0x4f15c57b, 0x67a0da7a, 0x5dc75c74, 0xe9052d36,
	0xfe3c7ccb, 0x41bfa0c3, 0x2b7d6377, 0x97471c44, 0x4e5efb9f, 0xf0f82ef7,
	0xb7ae0f12, 0x2f7e91f5, 0xc77a458d, 0xaf682bc5, 0xf5cbdb9d, 0xfc6779c6,
	0xde813393, 0xf5cdf7e7, 0xcb97d032, 0xc7cde75a, 0x5b2fe5fc, 0xb5d3b414,
	0x783c2b97, 0xdcb3fc6e, 0x853051e1, 0xffdc6176, 0x7a8490e5, 0x9b395c6a,
	0x85c7f58b, 0x3f42a665, 0xbe726763, 0x0e517b19, 0x27cf05e1, 0x8b7e4f90,
	0x6fc962af, 0x61faff01, 0x5fb2c77c, 0x41877f73, 0x35dce307, 0x1073ac5e,
	0x4fe12588, 0xf31697e4, 0x3df68ffc, 0xbbfb1b37, 0xe0a6d070, 0x683b3fbc,
	0xc357fea3, 0xe30ac979, 0xcfcc3f9d, 0x64c70823, 0x73f37ca2, 0x7e66eac7,
	0xd3bea8ee, 0xf7c7b3e6, 0x88d2cfe4, 0x83ae787a, 0x5dc7153c, 0xe0cff825,
	0xbe3ed5db, 0xbfb0d5be, 0xf9a37ae1, 0x6f358138, 0x8b5d3c45, 0x1f29bf9f,
	0xeb35c80f, 0xe16df78d, 0x9f105be4, 0xfc8d2427, 0x87f07d30, 0x03d45781,
	0x3f06c7c8, 0xefcbdeac, 0x0b9b13d5, 0x0d1f904b, 0x8df430fe, 0xe1e5993e,
	0x67675a3e, 0xa39f1879, 0x9ee9635b, 0xdaa5c2b7, 0x9b985f70, 0xe88651d4,
	0xfae5cba9, 0xfab52a56, 0xd53fb8ac, 0x448f4839, 0xb9d1a1eb, 0x80bf3f5c,
	0x67f5074c, 0xdb042ae5, 0x279d2d58, 0x960c148c, 0x575fb881, 0x87fe25c4,
	0x877c550a, 0xc3239b1e, 0x27c62bfc, 0xc1ad9dde, 0xe0e873e6, 0xbdf8191c,
	0x68e26462, 0xd2cb941b, 0xa0ca7313, 0xefae597c, 0xddd1dc86, 0x94385efd,
	0x03d71032, 0x30b925f9, 0x40a4bede, 0x7635a619, 0xcff7e917, 0x37c39d2d,
	0x3fd77664, 0xf4fbb2f5, 0xb86ed46f, 0x3432c6c3, 0xe6ba67dc, 0x5cc6d3cb,
	0x8e3e0cdf, 0x63317f39, 0xb1efd05b, 0xf797ff58, 0x7f812ed0, 0xe3d0277e,
	0x8b57c126, 0xd230ae9d, 0x2ed83595, 0x6019d976, 0x5e2d301a, 0x16cdba46,
	0x1c9370fc, 0xf9f6c56e, 0xe7395eac, 0xdf685324, 0xd6fafdd7, 0x760180ef,
	0xf80fe8ce, 0xac1b73e2, 0x02daf80f, 0x4401b66c, 0xac4802c7, 0x7966bd02,
	0x8afe5fe9, 0xace9d6fd, 0x5cf08623, 0xb43ea0a5, 0x6bf580b0, 0x3ce3ab48,
	0xe1afd1c3, 0x761dc17b, 0xfdd71d01, 0x7ff88e3c, 0x04df6195, 0xd76f898a,
	0x2c3d7c2b, 0xedf88e30, 0x1f6fc16e, 0x0e6d5905, 0xeca7e088, 0xcc3267e8,
	0x702626a3, 0x8d69e217, 0x758cadf5, 0x9d6bca2a, 0x4f8eed07, 0xa869217f,
	0x3b08d61a, 0x164c1d92, 0x27852f72, 0x665b7941, 0x77dc01fe, 0xe5f82fbe,
	0x73a32662, 0x41c9beb0, 0xabec8071, 0x01f71963, 0xa3759e5c, 0x8bcbe786,
	0x59cb6ccf, 0x80727406, 0x3ac0f17a, 0xc59f41a7, 0xc01b6eb0, 0x86f7dd12,
	0xd7281fa8, 0x35bf903d, 0x9c1947f3, 0xe51f98cf, 0x818fa0da, 0x80f41ef7,
	0xb4ded1a1, 0xcf0d993a, 0x9f6cf993, 0xd0687282, 0xf61e0a65, 0x3dd70e41,
	0xeb1efdcf, 0x460bac2c, 0x4e47cdbf, 0x7a2f6bc0, 0x6bc4faa6, 0xb8827764,
	0xb2fd26e9, 0xfbef496f, 0x3b7ef162, 0xbd3ffd76, 0xe8693e3f, 0x48564295,
	0x0d2e08f6, 0xea215bfa, 0x54aa914c, 0xec93d719, 0xd61f90d4, 0x829d9a3d,
	0xf0562de7, 0x8f591663, 0x7c47ebed, 0x225335b2, 0xb16aaffc, 0xace37c50,
	0x854c0196, 0xfd2d99a2, 0x495cf528, 0x4f0bfca3, 0xeb8a39be, 0x599f4e1b,
	0x4c99493f, 0x193fa871, 0x8f31a94c, 0x0cdf8275, 0x73f25f3c, 0xfe7acb3c,
	0x5f78099e, 0x216366d0, 0x5e10ec95, 0x7842cf3e, 0x81f6d4bf, 0x6f337c8c,
	0x03f585a2, 0xfce58a58, 0x32b548ed, 0x39fc17b5, 0xd4625d04, 0x9c46a658,
	0x3c62ea03, 0xd31db007, 0xf768ed7d, 0xc5ea22df, 0xea9a25e5, 0x2f9c7419,
	0x6b8b71d0, 0xc75c4ce5, 0x36d4cf36, 0xd6b72be4, 0x43ae34df, 0xfe90d972,
	0xf4ccabf3, 0x0ccf3798, 0x417c26db, 0xc136d67a, 0x45f0ef9c, 0xc2b939d9,
	0xf967c9be, 0xc08c7491, 0xf1ed0f9f, 0xc7073e4b, 0x4cf7531f, 0x047e7800,
	0xe55e30fe, 0xf84cba52, 0xf1c316db, 0x803b7805, 0x6c5f1bfc, 0xcf825bc6,
	0xe57ea78c, 0xfb247c66, 0xa94debcd, 0xa79532cc, 0xca988605, 0x322cac07,
	0xc76b03c1, 0xb75fea99, 0xce09b261, 0xea9ba7d4, 0x31cc3767, 0xb74db9c1,
	0xde0fea9a, 0x9e54d8bb, 0x2a6d5a1f, 0x9d787a1f, 0xfcd61e09, 0x11fd533d,
	0xe54d9b2d, 0xa61de185, 0x0f6d91f2, 0xedd1e09a, 0x5fea9b0f, 0x5301deff,
	0xa78ed8f9, 0xcfe3e54c, 0x27826b3f, 0xaa68be76, 0x51cae93f, 0xdec25c13,
	0x752fd534, 0xa78263be, 0xaa66ff28, 0x07ea637f, 0xea69f2a6, 0x19f2a627,
	0xe09a5f79, 0x9a7fda59, 0x07b52fea, 0x3b420d86, 0x7248ba4c, 0xcb90b755,
	0xb9b6a5d5, 0x11e3944e, 0x37fccc83, 0x2ca3ec52, 0xbfa06587, 0x21348a64,
	0x62d9f24c, 0x11dcf0d1, 0x9fc94fbd, 0x47e87df8, 0xc8582f63, 0xed87899e,
	0x3f188e46, 0x8384e7c1, 0xafdc3762, 0xc9c1315c, 0xfd5354fe, 0x54d54a94,
	0x33c8169e, 0xa9580f95, 0xb581e099, 0xd7faa6c5, 0xe099f06d, 0x54dcbd4c,
	0x6fc1bb3f, 0x2a9b7382, 0xef07f54d, 0xf3ca980d, 0xe54d2b43, 0x9ad70f43,
	0x1bcd61e0, 0xb447f54c, 0xc2f2a6e8, 0x7ca98370, 0x09935b64, 0xd7bedd1e,
	0xf7faff54, 0xb1f2a642, 0xe54d871d, 0x9b37cfe3, 0x2d9d89e0, 0xae93faa6,
	0x09704d84, 0x5faa613b, 0x82653cea, 0x347f28a7, 0xf531bfd5, 0x9a7ca98c,
	0x6e54c17a, 0xf23325d8, 0x0be730be, 0xf696653b, 0x7d7b5357, 0x7f218fb2,
	0xb45acfe8, 0xfbb1953a, 0xdd916507, 0x23bb7a05, 0xc6bb4246, 0x8946f14f,
	0x7c07b018, 0x885baf19, 0xadeb70af, 0x12503f22, 0x6b695bf9, 0x06ae3151,
	0x12007bf6, 0x689999ad, 0xdb75c6e7, 0x475fe95b, 0x65aea39c, 0x883e3d6f,
	0x96b63cd1, 0xc5bd9548, 0x883e3e11, 0x1f5e43fb, 0x2835d814, 0xcf15cf19,
	0x7b7b454c, 0xe2b7d315, 0x0548a73c, 0xeed01df1, 0x9fd98c64, 0x9cd3a461,
	0xf988b780, 0x4a69889c, 0xffc5ea2f, 0x22ff5dd7, 0x57eaefd5, 0xb02c39f8,
	0xfd1175fe, 0x01e7003f, 0xa6b5ec19, 0xd815c820, 0x15060fb0, 0x53057782,
	0x541dde09, 0xcc1bdd29, 0xa0e1f4a3, 0x82fbe546, 0x163f04c5, 0x0a1c11f4,
	0x207a5396, 0x83fca7e8, 0x9f824ac1, 0xa6337384, 0x8d1ce187, 0x1e7053e9,
	0xe1a7f2c6, 0x2ff08c7c, 0xcda53a82, 0x7fca06c1, 0xf044d836, 0x825ee091,
	0x510c157f, 0x4c3c12da, 0x66c18be9, 0xd8297f2a, 0xc12bf042, 0x60e1c130,
	0x8347c11b, 0x0f1f04ed, 0xebf047be, 0xdb4a0ec1, 0x7d29e782, 0xe549d823,
	0x10af056f, 0xb34f4ddc, 0xcf8d1c1d, 0x95bf858f, 0x85717b09, 0xc4961fe0,
	0x9ce5c4ed, 0xc10ad815, 0x60c9b6b7, 0xda9f0086, 0x803a0ffa, 0x91a3d171,
	0xaf88f2af, 0x7636fade, 0xcc39f47c, 0xf8cf8148, 0x0b4efa39, 0xfb18d7f7,
	0x301f88bc, 0xbbaaa4ec, 0x2175f9f9, 0x2f78bdd8, 0xb70c7ef0, 0xdad52f43,
	0xab9ed0f2, 0x786ac4b2, 0xf6a9726f, 0x308764cf, 0x1106cfbc, 0xc725fdb9,
	0xe7111dfe, 0x6f682ab7, 0x33cbf685, 0x8aac3168, 0x9ee8d9b5, 0x093e6654,
	0xc0ee6ae4, 0x2fb8e7c0, 0xd5681eac, 0x0aed3ce9, 0xdbf3c20d, 0x4b818186,
	0x76a97f98, 0x1f84ebd9, 0xc2fba345, 0x6e7e0e59, 0x2b7384ed, 0xc2fb01fa,
	0x07888d47, 0x95fcb3ef, 0x8f68e90b, 0x0a5dff97, 0xda4e7d20, 0x47e895dc,
	0xe7e60db0, 0xab60db51, 0xc808cd39, 0x8bfd2183, 0x2b36f6bb, 0x372ff0a0,
	0x5de4f9dc, 0xa07edd99, 0x0a08f09b, 0x53057376, 0xc8b7146d, 0xd3e1af7c,
	0x80599b85, 0x4e985be0, 0x01e93de9, 0x80b3f637, 0x8c0e0885, 0xb6f46473,
	0xa579e8ae, 0x8aa5798a, 0xc8e918f9, 0xe0ca408c, 0x1f2f38d1, 0xd8e4ebcd,
	0xbae1071b, 0x95dd798c, 0xe3f88aa1, 0x7e70c7ce, 0x8bf9797f, 0x9eec9673,
	0xe04ff1fc, 0x1dba170b, 0x7bc31ea1, 0x1d903a8f, 0xaf775f6c, 0x0dfde285,
	0x8742a8be, 0x08dbb621, 0x3e4896f9, 0xf3c0fe01, 0xbd275257, 0x193e0403,
	0x3d5b7885, 0x60edd256, 0x86b49e57, 0x1ee85906, 0xfd1d9979, 0x80922b09,
	0xe6fab23f, 0xfde2b583, 0xfc0f9182, 0xf7f60375, 0xcfafafd9, 0xbcd57c43,
	0x7c455632, 0x7bf959d5, 0xe10dfd24, 0x5faa1117, 0xfc8c3f1a, 0x34d64c99,
	0x72cd3bf4, 0x176faef4, 0xfafae60d, 0x3cadaa64, 0xef99fd44, 0xba08165b,
	0x7cf4102d, 0xbe28c2df, 0x471b1f57, 0x34793f78, 0x58f887c6, 0x881d26db,
	0x7f855cb1, 0x9ee0fc37, 0xd35ebd48, 0xafaa6672, 0x51bebd17, 0x27e0c7cc,
	0xec0eeec9, 0x97ce4577, 0xbf81939f, 0x0947c403, 0xc4d9dfc0, 0xbef0e7df,
	0x8d43b671, 0x0ed205bf, 0xd2185540, 0x9d0ae3c0, 0x8d33170f, 0x4fcca5d2,
	0x07600ae9, 0xbebf67e4, 0x58748ed3, 0x7f299acd, 0x2f12f16d, 0x6b72f7f2,
	0x6bcdce80, 0xef174230, 0x5967597f, 0xe6f7ac2a, 0xa5af4d86, 0x36e75a02,
	0x7e829ced, 0x45a139dd, 0x715a61af, 0xe30e72d0, 0xee5e4155, 0x58753a42,
	0x87f4b76a, 0xba7d6ff1, 0xc800cb64, 0x3a712d9f, 0x9d3937b1, 0xbd127d0c,
	0xfb8f906e, 0xb47cbaf8, 0x6e53c92e, 0xcdaa8f92, 0xea4967cc, 0x92ef9b8e,
	0xfe3be297, 0x35ea007d, 0x07fc93b9, 0x1238af35, 0x19abfe91, 0x3e2c13b7,
	0xd8623fc3, 0xfff88c07, 0x61ab160e, 0xbf058fbd, 0x11903c7f, 0x740c7fbf,
	0x8674f7c6, 0x0232cadd, 0xddd945a9, 0xf58d78fb, 0x2788e1e9, 0xc41fe7d8,
	0xa0feaef9, 0x26616b79, 0x0ca107ee, 0x4f6c5bb4, 0x4cbab439, 0xbec37ed3,
	0x7bf6eb8e, 0x7ee3603d, 0x5979e8a9, 0x2bff5f8a, 0x3b0e29da, 0x049ef1d3,
	0x418d9de4, 0x276feb7e, 0xd443ab79, 0xb26cffa2, 0xb1f7e55f, 0x8a4ffee6,
	0x8dfdb6f9, 0x587579fb, 0x7a51fa0f, 0x2ff7c38e, 0x38f76c47, 0x8cbc4fa4,
	0x307679c6, 0x3c636b97, 0x4748eae6, 0x6c737ebb, 0x6be919a0, 0xf38c83f8,
	0x47e65b66, 0xd99f4839, 0x61542ee3, 0x1d636d3f, 0x3d24ca4c, 0x9bb27e4b,
	0xec9fb98a, 0x362fc326, 0x162fca21, 0x13619fe5, 0x1993f77a, 0xcd319afa,
	0x67c9f386, 0x27eb1bef, 0x1fa18cff, 0xb0b7ec7b, 0x5ff27690, 0xe8cfe4ab,
	0xda14dbf2, 0x594dbc79, 0xede1f91a, 0xefde7f42, 0x68cb7ae7, 0x4709529f,
	0xc2f9d31b, 0xe74c72c9, 0x0f04c50b, 0xd5354dac, 0x6a836ebf, 0xf3d4cf2a,
	0x0dd9e54c, 0x6dce099a, 0x1fd5362a, 0x8267d7bc, 0xa6e543f3, 0xfb0f43fa,
	0xe6b0f04d, 0x11fd534a, 0x7953012d, 0xa9a57861, 0xad5b647c, 0xbedd1e09,
	0xfaff54c1, 0xf95374f7, 0x53068ed8, 0x4df3f8f9, 0xe7627826, 0x49fd535e,
	0xf2a64257, 0x5353f612, 0x19f3a979, 0xf9453c13, 0xa3fea9b5, 0x31badf62,
	0xbf94d5b5, 0xa62bf84f, 0xed4c27a9, 0x329de467, 0xbd228fc1, 0xd8161e51,
	0xd75a1e49, 0x0553d90d, 0xceb81ff4, 0x682fa1aa, 0x5347f696, 0x3fbd2cbf,
	0x863db7f1, 0xed4ba5e7, 0x8fb72885, 0x31323b5a, 0x6ea2cc7d, 0xf670f3c6,
	0x83721284, 0xda2d96e7, 0x99e0e98c, 0x2ac9ac9b, 0xfede67d0, 0x432628cd,
	0x5ead5aab, 0x3d2d8780, 0x748bd9b3, 0x52916358, 0x33ebff10, 0xb91d30eb,
	0x854a44b1, 0x8bf5d1f2, 0x2eaf50ea, 0x68b53c69, 0xfaebcc05, 0x73624ef5,
	0x7682e80f, 0x3ec99bf4, 0xc0f5dbe2, 0xf58eb8a6, 0xee2963a3, 0x2e71feee,
	0xf7390f19, 0xa3d6f0ef, 0x1dfef11f, 0x6e980d45, 0x343f7b05, 0xb006b198,
	0x01dd31f7, 0x16087ef6, 0x9fd4feba, 0x954e5013, 0xc54adeeb, 0x936dfdfb,
	0x1aacd63f, 0xde6530ae, 0x31b7e871, 0x3bc45639, 0x012bcca6, 0x947ee05b,
	0x7f938055, 0x8c3cdd7a, 0xff868de3, 0xe5afd43c, 0xa6e542e1, 0x7b03b44c,
	0x9ba7abf4, 0x9bf805fb, 0x971bebf5, 0x7bf29a37, 0x94987f8d, 0xe4e3f7c7,
	0x4f11ab7c, 0xdc5b7140, 0xec148774, 0x73d07895, 0x02db638d, 0xb2bf002b,
	0x7dc16b52, 0x42af78c4, 0x04d9f857, 0x38024a4f, 0xb17bb455, 0xc70b3020,
	0x73418175, 0x527f8236, 0xc11c0297, 0xbf007b1f, 0xf3dd6d67, 0xd56eddb1,
	0xb617d065, 0x834d0ad2, 0x18591e71, 0x3dd1874b, 0x91ddb376, 0x9a4fe22b,
	0xc8bc44f3, 0xb4357357, 0xf8f39a97, 0x5050f7fe, 0x0da1f319, 0x34a54ffb,
	0x0598696d, 0x34b9cf40, 0x162186bf, 0xd89fafb6, 0xc04def84, 0x7dc66a36,
	0x0d37f314, 0x497feeeb, 0xbf7fb09e, 0x6edfc896, 0x896bf3ab, 0x24dbe311,
	0xe76f6d4b, 0x08f875d6, 0x31d5db04, 0x3b1db72a, 0xd3edef41, 0x32cb26b4,
	0xf0cc27ea, 0xe615c47e, 0x90b5fdf9, 0xa1c02965, 0x19da953c, 0x0a5ff4fd,
	0x03f48ff3, 0x8c16b5ca, 0x58d94867, 0xa43c416b, 0xef0d7e28, 0x37ea991b,
	0x6ca76fdd, 0xe1f318c8, 0x5fb79c48, 0xdb0938c3, 0xc3ef830c, 0xedaa244e,
	0x1b3e2d03, 0x895bfdd7, 0x4be4821d, 0xba4f8b55, 0xabb83dca, 0xf577df83,
	0x7a29ee55, 0x5de296a3, 0x5e2a5c8b, 0xe85a3d69, 0x0bdfdcaa, 0x9f04859f,
	0xf3cc7a35, 0x19f71971, 0x52f8df62, 0x12df7c61, 0x04aee37a, 0xdcfd1b0e,
	0xc2945855, 0xbddf36ae, 0x6e7dd316, 0x78838c23, 0xd5aafc6b, 0xc46b7889,
	0xbfda0c38, 0x8f5bed18, 0xff6f38fd, 0xfe4f4b0e, 0x200721e9, 0xc845f171,
	0x75426797, 0xa1773f80, 0xbbedde9d, 0x416e59ee, 0xd595205b, 0x6b90e052,
	0x3c9b5974, 0xabf32afc, 0x4a7ff334, 0x4c1f2cc0, 0x3bd1a40e, 0xc3574103,
	0x4749e82e, 0xf11b2535, 0x278f26fe, 0xa6a9975f, 0x7e0d1d20, 0x3fe2775d,
	0x74110262, 0xa4e42938, 0x28493598, 0x3358e3af, 0x3b5813a5, 0x4eb037a5,
	0x914c7d4a, 0x34cc9d31, 0x9f98cb4a, 0x96aca9d2, 0x44d672d2, 0x4cd674e9,
	0x4ed64ce9, 0x28b39c29, 0xce8533f5, 0xaec07383, 0xf31e74c0, 0xd59f3a53,
	0x7c81da52, 0x64a8f30e, 0xcadf044d, 0x016d299a, 0x460ea03d, 0xd293857f,
	0x62cf4097, 0x95304afa, 0x655070d2, 0x15fd03aa, 0x0f1e9479, 0x1ebe946a,
	0x2db4a62c, 0x6f7aa3e8, 0x7d29cb04, 0xf4a7e82b, 0xd292b064, 0xea8060f6,
	0x495c1dbd, 0x5ac1bbe9, 0xdc1f7f4a, 0x417be940, 0x0d7fd29d, 0x6b9a5036,
	0x606e7467, 0x39c2e179, 0x0ff48f40, 0xe8153eec, 0xc9e8443a, 0x726b3e63,
	0x53d2127e, 0x7597e866, 0x26231d95, 0x7a56a971, 0x1ea0d7b7, 0x1f504b65,
	0xa476e49f, 0x764dc53b, 0x38e9abaa, 0x16c8f8c3, 0x8714874b, 0x6fbfcdb4,
	0xf61f339e, 0x7d5897f1, 0x7cf9ea1c, 0xf613977d, 0xed6cc7a3, 0xf9404fb5,
	0xfefe1e7f, 0x9dec273c, 0x960fdce3, 0xffb600ba, 0xae54fbf4, 0x29f55b39,
	0xb5877f50, 0xe7c61e6e, 0xfae7c90e, 0x3a52ce03, 0xe9dd5dc5, 0xc2abb8a2,
	0xb885a3a6, 0x75ad8eb1, 0x3d733115, 0x55f45bf2, 0x68dcba2f, 0x57b548f7,
	0xfe3775c2, 0x2c038e99, 0x885c3b3d, 0x7ec8b1fe, 0x7c6cdfad, 0xfc655d26,
	0xab967ac8, 0x8162f7f4, 0xfc9f9bcf, 0xa3af9fff, 0xf5f6d9f9, 0xe4ac67b1,
	0x418ce86f, 0xc0903e79, 0xd8274df5, 0x6ade78c9, 0xa6e37014, 0x0f9bb22c,
	0xdf72f118, 0x40fca997, 0x0da976ac, 0xe4394de1, 0xf04c6917, 0xfd63e6c5,
	0x77a4592d, 0xc518e3d2, 0xbdafddc1, 0x7211a8ae, 0xf5cf925e, 0x65e26b97,
	0x87ea0965, 0xaf0ccbef, 0xfefbafda, 0x02376dbb, 0x562dd4de, 0xfc52defa,
	0x71cb77c4, 0x946d081f, 0xc74248c7, 0xfc5f2a31, 0xeee39e24, 0x83b1ecd7,
	0x11fbae80, 0x35ef6875, 0x4bdec8b8, 0xbc2e17ef, 0x22dbc60b, 0x68b678f3,
	0x9f3db6fd, 0x7bab79eb, 0x5bb63b54, 0x3aa9c0b7, 0x6f9e72ae, 0x7885ea0c,
	0x0d8dedff, 0xcfc0622c, 0x269ffc81, 0xc223016d, 0xcc76e1eb, 0xc857fcda,
	0xf114698e, 0xac925bb0, 0x157027e4, 0x114bf779, 0x61ecbafd, 0xab55f695,
	0x9eb15b90, 0x14e9edc6, 0x9e73dc6f, 0xadd6fde6, 0xf4223cc1, 0x5ff0a372,
	0xb2378d74, 0xc2297eff, 0x8472e7bf, 0xd8cf1a35, 0x76f18cbf, 0xdde363fc,
	0x8d3ce22f, 0xcc63dcf1, 0xdbdb73eb, 0x616e7d69, 0xdde318f7, 0x25ebeb8f,
	0xe39ae46e, 0xc722fae1, 0x3ebcdebb, 0xd69da3b7, 0x1db896e7, 0x8ede35d3,
	0x6bebc7de, 0xf151dd9c, 0x40fa4680, 0xc08fdf3e, 0x8167641c, 0x9c1dd341,
	0xf1131f9f, 0x5fbd465c, 0x7dfe7e0a, 0x4e4ff081, 0xe6c97ae2, 0xa43bd3b5,
	0x9df9ef12, 0x5daed7c8, 0x731fba56, 0x764ebd25, 0x16f29c95, 0xca5ce893,
	0x31ff319a, 0x27a76f0b, 0xb38d7bdb, 0x3f3c1dd9, 0xbfc2273a, 0x5ad5a29d,
	0xc4ab6e30, 0x3ef0c6db, 0xa76495c0, 0x9c92bbf5, 0xb94ff421, 0x7b602634,
	0x2fe00e28, 0xcb3f020a, 0x357a7987, 0x24de2f2e, 0xa78c7efb, 0x7e84a94a,
	0x98f1f023, 0x772663e0, 0xbc445664, 0xc0533a0b, 0x75c861f1, 0x0cd6fcf4,
	0x303878e1, 0xdea29a19, 0x36fdcb1c, 0xa7f50f27, 0x07eccb73, 0xae787d62,
	0x487db93f, 0xc63bc119, 0xc9c03c51, 0xe2a6e343, 0x8ef66639, 0x2d8256e9,
	0x31fd0dac, 0x6adc77b3, 0x6cf4fcc5, 0x3ceff446, 0x3afd2763, 0x516ac77b,
	0xb1537bff, 0xff55b17e, 0x8a31fa19, 0x0e387bbf, 0xdce334fd, 0xf4c00ecf,
	0x3d63b5a4, 0x26e8ef7e, 0x345ffd85, 0x129bfcd7, 0x57b5b8dd, 0xa1b2cf6c,
	0xf977ec1f, 0x2e777e3c, 0xdc78d9f3, 0x0cfc9f88, 0x1fb70e13, 0x37c6a7c3,
	0x62967734, 0x45af84f8, 0xe4e98e39, 0x664656b0, 0x38ff9b60, 0x6bdb53a6,
	0x2dbcd0cb, 0x38e9af7f, 0x088ef7a6, 0x7bf10efc, 0x45319ee8, 0x3271813f,
	0x8b179dee, 0xe6d64df6, 0xe4fd89f0, 0x7bd1b63f, 0xfec5ddb6, 0xdbc60906,
	0xb89dfaad, 0xca4eed0f, 0x4d7e92b2, 0xeb495da8, 0x70cb181c, 0x4095bb9d,
	0x07f3da0c, 0x1bd1fdc4, 0xfd207f60, 0x7963f2bb, 0x9f4207fe, 0x4efc516d,
	0xc0c30b8a, 0x850bb470, 0x7cc8d65d, 0xca11b8a9, 0xfd085f6e, 0x5c7dbb84,
	0x7e2eeb8f, 0x5beac63e, 0xa7a38ec1, 0x7a6ed6a4, 0x8e6c9aca, 0x0673069b,
	0x3d4595fb, 0xff6885d4, 0x845af3e1, 0xdfe0ff61, 0x3f7c620b, 0x74bcbb74,
	0x5fcc60df, 0x45fd051e, 0x7fce19f0, 0x9dbbab8e, 0x0873ae31, 0xd22c8f5f,
	0x9fde01dd, 0x2198df31, 0x67bf88aa, 0x23e715aa, 0x3ac0f989, 0x89f311ac,
	0xebeb47a8, 0x52d3379a, 0x1f593bf9, 0x9967efe3, 0xdfac472a, 0x253bf0e3,
	0x0aad07da, 0xb35baff2, 0xb7047bd2, 0x8ef457eb, 0x031d7a20, 0x3cd26487,
	0xb9c3287f, 0x5d33d609, 0xcb9431f3, 0xb23e2a1f, 0xcb0164a3, 0x92eedc49,
	0xb6664c27, 0x49caf588, 0x74dea993, 0xcefe8fa8, 0x1a71c5e9, 0xd60cebf2,
	0x73f0af5c, 0x981cf1c0, 0xe2632e5f, 0x1e3c60fb, 0x23f0165d, 0x6456cf95,
	0xae04f8aa, 0xed0f35a9, 0x5397bba2, 0xbafd519c, 0xdf386de9, 0x5b3bbcd4,
	0xffdca113, 0x2b3ba705, 0x01c27ee4, 0x1c5364bb, 0x804ada73, 0x03d9ef23,
	0xc1f81866, 0x2be0df54, 0x415ca597, 0xf71ac23b, 0x985cced5, 0xfbe1ecbf,
	0x6cb45837, 0x7a9eb0de, 0x095f07a2, 0x29f41bfc, 0xe9c3921b, 0x6778e2ef,
	0x66f39a9d, 0x37e2274e, 0xabc613fa, 0xf8c5b103, 0x2932bafa, 0xdd40ef84,
	0x3259f55d, 0x4e9a35d2, 0x9dce8e59, 0x1afeb8b9, 0x47bbc52b, 0x88ec15e3,
	0xcf91339b, 0x395124d6, 0x3afc53e4, 0xf5752446, 0x9b06f523, 0xfaad71e9,
	0x4ed0b30f, 0xce6b271e, 0x7a2a4d4f, 0xf9146f23, 0x664e341f, 0x7aee7973,
	0xa7d15d33, 0x453c7a84, 0x5efc2163, 0xe7a5b7db, 0x6503a4f4, 0xae93d5cc,
	0xf7a5df06, 0xffcf5deb, 0xf4f9e855, 0x1e7a6538, 0x2b64f9ea, 0xf10c7fd9,
	0x93a3f007, 0xc7076c6d, 0xf582e4af, 0x1426c714, 0xcbdf3c62, 0x166f454d,
	0x5272fc00, 0x1e2c42bf, 0xef79d3f2, 0x427804ce, 0xc6217272, 0x06756f57,
	0xc8bd7f48, 0x715a27c2, 0xd1b36c1f, 0xa7d37ff9, 0x48c9955b, 0xff918d67,
	0x23c798ce, 0xe739f843, 0x4fdd3637, 0x6653337a, 0xd8fdf807, 0xf41b5f57,
	0x8a1f7ee0, 0x7c2d962f, 0xb6ad7e8d, 0xf4c5f696, 0x3f20e602, 0xda2afb7b,
	0xd2c7d777, 0x28e6b2f7, 0x7841dfcd, 0xb32f45ce, 0x34737f42, 0xef08b6d5,
	0x393d848b, 0x256cd157, 0xcf1a6a98, 0x79fcf277, 0xe7f28f8a, 0xef9e3e69,
	0x9bf8e7e2, 0x083dbd15, 0x4aecddfd, 0x9bbfb154, 0xbf2f3f35, 0xb7f2a0e2,
	0xf6875ce0, 0x574633a5, 0xe74dfd70, 0x6e3efcad, 0xafbd2c69, 0x6a2ae2d9,
	0xe931efc3, 0x877a5695, 0xbd10f607, 0xf8adde97, 0x5ef4bde9, 0xeb869b56,
	0x4e72b17c, 0x8bdfca03, 0x5f7a5649, 0x4acfa2f5, 0x407a5f71, 0x051defe6,
	0x9558bcbf, 0xca9fdf4e, 0x3ca26442, 0x7d24eedc, 0x1e2f05b0, 0x7f557eb1,
	0xfc28cf7e, 0x518d0f0f, 0xe3cd7ee8, 0x02f0fb10, 0x70ffff6e, 0x1cb13582,
	0x0e70fde5, 0xfe06e3bd, 0x5c9bc932, 0xc3ea9939, 0xbf20a13e, 0x7f78d4cf,
	0x21ad8775, 0x02ec83c4, 0x1eba477e, 0x7c8ef464, 0x65dbe577, 0xd26e10fd,
	0x13f38934, 0x5d3205e9, 0xabaeab61, 0xf0827c5c, 0xe4aad4b0, 0x1fee7d52,
	0xf93a5bad, 0x90c1e220, 0x5d0e4367, 0x5e400fa8, 0xf5a2a35c, 0xf4f8468d,
	0x38a64e16, 0xa01a1953, 0xe7643f9c, 0x4c917af9, 0xa57256f7, 0x7786561c,
	0xd17f77cb, 0xd0e42caf, 0x26e598a5, 0xbe59b0ff, 0xfa72161e, 0xb8cb0b10,
	0xa3177d2e, 0x513966f7, 0xb358ca72, 0xfea3f705, 0x17f9cc6b, 0x8d193d84,
	0xbb3c6887, 0x17bd7296, 0x75eecebd, 0x441b4d35, 0x75f2b2eb, 0xeb96bd09,
	0x73f2907a, 0x55535935, 0xbd0ae70c, 0x727d02ad, 0x8860cb0e, 0xad2abd02,
	0x9cbea20f, 0xd6a4cba9, 0xd276b166, 0xf75ad70b, 0x8abfe116, 0xfaf4675e,
	0xd1221bee, 0x03b3d2fa, 0xd28fb27e, 0x6c8fb264, 0x3484e0eb, 0xfb899f02,
	0x8998dc77, 0x361ceb76, 0xefd9ea14, 0xbfa0ad5e, 0x62d436d9, 0x7f393df8,
	0xd7f9c7dd, 0x2f333296, 0x864d9df2, 0x1436d936, 0xfebf4fef, 0xf460c4f2,
	0xa369be27, 0xb3eb47f5, 0xb1bfa2e1, 0xc838e61d, 0xa363e7f1, 0x71ccf6e2,
	0xf4ae9390, 0xcbdb8a8f, 0x1bdb8a8e, 0xa29f2a6a, 0xdb8a8c8c, 0xb7151f1b,
	0x67826a57, 0x8a88cde4, 0x826b9bdb, 0x8efe2a6f, 0x6f857ea9, 0x6e7ca989,
	0xf2a61df9, 0x9977fd9b, 0xef2a5be0, 0x105fd533, 0x7f9533a8, 0x4c0fe567,
	0x7a2fa0e5, 0x0f1727f5, 0xfa82e7e5, 0x7d3b5f54, 0xde040bf0, 0x2fbecbdf,
	0x24677229, 0x9c7d3dfd, 0xca1dee23, 0x8d4797f7, 0xca9e8873, 0xcfc2c7fd,
	0xc987660a, 0x371e1b0f, 0x9fe789dd, 0x8296874c, 0x2dfb37fb, 0x276037df,
	0x965bdd35, 0xf54e53dc, 0xd16425d6, 0x60c3cafd, 0x0740074f, 0x7c7887d6,
	0xac1d7f4b, 0x5fefc86e, 0xebd4290f, 0x7e4ec57f, 0xb079aeda, 0x4befea72,
	0xcc686f71, 0x05fa2f73, 0x733e781d, 0xd37cca52, 0x86385fb8, 0x6bc07bd7,
	0x0c6a47dc, 0xdb1775fb, 0x1c8f8a75, 0xc3b56a15, 0x3f41eb7c, 0x1f093362,
	0x2fbd43d1, 0xeb3c5a5d, 0x5a462f05, 0xf7a54c17, 0x61a5ae3f, 0x2e5d06dd,
	0xc7e47a1d, 0xae38c10f, 0x27dfe300, 0x1fabfa1a, 0xd63d77e3, 0xaf89550f,
	0xf3c732dd, 0x77bedb9e, 0xcbea10e1, 0x47bd2f04, 0xb94f2e8c, 0xaf17e37d,
	0xcf7ca55d, 0xb8fe7bc2, 0x6fed6aec, 0x4b6670db, 0xf35f7944, 0x99fd5d97,
	0x320f822f, 0xb677e6ec, 0x943f5a46, 0xe335efef, 0x9c97e4ec, 0xa136052d,
	0xee3e7f3c, 0x0db3ddff, 0x76567dda, 0x87d436f9, 0xf98f5f90, 0xfaf08f50,
	0x0ca5fa59, 0x0a1f4fcc, 0xb3ee3e76, 0xf8d7ac31, 0xfe8a5fbd, 0x4eaa94e5,
	0xd827873a, 0xb69f8c55, 0x7cc66339, 0x96b18fd8, 0x2340bf28, 0x9f61bf9e,
	0x3e75d2de, 0x9da2a7f6, 0x67e884f9, 0xe603908f, 0x2bbde9d4, 0xa98a8289,
	0x23f50e7c, 0x8d7d43de, 0x760991f7, 0x1495978a, 0x48ebc527, 0x03f9314a,
	0xe3b03824, 0xd5db8ffd, 0xd685e74e, 0x03ac3184, 0x63c291c6, 0x0ae5dca9,
	0xfe4f3c33, 0x66bbc0d2, 0x9cdbb73e, 0xdf779a2e, 0x02ff73fd, 0xa03fa3e6,
	0xf35138c7, 0x3cb0f1c0, 0xf8fd9c7a, 0x93b4371d, 0xf57b3b97, 0x6879fc53,
	0xd7d411c9, 0x9d8e8e99, 0xbe3ca237, 0x35debbd3, 0x0fdb8c52, 0xa39de845,
	0x27fc7943, 0x2287ebc6, 0xfcb8c5c6, 0x4c281848, 0x860835ef, 0x23a064ad,
	0xdf98331c, 0x9278d037, 0x89f3a35d, 0x909b4e31, 0x4bc0d3d7, 0xe714ae74,
	0xb720bde9, 0x541c3e98, 0x07db0ec8, 0x63f085f2, 0x50d29541, 0x03d28f30,
	0x0fca8d41, 0x7e098b06, 0xf823e832, 0xd29cb070, 0xca7e82a7, 0x49583a7f,
	0x01822ff0, 0x2b839b4a, 0x60d9ff29, 0x8247c12d, 0x15fe081b, 0x78b97dda,
	0xe940d0af, 0x2a26c18b, 0x97b8297f, 0x218257e0, 0xc3c1c34a, 0xd8347f94,
	0x60f1f04c, 0x07afc10b, 0x05b704c3, 0x237d28db, 0x6ff94ed8, 0xf823df05,
	0xd04eb113, 0x8082a783, 0x56859497, 0x94b8ed15, 0x94e78b85, 0x52a7bc01,
	0xdec077a6, 0xfd85f205, 0x6b0f17c0, 0xf6db9d32, 0xff92b4ac, 0x76e2af46,
	0x75aa9ee3, 0x3e54a509, 0x329bca8f, 0xdaeec962, 0xf64ed4bb, 0xb7156ba9,
	0x1732d957, 0xca1577d5, 0xcaf0fe54, 0xd7f42179, 0x8014e235, 0xfaacd3f9,
	0x6f5829f6, 0xf3f495b1, 0x6cff28de, 0x4fa7014c, 0xe94c814c, 0xf463871d,
	0xeac5fbc8, 0x5c1304e6, 0x7fa692d3, 0x7737c118, 0x7ad87188, 0xa77e4726,
	0xefbdd3f1, 0x75832fce, 0xc40a577e, 0x3e3e0014, 0x3e7677db, 0x756647a8,
	0x9e51da76, 0xefbdd93c, 0x8c0ac343, 0x13d4b67b, 0x9a3dbf88, 0xa3dbf84c,
	0x839e9fad, 0x328587e7, 0x6522f77d, 0x9e05fca1, 0x902ffa57, 0x6ba89de9,
	0x3d7e4c95, 0xf02ad0b6, 0xddd69eb1, 0x2a3cc17f, 0x8b7bae57, 0x55dee1fc,
	0xa0a7dbc7, 0xcaf8025d, 0x4c1c3a25, 0x34d7fbc0, 0x9bdd3fe1, 0x6a714b14,
	0xf619f3d1, 0x86cfc5df, 0xac33f13e, 0x2c3cfc37, 0x17f785de, 0xc68879df,
	0xd51df193, 0x1f3f1987, 0x1fb9ebe8, 0x995eba3e, 0x8ac63f98, 0xaa5877d1,
	0xfb1fd265, 0x20fb6858, 0x7a65c7b2, 0xe4d0fc57, 0xc3f667d5, 0x020aea7c,
	0xffa802be, 0x147c9948, 0x72c4fa6d, 0x6b75ffde, 0xaf9127e4, 0x3d575f80,
	0xddb6f509, 0x106a7a9a, 0xb574fda4, 0xeea8fd15, 0x05a5f7eb, 0xd37b7cc4,
	0x5d8473fb, 0xfc27cfbd, 0x5dfcd5a0, 0xaed56b8c, 0xdc7ce3fc, 0x6f0788d9,
	0xf0d34bc6, 0xbcea0413, 0xd20d8b4e, 0x9df285fe, 0x3be39e38, 0xbc7027a9,
	0x8c67dd64, 0x7de38857, 0xdc653c53, 0xdbd2965b, 0xf4bef07b, 0xe0f4b5e1,
	0xcef10292, 0x801b006b, 0x5b21f07a, 0xf59bf907, 0x320f5c53, 0xe1de912d,
	0x57d38f45, 0x829dc8dc, 0x7e0e694e, 0xeedd106f, 0x12e75d7b, 0x7fb1e05d,
	0x4d57c505, 0xf2f7c591, 0xd7a79d19, 0x9b2ac495, 0xf2af72ae, 0xd05fea20,
	0x980a6b57, 0x1a7d27e8, 0xfbcac7ef, 0x24eec899, 0xe8a5c4b8, 0xefe7f157,
	0x62d4fd12, 0x87ef303f, 0x73b95d6e, 0xdf1ffa0b, 0x9c0c51b4, 0x24ec0a5b,
	0x895bf3bd, 0x6b5e5fce, 0x1163aad3, 0xeb14edfd, 0x3013ee31, 0xb720a3de,
	0xb5215efb, 0x1140ce0a, 0xedda36f8, 0xfefbe028, 0x377d5f23, 0x0a1de281,
	0x7da0c7d7, 0x893987b7, 0xb0b65c0f, 0x3f811852, 0x8f7f8597, 0xcffe7a27,
	0xfb8dd815, 0x18c9577c, 0xfc640fbc, 0x51ea32bd, 0x3c0497f4, 0x0b4bbbfc,
	0x02319ddf, 0x659725fd, 0x2ef047ba, 0xb0efe58b, 0xf8a56cff, 0xdf8457a0,
	0x65b586ef, 0x152d2ef4, 0xee173853, 0xc02873c5, 0x2d323613, 0x2e03ed8c,
	0xbc4def3a, 0x3c8d9f22, 0x60ab21b7, 0x33cfe37f, 0xef8f13f2, 0xd0ef4d94,
	0xd7379ec6, 0x684bfa07, 0x9876a4ff, 0xfd08a5eb, 0x0aed1def, 0x44282371,
	0x6dfef3eb, 0xed297e4f, 0xffa4b113, 0x9264d11f, 0xb94647e7, 0x6dbd63f6,
	0xcf01764e, 0x4e05ee81, 0xab40f505, 0xaaf49637, 0xd92c646b, 0x8fd2dbc7,
	0x714ed13a, 0x41577e8c, 0x23a07e3b, 0xd07d1fb0, 0x9d2c146f, 0xf4963a9f,
	0x8877f778, 0xc1df618b, 0x2f0414c7, 0xe9ac8ddb, 0x21d2b42e, 0xa582adfe,
	0x7cf7f9bb, 0x995e689b, 0xc7843292, 0xabc17619, 0xe8d29fd1, 0xfe875c4a,
	0xeb859748, 0x0223cbcd, 0xec2f50a7, 0xe825eab7, 0xd7494c6f, 0x9e0fdc02,
	0x0b65f244, 0x4f5186d4, 0xce456a34, 0xe436f948, 0xfdcadbe4, 0x6c7ef08f,
	0xffe5b5f4, 0x25f6fd5a, 0xe7ccbfe7, 0x39d7d772, 0x47c738df, 0xdb9c67f7,
	0xb7843aff, 0xb9f422df, 0xabdec67e, 0x8c385fde, 0x116293eb, 0xa93b30af,
	0x3f3bbe9c, 0x3190ef5b, 0x1870b37e, 0x24f79bb7, 0x610e29bb, 0xa30b264f,
	0xc05f5c1f, 0x2bda07f7, 0xc8b29f88, 0x6968d50f, 0xbc6cf457, 0x48ab0cd7,
	0xb39c2f27, 0x1a39f7f0, 0xe886b56f, 0x40a17a3b, 0x0ecf7e0c, 0xfdd931fa,
	0xfc40fd3d, 0x3f8634bb, 0x6007bf19, 0xb8b3f08f, 0x1ff77b2b, 0xc334ec4d,
	0xe198ae93, 0xdefe6612, 0x0cd3a94c, 0x70cc514f, 0x47ae30c6, 0xe7354c6e,
	0x70cd534f, 0x620705ff, 0x073dfcac, 0x2b8ca3f9, 0x2ef7f85d, 0x0806bdfa,
	0x7f307b20, 0x63a03ad7, 0xc683e90d, 0xfc926607, 0xd25ffb47, 0x1b2b6018,
	0xfce6cdfd, 0xad45bc94, 0xaded3618, 0xb553f68a, 0xe0097dd3, 0x239f94c3,
	0x20d0e3e4, 0xef79b71e, 0x6198c088, 0x71e7bba3, 0xba1cd768, 0x03d9b307,
	0xcb48254d, 0xb6bfdc31, 0xdd74e655, 0x6e9c29aa, 0x6f74692d, 0x2d10a295,
	0xd023b158, 0xcee4fe80, 0x2efa56d1, 0x72e26b07, 0xbc01d4c6, 0x439f025e,
	0x3af9d74b, 0x1d97fa40, 0xfe7e4f5f, 0x7d32553d, 0xa9cd3bf7, 0xac13dc53,
	0x4fc992f3, 0x02edf065, 0xeb021f7e, 0x3ac39535, 0xe5f9992f, 0xb193a241,
	0x3d57945e, 0xa7280f02, 0x8f7d447a, 0x3c44a816, 0xe646bca0, 0xd874e4c7,
	0x58b47de8, 0x6b725f4f, 0x71628de8, 0x9fc46cef, 0x1a63165d, 0x45eb67f1,
	0xc78b6adc, 0x95cb878c, 0x708fc993, 0x6c6e7db9, 0x463917a0, 0xb83ba0bd,
	0x1b74c05e, 0xdfb943b4, 0x69a2d5fd, 0x09ea1e38, 0x12bbe23d, 0xbff7117f,
	0xd9ddb0ff, 0x98e77608, 0xccf3bb08, 0xc7593ebf, 0x38dceec8, 0x3d59d60c,
	0x377f2cf0, 0xf5c3be2f, 0x48176117, 0xfaaf9c71, 0xebaef78a, 0xe2759b8e,
	0x78a8a5ba, 0xf8514bbd, 0x65f0275a, 0x64a4bfb4, 0xb52e9e11, 0xc2fb3a95,
	0x93fa1313, 0x8f89fd09, 0x9e976713, 0xc1ac9f59, 0xadec3afe, 0x8b1df8f9,
	0x199c77d9, 0xf3700195, 0xfc38f7b0, 0x06473393, 0xe1f4d540, 0x47f8721f,
	0x6ba72e67, 0x5b9eb728, 0x1e16bbf0, 0xcc62bf71, 0xd0ef18d7, 0xd48f6e30,
	0xf3a3886c, 0x24fd933c, 0x3f5e7577, 0x4f3fcf9d, 0xfde0f4ea, 0xa7724d41,
	0xf455f177, 0x0f06cd7e, 0x50618f6f, 0x882e3063, 0x231cd5cb, 0x1cdcbf2e,
	0xacf1ef97, 0x60e7bd26, 0x217a82ba, 0x7ba3e9c6, 0x55c3e1f2, 0x4ccdcf9a,
	0xe4f7e4ab, 0x67d22e6a, 0x5e961df6, 0x0b5fc3ed, 0xd7270e7d, 0x132e346f,
	0x16e601ef, 0x84ca7a8b, 0x9b9c71e7, 0x682dbead, 0xec6efc17, 0x4f7a64c2,
	0x8698e22f, 0x3bbbbf76, 0x73de6df8, 0xd0a11e9e, 0x40bf0cbc, 0xa3fff85f,
	0xf1baafd8, 0x667f23ef, 0xe38fa25d, 0x6cf4e95f, 0x7427fc42, 0xf417377a,
	0x741ecebd, 0x19f75a88, 0x3c2683bc, 0xe5f212e9, 0xd064f0b5, 0xaaeb88c1,
	0x64b9a8b3, 0x6fee5cb7, 0x2fe273f2, 0xbdddf9a2, 0xf11ab1f3, 0xaa7b20dd,
	0xb649fc9f, 0xe30f2d24, 0x2efeeb8d, 0x9d7f1af5, 0xe3f39c34, 0xf92c4f26,
	0x763cea95, 0x7ab52bf2, 0xc8df9076, 0x784adae9, 0x3034f329, 0xcfab7b8c,
	0x9bfccd62, 0xdfb8e60b, 0xbcadcf7a, 0x5967cbdc, 0x57d0dd3f, 0xcfeb6e5c,
	0xefa8f16a, 0x2cdf93f5, 0xe0ee57ee, 0x57d21bbf, 0x3a7127b9, 0xd8f5fb8f,
	0x8a57ee29, 0x16f6d7b7, 0xf0417bf7, 0x2fae2b6b, 0x2763d709, 0x9758db7b,
	0x8af1e553, 0xf9071f98, 0xbf403576, 0xffac6333, 0xda9530c2, 0x6a1df51b,
	0x0efd432d, 0x3ea2a67c, 0x0477c495, 0x8bc8bf71, 0xf8c68bd0, 0x71b30e1f,
	0x1e14d4be, 0xfbe4e697, 0xf6dfecc3, 0x3b9dbf1e, 0xe4adf2dc, 0x399be0cb,
	0x62e71e56, 0x973cf1c8, 0xc1f687dd, 0xc52a573c, 0xd403cce1, 0xa88c4f9f,
	0xfc2dc37f, 0x91aca8fd, 0xf19df39f, 0x077f9e93, 0xba61b7c0, 0xa7b7a788,
	0xd4fde8d9, 0xc3e616db, 0x9c746623, 0x309fdfa1, 0x37898f05, 0x8f533ccd,
	0x60f67edb, 0x0e37ef46, 0x4c76aa79, 0x8c276460, 0x1cfc8e1f, 0xef8298a8,
	0x1654e625, 0x6bf586be, 0xfc37be84, 0x197135be, 0x92178a21, 0xc9c32502,
	0xecf1fbff, 0xceef1232, 0x653efa0c, 0xfff27d77, 0x51bfd446, 0x49993fd4,
	0xdf49d71c, 0x14a4b82b, 0x3b080475, 0x1a240e3c, 0xc8a748bf, 0x3d3b45df,
	0xc3b2ed42, 0x1e1d9459, 0xde20ff09, 0xdcc3e639, 0xd1aa7dee, 0xf9dfbbd6,
	0x1de2e185, 0xe2b72183, 0x02c9c13e, 0xb24410f4, 0x7a3db9f8, 0x9ea7a9f8,
	0xa3db76f2, 0x643ec5db, 0x139b13f4, 0x8c58c2a2, 0xa2d4812f, 0x651f88f8,
	0x875536a5, 0x5bfb6d75, 0xb7d6efef, 0x34d9fe0b, 0xac549ef0, 0xf206a65f,
	0xe78e8d30, 0x3cb19ade, 0xeb72e50f, 0xd57f6374, 0xeb7bae28, 0x780ff559,
	0xc1bfa84f, 0x075bbae3, 0x38c14a0e, 0x4d9b5726, 0xa51c5abe, 0xbd55e41d,
	0x8bb6be8a, 0x8f5b9b77, 0xefe2758e, 0x15756cfa, 0xec7de3b5, 0x11525756,
	0x665ccf1d, 0x3c5cb97a, 0x71a5ce8e, 0xc5cbb6bf, 0x788cdce3, 0xaf81d69b,
	0x7a8c3e13, 0xbb5f044b, 0x22cefe34, 0x7aa26b46, 0xdf4fd94e, 0x312672b7,
	0x15393ff2, 0xf8407bfe, 0x2f67533d, 0x9c355af2, 0x82d6ebcb, 0x34c9f6a2,
	0x3145593f, 0x945a9ad9, 0xf1147a4a, 0xdcebed0e, 0x478b785d, 0x7a13ee3c,
	0xaea7e8d4, 0xb6f3af95, 0xca8b3b0d, 0xe8bda1fa, 0x75f9107f, 0x13b16bab,
	0xf72549e3, 0xf7f6aba8, 0x95fd9f64, 0x491b2a8c, 0xf943edfd, 0x0a45dc92,
	0xbd6367f6, 0xb3626eff, 0x71ae4fa1, 0xbf37816f, 0xc6101df4, 0xb84b5c44,
	0xa2e9f957, 0x888fb88f, 0xdb0ff76e, 0xbf660d8f, 0xc78dd825, 0x05d55f10,
	0x4c9f5f67, 0xdc6edc39, 0xcbbe2b12, 0x593fec24, 0x58b7f5e1, 0xe3503bf9,
	0x3d86677b, 0xc57b8b28, 0x63c37dae, 0x0a97f3c6, 0xe97c67f7, 0x8967e462,
	0xdf2fdb96, 0xc77a663a, 0x4facfb80, 0xa298d5d8, 0x8c1be8bd, 0x7e5c47f7,
	0x9d46b90d, 0x5dd5fa87, 0xbf10fea9, 0xac52e477, 0x0ef1159a, 0xdb7c49fc,
	0xea480ef5, 0x1dcaced5, 0x496fe9c1, 0x8e48d2a9, 0xdefce15d, 0xf79f78e4,
	0xdb947cad, 0xadfbdd7d, 0x5678fc42, 0x9089294d, 0x867de363, 0x13baffd1,
	0x75c89453, 0x83fdeb5d, 0xbb8eece7, 0xf2f5bf68, 0xfb7ff6fd, 0xaf16c43d,
	0xefee257d, 0xdeb3162d, 0xd7046ebd, 0xbe05fdb7, 0x7a6457dc, 0x4145fe77,
	0xf0046e20, 0xafeacd8f, 0xafbbbd44, 0xe5539f96, 0xa7f21c84, 0x3d375bec,
	0x90209e2a, 0xde422230, 0xa4ec1b8a, 0xfce1eacf, 0x28b9e740, 0xcbd346ba,
	0xbb01bfa0, 0x9afdf92b, 0x1492ef41, 0xe5c45857, 0x4de1fd92, 0xbd416e5a,
	0x580cade5, 0xdfac6e02, 0xafbe7a4e, 0xe70fef7a, 0xdf5194fb, 0x70bbfd85,
	0x67e4457e, 0x853a84bb, 0xff7b03ee, 0xa3dfb45d, 0xf1cd18b2, 0x71fd44e3,
	0xf7429a74, 0xde0ec281, 0xebcde222, 0x5f4e5194, 0x61297b44, 0x04727394,
	0xe1f5d49f, 0xc2395a37, 0x29871bf0, 0xe988cf8e, 0xc16ed097, 0x7c973db8,
	0x40afcbb1, 0xd37282e7, 0xf18d0f77, 0xe75fbefb, 0x32a5fd7c, 0xf273ce8a,
	0xc007b058, 0x2c24b07e, 0x45f68ebd, 0x14f1e05b, 0xa3f9338c, 0x4f6be283,
	0x10ecf90b, 0x1e97d9f2, 0x7a51d9d3, 0x1d99b834, 0xc01c47c7, 0xc8f14527,
	0x56e97527, 0x918cfdd3, 0xce211f2e, 0x31db7d0f, 0x7d1f22b7, 0x20263b0b,
	0x18ec9bea, 0xef2253b4, 0xf13ed1d1, 0xb44de845, 0x3b267c4f, 0xa676e146,
	0x3f7e2355, 0x3a5b5369, 0x27271f00, 0x7777d3c6, 0xfbf8e3b2, 0xcf6893da,
	0xf6dd8115, 0x58393393, 0xeba5b66f, 0x7ec219bb, 0xfd830464, 0x4fca1776,
	0xc6aff305, 0xe4359fdf, 0x7fdf8987, 0x277d16b9, 0x1f904e00, 0xb7fbe1b6,
	0x56ff7a02, 0xdc3ddbde, 0x06f8bacf, 0x5fc328b6, 0xaa007847, 0x7ac1f844,
	0xfca2f7f8, 0xe94ee879, 0xeecdf38a, 0x57db7f59, 0xa0bbd0cf, 0x6da64ac6,
	0x8d35f806, 0x06366bdf, 0x4dd9c918, 0x5c7f66c5, 0xf78dfe23, 0x7d194baa,
	0x67c2b427, 0x1e5b9f2e, 0xb369ddfd, 0xbf66ee9f, 0x7abe7a2d, 0x80d99c64,
	0x7fc9ab5d, 0x8bb7ed17, 0xbe91d7f6, 0xfd714519, 0xf68fb7e4, 0x671ab9db,
	0xaddfe05e, 0x77a72dac, 0x8656e914, 0x3f68d47e, 0x88f7d75e, 0xbe458f99,
	0x2fbe342b, 0xe5605de2, 0x27d54ddf, 0x175a7951, 0x12ae7c1d, 0xbcbaf76f,
	0xfaaeb277, 0x7bd3d7e4, 0x97e1975f, 0x6b082d4c, 0x134fc861, 0xe2ab4cf8,
	0x9b7584f8, 0xed0e15ee, 0xdfa16cda, 0xfa3008cd, 0xc1e0193e, 0xdac0ef7c,
	0x7eb0ae89, 0xd3ac3e53, 0x28bd7dfc, 0x765afefb, 0x595da1fd, 0xd9bf7ebd,
	0x507f0d48, 0x76113f0f, 0xc3fa4800, 0x373f7108, 0xfb430d8c, 0x3d60bbc7,
	0xd012e1d1, 0xf316e281, 0xdb9fbf7a, 0xf7e1fd01, 0x908ffe8c, 0x5fc33a93,
	0xc0f3be29, 0xe3c5327c, 0x5cf98a5b, 0x5cfcfd2d, 0x02c00ae8, 0x7bdf4618,
	0x9f9c6270, 0x73a4e3c5, 0x3001c39e, 0x7c420f7e, 0x9a299b3f, 0x1bc1c793,
	0xd10895df, 0xeafa2577, 0x971ef8d7, 0x5fa33f31, 0xc3f747a6, 0xb574b7bf,
	0xbc5e307e, 0xf35d3f47, 0x8eff2329, 0xf0be9f31, 0xe1f35ffe, 0x80001f43,
	0x00008000, 0x00088b1f, 0x00000000, 0xcfedff00, 0x51832f3f, 0x53e00714,
	0xa4a8912a, 0x48837f83, 0x8a4d2443, 0xc12b2874, 0x0c1a3166, 0x3168c184,
	0x1f16a46b, 0x47e926c0, 0x9b1a11f0, 0x34b560cd, 0xea29f122, 0x225546de,
	0x39ed8306, 0x3dee7dc3, 0x9ef7f737, 0x6f18a237, 0x6f57e8d5, 0x88cdaf34,
	0x9d9788e9, 0xca58f5e7, 0x9988f9e7, 0xd418c388, 0x9c7cff56, 0x14bc95b7,
	0x7111b8a3, 0x7b9eb832, 0x8a991d5a, 0xd44c5ee8, 0x71b90a6f, 0x45ab7e58,
	0xa37b9a14, 0xf3dfdabd, 0xab98e6be, 0xe64fec2c, 0xcf396ece, 0xe5ebc83b,
	0xfc69fcda, 0x4afd5ff2, 0x62eca5f9, 0x0d3b6b44, 0x6eb888d9, 0xb699bb44,
	0xf7eda9a5, 0xf5325ae2, 0xef9fe3ba, 0xbf759f3f, 0xe2aeb5e5, 0xdc853eec,
	0x5e37965e, 0xe1f9d2c7, 0xe9ab2a31, 0x8547ea57, 0xdf7c95eb, 0x2fba7a89,
	0xcd3f5275, 0x2f3f5b3d, 0x34f9d2b4, 0x94e72ce7, 0x70fac476, 0x9483d9de,
	0x6f7e1d53, 0xb3cbbfd0, 0x4924934f, 0x92492492, 0x24924924, 0x49249249,
	0x92492492, 0x24924924, 0x49249249, 0x92492492, 0x24924924, 0x49249249,
	0x92492492, 0x24924924, 0xe60fdbff, 0x004746e3, 0x00004746, 0x00088b1f,
	0x00000000, 0xc5edff00, 0x30000d41, 0x4bb10008, 0x78f930d0, 0x4fdac845,
	0x6b57aa77, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0xc7f6db6d, 0xa6af781f, 0x00800060, 0x00000000, 0x00088b1f, 0x00000000,
	0xc5edff00, 0x30000d41, 0x4bb10008, 0x78f930d0, 0x4fdac845, 0x6b57aa77,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xc7f6db6d,
	0xa6af781f, 0x00800060, 0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00,
	0x30000d41, 0x4bb10008, 0x78f930d0, 0x4fdac845, 0x6b57aa77, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xc7f6db6d, 0xa6af781f,
	0x00800060, 0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41,
	0x4bb10008, 0x78f930d0, 0x4fdac845, 0x6b57aa77, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xc7f6db6d, 0xa6af781f, 0x00800060,
	0x00000000, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x00088b1f,
	0x00000000, 0xe753ff00, 0x51f86062, 0x3897c10f, 0x71de1819, 0x0143f822,
	0x68433177, 0x0606162e, 0x6366201e, 0x67606062, 0x25bf5e22, 0x817d8207,
	0x3761819d, 0x1f665f10, 0x240d7f78, 0x9fa6e04e, 0x68e91b5d, 0x1d783117,
	0x06c3033f, 0x30860601, 0xb5ff0841, 0x7afcaa20, 0x419b047e, 0x78bb328c,
	0x0d4fd428, 0x47ea000c, 0x040014d9, 0x00000400, 0x00088b1f, 0x00000000,
	0x7dd5ff00, 0x45547809, 0xbedd70b6, 0x97a7774b, 0x42c84274, 0x20087420,
	0x4026c60a, 0x2126f1d8, 0x41803a21, 0x946f7040, 0x08b20425, 0x1bcc79bc,
	0x418ddfdf, 0xb89c65c4, 0xe1f01bcc, 0x51a0834c, 0x31183483, 0x16699268,
	0xdef28c33, 0xc751d1c4, 0xb22a2665, 0xf4044909, 0xbc8c3331, 0x76eaa73a,
	0x36e9bdf7, 0x7df79971, 0x8b4fbe7f, 0xd56f75ba, 0x39d5b3a9, 0x4b554ea7,
	0x5f249d92, 0xf825c84d, 0x22ebe5a3, 0xa45c6421, 0x3eec2aec, 0xf1085246,
	0x3bdd95ef, 0xdf844204, 0x8f574238, 0x56c8e425, 0xf5a66021, 0x108dab50,
	0x65b33f5a, 0x4d9cc04e, 0x66d1fec8, 0xb33fde15, 0x45eb00bd, 0x29d1fd2f,
	0x97caf6d1, 0xa6ea0944, 0x0ece93d6, 0xe6d5213b, 0xd32787f6, 0x892fdde7,
	0x8a1d1b64, 0x244c8bf8, 0x16639095, 0xb02efec2, 0xab2b52fa, 0x7fdd6e56,
	0xde5bf41b, 0xda562664, 0x65bee54f, 0xfad327b3, 0x8132c3b2, 0xac772a57,
	0xfad00653, 0x841080f2, 0x1fad3dfa, 0x855d38e0, 0x8a383ca4, 0x0b3e5390,
	0xeb465f71, 0xf9d4f6ce, 0x604579f4, 0x5fbc0977, 0x4c7820d1, 0x2d8afdf4,
	0xfe843ffb, 0xa1e51a2b, 0x457fed22, 0x47b88dbd, 0x112fb1b0, 0xd992c798,
	0xefe56f00, 0xf5a66264, 0x15ab8bf2, 0xea923802, 0x8c073294, 0x76e288ff,
	0x718738c0, 0x959f0d1c, 0xe871d2cf, 0x082f5577, 0x955a981e, 0x9e017889,
	0x85d67dce, 0x5e61d94f, 0xf0e194eb, 0x14fbbefd, 0x60596f78, 0x1bab5ed1,
	0x94aadbe0, 0xb65b9c00, 0x45474b2a, 0xff515bfa, 0x63ae0e86, 0xbcd2729b,
	0xf2c6ed51, 0xb7108f94, 0x20af5239, 0x01da0d44, 0xe73280ee, 0xf3f3c8ca,
	0x7bd21242, 0xdc48bd45, 0x94ff4896, 0xa7f48430, 0xfd23ffff, 0x8b41f027,
	0x3b23b023, 0x2e55af42, 0x84776ffa, 0x9c5d675e, 0x7e77527e, 0xf95aff74,
	0xc281d030, 0x6173e753, 0x1d2fa8f9, 0x6e7dc7cb, 0xf87fdbc4, 0xc9b96046,
	0x4fe7c1e7, 0xb96026f8, 0xf962a7c5, 0x96295f2b, 0xbe195f01, 0x10b7cdb7,
	0x2f3eedcb, 0x57da7f3e, 0xafbd658e, 0xe73f9f06, 0x83658b5b, 0x5fcf8fcf,
	0x32c46df0, 0x72c3abe8, 0x96136f8f, 0xbe00be8d, 0x8f57d7b7, 0x882f9365,
	0x35f15fcf, 0x0becd961, 0xf40ad961, 0xd7c865a5, 0xdf01e58e, 0xf21e587b,
	0x6d77e075, 0x3e5813be, 0x9ceef1c4, 0x8a240a42, 0x5c4aa737, 0xf2485c54,
	0xa640b54c, 0x5632e4f5, 0x5fc5bd4f, 0xaa7ad0a0, 0x1e29d697, 0x150cac07,
	0x407d6998, 0xbacf6b0d, 0x685a149b, 0xdacfcb3d, 0x16a43c87, 0x487d695a,
	0xbe1f6b1d, 0x40985fc5, 0xac03c3eb, 0x50868afd, 0xafd68da1, 0xdcf6b208,
	0xa7645266, 0xab10dcf5, 0x8b511de7, 0xd79eb41c, 0x1ff9eace, 0xb49c8bfa,
	0xbec1df9e, 0x543a749f, 0x93eb4894, 0xb4fb59ba, 0x8bba648b, 0x0111a7d6,
	0x82f685eb, 0x5eb449e9, 0x92f562e8, 0x77248b81, 0x956bfe0c, 0x9424ee3b,
	0xd7fdea17, 0xad0652a9, 0x89ab1d2b, 0xbfd3e287, 0x9921eb10, 0x23f6862c,
	0x34aa45fe, 0xb215d691, 0xecffda06, 0x03f6c0af, 0xbbdb1bb2, 0xfdb1abfd,
	0x76c6e280, 0xb1bbbad3, 0xb156487e, 0xbddd653d, 0x4521fef8, 0xebe1f6c5,
	0x9b7ac61e, 0x09f6c5ec, 0xef897eeb, 0x6c5e29b7, 0x407d747f, 0xffeb4e9d,
	0x01b77829, 0xde0ad75f, 0xfc039272, 0xa32f4c1a, 0x2041bafc, 0x1e3e410b,
	0xf2a6a600, 0x514321b0, 0xfeb5bf41, 0x5129ff23, 0x029dbce0, 0x3f4fa5f5,
	0x3cfd8d90, 0xb4c8fd8f, 0x7ef7b11f, 0x413d7da6, 0xafb4cfd7, 0x1a7eb5cb,
	0x6b5abde1, 0xfd69fadf, 0x9e1e927a, 0x7eb42baf, 0x471fb05a, 0xed35e6df,
	0x3c3d14d2, 0xfd6a5697, 0x493f61b4, 0x2427837d, 0x13f5d78f, 0xfd699792,
	0xe9fb1efc, 0x547837df, 0x1faea265, 0xf5ae5955, 0x93f61ef3, 0x427eb7d1,
	0x3c3d64ca, 0x9fad0aca, 0x419fb18f, 0x6a979b7d, 0xc787aa9e, 0x73f5a95c,
	0xdd9ee90a, 0x380e7eb7, 0xe039f8f4, 0x1ce7e308, 0x6fac33c2, 0xea742af3,
	0x0ce853f1, 0xf622e7e3, 0xfadf7973, 0xe3d4e039, 0x8c3380e7, 0x7980591f,
	0x79b7d95d, 0xf1ea2615, 0xc6189853, 0x7800538f, 0x9e0df746, 0xf8f5fd43,
	0x8c3fd439, 0x6784349f, 0x99e0df5c, 0xcfc7aa9e, 0x7e30d4f4, 0xc4cf08dc,
	0x2873f5be, 0x439f8f55, 0x5cfc61a9, 0xed4cfd8e, 0xa7a6bcdb, 0x3d33f1e9,
	0x3c9f8c2d, 0x5bc0a7ec, 0xda10f08f, 0x3f7e238f, 0xf8f4836d, 0xc6141b69,
	0xa7ec64cf, 0xd393f698, 0x59253f7b, 0x6494fc7a, 0x1d33f185, 0xdf4d7cf1,
	0xd2cb69fa, 0x2b2da7e3, 0xd8599f8c, 0xcdbeaccf, 0x1eb064ab, 0x1983253f,
	0x4696ae7e, 0xd7433ae3, 0x3f488f4e, 0x40b03199, 0xa2fbe815, 0x9745d58b,
	0x23dd8087, 0x690cf66a, 0xbefa4557, 0xef2921bd, 0xd76d1201, 0xf80ade14,
	0x2f2b5071, 0x9c49aeda, 0xa3b3a090, 0x5d64d492, 0x00e95fbd, 0xcbfdfbdd,
	0xd3dae886, 0x6ba15e16, 0xe9e6f0cf, 0x93e599ea, 0xaa0fef74, 0x07d5d429,
	0xf756bdaf, 0x7affb67e, 0xe3673d5d, 0x87f7ba4d, 0x6ba1ddd5, 0x85536cbf,
	0xc0f2fdae, 0x647d5d2a, 0xdee9bffd, 0x8f7832bf, 0xa6aafdae, 0xa3ed7407,
	0xeaea8f43, 0xa13f0e63, 0xfb5c7f7b, 0xf8fb5d36, 0xb5d39ef7, 0xa3d8ec4f,
	0xf13e4fab, 0xa9fdee8a, 0xf57407dd, 0xaebc2fab, 0xbc80bf7b, 0x2db7b7a5,
	0x2fdee81f, 0x6baa7d76, 0xb9fe919f, 0xbbb54ec1, 0x75e48d8e, 0xa08ae411,
	0x50cfe25f, 0x390d5ed0, 0x032bac14, 0x714fccec, 0xa51f752c, 0xb81ca3fc,
	0x7c829dd3, 0xdda8ff49, 0xfca03050, 0xfcfa0eb2, 0x97bc93c7, 0x1ff3e8b9,
	0x5cabde2b, 0xca1bec31, 0x8749026f, 0xd2826dd2, 0xcc9f7ed8, 0xf330bdf8,
	0xe98ff0e2, 0xeea6d5f7, 0x3eb449e1, 0x82082c40, 0x4c15ec7c, 0x88275768,
	0x4bde06a4, 0x9bf41330, 0x7fcecbee, 0x0f251fca, 0x3b51071b, 0xbbf48843,
	0xa3a6f651, 0x23eeb51d, 0x1b39d83f, 0x0d79d106, 0xe155e420, 0x287f90a3,
	0xd2d07efd, 0xcfed2f74, 0x233f50ac, 0x8e857c7a, 0x0fc70a3f, 0xc1b43c81,
	0x8e7ae3f8, 0x41321e6f, 0xab25be37, 0x45be375c, 0xa8bbe3a1, 0x33eeb87f,
	0xc2253e3e, 0x10de4224, 0xcdf1c33e, 0xfe38e559, 0xbbf50a7d, 0x084fc7a2,
	0xf30edf8f, 0xfcde277f, 0xcfd24c87, 0x3f42ab3f, 0xffcd857f, 0xf86775fd,
	0xff3809f8, 0x6c33840f, 0x6c1559fe, 0x6fd666fe, 0x18677c78, 0xfe301dff,
	0x9be338b1, 0xe7e8a673, 0x7ea5783f, 0xfe3666fe, 0xf25f75a9, 0xfe38edf1,
	0x6c97c2e7, 0xe25783fe, 0xebd98af8, 0x3251fe01, 0x74026a13, 0x2a90327c,
	0x176034be, 0x23940e3a, 0x10d0a992, 0x821843b2, 0x8138fc70, 0x0957dbf1,
	0x9f50df94, 0x0939f1f9, 0x4f99cd50, 0xebce46fd, 0x140a1a2b, 0x4ed87bd0,
	0x1c25adfd, 0x224dc5d4, 0xdc7937f2, 0xe146181c, 0xfd126ced, 0xf8fc5f50,
	0xd7e800d4, 0xbdb9336a, 0x4893be0c, 0xf67f9e08, 0x45b72b8b, 0x2e58cbcf,
	0x758f93a9, 0xd85bc944, 0x23242c0f, 0xc57c286a, 0x22e304c0, 0x1fa84ff5,
	0x87f18e07, 0xd421efd4, 0x6654f9ff, 0xfa99fde3, 0xa0ef507b, 0xce3a1efe,
	0x477e1d64, 0x9d3b7bbb, 0xe1c65fc2, 0xf26244ff, 0x422dc9fa, 0xf3e54fc0,
	0x468c9fab, 0xb5f6faff, 0x08f48a36, 0xfdfc8b1c, 0x2f3a7574, 0x7ba9d03f,
	0x4db0399f, 0x01bafc40, 0x3450735f, 0x6373b909, 0xe475c526, 0x675b77fd,
	0x424e09b5, 0x9caa206e, 0x75bfdf46, 0x45c8308d, 0x9aaf9dc7, 0xa43ad8f3,
	0xae509a66, 0x0269a649, 0x8e37d721, 0x640f6996, 0xd27f2a8e, 0xdcee3511,
	0x7e7d7d52, 0x29debe99, 0xc289b2ab, 0x204739d5, 0x0bbf695b, 0xb5dbea16,
	0x929a8671, 0x78f99d19, 0x19271465, 0x2802d1f4, 0x0bb1e0f3, 0xc5d0bce9,
	0xa9e0d5be, 0x212653be, 0xfdfde3f4, 0x9fd5d009, 0xe4ddef82, 0xc236f362,
	0xa8b650bb, 0x0b9e7465, 0xe0018917, 0xeffc236f, 0x5354dab7, 0x3e372d2e,
	0xcf531326, 0xbfe118f9, 0x4f9c6bd1, 0xfe758650, 0x73e372e6, 0x38c737c6,
	0xfe013ffd, 0xe071e5a0, 0x51ff0a0f, 0xbd111fce, 0xdaa3f8ca, 0xfc0d9dec,
	0x2459bdd0, 0x2fce5748, 0x597e7037, 0x0be7a752, 0xd032bc42, 0x2142d971,
	0x3e2881ef, 0x60f9c058, 0xdf3d26d9, 0x72fc4adc, 0xdcba0c46, 0x7bd6f8f8,
	0xe73dddd3, 0x9be711f7, 0x8fda1f9b, 0x4f39e9f8, 0x38dba746, 0xd1ad6e9d,
	0xe9c0dfb7, 0xeba72b7a, 0xbc8f4dc2, 0xb907d546, 0x41901dc9, 0xaa7fabde,
	0x4743b3d1, 0xa7a72f4f, 0x38dbce11, 0x09fb6f3d, 0xde11a7a3, 0x8ecf4e0e,
	0x3264e74d, 0x46bc27a4, 0xdb5f6ef8, 0xd7183e63, 0x4d8fe45a, 0x82a6eacf,
	0x9ea347d5, 0x59af0657, 0xce4a347d, 0xd1cfd456, 0x6e0797d5, 0x6cbfbdd4,
	0xfb5d22d3, 0xbae5ba92, 0xde373bf6, 0xf22faba5, 0xfef744ff, 0xe9d76bed,
	0xb9ad6fda, 0x737ed75f, 0xfaba23f9, 0xbacdde8d, 0xdc2c17f7, 0x5f9f6baa,
	0x7daeacf6, 0x5d6ee96e, 0x4fba8e7d, 0xbad0bef7, 0xae07707c, 0xa75fdeab,
	0x4ff3bc41, 0xa353e466, 0xe2f4d3be, 0x9f1b9f51, 0xc08df31f, 0x83cf84f2,
	0x26f94fcf, 0xf40eb960, 0x4c175d37, 0xfd5958fb, 0xc0c1a2e8, 0x7c5c9a17,
	0x40b27b2a, 0x0fa6f6cf, 0x7a8df7b5, 0xc665fe8f, 0x72b453b2, 0x60ca40a5,
	0x76e2ec1d, 0x6adcf6ba, 0x21027662, 0x52b960f7, 0x72bb7261, 0x7121464f,
	0xbc343d42, 0x5fbf1ec6, 0x3e701412, 0x7472ea4b, 0x34db2e70, 0x36df00d2,
	0x81e5abe4, 0x2be7ba31, 0xbeeb27ea, 0x445fbd3b, 0xc640aaf8, 0x5672c227,
	0xf409bef6, 0xd660e867, 0x5e012bdc, 0x37ac03f5, 0xee7b47f5, 0xf574afb4,
	0xe78061d1, 0xf84f2c32, 0xcc796216, 0xa8f2c5e7, 0x4fcb1caf, 0x7658357c,
	0xf962d6f8, 0xcb1f9f67, 0xb11b7d0f, 0x8757df7c, 0x4dbe7be5, 0x0be3be58,
	0xafb6f960, 0xf83fcb1e, 0xfbb65882, 0xf4ecb09a, 0xf26a58a9, 0x832fc512,
	0x45f8a233, 0x7e9a7fd3, 0xe5f9c13c, 0x2c4bf014, 0xe7a6d8be, 0x0d72e38b,
	0x1f5185f2, 0xd460e91a, 0x1f95df7f, 0xfc40fd66, 0xa677a110, 0xbd39de81,
	0x8c5d3bd1, 0x932cf7a2, 0xe9c3c18b, 0x1bc020fd, 0x862f5ec3, 0x945c7dc5,
	0x9816a41d, 0xc5587d60, 0x03e817f7, 0x63e59fac, 0xdaeed2d7, 0x8c0a5ed1,
	0x767c7d00, 0x4386dfc4, 0x7becfe7c, 0xf1d92894, 0x5fa467e7, 0x78c03c5c,
	0x01a5d5f4, 0x3d7e974a, 0x0c09addb, 0x291356af, 0xb8bd7425, 0x9ed3d87f,
	0x5d61463b, 0x7df0c922, 0x11c733c0, 0x836a5fa3, 0xc37b7e02, 0xabe3ad6b,
	0xd8efe85c, 0x87cf7f13, 0xd9899672, 0x450709a1, 0xe84987b4, 0x37e00f29,
	0x9ecdefac, 0x77638874, 0xb85c530f, 0x3d22931e, 0x3a85fcfe, 0x714fddfc,
	0x59eb8ed4, 0x6fe23a5d, 0x33c357e8, 0xdebf80fa, 0xf86f64f4, 0xfde603bc,
	0x6f67c04f, 0xbd37abfa, 0x0bf75445, 0x5dfe744d, 0x3de657ad, 0xbf7186e0,
	0xbedadf19, 0xff1e1195, 0xaee3e4b7, 0xdb8f8d54, 0xe71d08b3, 0xb397970c,
	0x0225978d, 0xf4fdc25d, 0x37e14f42, 0xfe81651f, 0xefad933a, 0x7f633eef,
	0xae110a89, 0x143ae3a2, 0xb2122485, 0x89d6f45a, 0x3a7837e8, 0xb78fe0fc,
	0x6eb53cda, 0xfd4ec7f0, 0x3d0dc877, 0xb3f6fdeb, 0x82729f87, 0x5d2ab37f,
	0x831a39ac, 0x19595a8e, 0x47b1aecc, 0xfa4d01fb, 0xa13ad9fa, 0x72f38834,
	0x12bbce27, 0xcd5701d6, 0x72f41951, 0x3f5a963a, 0x1c15d2ab, 0xe99fd287,
	0xd4248691, 0x167ca733, 0x8687ef7c, 0x113f5e23, 0xa7c91a38, 0xb1107bf4,
	0xdff1394b, 0xd2072b8f, 0x91e20579, 0x0afe59a4, 0xfd2b37fc, 0xe810d2ef,
	0xd6bac257, 0xf450756f, 0xe782af9b, 0xe8f1ba0d, 0x0f6d6e77, 0x2f8bbe16,
	0xa639126f, 0xdba53bf1, 0xf17ef8ef, 0x8d6b7a8a, 0xd24c2ede, 0x329babd5,
	0x2276746a, 0xe10c03fc, 0xf6048285, 0x7ece4aee, 0x237d925d, 0x0876d1f0,
	0x0bbf01f6, 0x4b4abdec, 0x8fa5e287, 0x40e4bd56, 0x23d57cff, 0x7ee08042,
	0x7e076924, 0xef0263bd, 0x2a8522e0, 0x5d1fd23f, 0xd6898941, 0x6d35e4ef,
	0xc68ef45f, 0xdd613315, 0xd1f88cfa, 0xd6293cdf, 0xb3fc43e5, 0x5155b822,
	0xa989df81, 0x0cf3e414, 0x4c7383f9, 0x179e3c94, 0x3bd39415, 0x63edea37,
	0xeaeb37ea, 0xebe936cb, 0xa9f5c94b, 0xf4be1fb0, 0x04049971, 0xf6fa1bd0,
	0xfb0ba2a3, 0x366a465d, 0x69ff3ac0, 0x261b98e3, 0x7e5f1e03, 0x0ae21f32,
	0x4ce6d077, 0xea2aafaa, 0xc038c4df, 0x397f1db7, 0x73d79f7c, 0x3d5e6d5c,
	0x1e398bf6, 0x3505eb2a, 0x175d6310, 0xaffb8124, 0x4b872c7e, 0x209c5d2e,
	0xceff50cf, 0x744291fc, 0xf45db1fc, 0x33fa900e, 0x48ff007e, 0xef15ba90,
	0xbd3fe9f7, 0x7fc3ff47, 0xd207fed0, 0xfd75f3fe, 0xfda0fde7, 0xff01ed0f,
	0x57fd58b4, 0xaf73bcbe, 0x8a87ea9f, 0x1270bf5d, 0xa527422a, 0xa50f54ba,
	0xf71dcaef, 0x27ce813a, 0xf813bf24, 0x2c4064ee, 0x7f58c40d, 0xb70248d6,
	0x00bb54ff, 0x27f82971, 0x73d4ffed, 0xfebfa20f, 0x85d90ed5, 0x737aa6f1,
	0xaae54cc8, 0x4cf971aa, 0x8ff58b92, 0x2fbefd59, 0xe937a844, 0x99e2aff9,
	0xfe42a45f, 0x1e14e504, 0x7da1097f, 0xb3fdb55a, 0xaa675812, 0x83ca3749,
	0xff183bf1, 0xb3ea3242, 0xcf624a45, 0xfa270a76, 0x2f1cd5d1, 0x7e0f8dd5,
	0x5fe13a21, 0x1adfe81d, 0x76e72fdf, 0x91c912e6, 0xd49a8c72, 0x0f193c64,
	0x07c34dfa, 0x533b3009, 0x5cc9f97c, 0xde9e2b88, 0x885386fe, 0x176693c2,
	0xf9de0d9f, 0xf1dc57eb, 0x952767f5, 0x467b68b3, 0x4ddc7f5b, 0x666e3edc,
	0xe4394ae5, 0x95973c84, 0x9f8f655b, 0xf3b95e3e, 0x809fa7a9, 0xcc9fdf38,
	0xffb4619e, 0x7b5f3b15, 0xafad1267, 0xcca72dd8, 0x0bb0d364, 0x54ba11a9,
	0xe6d6ffd3, 0xf150e845, 0xfb8a6be2, 0xeefcf64a, 0x563d08e4, 0x90afdeec,
	0xa3e27b2b, 0xe95fb828, 0x4ba0c7b0, 0x5812e3f0, 0xff97c5ef, 0x4fdd00a1,
	0x2d240ab6, 0xb73e063b, 0x39eb86be, 0xc8e909e0, 0x9ba614e9, 0x4a6afde1,
	0x1abfd017, 0x33ed8c9d, 0x638c9f40, 0x01de41fd, 0x5e17e7e5, 0xf7a0bc81,
	0x7f981ecd, 0x9dab0bf9, 0x52e38f30, 0x27ebe30d, 0xe9554def, 0x3fb2e5b8,
	0x7b2585d5, 0x7fabfe5e, 0xf65b7e41, 0x62a4bfe6, 0x19a885bc, 0xfc3b5c26,
	0x25bf3019, 0xfce3e65b, 0xf22f1296, 0x6293f95d, 0x2fbfe819, 0x3bba5225,
	0xe29c5c86, 0x36f8f07a, 0xbf3a544a, 0xc07974e3, 0x883f997c, 0x2f681d81,
	0xfe4045df, 0x85cf85ff, 0xff585cae, 0xb4e8c2d2, 0x7169325f, 0x5f8e8b40,
	0x0ed7dfb7, 0x483539f4, 0x887d834d, 0x39f9226a, 0xb44b843e, 0xe2cdf15f,
	0xe21f4634, 0x77f9f296, 0x822edd74, 0xbb7ef0e7, 0x75735aac, 0xd94b91df,
	0xf0d7f191, 0x09dc29f1, 0x4f1edeb0, 0xa6776d8d, 0xd3dc9aca, 0xbf8a3675,
	0xc99be4a2, 0x99fbf6fb, 0x1ef26b7c, 0xed0a5398, 0xf266dfe7, 0xfac1df03,
	0xa50ae143, 0x79fefb61, 0x3303ea02, 0xeb92c509, 0x6b9732ed, 0x27c6bb7d,
	0x48496e14, 0xc217e28c, 0x7ce3c7d6, 0xe3e961ff, 0x7d28bbf4, 0x39e30d59,
	0xc9a7f67b, 0xff2e32ed, 0x8ffc819f, 0xd93fc88c, 0xbe3ee4c2, 0xfa47e43d,
	0x4f0394ad, 0x4af2013f, 0x06efd3e5, 0x60cb9579, 0x1c379fde, 0x2a26e77c,
	0x35079f27, 0x4febd539, 0xef969ca3, 0xc9624719, 0x0f76e7e9, 0xf4a72989,
	0xb5394c79, 0xff1f2077, 0x0d4fe95f, 0xaf590e7f, 0x187d353f, 0x7d468f0f,
	0x8ee49cf8, 0xdfe90fa9, 0x27bf24db, 0xa77c69ff, 0xf3c55bf1, 0xef418395,
	0xe352f984, 0x6a5f30bb, 0xbe23d77c, 0xb19fc3a9, 0xa7d85dfd, 0xb2ccfb00,
	0xea51f679, 0x023c59f2, 0xa765f9ca, 0x690f984d, 0x3ee02b19, 0x124d88c6,
	0xb934dfd6, 0x395d81c6, 0x9fcbf27b, 0x7b7c84ff, 0x96bbfe7b, 0x7e7c532f,
	0x7d908c32, 0xbe08ca50, 0xf1c74d14, 0xeace0ccd, 0x04302423, 0x962a81f5,
	0xabbff945, 0xfcbfbcb9, 0x80319ee1, 0x51ae82c7, 0x27a81d89, 0x585fa387,
	0x59c6f5cd, 0xf4113bbf, 0x1ce6d9e9, 0x1ecefff4, 0xf2b11d16, 0xf4e59f11,
	0x5de21e7d, 0x4edaecb4, 0x6fca44ea, 0xed1ba45d, 0x0b76ff06, 0x3f6311d9,
	0xc59936ea, 0x3e2fbe9b, 0x8f80fe80, 0x251dad67, 0xd8ec3165, 0xd9df3e1a,
	0xeb8afe07, 0x5bcd15e3, 0x5d2f604d, 0xf3a4ddb1, 0xbe35cbe3, 0xc07923ce,
	0x580fb3d7, 0x8f01631d, 0xe40f4587, 0x7f37566d, 0xf86378a1, 0x43f9c679,
	0x3d6f60ff, 0xdc70bb29, 0x9de0e557, 0xcf578780, 0x7fec0858, 0x56ea53ed,
	0x5ef382c4, 0xefb9c185, 0x0fcba328, 0x2e829785, 0xe210a87b, 0xf209db33,
	0x133a4f6d, 0xf5b3f3e4, 0x1b2eb024, 0x7ab22de8, 0xe85c3503, 0x9f9414fb,
	0x2eef814d, 0xe4a35ed2, 0xdda6b2f3, 0xbdf40bcf, 0x65c166aa, 0x5255eda2,
	0x52fc0287, 0x822494dd, 0xd6ed1b1e, 0x575d51f2, 0xbfe28bce, 0xe7096527,
	0xabd27079, 0xce5e0337, 0xec08569d, 0xba87abdb, 0x5cf7af31, 0xb7e418f3,
	0xd17af378, 0x974f6647, 0xaf261fa1, 0x6a8e3a46, 0x27d5d048, 0x00077917,
	0x1dcdb35c, 0xf0313c6b, 0xf5b0a99e, 0xcf9287fd, 0xcb3ecade, 0xfc9adbef,
	0x28b2c57a, 0x53dd3bbe, 0xc962d37e, 0xee75aaef, 0xaaf79834, 0xc0349c96,
	0xc9dfaae7, 0xd5f163fd, 0x0bf31f4e, 0xddfcf177, 0xbf2a46ae, 0x6fc94557,
	0x18df9523, 0x7e77bd71, 0x09ddf960, 0xbe031bf2, 0xcdf90693, 0xe518fe6d,
	0xa4d1b737, 0xe8e91bcb, 0xfe857e55, 0x2ea052f3, 0xf4316c7b, 0xe201e035,
	0xdc78bb92, 0x3901c61e, 0x9dbe554e, 0x4ff23f1c, 0x2f55e396, 0xe973cc11,
	0xc7266f49, 0x3951f6ab, 0x4cee8016, 0x10b5578e, 0xc8314716, 0xf21e88ef,
	0x0aafbecb, 0x9babefb1, 0x0b797fb2, 0x954f2f1d, 0x7efa163d, 0xc79e445e,
	0xaa73cb45, 0x0f9e4712, 0x5f9e4df7, 0xe54cf2e2, 0x06278874, 0xfacd3d5d,
	0x2757ae7c, 0x11786f1e, 0x44bff2f8, 0x34de93f4, 0xbff6bb31, 0x0b1f1e27,
	0x871d717c, 0x43a73467, 0xfd8fcfa7, 0x9cda4c97, 0x7452720a, 0x203feea8,
	0xbb72ba6f, 0x561f404c, 0x7e8c7e35, 0xa2be31a8, 0x38c655d9, 0x8c47a68b,
	0xf5159671, 0xae74fafa, 0x1d88e657, 0xbdf92f08, 0x8311d9e8, 0x7af7b4ef,
	0xeeb879c0, 0x08d8fb1d, 0x7fc5bd9c, 0x06f479b4, 0x12af3697, 0x68cbcb85,
	0x83e20632, 0x2f288f14, 0x9c29d7fe, 0x0565af14, 0x0fe774c3, 0x8e7c7266,
	0x82282ba9, 0xc81cc4b0, 0x6a3f01af, 0xb06d5dd3, 0x3dee35ef, 0xd3981e77,
	0xbd992793, 0x6b3d4fe0, 0xd67946ed, 0x74e3e2e8, 0xbcfde729, 0x10a6a03a,
	0x49baadf8, 0x53bac170, 0x9e2bfa1d, 0xf9b838b3, 0xa3e012ab, 0xcb822de5,
	0x85f87c8c, 0x095e7e02, 0x9f817f5d, 0x817f34c6, 0x96f2ef76, 0x5fbe1102,
	0x84c04fbe, 0xd3f0def6, 0x3bfdba57, 0x804ec7a7, 0x76700edf, 0xc38d75b3,
	0x4b57b5a7, 0x45fc1d7e, 0x90d85c4f, 0x9b76e0c9, 0xc77811dd, 0x245de185,
	0x08fabce2, 0xdef786af, 0xe819f5e0, 0xe729fbf8, 0x9a441e30, 0xd7e4fa93,
	0x54b8db7c, 0xff476935, 0x6d4f8b4c, 0x2affbd17, 0x413b7f83, 0xa425e71f,
	0x3fd5e31b, 0xdfddff40, 0x17f83fd4, 0xfd6eba21, 0xc429e1b6, 0x3ee799f7,
	0x59740d9e, 0x2c48aaf1, 0x0d9d2e94, 0x7dc2120e, 0x7402808d, 0x551468a8,
	0xa148f78c, 0x688eb9fc, 0x7c32d47c, 0xe7f162ec, 0xc0e63d8a, 0xc57dfa4c,
	0xc1734fde, 0xa7bce99e, 0xfc132dbb, 0x9404e7fe, 0xc8efe263, 0x0a9d7d85,
	0x18b3ed89, 0x6157bbf1, 0x7de9e3eb, 0x0f2085b6, 0xe73b3d42, 0x205c1154,
	0xe1eca39b, 0xe38c8a9d, 0x4f30f7d2, 0x80acffcd, 0x5f005e79, 0x2d1b39f4,
	0xb3f4e67f, 0x68a92fcc, 0x5e700392, 0x777ea2aa, 0x2a49c427, 0xbae333de,
	0x05ff5d56, 0x768b75c6, 0xb1e764ed, 0x9f9d449a, 0xad3fc3dc, 0xf0664317,
	0x312b1aaf, 0x1feb4e5e, 0x3b183d63, 0x1f9bd34e, 0xcb5762b5, 0xe1453f5e,
	0x719f178a, 0xf6a9b9e2, 0x53f44e1d, 0x3e39bfeb, 0x0d1fc3d4, 0xfe8dffde,
	0x1fce29e8, 0xfef4517f, 0x87efa928, 0x2f852a7e, 0xbd862cbf, 0x9dfbe61e,
	0xe20afe5f, 0x7cf7a7a5, 0x77802bfe, 0x7ee7d7e5, 0x478a53f5, 0x81756ad2,
	0xee7eabfe, 0xd26f188f, 0xa6abfbbe, 0x067d9fa7, 0x7f9d74e3, 0xb7a07b32,
	0x59e396ce, 0xdceaaf10, 0xb054d7fd, 0x14b4d64f, 0xe6b5bda3, 0x1234a2a5,
	0x4ad03ec3, 0x1f40dbe0, 0x7a4684e2, 0x983c6c1d, 0xa19e7005, 0xbbb486f4,
	0x58217c70, 0x6e35e2c9, 0x8868571e, 0x11ed8f1d, 0x7b9c6847, 0x50b1d4dd,
	0xe9371eca, 0x6de13c43, 0xfaabc74a, 0xe606bf40, 0xdfa3c7b7, 0xa507f819,
	0x4f599a53, 0x971b2fbf, 0x6809fafc, 0x3717ec6b, 0x03ea109e, 0xef78b4de,
	0x621d4551, 0xf3d9b906, 0x806fc63c, 0x44e9336e, 0x997e773b, 0x13f27105,
	0x986df772, 0xc662d68f, 0x968aeffd, 0x3a7e5177, 0xed137a5f, 0xaee3c24d,
	0xc7fc249d, 0x973c64e2, 0x83bb7ab4, 0xfe3821c5, 0x76e14e21, 0x8f1e73e2,
	0xc5ac7c60, 0x27c5e229, 0xe10f326e, 0x8e2ca179, 0x03fdb952, 0x3ee21885,
	0x3ac884c2, 0x1a4e8f1f, 0x87805c1e, 0xb6f1d1f1, 0x70a071d8, 0x0bd3965c,
	0xb67107e8, 0xd68d3c70, 0x257c4207, 0x784bbc20, 0xf90c507d, 0xe2cadced,
	0x3eb29d75, 0x274224af, 0x6f9b8716, 0xdf36b7a0, 0xdea9d6de, 0xf16df1e6,
	0x748b0c54, 0x3af89eff, 0x3eb6317d, 0xbe166b5f, 0x3ce83edf, 0xf38fb8c1,
	0x9597c0af, 0x902b1f8d, 0x67ada877, 0x734f7cda, 0x73f4fc7b, 0x6ecde622,
	0x7d441e08, 0x551bd46e, 0x06224e70, 0x99980fbc, 0x626aaabe, 0x3de9c5eb,
	0xf69d808e, 0x3ec0fa73, 0x86aaebe4, 0xed3f158f, 0x45feadaf, 0x4c8ff985,
	0x08bd608e, 0xfa7fc144, 0x2cb9fd85, 0x7fecc8ce, 0xf89b38e3, 0xb1cdd538,
	0xf86ea9c7, 0x0ace3742, 0x7961507f, 0xde3cdfd0, 0x005d4929, 0x976a9dfd,
	0x9e41e409, 0xb1a58a0a, 0x6a7f29f6, 0xbd7c7996, 0xe9b1c58e, 0x52e789ba,
	0x8a1cec1c, 0xdc60ac98, 0xc2638d63, 0x71fe707b, 0x8371438d, 0x8ebb543f,
	0xfed513e5, 0xe81d27bb, 0x03749b5d, 0x0ceb65c6, 0xb8a575f8, 0x8a7ce00a,
	0x58d97a6b, 0xdea35760, 0x3a4d5249, 0x4a38d7f8, 0xce14dcd3, 0x381fb4f5,
	0x0f244a2f, 0x9d11939e, 0x1f30a525, 0x597265d1, 0x64c3c463, 0x46f1197b,
	0xe97645e1, 0x8b90b5cf, 0x8fd0dc63, 0xd2badfb6, 0x8d86ded2, 0xbe00552e,
	0x78fef892, 0xce173cc1, 0xf041abbb, 0xb5538b00, 0xb2a576ec, 0x3f58003c,
	0xe624f6ba, 0x43f0ab92, 0xc575d2a2, 0x0d0b9fc6, 0x5e83f7fb, 0x6a24ef5a,
	0x8a339512, 0x0398b755, 0x5b467be7, 0xd3e01c84, 0x55fbfe2f, 0x59b5afda,
	0xdf75b024, 0x80f2d765, 0x339024d4, 0xf308791b, 0x2f95803d, 0x69c08bf5,
	0xf02103cc, 0xe2f9d44a, 0xf18ed162, 0x445bb38e, 0x72456bf4, 0x30a72fc5,
	0x00049d3f, 0xacaebe7e, 0xa59e70e0, 0xde08612e, 0x1c60706f, 0xeeefd97e,
	0x3a01f944, 0x5fabe344, 0xdc6fdea9, 0xc2e67564, 0xab66cdfe, 0xc4941b73,
	0xde43b6af, 0x6fde62f1, 0x39fd32ff, 0x7e862a21, 0x709797f0, 0x697cfd79,
	0x87d061c9, 0x514bbd8b, 0xd42da7cf, 0xda32239f, 0xf6a112f3, 0x01abac22,
	0x312213c1, 0xb69bebf6, 0xd9bddc22, 0x2f1e1af7, 0x1cbcde81, 0x80ec49d0,
	0xb2faf8c7, 0x0c76fc17, 0xb194e5ff, 0xe6bf1edf, 0xad7e3d74, 0x6d7e3d6e,
	0xd3f88c23, 0xd1e1d7e3, 0x79b28be3, 0x9bf09be0, 0x2e7f4138, 0xdf859feb,
	0x3d7c2ccb, 0x7fa578e2, 0xa6549665, 0x0cee01b2, 0x61728429, 0x7b4ca394,
	0x0f7f8048, 0xc3ac094a, 0xcc0e3caf, 0xf3e74803, 0xefb31611, 0x2247206c,
	0x3941ebc0, 0xa0119382, 0x43e46de7, 0x102b31d7, 0x697253eb, 0xae7a7c64,
	0xe3e8739e, 0x5b57e83b, 0x42af7f80, 0x9fe7607e, 0x36a04992, 0xe3d4e41b,
	0xe83bf582, 0xcb1678b3, 0x789e0e70, 0xf3830f16, 0x1f2c2eef, 0x77ef63ce,
	0x8e78228d, 0x9f3a1822, 0x7aa9fa0a, 0xfd032909, 0x3dd2b0f7, 0x5fdcfc1b,
	0xe53ed95b, 0x7fcb2b34, 0xcb55b9f9, 0xbbfe9d07, 0x763ca9ab, 0x386ecb35,
	0xbcd5d7bf, 0xea0c32c3, 0x2b9e224d, 0xbbaa4eaf, 0x6cefc61c, 0x8b5c1996,
	0xe061812d, 0xb8c8b7cf, 0x9e2e741e, 0xc254e782, 0xdb335bf6, 0xfe6aec2f,
	0x946779d4, 0x7a6cef3e, 0x378872ec, 0xdec5366c, 0x31665ca7, 0x357f277d,
	0xf7d6febc, 0x6658d3c8, 0x0f147961, 0xa8f3a10f, 0xaf96739a, 0x261e4cc3,
	0x5a1f3a73, 0xffce2d7a, 0xd7ea66a5, 0x889479d3, 0x4ae8fcb7, 0x7f89cf3a,
	0x257e9894, 0xa945ccea, 0xbc0e88ec, 0x05fa0b5f, 0x5bdd6bf5, 0x038858e2,
	0x2dce044a, 0x8a59ad8c, 0x4eabd5fe, 0x2f94e7ca, 0x18e0d5f2, 0xcde9dbe0,
	0x408f7849, 0xed0487f5, 0x92ed71f9, 0xf9f33f8e, 0xc1df9aba, 0xdfe3f1e2,
	0xec4fb7d3, 0x50760c90, 0x93c5e300, 0xaf9fe84f, 0x49dcf8d7, 0x1fcf8152,
	0x900a28bf, 0x4dd5d4af, 0xb850f73c, 0x400f16bb, 0xc3ceba38, 0x5e5a2829,
	0xad634b14, 0x30b0bff7, 0x10acd8fe, 0x2f36675c, 0xc1bee3b5, 0x9815a581,
	0x4fd5fd07, 0x9d6383bc, 0x4fd28bab, 0x5e3f6c89, 0x8013244d, 0x0c0bd7bf,
	0xd11975ef, 0xa95a54fb, 0xdfc6b3f1, 0x2c675f1a, 0xcac6f04d, 0x995b7163,
	0x74b8569d, 0x9f80a084, 0xf1e02ad6, 0xbc7bcea4, 0x636afcba, 0x64f727e9,
	0x4dd53c02, 0xb6eed0e7, 0x8bcec734, 0x32716bda, 0xff1ef03f, 0xf8dfc83a,
	0xd04e1531, 0x7dfbf193, 0x2dacfd1c, 0x78854410, 0x116ea5a4, 0x625a6b9e,
	0x2e20db21, 0x5c65d52b, 0x2ffe00ef, 0x850366ba, 0x133289f7, 0x659bafae,
	0xafefc20f, 0x0de30424, 0xc0d51cfc, 0xf46b64d9, 0xa590aef9, 0xf68588e0,
	0xc2e2c47b, 0x3d79fbfe, 0xf9efc002, 0xc138ffc7, 0x60bae9ae, 0xe00e3a46,
	0xddf690fe, 0x53c30b71, 0x036d5595, 0x29e52039, 0xaf1e2728, 0x0c78b3d3,
	0x78a5239c, 0x08a3928f, 0xff38fcfd, 0x71d52f64, 0xbb649e14, 0xa892f909,
	0xe5a5dbaa, 0x5efe1029, 0x90905c94, 0x418f2040, 0xb342abd3, 0x39507210,
	0x87b16b18, 0x2e48efc0, 0x20a6f3a7, 0xf5858958, 0x0e9d2ed7, 0x3cc3539f,
	0xf997ca47, 0x304edc90, 0xaf12020f, 0xdf4d7fa0, 0x7d7a7a6a, 0x59794112,
	0xa81488ff, 0x916cfda5, 0x4f10ac3a, 0x85dd56c9, 0x2c9cf5b0, 0xdcfcf1b9,
	0x798272a0, 0x279cb637, 0x0b76c293, 0x5fd1fa15, 0x8ac7b78b, 0x6ab30feb,
	0x0176f2f8, 0x770f72be, 0xc6f3001f, 0x79e36563, 0x9da0b35e, 0xdc1fd61e,
	0xebe12b1e, 0xd8cfc4ef, 0x5d09323e, 0xf6e3a24d, 0xd9a1fd46, 0x76a71327,
	0xef8363dc, 0xa4e0c4fe, 0xddf0aadd, 0xb0df3e38, 0xe6ebe13e, 0x4faa66f8,
	0xcd79f7e8, 0x7c420e63, 0x2643ef3b, 0xc9f43dc7, 0xf808bf61, 0xc47aaefb,
	0x43a317c8, 0xfb792e54, 0x2f9c3728, 0x68eb8576, 0x7af55987, 0xd8ce6527,
	0x3973b434, 0xacf119bf, 0xee51b7c9, 0x0e7ad6f3, 0x2c5c199a, 0x87186d0e,
	0xdc381108, 0x8e97a039, 0x77ef6088, 0x503c5015, 0xfcb89ab8, 0x5c0f9d25,
	0xbc7ff303, 0xe4158679, 0x27af3be4, 0xa8ebf48d, 0xd151e4f5, 0x0e3ada3b,
	0xe02713d7, 0x79ff6aa1, 0x90849ebe, 0xa03961de, 0x271d1272, 0xc8dff8d1,
	0xd47c9aef, 0x1ce441c2, 0x60411f3c, 0x2085159d, 0x93378e1e, 0xabc02e2d,
	0x7f136f66, 0x6b7dda06, 0x2d9c6c5c, 0x1ac4bcfc, 0xfc969aab, 0xfab8fa0d,
	0xa2bff502, 0xa5aba0f2, 0xaacff46e, 0xfcf8282f, 0x4827e33b, 0xc3aa93f1,
	0xff6b7ccf, 0x0d19f89e, 0xffffd3f2, 0x8d2bf80b, 0x1dcfbdf4, 0xf1327f81,
	0xe541dabe, 0xc6f57f3f, 0x3f1b9b5a, 0xbf3d3b79, 0xe76b5ca7, 0xb1c9e317,
	0xafc75e51, 0xe1883bac, 0xb5e45e92, 0x1bfcc6da, 0xf41737fa, 0xb510a4d1,
	0xca7bb23b, 0xbf3e79ef, 0x00565b6a, 0xa1baedc6, 0xc3c8387b, 0x80fbd16a,
	0x30ea8115, 0xd82ec099, 0xf16ed047, 0x44ea3fec, 0xa7ef6d79, 0xae7a3f5b,
	0x47467eeb, 0xf1680ebe, 0xf289a14a, 0xc9a71d31, 0xf405fdea, 0x7e62eb5f,
	0x02181c25, 0x78b212fd, 0x1b73c137, 0xce013185, 0x65088c6b, 0x484838b3,
	0xe4f13727, 0x839066c4, 0xac379d20, 0x2eba7e4b, 0xc3e2130d, 0x89358373,
	0x076a8111, 0xe6063bb0, 0x15583613, 0x81bebcc1, 0xfd9cecb9, 0xaf763cc0,
	0xffae5ed7, 0x78b2b65f, 0x2c865687, 0xaf80bb65, 0xcdf88965, 0x6e1ddf79,
	0x83e21500, 0x2775564d, 0xaa52c3e0, 0x5d323ce2, 0x3a5023c4, 0x01414a66,
	0x5792a1f6, 0x171605ba, 0x811d6c24, 0x3997f692, 0x74005dd3, 0xf04a1ccf,
	0xd8264e1c, 0xa6e4312f, 0x3f7f2add, 0x47a1ba3b, 0x973b723e, 0xce85368b,
	0x964cdfb7, 0xc78e1c8f, 0xbf01f050, 0x701b8e9d, 0xb25f9db2, 0x127f06fc,
	0xafd1b3c3, 0xbcc18202, 0x57bf5e24, 0x19359221, 0xf03f1efd, 0x4164dfa5,
	0x3c46c7bf, 0xa783d041, 0xba6e2cad, 0x846cf041, 0x6ea5cffa, 0xa047dc0b,
	0xe7c683c9, 0xdeb94f0f, 0x9d57d123, 0x82e6cf53, 0xfdf94a4f, 0x73add038,
	0xebe1d9ca, 0x59dd2671, 0x5154ef8c, 0xd1a90797, 0xd1d649af, 0x8ef10acf,
	0x3ad5fa28, 0x4f601194, 0x1e090a77, 0x973a77f0, 0xc15e0c0b, 0x2129e7c2,
	0x30e3861f, 0x4ae11e3c, 0x35f846c8, 0xb5e74efd, 0x06b1e311, 0x79e7c3f8,
	0x8c77e70c, 0xdf847be7, 0x3880cacc, 0xe1d9e3e1, 0xe6064cf8, 0x7029956f,
	0xdb390ae7, 0xaafb436c, 0x459dd9da, 0x49439c62, 0x3cc6b0eb, 0x1495a567,
	0x4a04ce6f, 0x26b934d7, 0xda6cf409, 0x183f4cad, 0x2f9da1f1, 0xf7183fc4,
	0x0fadbf48, 0x544bbda0, 0x86d9cf56, 0xf2067f75, 0xc31712f1, 0x596b12cb,
	0x7fbeb46a, 0x924967dc, 0x3fbd48e4, 0x87fe778f, 0xe9a4feef, 0x61633f98,
	0x43624ff3, 0x9a72e05d, 0x19fece4a, 0x369649f6, 0xe7103cda, 0x0ef45778,
	0x9f1fa04f, 0x057bdd51, 0x046bf3f4, 0xd7f2a380, 0x1b227902, 0x8e2c23be,
	0xe53bc069, 0x63c58cbb, 0xe89be723, 0x621373fc, 0x4c974df0, 0x88c4849a,
	0xe468a7fc, 0xa347fae1, 0x13f00a7b, 0x51956bec, 0xdbc9a07d, 0x2a6afe10,
	0x1d18ddc6, 0x57fb7f9b, 0x539d67b0, 0x35be510b, 0x982320be, 0xfe82b2be,
	0x75b78a88, 0x083bbcb5, 0xfa3eb3f6, 0xd80e73f7, 0xd48bf8d7, 0x717d00ed,
	0x1cb7eee2, 0xd1fe7fb0, 0xbeefccdd, 0xcc07e0cd, 0xdaf86049, 0x0a56509a,
	0xf7ddbaf3, 0x128f3c0f, 0x596bebd6, 0x40797e7c, 0xd3839c34, 0x0cad4b9f,
	0xfaa1cf1a, 0x52959f11, 0x86f1b8ec, 0x585f1604, 0xc955b0de, 0xdef8c374,
	0x13fc609b, 0xd139cfdc, 0xd08beec8, 0x61a3b9e0, 0xffb602b4, 0x7ccd9a5f,
	0x665db73f, 0x099d507a, 0x8e5e33fb, 0x6d9c2337, 0x25cb1efc, 0xfed110bf,
	0x5ac7445e, 0xb789f54b, 0x1a97e599, 0x23e4b1e7, 0xfb9c0977, 0x80bf725e,
	0x7fbc1d7e, 0xdecbd537, 0x3ee1f7b5, 0xc69e718e, 0x73c6f473, 0xb03f9a3b,
	0x317fd38c, 0x4b7ee2f1, 0x66fffd8f, 0x8c6adfb6, 0x9c3d9d63, 0xdff98363,
	0xe8edc09d, 0xf61e327c, 0x1e1cf7f9, 0xf94df892, 0xb9f9a745, 0x2f3c53e3,
	0x608f84f1, 0x66e09a59, 0x6fcdccf9, 0x555f0096, 0xf3c6ed35, 0x3d76df46,
	0xe93e6ca8, 0xd64489bc, 0x3d1f6a05, 0x94817a0a, 0xa9bb3a09, 0xa7f52b6a,
	0x70f04487, 0x0b7e7f0b, 0x07f717cc, 0xb712fdd9, 0x47cf94ac, 0x44f24bdf,
	0xfb4f3e82, 0x351cf874, 0xd725479b, 0x8cfcda03, 0xc09a5cfc, 0xb78b45e2,
	0x8030d9cf, 0xe5b6b94e, 0xa7cf1678, 0x8d633cc7, 0xb0fc8c5f, 0x943637ec,
	0x9bdd30cf, 0x2e70867f, 0x8140bc79, 0xa9296fe5, 0xbfeec699, 0xfdf3a7f2,
	0x678874a6, 0x4607c6f4, 0x1dca777a, 0x469f2059, 0x39c6777a, 0xc254fce7,
	0x62d79c10, 0xf1025ab7, 0x6ca42595, 0x9d6a2b83, 0xb5d5213d, 0x66e414fd,
	0xb0dbe33b, 0x09a7031e, 0x6437918c, 0x3956875c, 0x5f7069dc, 0x2261d20e,
	0xfd9b5bec, 0xce369ef0, 0x0eaa9f31, 0xa5cf0195, 0x95f29e58, 0x458743a9,
	0x3e6e97da, 0x61f884e7, 0x718208d7, 0x1e874e85, 0x4412b7de, 0x9c5bfbc4,
	0xf6a52b0e, 0x9d003faf, 0xf71dbdb3, 0xe45d8fe3, 0xe68b8971, 0xecf358d2,
	0x3fb8104c, 0xb905eec0, 0x668dcb8d, 0xe9cedf37, 0xdb335b76, 0xcb63bd6f,
	0xe32fe41c, 0xb847173d, 0x51a8bdbd, 0xa461bd40, 0x8ccf12cf, 0xef5fa093,
	0xf7e0140c, 0x1e45e83d, 0xd0377462, 0xc5cd816d, 0x6a913dee, 0xe607b814,
	0x60547518, 0x1c456a7f, 0x66d5373d, 0x31f356fa, 0xfc1e23ce, 0xdbafb6cb,
	0xfcc08030, 0xdfc02b47, 0xf9b5f846, 0xd32a212f, 0xf1be7c37, 0xae3a45e6,
	0x3cf7fb66, 0x99bcb12e, 0xf5543bdd, 0x07f2c890, 0x83429c79, 0x38d7835f,
	0x2571128f, 0x6d768de6, 0xed6f3112, 0x03607f36, 0xdb7bc7dc, 0xcfd7017a,
	0xf4d27478, 0x501fb683, 0xf308b4d5, 0x1fb4bc78, 0x3ebaa7b0, 0x76a8b824,
	0x5ef0146d, 0x6cf4b894, 0xf12bf966, 0x7dd749e8, 0x4a62dba4, 0xe66207b7,
	0x43a81561, 0x0211f7a3, 0xa343a8d7, 0x104835f7, 0xd45619f3, 0xf73dd1cf,
	0xb9faf4d8, 0x3523f937, 0x34b3f3b1, 0x4fe4d379, 0xe005c793, 0x2edd8254,
	0xb332da05, 0xa08f3f01, 0xaef54d9d, 0xec71e36a, 0x552be91b, 0xe2e9cf9b,
	0x30264bd8, 0x67112d7a, 0xeb78f3e2, 0x4e83c505, 0xd36b5eff, 0x3befdfeb,
	0x9a1e6d1f, 0x33f3689c, 0x7bf189ca, 0xf8b43d23, 0x462e918f, 0xa669887a,
	0x12ef6011, 0xf903c131, 0xa9a662cb, 0x571d0f66, 0x51cb4c1c, 0x11eac690,
	0xaeb2d117, 0xf7089a68, 0x7ccad405, 0xcec4d83f, 0x09e38517, 0x68a76636,
	0x595b0ee5, 0xccfbe025, 0x6df3dbef, 0x76890e2c, 0xf70b8e2f, 0x6fd409d3,
	0xd7ae3c83, 0xe651e608, 0x808390a5, 0x27511b7f, 0x623e1c80, 0x117ee64b,
	0x7fa207db, 0xcc7a5099, 0x1edd17a6, 0x85b1ee42, 0x31fee18a, 0x7569a24f,
	0xf03fad36, 0xb862a1e0, 0x6993d6e7, 0x22ed973a, 0x5f07a1e4, 0x4d23ed63,
	0xfad086e7, 0xb1b60fc3, 0xa0b0d876, 0xc1eea10a, 0x47fb16df, 0xa62e38c1,
	0x91d41a77, 0x8992afc0, 0x01d25df9, 0xdaa2e305, 0x4a7aef3e, 0x1eaff003,
	0x61b5fce1, 0x36f3e15d, 0xaa153788, 0xdc77d86e, 0xff5d6b0e, 0x786a5eef,
	0xbc266d15, 0xc04a010f, 0x6f4e26ff, 0x51a42e8d, 0x6ef9091d, 0x848ea824,
	0x9b0ef878, 0xcf013ff7, 0x4fb48e63, 0xfc6f3e03, 0x78f9fbc3, 0xd660e42f,
	0xd42398cf, 0x39f3a636, 0xada0f2f3, 0x3b4bfbd1, 0x1b01056c, 0x03252fc5,
	0xdb82ebae, 0xeba16e45, 0x33f52d78, 0xf5481c95, 0x8dcddbd0, 0xa7b80140,
	0x1eaca138, 0x430323be, 0xf3895f2c, 0x1bf7b53b, 0x615779e0, 0x6113c3c7,
	0xfcc4cb5f, 0xdc9ed226, 0x2515bca7, 0x5bc62d77, 0xde9b3393, 0xe6e403bb,
	0xa77cec37, 0xc85cdd40, 0xbe15dadb, 0xffa082a7, 0x1e092368, 0x243c8bf4,
	0xfdca9fdd, 0xafe31360, 0xff28fc94, 0x7e8bcf80, 0xbdee1d3f, 0xfb636f18,
	0x229e7483, 0x89a327d8, 0xe031cb1b, 0xcb00e6cf, 0x0afeb179, 0x53f7be09,
	0x56a3ffda, 0xea5a4fe6, 0xf04e2e89, 0xdbad8db9, 0xbb321c03, 0x5e0e5047,
	0xe1377a0f, 0xbd02e20b, 0x22a4f5db, 0xe496fee1, 0xbdc611fa, 0x67184cdb,
	0xb80e467a, 0x7ddade20, 0x46dee4b9, 0x7175fd22, 0x3efd6bfa, 0x072fb8aa,
	0x83b07cff, 0x14cff3ad, 0xfbb07f30, 0xfd8012a4, 0x4b4ce490, 0xcbbef44d,
	0x595dfe51, 0x819fe162, 0x092d821f, 0xdf1fc604, 0x4a3c0d4a, 0xf21be79f,
	0xbb1fc0ac, 0x0f144700, 0x5dd766c9, 0x39f25fd0, 0x3e366f0a, 0x92bf1157,
	0xc522747b, 0xed6ba4ef, 0xe3a7b86e, 0x5af06b19, 0x69dafbcc, 0x767afbc2,
	0x50399e29, 0xedd675df, 0x33c2f882, 0x9c04c1d9, 0xce134ecf, 0xf7425767,
	0xdc28ab15, 0x30908c0f, 0x11b2450f, 0x720c92c9, 0x8bbee855, 0xf5c73f3e,
	0x93137ac3, 0x3776e1ab, 0xc740af9b, 0x0af783cf, 0xfdb49e50, 0x966eaef8,
	0x5e7fdfc7, 0x9d7c08bb, 0xd7f34730, 0xebf82243, 0xae08ca53, 0x72ec5377,
	0xa3ce8dc0, 0x0f945f6a, 0x7d3375f7, 0x95c3ed3e, 0x14a43718, 0xafee1b78,
	0x0997683f, 0x27db4bcc, 0xc9f39ab8, 0x5a21d254, 0x0bd4fb68, 0x86ca13c4,
	0xf1f539fb, 0xeb0da7c0, 0x5fef316f, 0x874d76ed, 0x90c405c7, 0xe4a9b537,
	0x0b29c424, 0x3f012a89, 0xed0c5915, 0xe13aceb0, 0xf3fd4f5e, 0x4f5f3b14,
	0x745648b2, 0xef16881e, 0x6d47162d, 0x54bdf5c6, 0x765e00f1, 0x6177d5db,
	0xdd4fcd7f, 0xbe241dbc, 0x63ed3d9c, 0x2e233af9, 0xd55c08d8, 0x0ed3f942,
	0x5362b9f3, 0xe74adf9d, 0xd650c57d, 0xe821f03f, 0x4c9ecb99, 0xff7a07e9,
	0x5a3fd710, 0xf01df1a9, 0xf1912b97, 0x88aaeb97, 0xb3b68e7c, 0x6f268d38,
	0xcfd077c0, 0xe6e0722b, 0x9445fb58, 0xfbdb475f, 0xda083cc3, 0x58660fb9,
	0x699c8216, 0x33b5ace3, 0x1b9637fe, 0x0fdaadd6, 0xbffbc8f7, 0xf4c7eb64,
	0x6f301701, 0x44df3c2a, 0xbbb56f06, 0xc86cee6e, 0x98cbb0e3, 0xcfca91a7,
	0x4bf3450d, 0x68bf1446, 0x6769d77c, 0x3fc6b07e, 0xc2defb45, 0x2fa2f4bc,
	0x93657109, 0xf1a73db0, 0x087f34cf, 0x11a651f7, 0xf919bf66, 0xfe1c4f67,
	0x96ef3829, 0xe0f56f40, 0x7f8cc39f, 0x040df1e2, 0x343d60ca, 0xbd2dcff2,
	0x2745cff2, 0x4b4d69e0, 0x9d37da51, 0xe9f26937, 0xe58cbbf3, 0xfcec5b44,
	0x4c89adbf, 0x7529f7be, 0xbd05ca3f, 0x01e4cb31, 0x23b940bd, 0xef0a7af3,
	0x1eed04be, 0xa81c9ace, 0x1e9896ef, 0x466cddda, 0xeedbb43d, 0x777e62f5,
	0x454f3b3a, 0xc4076f24, 0x2c033ca7, 0x8d7be8ee, 0x9c6cecf3, 0x789a1ca0,
	0xbf4ee21c, 0x61307c63, 0x4cdc1e56, 0x33163242, 0x84f630bd, 0xcf7e15b2,
	0xe051c722, 0x06db3e03, 0xe2f803ba, 0xd4e782a8, 0xa82a8eab, 0x7d6e5f1f,
	0x3fe204b3, 0xf8e09e5a, 0x292cde57, 0x33ef051c, 0xe71f7abd, 0xa98ead3b,
	0x0d2fa0d3, 0x244e78f7, 0xef198f4c, 0x3e032ce1, 0x1bb48dca, 0x260ca7ef,
	0x05887cb0, 0xe93b2dc4, 0x968f7310, 0x41d70bdd, 0x5ca9ef18, 0xed16ba10,
	0x7b6f79f7, 0xc953df63, 0x5f78c3f9, 0x1bc12862, 0xf9fc43b0, 0x9856f6f9,
	0xf5b37102, 0x8cd4a83b, 0x4d7a7e64, 0x2693f00e, 0xf147f887, 0x8468fc17,
	0xe3d49eee, 0x790f0f1c, 0xbfbe7624, 0x83fdc143, 0x5df6119f, 0xad63af90,
	0x78e807a0, 0xb85e6b79, 0x531ce019, 0xba041eae, 0xf1144a4c, 0xc849cff9,
	0xf3740392, 0x204e7848, 0x8e8bbb28, 0x88f7910b, 0xce023654, 0x3fd2bcf5,
	0x9f8c0c61, 0x07eef0e3, 0xfba911fa, 0x7e377c30, 0xd018de52, 0xebd1f6e3,
	0xa6bac1fb, 0x2ae14dc1, 0xc08f61dd, 0x02f5c1a1, 0xc71c97e7, 0x0780fda2,
	0x52f40ef8, 0x2cc7c7d3, 0x0fc6bdf0, 0x182f96c1, 0x05f1441f, 0x2f8441f0,
	0xaea1db84, 0x5e75e1e1, 0x9a1ff56a, 0xafbf342f, 0xbf00be57, 0xf89df9ce,
	0xabc053e2, 0x3b342f91, 0xdd75da8e, 0x97fd5ed0, 0x7c59c38b, 0xc771c58a,
	0x3937788b, 0x786cd3b5, 0x7a6774bf, 0xc1e70a91, 0xc66e32ab, 0xb9d5f292,
	0xb078c2ff, 0xd9abe903, 0xad1f1a83, 0x5fb00b16, 0xcf30428f, 0xd95ab480,
	0x9378aaef, 0xa2fc2e30, 0xf5d8c18b, 0x6a2cb1d1, 0x91d112c2, 0xdf96e4cc,
	0x243a3ce3, 0x9a3adda0, 0xd05b962a, 0x7a881c2e, 0x4df1c3d5, 0xdc02098e,
	0xa8b984cf, 0x86bf6099, 0xa3f8c1fa, 0x204333cd, 0xd36c7b3f, 0x793e6132,
	0x803929b6, 0xd623bdaf, 0xe04b01bc, 0x2fe501de, 0xec47776e, 0x1e7f4d31,
	0xe36adde4, 0x3f183b27, 0x73b2ad5d, 0x440eb005, 0x27ada1c3, 0x43805640,
	0x5d302d08, 0x6fdea1b2, 0xbe78a0ee, 0xf4a0e01a, 0x46902fd8, 0x4c0a37b0,
	0xd8114a6a, 0x1243fd8d, 0xf2d5d9c0, 0x1f882cd7, 0xedfe6ccd, 0x4cef007b,
	0xa3c57f6d, 0xda315fdf, 0xa4fd9ae9, 0x7d9a2df9, 0x68445125, 0x7fb41876,
	0x5dcf636e, 0xac33ef70, 0x9e0b2187, 0xacf47c67, 0xcb9572fb, 0x31e744bf,
	0x3ae3cf93, 0x91708ed2, 0x4d2e978b, 0xcd99f4a1, 0x30f331f1, 0x685ca165,
	0xc5166427, 0xf8892cc3, 0xb338e913, 0x24f9023c, 0x9baecf8a, 0xdfc3afa0,
	0x3f48d4b4, 0x5c6fbdbd, 0xe21b2667, 0x3cb7dff3, 0x8ce763ec, 0x73b1f75f,
	0x888693a4, 0xebd6097e, 0xfcecd909, 0xe1e18ba8, 0xdd7b12b0, 0xeb60e8db,
	0x475324c2, 0xdb9f9c2e, 0x71dfcaff, 0xcaf03d9d, 0xbb01dfdf, 0x8949e273,
	0xa4dc1e40, 0x71136393, 0x1b826fdf, 0xb7eb4af9, 0x1b46b3fa, 0xf449cf61,
	0x146dd77d, 0x8032f51e, 0xabe582cf, 0x0c7d1fa7, 0x547f3bfa, 0xd679d122,
	0x28778a25, 0xf6c8af3b, 0x6604db63, 0x6ded697f, 0xbbe1befc, 0x62be5a1c,
	0x6afdc4bb, 0xf3a28e62, 0x89b22a2c, 0xceba1179, 0x527a513a, 0x1f49edca,
	0xe344fbf8, 0xb3c86fc3, 0xced4aded, 0x3f72d6ed, 0x13fc1c87, 0x68cfc3e6,
	0x7b024bbc, 0x48ba467f, 0xaf71a8d4, 0x1a88db71, 0x37f8bf15, 0x39dec187,
	0xb363ecf8, 0x88f04f21, 0xd5472988, 0xc8dfbbcd, 0x18bb7a85, 0x11b33cf3,
	0xef9a33bf, 0x4fff8092, 0x4f08dc3a, 0xba4fe36f, 0x55c9f282, 0xecc27740,
	0xe5017cc6, 0x03df48c8, 0xbf67fcaf, 0xf1f1518e, 0x46fe8f1d, 0xba7abc3a,
	0x7a33f710, 0x6f9187a3, 0xfd3ce95b, 0x36efc197, 0x7f1f8859, 0xf585c9b7,
	0xac74be43, 0xdd5afc6b, 0xb03f54f2, 0x2d3e350b, 0x66f8c7ee, 0xfac7bee2,
	0x5e847b11, 0x70b5bc46, 0xaac97ffe, 0xf99e31d9, 0xb7a3e9b3, 0x8c85bae8,
	0x90ed27ea, 0x61c651e7, 0x0976f05d, 0xe78431da, 0xc3d71b8f, 0xc52de205,
	0xbb7b4ea0, 0x7b9e7c77, 0xebee9f51, 0x27523d2e, 0x2259bac1, 0x8c7a61ad,
	0x3c1afddb, 0x91ff3a46, 0xf1fc2194, 0x81f233e0, 0xc297ce11, 0xae2aadf9,
	0xdc3dda07, 0xcb668773, 0xa1e631c9, 0xa11e63e1, 0xdf4e77eb, 0x0df7efd7,
	0xc4ee7ffc, 0x5a03dff4, 0x919bc9e3, 0x4d76c66e, 0x00c0947f, 0xc1fa5879,
	0x48e9399e, 0xb9287945, 0xf21510a0, 0xc95a06a8, 0x8779d1a7, 0x7e432f33,
	0xcf62ed5b, 0xd55bf1e2, 0xc7789105, 0x6e4ef844, 0x7c06c47a, 0xb3aa4fb7,
	0x54cf3ec1, 0x44da9cfb, 0x9fe9a78a, 0x73c3ce15, 0x02261dc3, 0xe6e2b921,
	0x5c420e2f, 0x823dfaa2, 0xcd85c4f9, 0x4f808bfb, 0xe8ed490f, 0x279d7597,
	0x3b2891e4, 0xd6b9a9b5, 0x535c7606, 0xd30f3b0a, 0xf9744496, 0x8c9d1b8a,
	0x9e8e9b5f, 0x68c6ad9d, 0xe9938dff, 0x4d44b9a3, 0x2cffa5c9, 0x03f948d9,
	0x0efee6fc, 0x174cab8c, 0x80a5af3c, 0x80a372dd, 0xcb57477e, 0x2852d7f8,
	0x26b79dbc, 0x6e299ea1, 0x172eefba, 0x1ff04425, 0xf779f063, 0x8db3c122,
	0xf6e257be, 0x7164bd60, 0xe389fa36, 0x7737eebf, 0x235fb426, 0x2c549fa3,
	0xbe2094ae, 0xc85d2675, 0x15f3ff03, 0xfc1d63a1, 0x0e7f9a1e, 0xfcb8871b,
	0xfd9fc0fd, 0xa37eccc3, 0xdc3b37f1, 0xfe187d5a, 0xf8310bee, 0x3a5e6b7b,
	0xdb4cdfb7, 0x3017ccd7, 0x95d8afbf, 0xfc51fc49, 0xc151b253, 0x9cdf5d79,
	0x3d7c0856, 0xce7f54b7, 0xcfedc428, 0x123665f9, 0x14e7de88, 0x6dd7285c,
	0xf01beed6, 0x645b0c77, 0xe4d3f302, 0xefce5afc, 0xd3f6160b, 0x3087377d,
	0xab93553b, 0xbbf9711f, 0x37d9fb96, 0xe375337a, 0x0f661197, 0x9ee917fd,
	0x61f1489e, 0x7bfb644f, 0xdfdbbbb3, 0x125e19be, 0x7d038e07, 0x0611a3f8,
	0xb95c593f, 0x5d22f91e, 0x671e00f0, 0xd7edf479, 0x8dd7d04d, 0x0fd46bf2,
	0x473b21f3, 0x3427a9ec, 0x45bf307d, 0x347e2194, 0x19e280bf, 0x9dbd68ed,
	0x18be9bdf, 0x5f47109f, 0x0bdf745c, 0x7d0f4866, 0x77e961f1, 0x532f17d2,
	0x95026737, 0xae4e45eb, 0x41910637, 0xc58a37a0, 0x8f80c786, 0x69bae8ba,
	0xda47c18e, 0x0dc5a3ba, 0xa31ca84a, 0xf2cd381e, 0x642f8b53, 0x4898ff10,
	0x47ac20dc, 0x89e25da8, 0x3ffd2f61, 0x5eee8e67, 0x895eb094, 0xfce44bb2,
	0x14976fef, 0xc9547b53, 0x2206f803, 0xc584257c, 0x01204b39, 0xe98de205,
	0xa8dc605f, 0x2ffea25a, 0x214fcfae, 0x84ffa05c, 0x187c88e4, 0x6e2d15ed,
	0x66a737fd, 0x25f9e94f, 0x279cbf1c, 0xe3491c63, 0x27c01293, 0x113cffc8,
	0xe37a17f7, 0x237c6d1b, 0xf10c84bf, 0x85f95ea4, 0xe5b7ddcb, 0x7c9da797,
	0x19286ebf, 0xd13e17da, 0x17e343f8, 0xbaf37ae3, 0x6f14ae21, 0x99d979bd,
	0x6710e8ca, 0x846d79bd, 0x37bd7a8c, 0x4485e6bb, 0xd389e7a6, 0x97b5e585,
	0x5d83b7cf, 0xcb2737f3, 0xadd6d387, 0x136c7c70, 0x3ad793e3, 0x7f6090ee,
	0x47f41aaa, 0x5a0e8476, 0xcbe3597c, 0xc6028daa, 0xfd726753, 0xe2c2d9d5,
	0xc5d3d58b, 0x281d1c00, 0x31e47e6a, 0x93f76756, 0xc59df468, 0xda40a4f9,
	0x5befc12f, 0x3c11e75e, 0x7952a710, 0x2ab6727c, 0xa8d27c60, 0x740d5ab7,
	0x01fbcb9f, 0xbbbe0bff, 0x800854ae, 0x6fd4693f, 0xfb302f73, 0xc53d87a2,
	0xfc8d7bf7, 0x1fa699f2, 0xffc19306, 0xbce2bb4c, 0x0aed9bf3, 0xe8defbed,
	0x029ac12c, 0xeec83e74, 0x1e3b011f, 0x82e33ce8, 0xd25efd84, 0x49db98f8,
	0xfde74fe7, 0xfe4f7d1c, 0x32def1be, 0x1b7a7ce3, 0x2fe6acff, 0x1b41ff70,
	0x9d895af7, 0x4fae3713, 0xfc47aebd, 0xd2bd233b, 0x7bdb6313, 0x81ee1e9a,
	0xe3a7ae77, 0x3d37add1, 0x7fc3e9ad, 0xfad69eb6, 0x6d11d6d7, 0x8efea35c,
	0xfa6a3fe7, 0x1356c378, 0x72a66dc6, 0x8f2a7d3f, 0x6448cf37, 0x3c35dcf6,
	0xa5f5dd3e, 0x6deb04c5, 0x6afb6650, 0x8c76fdfe, 0x656aed3f, 0x9dab5076,
	0x415ef3d1, 0xbdc8f8c4, 0xafa84ce3, 0x06340fa9, 0x12152de6, 0x89f60232,
	0xe27db007, 0x86542906, 0x1123defa, 0x8fb5e738, 0x3dee5dc7, 0xfa19bfe0,
	0xe193f7bf, 0x678c5aa6, 0x5ec1da87, 0xe1279f1a, 0xd9925afe, 0xceeff18d,
	0x8fde3316, 0x5fefb5d3, 0xcfd0cbf7, 0x2e03c497, 0x7316a1e5, 0xf40b7f78,
	0x4478b147, 0xae8cbc84, 0x47f7826e, 0x2a18594d, 0x2a6cbf02, 0xff05af69,
	0xf2c2927f, 0x7a788db0, 0x4ebf5128, 0x8ac7f719, 0x4b1e585a, 0xb1e78391,
	0x68dfd8f4, 0x9dc5dfc7, 0x5a9e0926, 0xe37f73d2, 0x13bf8305, 0xb38b1fd9,
	0xf4c4d1bf, 0xdfddb7d1, 0xa0340498, 0x4493fe7c, 0x3f5ccf2e, 0x1cfb3891,
	0x3fb614bb, 0xb726fdd6, 0xc4a44f4f, 0xb6f51b8c, 0x35afb1df, 0x2afb8541,
	0x51dff176, 0x403ad7d8, 0x7fc6e775, 0xbba3b73f, 0xabb1a610, 0xe3097ae1,
	0x1c1e3ca6, 0xf11a0b8e, 0x6f10e9cb, 0x726d48df, 0xc6e9821d, 0xef3a27dd,
	0xb7d570c6, 0x3726a7c5, 0xa8258ebb, 0x8ebbf7c0, 0x8e01500d, 0x3dff9cb5,
	0x601bd766, 0x7a3bec2f, 0x8ff70136, 0xfe0dd515, 0xc5927749, 0x31e5cec3,
	0x0c660839, 0x76fec00f, 0x5dfbe70d, 0x8fafdd09, 0xffde894c, 0xda3dfb61,
	0x855aed39, 0xdf89de60, 0x8c4ef2c4, 0xb1724bf8, 0xc763db75, 0x9c89b4eb,
	0xe56316e2, 0x588a7a71, 0x79f1839e, 0x15ffef88, 0x7ed03f03, 0xe6c896fe,
	0x232c5eb3, 0x093977fc, 0xf58db9c4, 0xb63e70da, 0xd4d77f07, 0x739d3363,
	0x4a3e3ed3, 0xe6066cfc, 0xad318c8f, 0xfff5a1ce, 0x0cfbfc49, 0x6c992fcc,
	0xa87b231a, 0xce2e449d, 0x2e55df80, 0x923b2a4e, 0xc7e21fd8, 0xe7908df6,
	0x7924f90c, 0xf13d1129, 0x2dbfb520, 0xacf89179, 0xd6fc4ccd, 0xc72f383c,
	0x7cb428f2, 0xb6ab2a92, 0xeec1ddcf, 0x4e343e67, 0x14d8a767, 0x7efd1dfa,
	0x41fbd999, 0x58ebec22, 0xe5374e42, 0x8afb35b3, 0xbf9d3ef1, 0xbe70ba25,
	0x9c9c5f23, 0xe147fc0e, 0xf7bc0bfa, 0x6757087f, 0x8f20b82c, 0xbd39c606,
	0xe8116467, 0x098391b5, 0xf469ade6, 0x9f116aa1, 0xf084835b, 0x60e98273,
	0x2926d587, 0xb7f1ef98, 0xb19e8d44, 0x34791ecb, 0xdd9aa689, 0x8c5c14b4,
	0x372e4c1f, 0x3ba307bf, 0xe4ef7e0b, 0xd410017f, 0x80005083, 0x00008000,
	0x00088b1f, 0x00000000, 0x5bedff00, 0xd554747b, 0x9cceffb9, 0x79333399,
	0x21264cce, 0x012708f2, 0x8e024242, 0xd43c3018, 0x04522031, 0xb9115809,
	0x4a821d5e, 0xda686bc8, 0xb5daaeda, 0x22904938, 0xf5b15cb8, 0xd596acb6,
	0x8ba57035, 0x9827624a, 0xdc26e060, 0xda979401, 0x2ed8df06, 0x4a452a3b,
	0xab8d3243, 0xcb5d5c56, 0xef7b7dfb, 0x4619ce43, 0xfedeeb8b, 0xf0584f75,
	0xcfbd9f65, 0x9efedfde, 0x0d9f6fbf, 0x2b051278, 0x24fe03a7, 0xca91aa0a,
	0xac44ccf2, 0x9eff5b02, 0xe2add819, 0xf789f1e3, 0x3bf6c31f, 0xb60597f7,
	0xb4bdfb61, 0x0d9019ac, 0xd4523ab0, 0x2bf6c716, 0x2786509e, 0x1d4b9f17,
	0xcd1b05df, 0x03f03103, 0xde4079ac, 0x90024db5, 0xf7df0082, 0x703d5521,
	0xb6804cff, 0x24caa820, 0xd3b03180, 0xd80cbe73, 0xa4e45f2b, 0x305c175a,
	0x39dee01b, 0x5d61bbf8, 0x79e7c0c8, 0x7f254fc8, 0xbc63e06e, 0x8f919667,
	0x4cea94c8, 0xe73de3a2, 0xf05f19d3, 0xbb700c85, 0xeb80019c, 0x8b64ff84,
	0x30bf9138, 0x0bf6a5fe, 0x0d116ce7, 0x75a21f7f, 0xc1d1a7ae, 0x59b3b58c,
	0xce675b17, 0x9b32ad6b, 0xf83fc357, 0x129f167c, 0x97eb7a2a, 0x07b61642,
	0x5dc61fec, 0x7bfc1d62, 0x82d0c9d3, 0xa6ef7c0c, 0x71cfcd77, 0xe7fe205e,
	0x212b7989, 0x63ca0322, 0x6e3cdc4e, 0x57f93c1e, 0x779de719, 0xd2bcfcc1,
	0xb927e993, 0x4b1858c1, 0x211201fb, 0xe2ecd7ce, 0x5abc8df3, 0x00e50d94,
	0x14ca3b76, 0x32a8aee5, 0x82fd2254, 0xe8056e7e, 0x9ce384de, 0xb9360700,
	0xa6fe9d18, 0xdff11d67, 0x3003c9bb, 0xa6d0e015, 0xcf3f467c, 0xf52e76c6,
	0xc33083c3, 0xaf878eb0, 0xe471cba3, 0x1bc72e5d, 0x9b3f25e2, 0x49c76d8f,
	0xd1d44407, 0x7215ce7d, 0x9008011a, 0x642e477e, 0xcf6c3404, 0x0cb7753e,
	0xbe42c845, 0xfec3540d, 0xa81a6adc, 0xf4eda325, 0x2da99f12, 0x766cfd0b,
	0xf666ed67, 0xf20705a0, 0xc51b9d71, 0xb181993a, 0x8220f9a6, 0x3c7a0c7f,
	0x52745be4, 0x98dcfdc2, 0xf694bb51, 0x64595d95, 0x55e2bf9a, 0x4267bcb3,
	0x97c25075, 0xfe407f03, 0x6fd9fdf1, 0x7c61bf62, 0xd99dac65, 0xcc1fe545,
	0x339ee7cf, 0xb7a4c3b7, 0xfb7a14f4, 0x8cc27932, 0x7ff7cd9f, 0x837a797d,
	0x2ce67966, 0xb733cb36, 0x31cf2cda, 0xbaf2cdab, 0xc796642e, 0xa669dab8,
	0x671b09fe, 0xbf13da9a, 0xbe34d73f, 0xb532ab50, 0x625d6d27, 0x7da53f1a,
	0x753da9a5, 0xf8d31ac7, 0xa98d48d2, 0xdd6f6cbf, 0xf4ffd2d7, 0x3c69b368,
	0x15f6d989, 0xf7bebffa, 0xfef5a607, 0x4dfffa55, 0x89fbfe92, 0x2fa459f7,
	0x17188f8c, 0x5b191d87, 0xc5e67c25, 0x7a4e2835, 0x965c4efb, 0x2ab52fd0,
	0xb5e62355, 0xc3681025, 0x6ae467be, 0x71fdf009, 0xc61b6a28, 0xa836cd8d,
	0x3fbfa28d, 0x583db365, 0xe7ea319d, 0xcd891efd, 0xec050bff, 0xdc799f6e,
	0x71d1f2ca, 0xb1e13d3a, 0xe3d77f31, 0xdaa71aec, 0x71642f16, 0xd5c504f5,
	0x84c8b635, 0xaf794e18, 0x425dbb47, 0xf01cda3e, 0xe3ce3560, 0x8cd4bf05,
	0x9e347b34, 0x32a05fab, 0x7b2253de, 0x9f7c4a7e, 0x707b0396, 0x10496ffc,
	0x020e91d7, 0xfbc7f236, 0xaaa578f4, 0x3f035ed9, 0x0187b823, 0x35760bfc,
	0x8c3d631b, 0xc589343c, 0x600fb3b3, 0x9fbd42b0, 0xf43ef855, 0x3c4417f1,
	0xd9e228bb, 0xe731c520, 0xaeed7f68, 0x38aa649f, 0x5812d9cf, 0xe7c8351c,
	0x2e4f9223, 0x961e03ad, 0x5d71e667, 0xddb757bd, 0xbfce08f1, 0x9e3cf64a,
	0x024f4851, 0xc77d3f26, 0xd0f239ab, 0x4b37132f, 0x1aad4f2c, 0xea2f7607,
	0xb80e556b, 0xf7da3ebc, 0xb43d4bc6, 0xb0292aef, 0x76695f07, 0xbe383fe0,
	0x889cbef9, 0xfdbdf386, 0xf90774c0, 0x7410dde9, 0x07bfdc50, 0x41cc7f42,
	0x43b7de7d, 0x36e51506, 0xfe7892dc, 0x8fed6451, 0x247b9775, 0x692de614,
	0x7e53bfa1, 0xe26d7f7d, 0xfdf00757, 0x927d0fb3, 0xfd272a19, 0x3ec2f970,
	0xbde75b27, 0x21c57dba, 0xef245c83, 0xbd20ff6d, 0xd7262541, 0x5beb5739,
	0x48d094a7, 0xe44a750e, 0x3e403f97, 0xcd83b4e1, 0x8369eba7, 0xa17353d0,
	0xa7a8c63a, 0x7a2bcce6, 0x6a7a431a, 0x3b3323de, 0x4777ee6d, 0x4b7cf900,
	0xefbc3be8, 0x503ff3f2, 0xc5f1c1a9, 0x152fa847, 0xd427f3f5, 0xe6798a97,
	0xb517d463, 0xe7572dbf, 0x8fdf9178, 0x2b28fc9e, 0xf37ef344, 0x961ef8da,
	0x1bff6f12, 0xe29dadf2, 0x23023676, 0xda38b36f, 0xbc92aa5d, 0xfcb81c17,
	0x4dfd84b6, 0x89d54edd, 0xf8de4bed, 0xf8d05ff1, 0xf8d01283, 0x059b98a6,
	0x296ea687, 0xbafec6e2, 0xe32daede, 0xb1d75db0, 0x74c282a2, 0xb7620b38,
	0x297eff52, 0xe7fd8ad2, 0xe7f56937, 0x0e0ba750, 0xf34f3e5d, 0xf3e21d0e,
	0xada4d85e, 0xf6c14fb3, 0xd3efb5fe, 0x4edd0d7c, 0xf09e1370, 0xb47194c6,
	0xa514975e, 0x4fa36af5, 0xed7f342b, 0x13262bb3, 0xdbdfa89c, 0x10d93352,
	0x9c0e866f, 0x53945451, 0x8bd3f76d, 0x9e0ab8c4, 0x9fcc222e, 0x886ffdf5,
	0x1bb3acb4, 0xaefe1cf3, 0x388b1d91, 0xff909af7, 0x6d49beea, 0xe3f44e24,
	0xb5e517a0, 0x7d7ebfe6, 0x2f64f7e9, 0x3cf6fbfd, 0xae2a6346, 0x53f8ce4d,
	0x20d0f64d, 0xc7542ce2, 0xa275da80, 0xd5e220d9, 0x286f0b86, 0xcf75d764,
	0x709bce3a, 0x9dba7e4f, 0xfe0bd7c6, 0x8ecd1e70, 0x81d0d2fe, 0x3af14ce3,
	0x6b6e10ae, 0x5f7a4eea, 0x6f2bf1f0, 0x07da6af5, 0x8d9299a6, 0x7c24b1b4,
	0x9bf855b7, 0xd9169856, 0x3397f283, 0xb45aca12, 0x00d11fdb, 0x93dda7dc,
	0xbdb06a50, 0x15c627d5, 0x0a7b22b9, 0x2ef7deaf, 0xdbc99daf, 0x63210455,
	0x2fe9d0dc, 0xa2b1ff45, 0xfb1c4a8b, 0x0a0bd49b, 0xec5341f9, 0xfc8a8acf,
	0x583f7b87, 0xdef14c14, 0x3b8f2f4e, 0xed755b0e, 0x7f518aae, 0xe35a966b,
	0x0f9a6794, 0x0e19554e, 0xc6716af5, 0xa55b8f5f, 0xf0382c7d, 0xc371d9e7,
	0x7b417f7c, 0x6d18ec9b, 0x83e6fd37, 0xdb920e19, 0xb0cc1f0b, 0x1f3e8e67,
	0x8da8cbca, 0xc783e4a4, 0xaab3c7fb, 0x8dbad02f, 0x2b6a9c07, 0x207717f3,
	0x97d2fe46, 0x24b7401e, 0x2b5a517f, 0x1f72fe8c, 0x4fa9bbe3, 0x40e7a00e,
	0x508aef53, 0x199f1b0b, 0xbdc83520, 0xb76469b7, 0xd99aa7b2, 0xd703fc37,
	0x14794d9b, 0x7ae7087f, 0xfd263f43, 0x1ab433d9, 0x4def41bb, 0xab4178b6,
	0xb50bfa44, 0x67f066df, 0x5b534339, 0x9ccf24fd, 0xea8eac80, 0x7ae361cf,
	0x59e35219, 0x6db76c3e, 0xffc8f9c2, 0x22ce7f62, 0x5de96ff9, 0xf238a2e7,
	0xf5c3d790, 0x07aa68a8, 0x1b520fdb, 0x54aadfd7, 0x6e9f92d7, 0x8a034bcd,
	0xc7de3013, 0xf99fe5fc, 0x3ff910c1, 0x1080e3ae, 0x121e1e50, 0x013436f6,
	0xd840fd58, 0x264cec8d, 0xdc8936bc, 0x71a1e432, 0xfa96dee1, 0x3f3f4673,
	0xf8806f78, 0xf7f1a473, 0x6bdb8f21, 0x08afbaf2, 0x56dc7b3b, 0x219b7ed3,
	0x3b8f269f, 0x4772e345, 0x2d7600e5, 0x0873d59f, 0xefd9531c, 0x11d56f1a,
	0xbee3c3d2, 0xeb8a12ea, 0xc80b1676, 0x7c949537, 0xc613f8e0, 0xae423df1,
	0x21e4238a, 0xdb4546b9, 0x393354a1, 0xc9508063, 0xafecaf8f, 0x67e94948,
	0x5bdf04e7, 0x4f7acd0b, 0x18a1f71e, 0xf969b0e7, 0x61e7c435, 0xb0cdf999,
	0xd7fa609a, 0x2ec70dc7, 0x7df7fd73, 0xfc905772, 0xb31570bc, 0x2ebf8bcf,
	0xe61b299d, 0x7155bc95, 0x746737ca, 0xf968707b, 0xa2abf7c4, 0x76e3efad,
	0x1a79f56f, 0x1833e3a7, 0x3b26bfef, 0x03ef8101, 0xbe227f22, 0xabe3b12f,
	0xa01690c3, 0x7025d17c, 0x2ac31dac, 0x043a49d9, 0x9a165254, 0x70f32bcd,
	0x6c476d7f, 0x599b0db0, 0x4661126d, 0xf3583d60, 0xbd36c966, 0xb0ba0808,
	0x27232b54, 0xbdcffec3, 0x466c6fae, 0x26820f7e, 0xea9279b3, 0x414a0857,
	0xbeb758c9, 0x6eba9754, 0x236a19dd, 0x7567febf, 0x6d989ceb, 0xf5fd92ad,
	0xcf8f57eb, 0x7cf3838c, 0x5a2a632a, 0x1a2fedc2, 0x0938634b, 0xfb246e7f,
	0x34e2977d, 0xe5c81ff6, 0x4a869154, 0xdd7c5e5c, 0xd6c4f697, 0x935fe8f9,
	0xdda9fef9, 0xe71c4646, 0x3d4ae5b8, 0x8634d2fc, 0xc90e311f, 0x08f40eac,
	0x56f4925e, 0x178bf881, 0x3d530111, 0x79fe3b1d, 0x4eddc516, 0xd23bfa9f,
	0x0c94e24b, 0xf6dcfb84, 0xe14de2b8, 0x8f080757, 0xf909ae22, 0xf5757c78,
	0xae08c14a, 0x408352ef, 0xf1edc178, 0xfc1b20dc, 0xf9e3efcb, 0x7bf8f1a0,
	0xc2e20a05, 0xb357b64b, 0x86fe71ca, 0x7459fd9e, 0xf67f532c, 0xcd04d9f5,
	0x2a87b16f, 0xa2ee387d, 0x85d8abb4, 0x91ad86f2, 0x689f2419, 0x709b28ac,
	0xe63b74df, 0xf35799d3, 0x9b81de13, 0xb4df14c2, 0xe9d18723, 0xa7ae377d,
	0xe31c27ba, 0x1c35a5fb, 0x5ed2e328, 0x7a87b589, 0x5f347cdb, 0xc7fbbff8,
	0x97da7c52, 0x7e29ab0b, 0x1959f73c, 0x760edf7f, 0xe7ccbf1a, 0xb114c615,
	0x3ed1f9d1, 0xf7c38e07, 0xd9933e86, 0xe9fd7d38, 0x1ec9b7bd, 0x58f283b4,
	0x038a51fb, 0xc3273eee, 0x8167ee65, 0xf10fa3cb, 0x1cc39d22, 0x0f2803be,
	0x20217b0d, 0x5a677f61, 0x44a8e182, 0x2ddd53bf, 0x81dadc91, 0xe153bcfc,
	0x1a294775, 0xd18cfee4, 0xee7afae7, 0x19d19fbe, 0x9045d911, 0xdedb9ef2,
	0x1867370e, 0xe4c99de5, 0x957644dd, 0x6cc4eb4b, 0x31e78419, 0x7c66ee66,
	0x6c09f28d, 0x52cf9d5d, 0x953bdf16, 0xfcc7f9c4, 0xd90f2f8c, 0x3e702941,
	0x4aaa6fa1, 0x09edcdf1, 0x3db87db2, 0xae93406a, 0x033c2be6, 0xcdfa1c81,
	0xc570ad53, 0xc3afc98f, 0x176da369, 0x116742fa, 0xe6d06bb7, 0xbe70b13f,
	0xa6014da1, 0x36fdf472, 0x6c4faddf, 0x7bcecf9e, 0x8ff51934, 0xf4cb4b28,
	0xb6553ed1, 0x6089743f, 0x872e4cee, 0xdd29ca00, 0x8caffbc5, 0xa0cf3b47,
	0x171f0676, 0x97d27a70, 0x617f3214, 0xf849aef8, 0xd8a477fb, 0xb5515bf9,
	0x67574f83, 0x06bee397, 0xed1f476d, 0x597f71c0, 0xbaa62d1b, 0x7a129cf0,
	0xf0f687ca, 0xb66a1fe2, 0xdb78a74f, 0xa52c08e9, 0x7ed713b8, 0x73f4f0cc,
	0xc19b750e, 0x227c60ef, 0x7937ec8f, 0xd6d9f09d, 0x1e5e131f, 0x2ea9283e,
	0xa26ee295, 0xea6ef880, 0x78a158fb, 0x01f83e1e, 0x39e5c7c3, 0x7ad39fa1,
	0x0b2dbd95, 0xa073ae48, 0x75e28dbd, 0xd105c099, 0x464f1e7c, 0xddde2cde,
	0x4c43d062, 0x42241bf8, 0xf53f2913, 0x4c3d7f09, 0x9ed223f5, 0xa24df723,
	0x7d447bf9, 0x02d7bfab, 0xdc91c747, 0x4625e15b, 0x889be4af, 0x59d9317d,
	0x07aedbd9, 0x87f18683, 0x1167ffc8, 0xf2f875e5, 0xfc94509c, 0x87c8feb7,
	0xf3ed164a, 0x8a80b45c, 0xb9d628e5, 0xe471149e, 0xf926ff8a, 0x509ed853,
	0x02f87c68, 0xfa82b8b0, 0xfa8d9cde, 0xef76f7db, 0xbcf8b5b4, 0x4d927507,
	0x93ace138, 0x471ef1e5, 0xdf1a38f5, 0x33a7d6f2, 0x26ed8e28, 0x4f9f9026,
	0x9227ebfb, 0xabfed0dc, 0xbacfc8d2, 0xdd35c580, 0x4fc9cb4f, 0xb272fdf1,
	0x976a0aff, 0xa9dcb8b2, 0x7e612c0c, 0xf20363d9, 0xe67fb44b, 0x1eff680f,
	0x1ee5c7ca, 0xfef607f4, 0x9de7e654, 0xc320b603, 0xa7d718b1, 0xddd576b0,
	0x581ceed4, 0x6e7e61e8, 0x499e7b43, 0xca3b1afe, 0x100289e6, 0xa090a97c,
	0xfbe758da, 0x6f4c597d, 0x122cbc7a, 0xa25a2179, 0x1f700766, 0xf26cb2e9,
	0xe49e430f, 0xcb47916d, 0xe27e127e, 0xf8f4f999, 0x3c279e06, 0x37aa3f22,
	0x6dffb8b0, 0x5f9aab91, 0x83bcbb9e, 0x326bf8f0, 0xce2c3feb, 0x4ec26219,
	0x06738a8e, 0xea2a1bca, 0x6e7125e7, 0x41db0b3a, 0x83b3a38c, 0x3a50171b,
	0x7edc5caa, 0xeadce88c, 0x8a8202e8, 0x1c0f57f3, 0x2f377073, 0x3eebfb23,
	0x3b328dfa, 0xbcb3bdc5, 0x3cfeec5e, 0x2873fef1, 0xa30f4787, 0x29e453fc,
	0x3fb30edc, 0x20e357c4, 0x61feeaff, 0xad238f49, 0x63faa0df, 0x6d1e5ba8,
	0x426cae63, 0x94b6a6c3, 0x21a13da3, 0x8273db63, 0x63941cf6, 0xcf643fa7,
	0xccfa7aa1, 0x96e479e7, 0xc87e6f3d, 0x256ef0ea, 0xd3f64658, 0x6ba5845d,
	0xf84d3b0a, 0x150f4c1c, 0xaa98d84e, 0xe78738bf, 0xb60d62c1, 0x96ceac4b,
	0xc3aa113d, 0x82a0e5bb, 0x6802e7f8, 0xbc51e6ab, 0x0f78e711, 0x6413fe83,
	0xb461a378, 0x3d7d2419, 0x130f9a22, 0xd63cc17e, 0x2150ff20, 0x19e47a3f,
	0x6dbce987, 0x50b7c42a, 0x2b3f091c, 0xaed86205, 0xafee69dd, 0xef62ebeb,
	0x7a6a9d61, 0x09a8f58e, 0x88e714af, 0x3049f6f3, 0xda0af089, 0x0e0b8b11,
	0xa2749c3b, 0x1fcefedd, 0xda9725ca, 0xc1f2e367, 0x31fcca78, 0x552fcf57,
	0x2e250e3c, 0xcbf98441, 0x2cb1e8de, 0x476e6be4, 0x98d68061, 0x73fde76b,
	0x7e590b7b, 0x5e447b01, 0x0ca80a81, 0x1c311686, 0xccdf05ad, 0x8ad77dc7,
	0x7e1e08f8, 0xc841b55e, 0xb8e056a1, 0xdf33110d, 0x46d22073, 0x2bdfaceb,
	0xfacb73b1, 0x78948ebd, 0x69e62c2e, 0x38e671d8, 0x4635cf1d, 0x84c2e3cd,
	0xf42f08e3, 0x07ef9f9a, 0xd12c08b6, 0x050053e5, 0xe4fb5cec, 0x7f51d5b5,
	0xf15c7071, 0xef4798ba, 0x71e1cbaf, 0xa3d909b3, 0x9110d138, 0xb52f6423,
	0x71c59692, 0x45ac642d, 0x76e9d7be, 0x941fe2a1, 0x3e4243c7, 0xb05d84eb,
	0x8dfbe17d, 0x0c48a53b, 0x49e87fdf, 0x470fff33, 0xa71a2ed7, 0xb5376d5e,
	0x6b860e1d, 0x3b2360eb, 0x6ecab8c7, 0xda003c84, 0xc95fca15, 0x9214d3f6,
	0x8e6f84be, 0x7cb7ffc7, 0xec623bd7, 0x3ffea8fc, 0xfc4680a4, 0xa14b7f77,
	0x7de4c4f3, 0xcfd5fae8, 0x7d7df467, 0xd16cfddd, 0xa60d3bf5, 0xce2efd31,
	0xc7fac6b9, 0x14bba38c, 0x76231fee, 0xdbabde7e, 0x8bfbf24f, 0x63bf0e04,
	0x97a3c707, 0xa2c93f7a, 0x81e1dbf3, 0xd4602c91, 0x1ef298b6, 0xe21b27b5,
	0x78734fcd, 0xff25bc9d, 0xa708a7a3, 0x08e5d1df, 0x86838220, 0xca6a8e09,
	0x5e130dcf, 0xc86c9bce, 0xf8c53b27, 0x6e1eba3b, 0xf89c5375, 0xf72014b5,
	0xeefbee1b, 0x1d6b6a51, 0xbe0a6052, 0xe4607c7f, 0x1f48f3b7, 0x69b3e9f9,
	0xedff70be, 0x3ed89d65, 0x80c6fbbe, 0xee3c9eb1, 0x63bbfbe3, 0xcbe58382,
	0xffe9b1c1, 0x13ce94b9, 0x1f98bb83, 0x417a1e0f, 0xee1f3f21, 0x171f2094,
	0xec7f9e3a, 0x3de50d79, 0x428ce078, 0xf7417c20, 0x15fe2519, 0x9612e038,
	0xde763159, 0x3d50aeda, 0x27f3dd53, 0xe8b84e25, 0xb9d80fd9, 0x77e11d53,
	0xe53b59c2, 0x1ebf8a88, 0x21517feb, 0x90ea6a3b, 0xb1a14c60, 0x31fac1df,
	0x3e7e3273, 0x4b9ffec6, 0x2359f6a3, 0x4fb751ec, 0x446b5edd, 0xd5b7599c,
	0x408f8f6c, 0x7c58cb70, 0xb58ee1ff, 0xdc3e9e2c, 0xe8ce3a9e, 0xd53d6af1,
	0xd7f7188d, 0xdb8f30ef, 0x350ec570, 0x1c97fe76, 0x11c9decf, 0x94296375,
	0xc48e1d92, 0xd1da266a, 0x533d3fee, 0x7c521137, 0xe45578cf, 0x7e5f3d6b,
	0x7a875c99, 0xcf28513f, 0x583bc785, 0xff1e10bd, 0x2768c537, 0x593b081f,
	0xa657f7d4, 0x477da59f, 0xcb7ad216, 0xf240d420, 0xee97d65d, 0x34bbfc21,
	0x4976fdce, 0x9112339f, 0xcb1b3f88, 0xba20cb6f, 0x7c3ff499, 0x1bcfc9d8,
	0x070c490f, 0xeb638881, 0x0bd7bc85, 0xfac7aef9, 0xc24cdc6a, 0xde7ebcc3,
	0x38ebb250, 0xf126f941, 0xb1d4e1bc, 0x12f3922c, 0x496671e0, 0x5d19c794,
	0x489e7a5f, 0x40cc73f6, 0xebbe900f, 0x0db09cfb, 0xe229dfc7, 0x181d9dcc,
	0xfdaba467, 0x74baf87e, 0x0f5a2f66, 0x2f3937e7, 0xc79b7536, 0xb8e1ca5f,
	0xd9e04472, 0x5f59bf4c, 0x5e90134b, 0x512df38e, 0xbd8440e5, 0xf5a76035,
	0xfb40ce4f, 0xaa4ff9c3, 0x2943b293, 0xdfd3a8f4, 0xb7ae9c0a, 0x16b9d397,
	0xda7a8f8e, 0xf8758c33, 0x6f1cfcf7, 0x3591cdd4, 0x6ea1bf92, 0x30b33e59,
	0xd932dd65, 0x189f7c8f, 0x1bc9eebf, 0x704b758c, 0xe1d93157, 0xb27ff28f,
	0x87c52674, 0x864f1e0e, 0x6cde712a, 0x70c0e1c2, 0x19c3b86d, 0x8c22faa1,
	0xfff84476, 0xf213b20e, 0x76e93ecf, 0xfdc413b2, 0x057f9a01, 0xee3f0642,
	0xc72f457f, 0xfe162b23, 0xa9ddd995, 0x28df7cc9, 0xeaa931b7, 0x37ff1d00,
	0xa671c67d, 0x1ec9bcfe, 0x53407567, 0xb6ecc49f, 0x82e5e8fb, 0xb877e442,
	0x6b05efff, 0x79f8d691, 0x8aaeed1e, 0x37f7487e, 0xa574ed3e, 0xe25793c4,
	0xf999b4b6, 0x9e239349, 0x41c770c7, 0x613775c4, 0x45faf0dd, 0x1f743756,
	0xf0c83f75, 0xa2684d64, 0xd4f42be7, 0x970cad02, 0x4666c2b6, 0x7118bf09,
	0xbf0f7adb, 0xc888f20f, 0x46728d77, 0x8f5cec8c, 0xa3958d13, 0xf6887ee3,
	0x71ce08fe, 0xf154cccb, 0x4f32db42, 0xd44e3aba, 0x42daef97, 0xbc6aebd0,
	0x2df96313, 0xcf7cdf19, 0xb09bf22f, 0xd3d796d3, 0x3e1d4e18, 0x2ce87b25,
	0xcbfae517, 0x10df84b1, 0x38a5179f, 0xec28bcbf, 0x7f7c5072, 0x9994a96c,
	0x38736cdc, 0xca10f1d5, 0xf0cbd98f, 0xe1088c99, 0x2fc3b2fc, 0xebfe9116,
	0xa338e2f7, 0x42fea1df, 0x844e3eec, 0x9a31afe9, 0xe8edbece, 0xbf0efbfd,
	0xacec8d38, 0x8bcff5e5, 0x172e5eb9, 0xe72ffe2b, 0xc492a74f, 0xc49b57eb,
	0x7b1ed7eb, 0xa6ea8b3c, 0x3ab941f0, 0xaea7d062, 0x8fc2ade7, 0xf4ebcec0,
	0xe32afd27, 0xdb8fa5a7, 0x539fad85, 0x3f157f5c, 0xf5b071a7, 0x42afeaaf,
	0xbc8af97b, 0xea17c406, 0x3048ec38, 0xb19f0bbb, 0x67c27e31, 0xf98cf246,
	0xc779a35d, 0x696bdc50, 0xd2471600, 0xc62ce281, 0xddea8d31, 0x3375df3b,
	0x68bc74bc, 0xb71652fb, 0xb8a0648a, 0x75ebe8f5, 0xc1f98d53, 0xb9f997eb,
	0x9f21c915, 0x7c33cad0, 0x5687217d, 0x7cea2958, 0x88cfc76e, 0xa3eb05fa,
	0xc9c7e4bd, 0xe2b5d1f5, 0x277e96dd, 0xf86ff9d0, 0xdfbb273d, 0x7aff69f1,
	0x67c37f56, 0x9eeca9a1, 0x3d742852, 0xaf0f47d1, 0x3fcf4a9f, 0x7ae1bc3d,
	0xb5296e76, 0x4697f29a, 0x2e13e5fc, 0xc54f2b7a, 0xb7fec6fe, 0x075180f2,
	0xc6da9fe3, 0xcfd075fc, 0x11f0d7f3, 0x909f3b37, 0x01db88a0, 0xdbcd364c,
	0xc332fdd0, 0x72bd0d11, 0xfa0f68d0, 0xfcfca77b, 0xdd35fdfc, 0x9052a20e,
	0xd38bb9e9, 0x1817de86, 0x288ef53f, 0x874b63d3, 0x7277f783, 0xbd92f88a,
	0x234f81a7, 0xdce8bbfe, 0x60cf7f9a, 0x923814e7, 0x4948c7f9, 0x8dee8469,
	0x508f42bd, 0x1b1123ae, 0xf64ee7f0, 0xe4edb95d, 0xfbb26ca4, 0xf82f9391,
	0x578be553, 0x9a07fbe9, 0x5e42e9ca, 0x3ff7245f, 0x0fcfcb99, 0x71e59f4e,
	0xa16df4ec, 0x99e2a9a9, 0xcebc5506, 0xbbbc8496, 0x7d538b1d, 0xe626db47,
	0x3b5e3bdb, 0xec19fb4d, 0x68efb372, 0x1e7e5e83, 0x29ff60ba, 0xdde50e7b,
	0xe516696e, 0x7792fa8f, 0x59f8e616, 0x74f282bb, 0xfb20ec7d, 0xd1d8d85e,
	0x829828b5, 0x7972fb8f, 0xa4a25f1c, 0x36390efe, 0x1be7db97, 0xf515c810,
	0xae1b76d1, 0x8752c6f7, 0x19c31b67, 0x30eb8cc1, 0xe225defe, 0x1ccbddef,
	0x01bc970c, 0x6f7f83aa, 0x9605dfe0, 0x73f22753, 0xcbcb8897, 0x7271cd2b,
	0x9c784ec5, 0x08ac0bbe, 0xf777c6a6, 0xd257f988, 0xf79c06bd, 0x71e6c5ee,
	0x777c08f7, 0xb9f9b54f, 0x84e0572f, 0xf8a62862, 0xcfb8c51b, 0xba944bee,
	0x73bd5e59, 0xb89494fa, 0x5dc638e0, 0x52703fba, 0xf5d023dc, 0x0efa52de,
	0x8fa757cb, 0xcbde7d9c, 0x8a1bb6e2, 0x1acf7c52, 0xbfba57cd, 0x5beb937f,
	0xf468277c, 0xbd751e70, 0xc7cac25f, 0xeba51e78, 0x4fd0967d, 0x46f75efd,
	0xc6bdf7e3, 0x0ed4d7a8, 0xf1b75ef7, 0xd7ce219c, 0xd8c6fb0b, 0x739e376f,
	0x66872b3c, 0x77dc52e5, 0x1efc2a0d, 0x2de58263, 0xd88157dc, 0x90d38157,
	0xb75d2e8f, 0x8efda536, 0xf1a7cfee, 0xf467efb8, 0xf993a948, 0x8a54635d,
	0xc6a877d0, 0xc6c3f718, 0xf3b3666f, 0x23eee287, 0xaac2beec, 0xc8205285,
	0xc49bd7c3, 0xcb3f6e9f, 0xeb7f3c5d, 0xe50f7276, 0xb90619ef, 0x71a23b09,
	0x12efbf94, 0x9ed93bf9, 0x22c0c2a6, 0xa0dee75a, 0x6dfba014, 0x72b576c9,
	0x532f0df5, 0x23b649fa, 0xc50737b4, 0x7a3b64c9, 0x7f74373a, 0x0bab2e6e,
	0xf9c74d57, 0x5c7e974e, 0xf4d37640, 0x3df37e25, 0x19bdb7a1, 0xf7ca69da,
	0xf7c5fb0d, 0xbda5fdef, 0x49c79271, 0xd06f7860, 0x99a5b03b, 0xfdf660e3,
	0x66e631bb, 0xfb1aeef7, 0x6a6e03d2, 0x4da4b777, 0x4fb0faa3, 0x7b63a40e,
	0x8599f769, 0xad2f9f54, 0x9a3bf7e0, 0x9bc30494, 0x6fa1bc73, 0x02cb7f11,
	0xdeefa62d, 0x665f9f3a, 0x6d71c9e7, 0xf60ef89b, 0xdb378aaf, 0x3e693c44,
	0x34de49f5, 0x1bdf2a5c, 0xeb9311fa, 0x3929cfcb, 0x5ed3c764, 0xd2a3945c,
	0x5b8d9538, 0x336471d6, 0xfceabb1d, 0xe1efdeff, 0x1911d5f1, 0xf96470cf,
	0x692fddb5, 0x06627839, 0x23a1e6e1, 0x062866a7, 0xc66c1efb, 0x7f429cf8,
	0x7e13602d, 0x9254676b, 0xc37c0a56, 0x7fdc38fd, 0x0dce8f2c, 0xcb7fc906,
	0x4595be89, 0xebb1b179, 0x8429ac8d, 0xd5387a33, 0x27d4bbe7, 0x8f6071b3,
	0x6993df17, 0xc671efe4, 0x9f28a5df, 0x7c5e2007, 0x7f6374f7, 0x3fffeb1b,
	0x921efff4, 0x6e2ba377, 0x4e5d7ff2, 0xac6bb558, 0x64ec3c8e, 0xfbe9d3df,
	0xd65ef188, 0x37d76119, 0x7e437161, 0x07be873a, 0x6628224f, 0x6da9fb87,
	0xbbdd1887, 0xf6310799, 0xd35a2e9c, 0xfac5b3fa, 0x4763d937, 0x1ce47ee8,
	0x2e713df1, 0xb771b00c, 0x20d18240, 0xab44ec78, 0xa568c020, 0xc127762b,
	0x5468f2e7, 0xf2c7fd26, 0x2ef3deec, 0x5200ef76, 0x6e547be9, 0xcbaf3876,
	0x4eefa643, 0x37ec91b0, 0x85173f79, 0xe414de3d, 0x04a08771, 0x84ac8fdd,
	0x7dcefb28, 0xf7c5c433, 0x98fbd4ee, 0x7d1a7587, 0xe119bae7, 0x47931a4b,
	0x4f9f8d84, 0xed5391fb, 0x53277e27, 0x10f42c33, 0xcf2c527f, 0xb5fa45f6,
	0x0f3863ef, 0xeb59bcd8, 0x558f4312, 0x0c277e8c, 0x97789df4, 0xc14947ee,
	0x19efbb20, 0x27ba8970, 0x12bc1f66, 0xfe008ac7, 0x37f35b9e, 0x7dfaff8a,
	0xbb010879, 0x5f7c9147, 0x217bb69e, 0x97bef46f, 0x6f736f7e, 0x436aa564,
	0x77ed58fb, 0x7642e405, 0x646febef, 0xcf5d334f, 0xe073a04f, 0x77c8b635,
	0x3db8bcb9, 0x92b043a5, 0xf5052df6, 0xecc0fa7b, 0xd6e71344, 0xe8441e5a,
	0xa63a49d3, 0xb3f2170d, 0xe5cfed1d, 0xd2af5663, 0xe1f853fd, 0xed709502,
	0x402baf16, 0x7c49cdb8, 0xd9f28fa6, 0x1cf7e2e6, 0x11055cda, 0xbdfa17ca,
	0xb63964ad, 0x98060ca1, 0x0c5c05ff, 0x8b34bf17, 0x8ef99f7d, 0xe22fef87,
	0xa1e7e50c, 0x5993be5c, 0x6ef08635, 0xe7e66fd9, 0x728dfc33, 0xc1cbaf98,
	0x27fff296, 0x92f7a44c, 0xbe805fff, 0x0aeffa6f, 0xc8478eb4, 0xc7839751,
	0x105af225, 0xb7eba3f5, 0xdb3e5468, 0x1c1cb8d3, 0x1263c374, 0x3f25577b,
	0x69ffde4d, 0x8b2cf592, 0x16a2d45a, 0x2d45a8b5, 0x5a8b516a, 0xb516a2d4,
	0x6a2d45a8, 0xd45a8b51, 0xa8b516a2, 0x516a2d45, 0xa2d45a8b, 0x45a8b516,
	0x8b516a2d, 0x16a2d45a, 0x2d45a8b5, 0x5a8b516a, 0xb516a2d4, 0x6a2d45a8,
	0xd45a8b51, 0xa8b516a2, 0x516a2d45, 0xa2d45a8b, 0x45a8b516, 0x8b516a2d,
	0x16a2d45a, 0x2d45a8b5, 0x5a8b516a, 0xb516a2d4, 0xfa77ffe8, 0xae4e2e3f,
	0x0080005c, 0x00000000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d31,
	0x48b0c00c, 0x7ffe34c5, 0xecc81551, 0xabd53bc7, 0xb6db6db5, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xfb6db6db, 0x3f4c0fe3, 0x80005eab,
	0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d31, 0x48b0c00c,
	0x7ffe34c5, 0xecc81551, 0xabd53bc7, 0xb6db6db5, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xfb6db6db, 0x3f4c0fe3, 0x80005eab, 0x00008000,
	0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d31, 0x48b0c00c, 0x7ffe34c5,
	0xecc81551, 0xabd53bc7, 0xb6db6db5, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xfb6db6db, 0x3f4c0fe3, 0x80005eab, 0x00008000, 0x00088b1f,
	0x00000000, 0xc5edff00, 0x30000d31, 0x48b0c00c, 0x7ffe34c5, 0xecc81551,
	0xabd53bc7, 0xb6db6db5, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xfb6db6db, 0x3f4c0fe3, 0x80005eab, 0x00008000, 0x00088b1f, 0x00000000,
	0xc5edff00, 0x30000d31, 0x48b0c00c, 0x7ffe34c5, 0xecc81551, 0xabd53bc7,
	0xb6db6db5, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xfb6db6db,
	0x3f4c0fe3, 0x80005eab, 0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00,
	0x30000d31, 0x48b0c00c, 0x7ffe34c5, 0x4ec49551, 0xf54ef1fb, 0xb6db6d6a,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0xedb6db6d, 0x73101f0f, 0x73305934,
	0x00007330, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x00001000,
	0x00002080, 0x00003100, 0x00004180, 0x00005200, 0x00006280, 0x00007300,
	0x00008380, 0x00009400, 0x0000a480, 0x0000b500, 0x0000c580, 0x0000d600,
	0x0000e680, 0x0000f700, 0x00010780, 0x00011800, 0x00012880, 0x00013900,
	0x00014980, 0x00015a00, 0x00016a80, 0x00017b00, 0x00018b80, 0x00019c00,
	0x0001ac80, 0x0001bd00, 0x0001cd80, 0x0001de00, 0x0001ee80, 0x0001ff00,
	0x00000000, 0x00010001, 0x00090404, 0xccccccc5, 0xffffffff, 0xffffffff,
	0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc,
	0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc,
	0xcccc0201, 0xcccccccc, 0xcccc0201, 0xcccccccc, 0x00000000, 0xffffffff,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000, 0x40000000,
	0x40000000, 0x40000000, 0x00088b1f, 0x00000000, 0x2bdbff00, 0xa3f0c0c5,
	0x495f811e, 0xf0a43032, 0x12d18aa0, 0x6064e12f, 0xd2c406f8, 0x560c0c5c,
	0x802b7b40, 0x0e206ef4, 0x986066e0, 0x7f584dc1, 0x43031311, 0x01971009,
	0xeb100571, 0xe8303230, 0xbf6f1232, 0x1ed0108c, 0x3aff0431, 0x825ffd90,
	0x6c1ffe7e, 0xbe995d58, 0xda026df6, 0x551b4c77, 0xff1a38ec, 0x337e3684,
	0x9fc9a24e, 0xc69fe342, 0x19ba7fa3, 0x3e9eff2a, 0x21a9ff2a, 0x39bd8303,
	0x1f5f7f82, 0x71d05bbf, 0xbe6f501e, 0xe87a6939, 0x4daf0189, 0x0400700c,
	0x00000400, 0x00088b1f, 0x00000000, 0x7de5ff00, 0xd554780b, 0x733ef0b5,
	0x27bcce66, 0xf083c813, 0xa0280388, 0x81093885, 0xe1eda446, 0x188b6221,
	0x84542b14, 0x27bc8f09, 0x58bd1113, 0x208337ed, 0xd436b50f, 0x3b06c168,
	0x1341a081, 0x9040301c, 0xc4580380, 0x6e1b6aff, 0x1d2d55f1, 0x4c428284,
	0xade17c42, 0xb5af7f96, 0x739cc9f7, 0xfda81132, 0xd3f8fbfe, 0xd9d66ecf,
	0x6bdaf5ef, 0x1ef6bdaf, 0x5241d1a3, 0x05c8447e, 0x8e69a3f8, 0x26321081,
	0x6cb22e9e, 0x6fb2711a, 0x266fff3c, 0x92322b32, 0xe94a91e6, 0xeff151d6,
	0xe5843c84, 0x595d5837, 0xccd20924, 0xcfd17130, 0x240c5353, 0xdc7b908d,
	0x2436ff04, 0x2e4299cb, 0xcd6b9d21, 0xe9838dee, 0x25c79377, 0xcd74d0a4,
	0x80487750, 0x80349e7a, 0xdc98d73b, 0xbe4c291b, 0xb19220be, 0xac2d1884,
	0x6876813e, 0xeff0457b, 0xce9884a1, 0xc747c48b, 0xc04afa67, 0xcc898374,
	0x33e3a7cb, 0x13256fb9, 0xb9f1f11c, 0x87c9f253, 0x8936fbf4, 0xa6efd3e6,
	0x6f8b7c94, 0x6aff3c64, 0xc9f8e022, 0x5f6c41d7, 0xf761efe9, 0xe71916ad,
	0xdfd5121b, 0x2e5ddc3b, 0xcb70fef8, 0xcd0ed86d, 0x0338c031, 0xcd0f3e30,
	0x2250f94f, 0x71fb7886, 0x1fb1853c, 0xd0b4f605, 0x884fbf7e, 0xa737caf0,
	0xf2f79d08, 0x998f261d, 0x0ed265e2, 0x1447f453, 0x610ad7f6, 0xacfb0d80,
	0xb5bc5084, 0xea3830d7, 0xff286494, 0x69851d49, 0xeb730113, 0x5e03d7e3,
	0x23648877, 0x788f9376, 0xade0a53f, 0x5685c199, 0xf76bfa06, 0xc5fa85cf,
	0xa56266cd, 0x1777f9ed, 0xc29ebf4d, 0x044d8745, 0x2f37f88a, 0xb853fa93,
	0x00442c24, 0xb04898ee, 0x314ed0ff, 0xef9699bc, 0xdda6b570, 0x2678f14e,
	0xe19e2168, 0xd6cedc74, 0x0f1499b4, 0x536de1a5, 0x83695ea0, 0x9a1605e0,
	0xa1f363b4, 0xbfcf5a0c, 0x299af045, 0xedeaca5e, 0x8d8233c4, 0xeffd02e1,
	0xfd189354, 0x4c5fcd11, 0x030649e7, 0x10a6ab5d, 0x2b5ffa11, 0x3c719c79,
	0x208e099d, 0xf61c731e, 0xd0fda16f, 0x055b157a, 0xc2b14c2f, 0x97c07c40,
	0xb3adbbed, 0x7e603936, 0x4e61a4cb, 0x092ad798, 0x0b8515ca, 0x303d5a76,
	0x0a695abe, 0xa9ad2fcd, 0xf4550a95, 0x1effab2f, 0xe35458f1, 0x5d34375a,
	0xf4fa1fcd, 0xf513650c, 0x91094a78, 0x83600e23, 0x254334b0, 0x6485fd17,
	0xbd5977a4, 0x629f69a8, 0xfa549092, 0x7fd16fff, 0xf6857c52, 0x0aaf113a,
	0x3e7316dd, 0xc5d6e852, 0x3b1887e5, 0x57dbaac7, 0x0e81c7d2, 0x41553c74,
	0x0ebfa637, 0x3ab4c3f6, 0x3cfa41e8, 0xe9a3f805, 0xaedc7c63, 0x918264f1,
	0x8992ebf6, 0xcfacc41b, 0x89827934, 0x19f27dc2, 0x27c7369c, 0xfe65be78,
	0xc994fa4a, 0xf9320057, 0x1b229924, 0xf92c2833, 0xda5e26ee, 0x7916f1bf,
	0xbc8475f2, 0x82bf7c4a, 0x5f068bf9, 0x9095d031, 0x4a7cbf48, 0xd5029597,
	0xab5f1423, 0x0f149260, 0x3f28332b, 0x753d3a53, 0xa24dd8d7, 0x029ae7c0,
	0x8fb3e170, 0xd676c60c, 0x6d123b61, 0xdbc5e867, 0xa79b9b49, 0x6e6d2769,
	0x2d4ed2b1, 0xb4bb63b6, 0x3b9a9e76, 0xb99e3b4e, 0xcf3b4aa5, 0x75d13943,
	0x9b4af369, 0x9e3b5e37, 0x4ed8e579, 0xf12f1cfa, 0xc2a2f2d1, 0x1655a43f,
	0x21a3be69, 0xa211e739, 0x3b89a3e6, 0x95273da1, 0x251f352a, 0xf234d9e5,
	0xd1f72c94, 0xf6a77dc0, 0xcd4f94d7, 0x4fc9a21f, 0x8e8d759f, 0x53ee1d2f,
	0x0c30e3df, 0xb94165ca, 0xa84bfa97, 0xb7f42677, 0xebeff8e0, 0x73bd40ef,
	0x70df38df, 0x8c371d37, 0xdffa5095, 0x75aef927, 0x3a1be027, 0x83f4812f,
	0x548063d4, 0xc4cabf9f, 0xc07136f0, 0xd38ec3d7, 0xe74301fa, 0x1f0a64b0,
	0x0dbc2616, 0x9400fef3, 0x4d9ba529, 0xce509524, 0xffa82666, 0xbb1e0d56,
	0xebc2a429, 0x5f9441ea, 0xabbb7884, 0xc07ebe4d, 0x6550b18f, 0xe573f808,
	0x93228920, 0x32a4e390, 0xd692ba1a, 0x0fd8541f, 0xa8966ff0, 0x2ff750fe,
	0x6247fed1, 0xffa0a7ff, 0x37fa5eb6, 0xf4d3c90f, 0xd62cc96f, 0x68916ff4,
	0x3a3e54ff, 0xff794b43, 0x08e37f14, 0x62964739, 0x62cce6ff, 0x44957fec,
	0xdbfd358a, 0x02fffbba, 0xfa1afdfa, 0xff304d4f, 0xf3b4e321, 0xced52ccf,
	0x27f3625f, 0x7fbc42cb, 0x105fce1b, 0x99fe6c42, 0x66fe6ca5, 0xff776ed6,
	0x4bfc6eae, 0x21d7ed02, 0xa1ff32f4, 0xbff3b5e3, 0x7f3b5ca2, 0xbddfeb33,
	0xdfef356c, 0x0b27fd81, 0xaffcd9ab, 0x25fec728, 0x7c0bcfb3, 0x55b00d24,
	0x1d3d6186, 0x1d280548, 0xe98ca075, 0x50843e88, 0x64eff27d, 0x3ee1e208,
	0x2fbbe31b, 0x1cdf946c, 0xc24a7d71, 0x3ae90254, 0xba79c15c, 0xc48261ac,
	0xae10e7d6, 0x50f88beb, 0xc88b3617, 0x1cdaa4d7, 0xb78e8abe, 0x010c59bd,
	0x07fab0bc, 0x53d71161, 0x23104766, 0xbff7c289, 0xa36a393d, 0x74fa5e7a,
	0x54e99551, 0xdd57254c, 0x19227dfa, 0x57c74951, 0x26304c09, 0x7aa29f0e,
	0xfc3d509a, 0x90c7d521, 0xbb31369e, 0xe3d524e4, 0x6e5ab864, 0x24bb3196,
	0xa08e8e44, 0x1f29ffe3, 0xc32329ff, 0x4225a9f7, 0xc5fff018, 0xd025bbda,
	0xecaa8b67, 0x71f1e914, 0x3a9d3804, 0x68c39b77, 0x00e5d14f, 0x8a0773f0,
	0xd97f2122, 0x8121f377, 0xeb4569da, 0xcdea6afa, 0xfb87e121, 0x1e0bf2d1,
	0xa6e4182b, 0x9673bff3, 0xf5844739, 0x0c03c889, 0x8064c728, 0x59908f21,
	0x034d6b4d, 0x2cc77028, 0x553187d3, 0x2d3ed9fd, 0x16b1677c, 0x4d85376e,
	0x4a67b006, 0xdb4b5204, 0x9b52abbd, 0x5533f4af, 0xcae8c3e8, 0xc529fbfb,
	0x74fd0641, 0xf039a417, 0x9d748dd9, 0x957566eb, 0x301e04f1, 0xc7ae2891,
	0xf48254b1, 0x3e72c54f, 0x7eb79b37, 0x164d73bc, 0x678e9f39, 0xe222fdee,
	0xd8fe3f53, 0xc86cbb3e, 0x4fbae9a2, 0xfa82c04d, 0x3fc7e8f9, 0x3e7ea96f,
	0x87d6096e, 0x3bfe9082, 0x3f3d13e3, 0x3c279a05, 0x4fc55271, 0x4f4dc8fe,
	0x2bd5549c, 0x81a19fab, 0x35b3c24b, 0x15d68be5, 0x5517f268, 0x17f26895,
	0x035bbeac, 0xd7ee8417, 0x74b79f94, 0xaeff2699, 0xfc9a35ca, 0x6ad78b3b,
	0xf5bed9e0, 0xcc77f29a, 0x0be4d5aa, 0x88ae4afb, 0x5df55ea1, 0xeb760191,
	0xfc02667b, 0x22bbf0a8, 0xbb511f0f, 0xd433d205, 0x1974816e, 0x7f9529c8,
	0x06966ec3, 0xe15c1636, 0xa7f5d956, 0x2099954d, 0xd7be7a4f, 0xdfcf53e3,
	0xa2406ff4, 0xcb494875, 0x7a0f9205, 0xe7af83ae, 0x056bf7ca, 0xb647e703,
	0xfbe729df, 0x19edf289, 0x53bf6113, 0x5587452e, 0x976f7a3a, 0x079c0444,
	0x153d2b01, 0x55b946e8, 0xfab2b785, 0xb6719aa1, 0xffb117ed, 0xaa5d900a,
	0x7e49b2ff, 0x20fa00b3, 0xb6f3307a, 0x791e3051, 0xd267e837, 0x6feb8a9c,
	0x13ea705b, 0xbf804d27, 0x0a3f4c7c, 0x54f4c2ce, 0xc9e987d0, 0x1fa63160,
	0x8d312b06, 0x7a629705, 0xf4c2182c, 0x4c6ae083, 0xc2ac1cff, 0x3ae0ddf4,
	0x860edf4c, 0xca0f6d31, 0xdb7c2a98, 0xb9f327ad, 0x17f7cadd, 0x5bb303f4,
	0xfa445cf9, 0x479456ef, 0xc7903f6f, 0xc317c72e, 0x7aef2ec0, 0x70791297,
	0xf3d2f8ef, 0x2578af43, 0x8515da32, 0xbee74a61, 0x36adf33d, 0x81ab2746,
	0x6f54254c, 0x59eab9ac, 0x0891fcef, 0xa81f491b, 0x70cef61f, 0xae976826,
	0x8baf4051, 0x9dc889d1, 0x3e1fb059, 0xc7dff4f5, 0x0ad7bb42, 0x797ad843,
	0x92f5c450, 0x81793744, 0x378b975e, 0x64bf95e1, 0x927cdc82, 0x35afe0aa,
	0x6ef4d093, 0x77ed8dc1, 0x11899935, 0x0f62d8f0, 0xebb616c3, 0xac1726f0,
	0x89fb8b77, 0xf7472755, 0x647f2f8e, 0x35439570, 0x16b3409f, 0xa612aaee,
	0x27be7db2, 0xe028e669, 0xc9d5772b, 0xfdfe80ab, 0x59da5530, 0x7ec24fdc,
	0x692d7d94, 0xa53e4648, 0xf72c42fb, 0x6f471eaf, 0xd1c7c4ed, 0xdc504e44,
	0x185cb881, 0x4bfdf17a, 0x3f1b7a0f, 0x4e81f293, 0x602fa62d, 0xffd1b73d,
	0x76810c2e, 0xed2b088d, 0xc8622206, 0x6f7c2d7c, 0xeb47f4d0, 0x373d9479,
	0x5f9debd4, 0x3294e48d, 0xb2daaa4f, 0xaca5bfb9, 0xd5a55ade, 0x381ac9fb,
	0xa5519cd0, 0x1fe00759, 0x2cc9ee54, 0x537c08c1, 0xc3a8b9ce, 0xd02d58e8,
	0x1e0c39f1, 0xb020376c, 0x4c4b7e72, 0x8b4fd1f2, 0x7ed13877, 0xed96bc58,
	0xb65b29bb, 0x3f305d82, 0xfdc0378f, 0x547b4a2e, 0x85031303, 0xd9487017,
	0x2a6fceff, 0xef7a069b, 0xc124246f, 0xb163e626, 0x21d82c6a, 0x095a91a5,
	0x109f23fc, 0xffe054c3, 0xb87fc84f, 0x05f6ab46, 0xca120c73, 0xdad582c1,
	0x51da90f5, 0x9d68b81a, 0xb7242e16, 0x17bf01a6, 0x58489b56, 0xe6d4b900,
	0xb1b8334f, 0xb95222dd, 0x1389d612, 0x7a7fa34d, 0xd771e03d, 0x6760b186,
	0x03d9a7ce, 0xd697bca8, 0xf0bb411f, 0x812ffb72, 0xfb3d39fa, 0xc3d5e655,
	0xe0f1c02f, 0x70e417af, 0xc4a17582, 0x5c4efdc0, 0x8f9cfc2f, 0x5713b15f,
	0xeb5fe0ea, 0xf07467e0, 0x293fcd3f, 0x0e3fc344, 0x21a56f83, 0xd80bf195,
	0x53b1824b, 0xf6977df2, 0xff68f5fb, 0xf6d2ffd7, 0xc7f6d207, 0xe67fda6a,
	0x95feda5f, 0xbcffc63d, 0xf6cf4c61, 0x771abbfd, 0x28fea886, 0x1749f17d,
	0xb1f622a1, 0x4bcd2ab1, 0xf9be5fe9, 0x7e17f461, 0x80b90c64, 0x8b0e3f2f,
	0xf609c353, 0x07e031c9, 0x87642fb4, 0xf818fb00, 0xccff6d27, 0x874e8ff3,
	0x9b17c87d, 0x9fdc6e4d, 0x66a39bd4, 0x4d15772a, 0x1648d325, 0xbc19c7c2,
	0x70089cea, 0x4b3f96b3, 0x0d327b9f, 0x539469fc, 0x451efdb8, 0xeea2a7fb,
	0x3d60536f, 0x944e9009, 0xe83d7d17, 0xd41f7cff, 0x52520577, 0x4e3a7ccf,
	0x1c03abb4, 0x47a6812f, 0xf7e089cf, 0x77b43125, 0xb98be5f5, 0xe0c4731d,
	0x4d45394c, 0xf27df236, 0x0a7fd07d, 0xd998483e, 0x0daee231, 0x6d0fb059,
	0x9777fbab, 0x6293c2a0, 0x16457577, 0x4f65eefc, 0x9db5faef, 0xf5e2abef,
	0xd3cf58c2, 0x16afedcc, 0xa29b9696, 0x967bf02e, 0x21bc9ad7, 0x71bcb9fa,
	0xc34fb3d3, 0xb33df0be, 0x7eda2af7, 0xdfefe359, 0xb2e1471e, 0x6994a66d,
	0x5a42f49c, 0xfa012e9c, 0x389cd2df, 0xfa5f4a1d, 0xc519e4bd, 0x27d83fbe,
	0x6db28f4e, 0xaa3225fb, 0x45263e27, 0x47314bf6, 0x8e44ba02, 0x493b014f,
	0x048df5dc, 0x9f78ff74, 0x2707d240, 0xefed67c0, 0x3c07bd71, 0x9d391d21,
	0x2ba6e9ba, 0x0174a01f, 0x49d0acfd, 0xd712ff9f, 0xf81ed027, 0x6f3f28ff,
	0xc4fc197d, 0x617b367f, 0xef5bc5fe, 0x4e3cc171, 0x5f192b1b, 0x4d38786f,
	0x9b16fda6, 0x4c6e6942, 0x67e2f7d9, 0x2b7e45ee, 0x1a6f723a, 0x19c97fdb,
	0x425b5c06, 0x45bf3019, 0xfce3b735, 0xf90f890a, 0x988378ae, 0x73f1fa0f,
	0x2dba9923, 0x54fc5c81, 0x7a717264, 0x9d2a2523, 0x7cba69df, 0x3ff4dfa0,
	0xf466f0c4, 0x404ddc3f, 0xfc55effe, 0xc23164dd, 0x9d185b9f, 0xdd8a8946,
	0x3536ad4e, 0x6aadd6bf, 0x199cfa05, 0xdf83a724, 0x218c402a, 0x02e10f8e,
	0x723c576d, 0x0fa33a43, 0xf2c718f1, 0x9f5d747a, 0x7ca1df04, 0x66b649ab,
	0x0b91ea69, 0x2ffde383, 0x71d3fde1, 0x3e3d60db, 0x238a469d, 0x90f7e609,
	0x5d3dc8a8, 0xa5fc5587, 0xef266f92, 0x7c986b75, 0x9e1ef22b, 0x3ff21531,
	0x07e4ca3b, 0x44fac1ea, 0xc74d15c7, 0x0533fdfc, 0x126607d4, 0x75d7244d,
	0xdad72e26, 0xe84f857c, 0x92428db8, 0x5b085f8a, 0x7f734f3f, 0xad356155,
	0xd09fd6a7, 0x7b67ab9f, 0x7116dc8a, 0x6a219ff9, 0x30d49fe5, 0x5eddefb9,
	0xca7e210a, 0x9f67e14d, 0xf2a57906, 0xbc80f219, 0xde61f29a, 0xbe0e1b67,
	0x272a33fd, 0x9c8a2367, 0x5ea7f56a, 0x6fb78b4e, 0xf53f8016, 0x98b67a72,
	0xe489155a, 0x284f7e94, 0xffb1c5a7, 0xc153faa7, 0xfc3afddf, 0x37b0fa29,
	0x61f5ea3c, 0xa849e89a, 0x51dfe90f, 0xff27b632, 0xf0a77c29, 0xfe0be95b,
	0x74ef402b, 0x77c2a5f3, 0xf0a97cdd, 0x877f0f5d, 0xf03d7f06, 0xa740bc0c,
	0xadfbbf90, 0x3d280329, 0xb9d85bcb, 0x0877ad11, 0x19278a60, 0x75523197,
	0x1a8a4068, 0x88e0eb0e, 0x83acbcae, 0x7de575f3, 0x5752b83a, 0xfbf6cc3e,
	0x822507cd, 0x94d5107c, 0x42443d37, 0xedb3f04e, 0xd6cfd115, 0x92bcc741,
	0x1868efd6, 0x7d510e1c, 0xed95b0f0, 0xa5533af7, 0x3abfa095, 0x3eae9ddc,
	0x7f995b00, 0xd3bf23a1, 0x0fb2ac95, 0xa888b78f, 0x3261637f, 0x887fed55,
	0xc472c3cb, 0x96f48c53, 0x3786fccf, 0xa5cc8e88, 0x12ac3fb0, 0x64fc94bd,
	0x5c3bb2e1, 0x68ee4ae0, 0x2ccb7a19, 0xebd17dfa, 0x745f1e22, 0x2db9d8d8,
	0x0cc6c909, 0x11ff9d95, 0x1e353d09, 0xcc2d80fc, 0x98f85fce, 0x2c771ece,
	0x521f4091, 0xad43fc7b, 0x75f193ff, 0xb8a76f29, 0x4a5f9b46, 0xa27e431e,
	0x56fdc474, 0xdf369d69, 0x6f2bf7c7, 0x4d9e7c2b, 0xc04f51b2, 0xcbf60446,
	0x20deaf5c, 0x1665bc8e, 0x61c77bc5, 0x749f0091, 0xf78888b5, 0x5f6506ae,
	0x52f28a93, 0x9f513a41, 0x0369f829, 0xbbde1879, 0xf1db69be, 0xd00fb197,
	0xdf3be522, 0x4d2dfacf, 0x37be76db, 0xbbc00f6c, 0x9f7cc9de, 0x693f2cf4,
	0xacfd159f, 0x789cfb1d, 0xf7b1d22e, 0x0007cccd, 0xe2f66dde, 0x2fbef079,
	0x3a6f80b3, 0x8317321e, 0xc418eabe, 0xef97d1ce, 0x862b32fd, 0xa40ae3eb,
	0x98946097, 0xf7f2d37d, 0xde0e7063, 0x056742d5, 0x3b3efeeb, 0x2f03abfa,
	0xdf9f715b, 0xdc4bf7b1, 0xe6abfccf, 0x3fcfc153, 0xd6649c3a, 0x325f1876,
	0xf6071bf3, 0x1969b75c, 0xed370f9c, 0xfcd01697, 0x937caf49, 0x63b07a05,
	0xda67b33b, 0xc067b14d, 0xf158efbf, 0xc51332e9, 0x43083b73, 0x57ea427f,
	0x8d0c4ee4, 0x6f97844c, 0xa9717fd0, 0x3ffa18f8, 0x9e021f06, 0x38b795f3,
	0xe60116c3, 0xf7b1d5fd, 0x99f7fe41, 0xf9952f91, 0x432c8d9e, 0xf362e37b,
	0xfb64689e, 0xf33dffe3, 0x3297a216, 0xe6ff82ef, 0xeb0d3ef4, 0x394f6a66,
	0x7be7c9e8, 0xd1b843ef, 0x5ef1c5e9, 0xfb2fbf22, 0xedf746df, 0x8baeee94,
	0xdffc3bcf, 0xd3bdde7c, 0x9cb9f5fd, 0x1f386eee, 0x0df2bc0f, 0xf572ef8e,
	0xe87ff45c, 0xfcbb15fc, 0x68e78335, 0x953f2d36, 0xa0c03954, 0xe07fc9b8,
	0xfb9a6cf5, 0xc983c0da, 0xfc89de30, 0xbe3f453c, 0xefb64673, 0xbce42899,
	0x92fda3eb, 0xb377a764, 0xdc79d707, 0xf6e00d07, 0x852580c3, 0x180c7f68,
	0x37664bf8, 0xc527f9c0, 0x0a7d6bcb, 0xfb2e70c2, 0x118c659a, 0x196a1aec,
	0x5d9f9838, 0xadfc1fbb, 0x4a386440, 0x93f9901c, 0x0e9760c3, 0xdda2281c,
	0x57b4534a, 0xcbdf2b27, 0xe5becd25, 0x1f768f26, 0xbb452533, 0x35d579df,
	0x40ddeb15, 0xa6cd1c86, 0x62c1bfe3, 0xf8e98772, 0x33e09a6f, 0xca6f1e02,
	0xea954810, 0x43b278dc, 0x309bdedb, 0xafff950f, 0x14bbb2c8, 0x5e2cede2,
	0xc3b7f701, 0x4fa80cdb, 0xce02b92c, 0x233ac477, 0xee0c47c2, 0xe9e78031,
	0x7b3aefd7, 0xa77f013f, 0x9438b12c, 0xfebfe67c, 0xf185c2fa, 0xcd7f6163,
	0xee5e20fe, 0x2f9f6a66, 0x1b5121ac, 0x2322ef9d, 0x01f52509, 0x3e40a77f,
	0xb53bf8d4, 0x30fdfc30, 0xc5cede2d, 0x87c6f7ca, 0x1774eaff, 0xaf0ffbe5,
	0xa4376422, 0xfcc51e78, 0xea3eca73, 0x5f0c2dfb, 0x78483781, 0x16b73b08,
	0x3be755f3, 0xef8c4db3, 0x7db07d76, 0x2663ec34, 0x624c8c74, 0xe2cb98f2,
	0xd97db8f8, 0x5e493c45, 0xd0e3c807, 0x3ab73c24, 0xc5133a2c, 0xfbe16d85,
	0x3ce017ab, 0x751da693, 0x3b044aa4, 0xdfa2749f, 0x2167542e, 0x0fc4139b,
	0x7e29364c, 0xfa374e09, 0x17fed227, 0x22ffd612, 0x4d49355a, 0x1f69b6b7,
	0xd27ab31b, 0x543efe01, 0x577c279d, 0x0e7ec2fc, 0x1ac5bbf0, 0x409f929b,
	0xf1ca7f6e, 0x57c0fd37, 0xa6baefe8, 0x7200d6a5, 0x419d4d7e, 0xdd362e73,
	0x8877ed44, 0x3921ca27, 0x07e9ae30, 0xa05cceac, 0x0bd161cb, 0x968178f1,
	0xc12f9273, 0x9f1e8eb9, 0x4ff83ed0, 0x51b9331f, 0x2298f65e, 0x7baf000b,
	0xd810b13e, 0xaa96ed5f, 0x938d12ca, 0x7d7f9998, 0x93dc8911, 0x1fbff835,
	0x3874277e, 0xbf6113a2, 0xae504752, 0x411ff27b, 0x27aaee3e, 0xb0c7d061,
	0xd0bd01bf, 0x3d7040d5, 0x25f928a0, 0xbca8cfec, 0x6fbd48ff, 0xedbcde1f,
	0x2a475805, 0xb837045a, 0x318c2b94, 0x8172fc09, 0xf41164e6, 0x8947b676,
	0x9a8f7457, 0xc78b92a9, 0xd7c4464c, 0xee7b71c1, 0x6d3f7e84, 0x6bac0893,
	0x2e9dabf2, 0xb69ffbd0, 0xe839468c, 0x052f5e6d, 0x1364e949, 0x3f9043b4,
	0xb230fcf4, 0xaf81a6c1, 0x41fd7d17, 0x639ba6be, 0xe809bc4b, 0xfc092597,
	0xf512e73c, 0x33fff85b, 0xd15476fd, 0x5f313e6f, 0xf45f4725, 0x89e96fd4,
	0xc162dbf4, 0x5f780e93, 0x3a6877bc, 0xebf175d0, 0xfa44d4a6, 0xcec831ad,
	0x71e45eb5, 0x544d1da6, 0xd2ab5dbf, 0xbf544d6f, 0x8fc73825, 0x7d7c0c99,
	0x0b7e88bb, 0x5fc8d7ff, 0x04b7e823, 0xa754fdf3, 0x8e5ab2df, 0x6acb7ea3,
	0x27e26832, 0x7fb898cf, 0x26fd57a2, 0x7b04cea4, 0x6bc9b0ea, 0x8d3fc04f,
	0x917b7edc, 0x3f40c1c7, 0x96aee7a0, 0xe7a597dc, 0xe7aa971c, 0xacf08bfe,
	0x3bc5b9e8, 0xf691c608, 0xe7a643e4, 0x7aa6ef16, 0x647e004e, 0x5ef16e7a,
	0x3a38fcc2, 0x87a236fd, 0xbe58237e, 0x07eaca22, 0x66ff079a, 0x472f6d0e,
	0xb42d7936, 0xdf5c4e7c, 0xbbeb518d, 0xf45ea5ab, 0xd34be1dd, 0xbeb83b77,
	0x086c7aa3, 0x7f3d57e8, 0xf1b45b78, 0x3bae7bb9, 0xc812f0dd, 0x9e229bcb,
	0xb0311d2f, 0x5c3f80f3, 0xf8173a77, 0x33c7c42b, 0x6cf46253, 0xfdb0860f,
	0xf9b2af49, 0xbc581bf9, 0xb313457f, 0xc4ea2b0f, 0x73fe87b0, 0xf0afb8ca,
	0xaf64a89c, 0x3c29d240, 0x94f55cc3, 0xe7e9ec03, 0x8f9d844c, 0x2ad96990,
	0x5798587e, 0xe5dd7e86, 0x4246d756, 0x91a178e5, 0x5b7fc058, 0x31f298e6,
	0x7965b3d8, 0xc65bdfcc, 0x83712bbf, 0xfea4fc4a, 0xf9b0bc9c, 0x480343ee,
	0xe9f2f3cf, 0xe9d74666, 0xc430849b, 0xcdcfe9f9, 0xf50fcee9, 0xf6bd5942,
	0xfe7cbdfb, 0xe218c433, 0xf451fc8b, 0x3f204e6e, 0x74f1eaf7, 0xe289e398,
	0xb0a78345, 0x944f1090, 0xd3b2d3d2, 0x792978e2, 0xfc12b633, 0x05eb25be,
	0xcfd40f3c, 0x7e9bc15b, 0x151e0afe, 0x6f1967bf, 0x16a5a8af, 0xf1e881ef,
	0x8f59e0a2, 0xebbc6e8f, 0x126ff1f0, 0xc9b2a3b7, 0xa1338868, 0x267a837c,
	0xdc447ff4, 0xb84fe52f, 0xe15f734a, 0x1cdd7c17, 0x1261355d, 0x80cf5f1c,
	0x6f385db8, 0x21f7775b, 0xf31bbf88, 0x960727ae, 0x99c7ebd3, 0xb6ee707d,
	0x7a89dac5, 0x3fc3e150, 0xe06c3e71, 0x5fe9eced, 0x85f71139, 0xec1b82cd,
	0x8ad44090, 0x7e500d78, 0x0722d2b4, 0x85317fd7, 0xf78dd5e3, 0xfaf99a51,
	0xa060e944, 0xeb28a7e5, 0x5fdd9855, 0xe8c2dd19, 0x7467a812, 0xe89d25c9,
	0x2758af6f, 0x3e74a378, 0x6377cd15, 0x9fa2867c, 0x4d439fe9, 0x6bfc04a7,
	0x04bfc44c, 0xe363939c, 0x2f1966eb, 0xf55cdd37, 0xa7eff836, 0x45a8f953,
	0xfbffa436, 0x11eefe16, 0x9ba7a207, 0x38475e8e, 0xaf011ade, 0x275fc00e,
	0x5fa2bfb3, 0x2516bde1, 0x690c603f, 0xe9e93af0, 0xf6ff8cf3, 0xa3f01e0a,
	0xf80de374, 0x518fe699, 0x0cfc06f0, 0x10296874, 0xf8a42e01, 0xe7b83bee,
	0x4c1ce17c, 0x7b25f72d, 0x37f6b38f, 0x60925e08, 0xdfcd97de, 0xbdd7c997,
	0xa49ffbc9, 0xf23f3f6e, 0x9dac1ff7, 0xfe068c6f, 0xdca02bde, 0xcd649693,
	0x12a7d6b9, 0xb16d37db, 0x73803952, 0xde4dd797, 0xfa9e9e8d, 0x33c724e1,
	0x2a3c27ec, 0x30d5c93f, 0xabfb8811, 0x16fc60b7, 0xb308638e, 0xbafad557,
	0x67524ad1, 0x7edef6e6, 0xbd3fd717, 0x3c0a4bd9, 0x3d03fa0a, 0x1bfb4cda,
	0xbf4fef11, 0x807e285e, 0xc2ebcd8b, 0xd2979c77, 0xc3c6e5cf, 0x9e2b4804,
	0x317128a3, 0x2eef830e, 0x7977d813, 0x3a33f8da, 0xefe74e72, 0x9a7ffedc,
	0x9f6f7b52, 0x1da0b3f4, 0xbc2fdca1, 0x10907441, 0xb2a7dbc5, 0x5a85e509,
	0x878d6f19, 0x5d2263f5, 0xe9f26907, 0x99de631b, 0x9e22f983, 0x66f2dccb,
	0x5f9c3f5f, 0xa062c2dd, 0x02d92dc8, 0xa0470fda, 0x0ec0ebb1, 0xccd910b7,
	0x79f9a4bb, 0x7f464fdf, 0xd55d7653, 0xeb950f24, 0x72f0fa9c, 0x3a93bd48,
	0xf400fe53, 0xa012209a, 0x77dcab57, 0xf7bfac12, 0x83648dfc, 0x09da8ceb,
	0x61ce4ed8, 0xc6e50a92, 0x9db8a9c9, 0xb3e9aeb9, 0xf1d1b7a3, 0xe886f75d,
	0x3372d0f5, 0x201c3a0e, 0x0c6a2367, 0xcbc2a7c4, 0x0e5e1238, 0x9dd7cbe7,
	0x7d036f94, 0x1eed4c50, 0x6e2fc788, 0x02ee5da9, 0xfac046b8, 0x8a6f9081,
	0x71af8e8b, 0xdf29b9dd, 0xcb40bd03, 0x1a813341, 0x27502e56, 0xb4d42178,
	0x84ad65b0, 0xc04ea37a, 0x618d5f0b, 0xbb585881, 0xb76d0b61, 0xcfd686b1,
	0xd68bf585, 0xceeb7687, 0xf40dbd1d, 0xd6271d0e, 0xb1e7606f, 0x079eb485,
	0x6eeea4e4, 0x46a4af6c, 0xa06f7020, 0x4fad81b8, 0xbc986fc5, 0x7fb4df90,
	0xd3bbae3d, 0x83197f68, 0x4e8a3d61, 0xa317fbc6, 0x7bde3705, 0xbd44c94b,
	0x861301d5, 0x640eef0a, 0x8702e2e7, 0xb147fef9, 0x599bf6ff, 0x77a16d7c,
	0xb697d499, 0xd4bc87f3, 0xa7e406c1, 0x6bd81273, 0x7dbe2927, 0x2cb3d066,
	0xde60e14e, 0x5aa62909, 0x87998f1f, 0xcd85fd62, 0x7efcf013, 0xf3c7c911,
	0x31d7e9fb, 0x3f8ff3bb, 0x3a0586b0, 0x3a9a3fae, 0x83f7c207, 0xf7e3303f,
	0x87a646f6, 0xd0c507db, 0xc6ba7b4f, 0xc0bee044, 0xf5111af2, 0x1306e9c4,
	0x1b8b579e, 0x8bb7a84c, 0x721d991a, 0x7bb586b0, 0x6fd99eba, 0x3edc3693,
	0xa2e1d605, 0x36f9cacd, 0x3ecad3d3, 0xa25dd0b4, 0x7af4df59, 0x7ec3d156,
	0xaae28f8e, 0xd5873c5a, 0xb2bf5deb, 0xadf4ea1e, 0x315fce1f, 0x728a20ce,
	0xe3e88fe4, 0x7df11c84, 0xf443f00d, 0x8aefe42b, 0xf6044c37, 0xb689c235,
	0x8f9f3029, 0xf9a7bd61, 0x3208b5d7, 0xbf177f9c, 0x3da30e6b, 0xf7982e1e,
	0xde675873, 0x03c11333, 0x1e94e7f1, 0x99e54f54, 0x82783f3b, 0x88f8ff7e,
	0x28422205, 0xfe2014ff, 0xdccd7895, 0x239e2ccd, 0x1a7548f7, 0x9324cfdc,
	0x281ea2fb, 0x9f12275a, 0x2c7c6f4a, 0x8cfdb7c8, 0xb06e0fad, 0xe6ba147f,
	0xb085554a, 0x4c2dbace, 0x9b367a3f, 0x2eed7ef0, 0xfba23fbe, 0x2cc38c05,
	0x4d36bdd9, 0xc943f152, 0x5469b5de, 0x3c959075, 0xbf39621e, 0xb1225b97,
	0x09f64a7e, 0x3f555aee, 0xbb4a3b4a, 0x6f566ed2, 0xf6965ee8, 0x8c097ed6,
	0xb9f9e70f, 0xdf437a04, 0x7bfe8f4e, 0x4fef2769, 0x1ee1abe7, 0x451fde75,
	0x3bce3e0c, 0xfaa86d31, 0x9549405c, 0x47b185b8, 0xe156440d, 0x1b03ef2f,
	0x6ef45591, 0x9fe5431a, 0x66e6efd2, 0x8d35cf66, 0x73f92e39, 0xbc837611,
	0x747f7057, 0xde7664c5, 0x647d94d3, 0xb4ffc805, 0x81f9015c, 0xdf527c84,
	0x3cdfb414, 0x28b8508f, 0xa22fd597, 0x9b2e41f5, 0xa53933d6, 0xfa03c2fa,
	0xed66a2a4, 0x275f2c14, 0xa6fda078, 0x4bb402da, 0x8244f38a, 0xd1c775f9,
	0x3e6e2a4e, 0x4cf2029e, 0xec1ab7e5, 0x66f18a81, 0x4563a837, 0xff39152e,
	0x483fbf23, 0xe051ee2c, 0x420f9fff, 0xbe53da95, 0xb70837c5, 0x065c995b,
	0xfedc98f2, 0x3304d1b1, 0x473914bc, 0x58e456b9, 0x8dce3904, 0x9ac1f1cb,
	0xf5c81249, 0xf180b0e9, 0x0f409316, 0x116f9c80, 0xd98f7fb8, 0xe72a97b1,
	0xfd33b317, 0xbd617e54, 0x915ce454, 0xb73cbd6b, 0x6133631a, 0xc0fcf71c,
	0xf498f38a, 0xdf6fddc3, 0x9e15f4c3, 0xe1fa4dd7, 0x1fa069fd, 0x8e2c8d0b,
	0xdfabc147, 0x7abde2c8, 0x997aab8c, 0xe3297194, 0x61e38dd3, 0xbc1fd6b3,
	0xe2cc9ccb, 0xc84ceb97, 0xcf9317f7, 0x8976721e, 0x72a979f2, 0x54f93175,
	0x6af717fa, 0x4805d9db, 0xbdb3d31c, 0x28c78a76, 0x0d6be3c5, 0xf3ce309b,
	0x4f8fe793, 0xed943a07, 0xfc0e7ca1, 0x5124e0d5, 0x30c673d0, 0x4da55bae,
	0xb0718ca2, 0xdbd8e8c6, 0x66396a9c, 0x2f653ef1, 0xd2fdb8b2, 0x34f0e6ed,
	0xe774bf5a, 0xc38c2c89, 0xe313a878, 0x73cf4291, 0xcb14397b, 0x35283902,
	0xbd23b8b2, 0xc2c1b85e, 0xddb6e7ec, 0x3f3059f6, 0x07bd9ea1, 0xc3b91a50,
	0x539d5664, 0x9498b78c, 0x182e7872, 0xf70c7ca2, 0xea7c6125, 0xbc4ae87b,
	0xa616db51, 0x4d9b4a27, 0xa0577861, 0x3b5b7eb4, 0xbe968fc4, 0x57ff466b,
	0xc61cfea0, 0xb17a4fc3, 0x812bfd11, 0x9e735166, 0xaf6e23d6, 0x219a8c5e,
	0x8fc9acee, 0x3e147fe7, 0x7124708e, 0xe2c5eafc, 0xdc5ecacb, 0x514433bb,
	0x73d2f658, 0x672fd02e, 0x00bb375a, 0x6fddb4ef, 0x11ed9b8d, 0xf35917a7,
	0x677a71ad, 0x70191fe0, 0xbbf3950f, 0xdf58e712, 0x3a4aed17, 0x09f9b1be,
	0xedba3dce, 0x9fcfc6f2, 0xb6f23881, 0x819f67ed, 0xe3ff96f1, 0x9e2067d3,
	0xe2b3ec88, 0xfe78177a, 0x55c38c2d, 0x70b6adea, 0xe796c83f, 0xfdb97e30,
	0x5a17b33d, 0x3a7bdf6b, 0xdac8e213, 0x06957db7, 0x7b25cc7e, 0xef3f406f,
	0xd2931d92, 0x42f58249, 0xc36f8149, 0xad3f1097, 0xa6c1d7a7, 0xf4f71883,
	0xe837a509, 0xcbb8eebf, 0xb1c59f88, 0x65bc787a, 0xf538e243, 0x4d95f11e,
	0x03f2ddb7, 0xcc4dfbd0, 0x9c68bc8e, 0xc74a51e5, 0x7e812f6b, 0x347eca0d,
	0x813efd31, 0x3d3a507f, 0x59c6d16b, 0xe8b4de7e, 0x5e434f77, 0xe35edf53,
	0x8097a32c, 0xfe0e2537, 0xcdbc8b1e, 0xfdb37202, 0x056b8c05, 0xc0f34dba,
	0x2679f3fa, 0xc8f81fdc, 0xd61739d4, 0x66bdce9b, 0x74a50f7c, 0x3f283bef,
	0xa08e3bed, 0x78f09a5f, 0xfdd276f4, 0x0587e2c7, 0x273acf3e, 0xf8e4cf8b,
	0x8f4df887, 0x38f3bf0b, 0x4ac7c64d, 0x716f66fc, 0x985b1f9b, 0xe7c4adbd,
	0xe7deebfb, 0x7a719071, 0xa7407909, 0x0f1adfe3, 0xcdc1e0ab, 0x0e3c70f5,
	0x6c7c7139, 0xa73abc77, 0xd60fd017, 0x6338eea3, 0x41cc0f0a, 0x843bc87f,
	0xc81283c3, 0x8b2d7b6f, 0x69376e63, 0xe9c673ef, 0x4f93e2c4, 0xccade8ea,
	0x513937b7, 0xf362f5e4, 0x1d3c5cb8, 0x4c682305, 0x7db57c4f, 0x9b9f589d,
	0xbb77c2ad, 0xd053363f, 0xac916fdf, 0x71ff10a9, 0x1571625c, 0xe7cdbf7c,
	0xedfdc6db, 0x188bcf6d, 0x7232badf, 0x5eb9f510, 0xbbc0546f, 0x9bc60916,
	0xd15bc7c1, 0xb68bd6cc, 0x83b0ceed, 0x6076d3b6, 0x4575f237, 0x442971c3,
	0xff543bdb, 0xadcec492, 0x7ac11c98, 0xa7cd5611, 0x2cfeeb6d, 0xfdfcdfd4,
	0xc33f7d0c, 0xd6cfdcad, 0x409fb892, 0x3f4d39c3, 0xe488a165, 0xbfbc5c76,
	0x0ef94633, 0x2b4cef68, 0x44cf0bb3, 0xee89a9c4, 0x26acd977, 0xc555fe7e,
	0xe26eba52, 0xf64e213b, 0xb2e8882e, 0xc4b99da1, 0x526ef799, 0xc612a40a,
	0xc65f2cfd, 0xe17e84e3, 0x5ef407ed, 0x8131fcee, 0xf80c3ef1, 0x4c7bf955,
	0xfb011f6e, 0x3f2fd4d4, 0x7a0cfc17, 0x18a523bd, 0xef455848, 0xe9a9ce25,
	0x89073c1e, 0x1e7a040e, 0x826d3ecb, 0xf3aaff76, 0x48d5fd57, 0xf1d3a656,
	0x782435fd, 0xc976d197, 0xe50627d7, 0xafb67b3b, 0x4507bec0, 0xc2a97f8d,
	0xf60c79dc, 0x2b15e427, 0xfb883f9e, 0x42bef8ac, 0xce2b19e0, 0x2f8ee0f7,
	0xfb3b459f, 0xcec26677, 0x062ee883, 0xb37275de, 0xf8ef4e36, 0x83bf99f2,
	0x69950d1d, 0xd0cf45ff, 0x687fb0f2, 0xa77ee3b0, 0x16527b63, 0x3cafcbda,
	0x5af41d30, 0x63f19d91, 0xe1e98bd1, 0x53bdb4e5, 0xd53e0ca9, 0xf3ef0838,
	0x62776d97, 0x1dc1e1fc, 0x7d602abb, 0x0ed17f6a, 0xfda40561, 0xbfef6e15,
	0x5a1fdfc0, 0xe3a8f267, 0xd1884b90, 0x51d7bea3, 0xc7cb3006, 0x37f821fb,
	0xf811cb96, 0xf0939aad, 0x83b5083e, 0x627ced35, 0x8bcfbcea, 0xcfea1c7c,
	0xfb44c1ee, 0x97d03e83, 0xad2bf253, 0x613df843, 0x2f11cf5a, 0x0b3a901f,
	0x9fd55c19, 0x2c5693e9, 0xcf850bff, 0x76cf7e79, 0xac07f959, 0xdbc78f4c,
	0xf82bf561, 0xfe7a1ffb, 0x2ddbcd5d, 0x7866ffab, 0x122df7a2, 0xdfbf1f8c,
	0x0190902b, 0x566d95ec, 0xee08d77c, 0xfbbc43c5, 0x779d894e, 0xf8a2bb95,
	0xae1ec8be, 0x516dcb8f, 0x3fa4ef7c, 0x0794071f, 0x5b625898, 0x5dfeee81,
	0xe5ef0256, 0xca715ff8, 0xceff6f40, 0x36fd4f2f, 0xecdbe217, 0xbff3c7e8,
	0x07c86ff2, 0x2e74737e, 0xcdb61fbe, 0xb17de04c, 0x67af6db6, 0x99b6bc82,
	0xbe7d99a2, 0x1fcf1ce5, 0x07deeb31, 0x1338f360, 0x7b830df4, 0xcafdcacc,
	0xccf45ed2, 0xfb81ab71, 0xac17e5fb, 0x7da3cf18, 0xb04ce747, 0xdefaa879,
	0xb127a974, 0x6ac57c5e, 0xb2fca7fa, 0xd1dc7add, 0x2be29ee3, 0xcf6031d6,
	0xc381a6b4, 0xdfda82b1, 0xeb4bcfa0, 0x7f040f07, 0x72ab01c1, 0x0493dcaf,
	0x9301d1eb, 0x07d5f707, 0xaa067906, 0x828f99d7, 0x84d18f16, 0x3b4c1c7e,
	0xf615cf6a, 0x688f1027, 0xef48959d, 0x71dab11d, 0xb316a51e, 0xe39ee89c,
	0x7057ce31, 0x08fc048c, 0x287c82fd, 0x85301efd, 0xd4ff0f51, 0x0ced61e6,
	0xbdf04b0c, 0x50f77eac, 0x8c4a1e35, 0xca8e5855, 0x84b3e229, 0x2ab94b54,
	0x57f4adfd, 0x31e1d4b2, 0xe370fde2, 0xabf3767f, 0x3a33a718, 0xbbef558d,
	0xfd1715d1, 0x033dcaca, 0x02df29a3, 0xbe4893f8, 0xab0228db, 0xdbbca154,
	0x07530448, 0x7bd8bb35, 0xf4049552, 0xefdd47e4, 0xe34c105a, 0xf51fbaf8,
	0x2110687e, 0x7b860d57, 0xb7249efe, 0xad677f0a, 0xd98f1c2e, 0xbe984958,
	0x7b06e698, 0xc8f90844, 0xcb4fca05, 0xd943f583, 0x86440bfb, 0x05b868fb,
	0xb973e3a1, 0xf6057d0f, 0xa7794850, 0xbc2487ed, 0xc218a29c, 0x3acfd14a,
	0xc5f7b091, 0xd44bbf56, 0x4db70efb, 0xeccbefe0, 0x20e63d47, 0x0a4ebff1,
	0x7d055a83, 0x1fe93cbb, 0xe71e7079, 0xd8289370, 0x89077687, 0x18ea69da,
	0x96a33c69, 0x852e577f, 0x1ee97c55, 0xcbd7cdaf, 0x5d00e505, 0x1fc411bf,
	0x5d33f76d, 0xdae99fbb, 0xdadbecfd, 0xb014f055, 0xef0c1d0c, 0x8c1c3c02,
	0xfeb1bc70, 0x146f1c2c, 0x1de0233f, 0x79b06234, 0xe23939f9, 0x6347c6d5,
	0xae94f286, 0x2306db37, 0xda4d1e9e, 0xb4f109d7, 0x811d6524, 0x410aeffd,
	0xe4910f79, 0x88f5543b, 0xb87282db, 0xb373f786, 0x0afbf18d, 0xa3d54fc5,
	0x2fef15bc, 0xed6f28f7, 0x712dbcad, 0xe36f6779, 0xcf1c27b1, 0x8a99eae5,
	0x03f9de57, 0xeb76cf9c, 0xa545371b, 0xcdf5def6, 0x931bb036, 0x8623fd4f,
	0x68dd985f, 0x9fa5a819, 0xf295f80d, 0xed4aed8f, 0x7bdd3d77, 0x3e0297e3,
	0x323b0a0f, 0xc67ebce8, 0xc75c9ffb, 0x2ce7b7ce, 0xba37fe61, 0xfca193ed,
	0xcffcbc9d, 0x47e8452c, 0x11bb6e38, 0xb39a3ddf, 0x7385d98e, 0x3cf1141e,
	0x3ebbc7b5, 0x3f2a0ff0, 0xc2152d77, 0xde89c1d1, 0x93472229, 0x78f3fb69,
	0x7f77faff, 0x6533c47c, 0xdde898b5, 0xca67c61f, 0x3bfd2b3d, 0x3e490b04,
	0xfb49cf7f, 0x9bab5dfd, 0x586343e9, 0x1674a2aa, 0xc17f941d, 0x5e6d12ae,
	0xb7299f7c, 0x547ee6af, 0xfc067000, 0x7bc04bbd, 0x4f3e5db2, 0xd96f9f52,
	0xce086ff7, 0xc6cb78c2, 0x334c3ae0, 0x6418c897, 0xe8226c68, 0x160dab07,
	0x4d51f7e3, 0xc2e20131, 0x5098ee8d, 0xc1cdd348, 0xc87df8a5, 0x51f96d0a,
	0x2b031e4d, 0xb94031e7, 0x587d05df, 0x12b0536e, 0xe096e2f5, 0x0b9f846a,
	0x561d3086, 0x7c6bc6cd, 0x8df182d0, 0xb0ab042f, 0xe98f6d1c, 0xe82cc7b1,
	0xc4d51a7f, 0xc9ab0dca, 0x8dbcc30b, 0x14370e6e, 0x3062fc23, 0xeb46e2cc,
	0x2c2d7b78, 0xc973288e, 0xb8ef34cf, 0xaf9c1e78, 0xac87f759, 0x2be4d528,
	0xb1f2b8f3, 0xa3729ac5, 0x0586c29a, 0x3fbc6123, 0xba377cd7, 0xb73806c3,
	0x90f35118, 0xea6b9da6, 0x41c5d11e, 0x9f935afe, 0x06b4f4d5, 0xd46cb6f6,
	0xca7d0ac0, 0x84224fcf, 0xf3b2b3ea, 0x373be02f, 0x6ef2ed5b, 0xb42fee1b,
	0x7c097272, 0xc5d67681, 0x4137e1f8, 0x0ab8f119, 0x3c3331d6, 0x9fecc0e3,
	0xf72e3c35, 0x89b77851, 0xfc97e7d2, 0xf15f9e9d, 0x06d67a77, 0x27f7e047,
	0x9f845e82, 0xbc21e60c, 0xe115383e, 0x11f306df, 0xf1676e9e, 0x323c7481,
	0xafa46dd8, 0xd373eec4, 0x74fce0e6, 0xf1ab86c5, 0xf048b5bc, 0xef23814d,
	0xa72bc9d3, 0xf93031ac, 0x7094f981, 0x696b29f9, 0x2ad4fbe4, 0xa58aef02,
	0x9e08495f, 0xbed3ac43, 0xd61256cb, 0xd57ed4c2, 0xaafbddc0, 0x27213fa5,
	0x9908ef54, 0xfb0265ca, 0x0cd56326, 0x9cb1a71c, 0xe8c8bee0, 0xbac2b56e,
	0x8133eab8, 0x56dfa2b4, 0xafff00b6, 0x7ee06258, 0xdd5b065d, 0x43e05139,
	0xc6be0a6b, 0x387bfa47, 0x7163f65f, 0xcef481bc, 0x2a6d30ad, 0x466fc8de,
	0x52291577, 0x5ed64dd9, 0xf6bdceec, 0xfa02be9b, 0x21fda95b, 0x011932e6,
	0xc37a60ff, 0xad0942dd, 0xc645e8ff, 0xd17184e5, 0x17184e3a, 0x4bdfd7ad,
	0x72e344e4, 0xe246b8c2, 0x6a91497c, 0xf65ece1c, 0x0e5c74f7, 0xbbe42a7b,
	0x275f5c05, 0x577f3c13, 0x182bf5c6, 0x71f7a397, 0x257c7325, 0x0992f82b,
	0xe3f51fee, 0x97c6ee4a, 0x2be3505b, 0x5d7c77b9, 0xf9031f61, 0xf00982f9,
	0xaf8b5335, 0xaf822e27, 0x54af8e54, 0xecf95f05, 0xb8fd407d, 0x95f1bb52,
	0x95f1a82f, 0x72be3bda, 0x81965c60, 0xdb6978da, 0x1e8d3695, 0xa3ec8c70,
	0x73da57c9, 0x7cd7f6e5, 0x1ee3e657, 0xbdf3443f, 0x346be4cf, 0x1cb4ca70,
	0x3369fb4d, 0x7ee069c7, 0xe06a2673, 0xac7f0bfe, 0xfcb03fa9, 0xfa7e4d56,
	0x077b289c, 0xbd26fce5, 0x4f6e9a9e, 0x4c3aa7a0, 0x45de0852, 0xecc518e8,
	0xed4090b0, 0xaafa04b0, 0xbb78c7cb, 0x2d5465ab, 0x67c89bf8, 0xe4ef357d,
	0x2959fbe2, 0x1c3a3f10, 0x5ce551fd, 0xeb05b77e, 0x14bccf51, 0xd9dea08c,
	0xbb1cfdc1, 0x72b31c78, 0x9af0288f, 0xf94cf507, 0xa044c31b, 0x969bfb73,
	0x76bf4059, 0x34cb976b, 0xea53de0a, 0xe14edd74, 0x028cd4a5, 0x2461d57d,
	0xf1d11353, 0x07db3b3e, 0xf4fbb43e, 0x65af7c31, 0xe783d5b7, 0xcc972ffd,
	0xfb1f8273, 0xd1dfcccf, 0x6bddbe9b, 0xc76bddf7, 0x9f7b23fd, 0x39fb62ae,
	0x6ec9df3c, 0xcf411648, 0x99bbb02c, 0xcb14df9f, 0xce437d84, 0xf06bcfab,
	0x76c6fb9f, 0x5fb27d0d, 0x9d1c608d, 0xfd650f42, 0x4108f4a0, 0xf0bdd93f,
	0x417653e3, 0x87a8cbd1, 0x3ed8efc9, 0xf8640c9e, 0x1521bd3a, 0x9bd0f5f1,
	0xfcd2ed54, 0x46f31ac2, 0xbae16798, 0x0cd68765, 0x875dfc81, 0x30e0f7de,
	0x895a7a34, 0xb9fa52ff, 0x5dfcfd5c, 0x9d72b9d7, 0xb2d2575e, 0x2f105bf3,
	0xf12470dd, 0x760d4d7b, 0x27a5e23b, 0x8c0d7d3e, 0x4f3c116e, 0x15bf3b28,
	0xde3f5ef9, 0xc12ad880, 0xc7b53739, 0x0f373df8, 0x70973bee, 0x1d925e3e,
	0x960f77c1, 0x977b2634, 0x1a48ad63, 0x18c96be0, 0xe8317d39, 0x5c2fafa1,
	0xb6f65510, 0x0de57c7e, 0x4fbf8d66, 0x1876dfd9, 0xa9e02b3a, 0x7a3fdfcc,
	0x877806e2, 0xd9d6c3b5, 0x4561b00e, 0x60a986ec, 0x49fe2bc7, 0x79fb844f,
	0xc1d6ec39, 0x8c6c1d16, 0x5e7153fc, 0x87b396fe, 0x2aa1fee0, 0xc42debce,
	0x7eed48df, 0xdcefdba2, 0xc7bb5d9b, 0xedaed09c, 0x0749e91a, 0x29b0e8f9,
	0x9e288dfe, 0xdead96af, 0x7876e8cd, 0x9f75c60c, 0xf2b7fbe5, 0x5f4cb5f3,
	0xffbe5985, 0xf46440bc, 0xf8d32c17, 0x121ace11, 0xe692dfbf, 0x6fe2f260,
	0x1b9e13f9, 0xf8ff39fb, 0xcff97cb9, 0x73bdb11b, 0xc3d23376, 0x0a62b0e8,
	0x7284b03e, 0x53f360e6, 0x05690ce4, 0x08c1faf0, 0x2e933953, 0x1cfcce45,
	0x672b97bf, 0xd03fd069, 0x061b12c3, 0xa3b4acfc, 0x9545779f, 0x792ac88b,
	0xe8b9072a, 0x764c7a0b, 0x3f00c638, 0x944f680a, 0x5df19b37, 0x878734dd,
	0x32534df1, 0x9f957f9e, 0x89c9967f, 0x9bd3f591, 0x53f7d45e, 0x235bb556,
	0x99e43daf, 0xffaf07bf, 0xd4e9cb9e, 0xdef83c45, 0x143f9e8f, 0x5dade8be,
	0xd23b79ff, 0xe8561bb1, 0x97674ddd, 0x61d73f26, 0x7086ef61, 0x91e0a13d,
	0x089bc7e2, 0x4cbc713f, 0x79caf2c1, 0xc4df5e95, 0xdf8155d7, 0xfe72641f,
	0x0232d068, 0xbf8a1cfc, 0x7e8bded2, 0xb0f1cf9f, 0x7e8ad826, 0xd901e311,
	0x15adfe0d, 0x87e86f56, 0x249f9c62, 0x13364dce, 0xe3a6ae89, 0x8c7b7ba4,
	0x01f7048f, 0x3306c7ee, 0x61d192bf, 0x948ff0d4, 0x1e8d6142, 0x97bf42aa,
	0x00224af9, 0x6a065aff, 0xfa3ae7f3, 0x191ff8e0, 0x405dd1b1, 0x11ebfdc7,
	0x788211ff, 0x9f781736, 0x74fff444, 0xd57bda69, 0x1639d0b8, 0x3fc2829f,
	0xaf9a78f7, 0xa57adfea, 0xa43b005b, 0x3d6d64cf, 0x576c1e3d, 0x89fc6ab6,
	0xb46d7d7a, 0x819cf0b8, 0x4fccfaae, 0xc27db844, 0x9561ef7f, 0x6aa3e99b,
	0x0a7a6fee, 0xd1574cfc, 0x42eed175, 0x85795df9, 0x62d5d181, 0xe105fd44,
	0x4a5e502e, 0xc95fa10a, 0x114a7e0a, 0xd84514e8, 0x88ba2f09, 0xe0012f38,
	0xf9c1e264, 0x95d125f7, 0x98ed7fb0, 0xbe0fbb10, 0xfbeac4ff, 0xebe283b9,
	0x63d68c8b, 0xf31df802, 0xde41c37d, 0x6ca189d7, 0x3bff2d0f, 0xca1b33b1,
	0x77acd265, 0x0af4b0fb, 0xa9f63f88, 0xbbd833ce, 0xec587196, 0xd4b15f09,
	0x7feff3a8, 0xdf9d5c3d, 0xc0d79568, 0xfbbff438, 0xc0427291, 0xb7437775,
	0xe51f397f, 0xf7e0ec2a, 0xdcfa755d, 0x83bed848, 0x4fc808b4, 0xdc873e8a,
	0x5afe3557, 0x5555e78b, 0x031d0aff, 0xde6b27e7, 0x3903ad7d, 0xafdbf950,
	0xf006ca34, 0x45555ea7, 0xbd0b7fbf, 0xf3fb74f7, 0xcc7defd8, 0x3565de56,
	0x327060ae, 0x7df0fe51, 0xfdbaf7cc, 0xec182bc5, 0x3e605066, 0x303a9f3b,
	0xbae3093f, 0x6ecc7194, 0x7e0ad559, 0x192dd9a7, 0x62bce00b, 0x7f7be5b6,
	0xa98f7483, 0xec1d80f3, 0x5d997bdf, 0x5eb7b3f0, 0xba69d935, 0xbc46e8e3,
	0xc1c7bc6f, 0xe92e7ce4, 0x7d5d0134, 0x7f312dc4, 0x78e51873, 0x3872f13e,
	0x3a3d0262, 0xfdbe1a27, 0xf5dd0a66, 0x5866f86a, 0xee1ee73e, 0xd3a03dfc,
	0x414f7117, 0xaf52ae9f, 0xc1887bd9, 0xfcf75eac, 0x4f9c168d, 0x9c16be7c,
	0x3a3f32bf, 0x6effe452, 0x7977f0fc, 0x5c4c7c14, 0xdb3de6c0, 0x818fe77e,
	0xa7d37a1f, 0x70a32db3, 0xf478cafe, 0xb20cf9f8, 0xe03cbea8, 0x3e06df90,
	0xdf90e6db, 0xd2dcb481, 0x821c6999, 0xe83ef072, 0x77d10ad1, 0xff9d1a45,
	0xc37c8327, 0xad0f0153, 0xb7a6ce2c, 0xfefdbb7e, 0x9f8d1496, 0x8dd7cfdf,
	0x27863be5, 0xcce11f81, 0xec01a2eb, 0x77fc33da, 0x87eaba65, 0xdc5b7d27,
	0x4fdc47cc, 0x7e66e5d2, 0x7ef0e2fd, 0x25ce00a9, 0xf34bf6ea, 0xa72cf647,
	0x6de1c5c0, 0x92bde812, 0x7cd26dba, 0xbefcf7d0, 0xb87e8f4e, 0x45319cfc,
	0x674dbef0, 0xa3bf80a3, 0xedb0d653, 0x4aeefc10, 0x0e725d71, 0xbf77039c,
	0xb35a4bc7, 0x6125ae80, 0x717efb51, 0xc427d984, 0xbea59ad8, 0x47bca70f,
	0xdf1f6aa1, 0xf6dcbee9, 0x449d2c17, 0xf3868c4e, 0xb004f73e, 0x30cf43cf,
	0x59305ebe, 0x784e2116, 0xf7016adc, 0x8c9dd7cf, 0x0babd011, 0xb40993aa,
	0x3ffee0bb, 0x0ff7850d, 0xcd3d5a2a, 0x6107d031, 0x98c54bc1, 0x67778ba4,
	0xe3e282ff, 0x0e8c03c9, 0x7c0ddf00, 0x0e3d90ea, 0xcdb83f95, 0x06ed9954,
	0x21cbba39, 0x30585d83, 0xdf0f7e53, 0xf74637b7, 0x9959bf83, 0x4f1cc167,
	0x4165f01e, 0x6a632ac4, 0x0e5b4621, 0x2c433fbc, 0xc44ba690, 0xe5b80568,
	0x21d9cfb9, 0xba6f9b0b, 0xf7d8588d, 0xfe02bfd7, 0xa4bd5efc, 0xb4460bf5,
	0x5acdb5f0, 0x85aa3b38, 0xc2d61f47, 0x24fde06b, 0xfe38cfda, 0xf6074bbb,
	0x2efc099a, 0x668bd94b, 0x197d1f8c, 0xc38c12d6, 0x3bdda2b3, 0x2c65aca9,
	0x6ecea3f8, 0x5f601a75, 0x979be7b9, 0xd9ba32b6, 0xfffb6e91, 0x8836236c,
	0xbad17bbf, 0x28cbf211, 0x51efc04d, 0x16b5a2f6, 0x5e77c5ce, 0x23bfb843,
	0x3b0d718c, 0xd4e2c1ff, 0xc398b73b, 0x776757c0, 0x01f5b73f, 0x96ecfe5a,
	0x8e207d01, 0x642165fb, 0x6b42f680, 0xd9c73d18, 0xce38fad8, 0x9e3ef546,
	0x51cf6b7b, 0xde993967, 0x42ac153a, 0x1f5c64bb, 0xa9f70ef6, 0xf3067ae0,
	0x6a8bb977, 0xc63e500a, 0xddd4f7f1, 0x0fa40aeb, 0xf5077ed9, 0x9f2e08d0,
	0x92f9e185, 0xd7fb40ec, 0xe3b17a06, 0xc41e6963, 0xa75f0d43, 0xe742a3c5,
	0xefdac3ab, 0xf33c7c05, 0x60fbea89, 0xacf67738, 0xb6fc07ec, 0x67bc2489,
	0x7264ec58, 0x92f3fcf7, 0x7f22e7c2, 0x54788c8f, 0xebe2a1f7, 0x00325907,
	0x5e8002e2, 0xcbdfe243, 0xed2afd74, 0x3f32708f, 0x594147e8, 0x852b7586,
	0xf0a3e1e3, 0x0bd034c1, 0x4c1dd71f, 0x2670bd03, 0x8ced1878, 0xfb9b6df2,
	0xbe537d80, 0xf00ba0e5, 0xd9fb3e51, 0x1d81c7c7, 0xc08c45b9, 0x7c77e838,
	0xf22db397, 0xf49dd77b, 0x7d7547fb, 0x21f1d473, 0x3c24b4fa, 0xcfef5641,
	0xbbaf972e, 0x33768bdf, 0xcbcaec3c, 0xe066edbf, 0x6bd11ab3, 0xfb737d41,
	0x7e01464f, 0xef784c6b, 0x099b7cb5, 0xd40f2ddf, 0xfafe8f5e, 0x532386b2,
	0xf5bd3df0, 0xe7185e05, 0x17c92358, 0x67a8f073, 0xb51fa426, 0xeb77c0ec,
	0x2d52feca, 0x9fb03d19, 0xe519f2d1, 0xb517c45b, 0x0adec6bc, 0xc32f2432,
	0x7be554f8, 0xeb6af9cf, 0x7112e9eb, 0x1935762a, 0xbeafa6a1, 0x2169df5c,
	0x2f94aff4, 0x654b7aa5, 0xac9f97f7, 0x7d38f8c2, 0xab51683f, 0x103d99ec,
	0xd4f202de, 0xd47df7c8, 0xe58cb3ee, 0x1943a3f1, 0x01e8ef8c, 0xaffcc11f,
	0x703d9321, 0x3256f1cf, 0x4f455215, 0xb245e5b4, 0x42cbfca0, 0x62dfd9ec,
	0x9d1dec7b, 0xdf147736, 0xd7cfec19, 0x830f3693, 0x5035df95, 0xac5b4bf2,
	0xf6715718, 0xe1f50913, 0x82e78832, 0x06ad5bf2, 0xceebb503, 0x113beb6e,
	0x22db04e2, 0x33d99dec, 0xa513be91, 0xf5d7596f, 0x6f59407a, 0xe93fc38f,
	0x5396fcba, 0x7e02756e, 0xca38b057, 0xd995bef4, 0xa4e80995, 0x2a914bd4,
	0xd7a03db3, 0x377872ee, 0x83429e22, 0xf2e8dd61, 0x5c42f3f5, 0xdac08148,
	0xffe5258d, 0x08e549c5, 0xfd326d7c, 0x7161cfaf, 0x09d7f023, 0x7b9f7bd1,
	0x6d5cfc68, 0xef0fae61, 0x2c1590cb, 0x91816fbe, 0x4ed48d44, 0x45eb005e,
	0xbfb8c216, 0x60235059, 0xc7c2d13c, 0x7781f3b4, 0x5debd54f, 0x76c2a931,
	0xd304494b, 0x7e6d1ae2, 0x2e3fac09, 0xe7608788, 0xda75a5e6, 0x4e1ee57c,
	0x7305c379, 0x4e7dbc22, 0x5fc9f994, 0xd590fcc2, 0x93aa9e41, 0xdc081d70,
	0xf81913ff, 0x1b79916f, 0xd7c73fbb, 0xc95242bb, 0x3a24c9e0, 0x418bbd88,
	0x645b7d60, 0x0e572121, 0x005de183, 0x3efa8f98, 0x981f3288, 0x393bfa87,
	0xd655e8ca, 0xc1474422, 0x81fee07c, 0x2ea3e6c8, 0x09e7ce57, 0xbdf528fe,
	0x73c43f13, 0xd34a1c42, 0x5da6b305, 0xeba24fee, 0x3a52b12b, 0x47add93c,
	0x8a2757c3, 0xf1c63f33, 0x85ede4f1, 0xbf7f2019, 0x3fb53b02, 0xdd1e5847,
	0xd059c247, 0x0b588638, 0xba36c7ed, 0xb1fcc61b, 0xc878310f, 0xd71beee3,
	0x31dfc78d, 0x6d7b00cb, 0x087f9881, 0xb9952fee, 0xb45cc37d, 0x3906059f,
	0x287288d3, 0xd43f430f, 0xdfff3652, 0x5d5e54e4, 0x533ec099, 0x1094f5e8,
	0x18fd8289, 0x49d6cdda, 0xba1fb97d, 0x3a497e98, 0xfdb8c310, 0xde021dce,
	0x1c2f5c1b, 0xeb757bc7, 0xe590f26f, 0xe947ee14, 0xbd6ffa03, 0xfbc05640,
	0x024db955, 0x9bf82b9e, 0x077e8826, 0x43d99bce, 0xf05acaf6, 0x1bcfa50f,
	0x3afc0391, 0xbf61e5d9, 0xcc9a313f, 0xf7e695bb, 0x1834287b, 0x074987fc,
	0x411bf5c2, 0xf0d9468e, 0xc53a695e, 0xa60fb38d, 0xe9aec1ab, 0x83f7b247,
	0xcd37ee5e, 0xc7fe0393, 0xfdac5d27, 0x6f388354, 0x395fd806, 0x4b93ee0c,
	0x9f488de4, 0x748f38b5, 0x1ea9fb33, 0x25760ef8, 0x86de566d, 0x74661a4c,
	0x0d99549d, 0x650fa7fd, 0xc5148a69, 0xe5721f38, 0x2837dc08, 0xc1bf24ef,
	0x40d9fee9, 0x14f50939, 0xcfc9bdff, 0xfa12721c, 0xd192daca, 0xa5fc575e,
	0x8325f94a, 0x1f2874e4, 0x90922f38, 0x66070f4a, 0x9d7e817d, 0xfb4979c0,
	0x125f7cfd, 0x5ca89bea, 0x79fbf69a, 0x6c27093b, 0x7efda5cf, 0x6bd6d05e,
	0x339792fe, 0x179277e2, 0x3c9d8173, 0xad35f40d, 0x843611d7, 0xc7c6d74c,
	0x698eeedf, 0x87bb74f4, 0x7dfc1dc1, 0x695f2557, 0xc4967dbf, 0xb13aa5cf,
	0x1520b69f, 0x3c84e1e8, 0x824e72dd, 0x96f2ff78, 0xb6bef8fd, 0x7c62b49f,
	0x27623fb1, 0x9ce704a1, 0x3a9c7ef0, 0xf8bcb49e, 0xe853d600, 0x8dafaf16,
	0xde5b4d83, 0x9950351a, 0x4ff8ff5b, 0x9abc8d56, 0x2e01c0b2, 0x579ba15f,
	0x7de1e3c9, 0xde468361, 0xf2ddb9ec, 0xa4ff6287, 0x1af26441, 0xf26abe9a,
	0xcbcc1540, 0xdd0fd777, 0xda64e372, 0x5648ee5e, 0xf9e3d37f, 0x8c643daf,
	0xff3a0beb, 0x0aa77ccc, 0x0760e8b6, 0x6cfe3585, 0x2e8a7e5d, 0x1e0e9fbf,
	0x39b7cac8, 0x97a299a3, 0xcf8fad90, 0xe7fc11bc, 0xb9d1196d, 0x31fe8370,
	0xe11b8ef1, 0xb9fd0e77, 0x2afb77ec, 0x0b2f045a, 0xabf86223, 0x707932f0,
	0xc4126378, 0x5b73d80b, 0xdfd0190f, 0x9ec1b827, 0x45b64476, 0x1e7a8611,
	0xdb08bd55, 0x8e47959f, 0xdb5ebd63, 0x7d40611f, 0x0f88c8f0, 0xfcc5dcb1,
	0xa0bc64f0, 0xde849df9, 0x061d08e2, 0x7fd021df, 0x6db9bbca, 0xff89dedb,
	0xf7951a8e, 0x20f90cf6, 0xfddd37ea, 0x078c00cb, 0x26997ee5, 0x1191f9ee,
	0xe08ef85d, 0xde5aa3fb, 0xbed76582, 0xb032dce4, 0x3fe2fee3, 0x1aec063d,
	0x7d000b38, 0xb61094fe, 0x194f7f42, 0x3ac357c2, 0xaaff9771, 0x2613f0fd,
	0x0db14cc7, 0xf9fc1270, 0x1a3795e3, 0xce63b969, 0x09f820d8, 0x0f5d2f9c,
	0xa58e3d20, 0x8345f0c6, 0x320f4999, 0x906c5078, 0x777fc281, 0xabe0cf3d,
	0x1e001b62, 0x066bf49a, 0x120d8a8f, 0x3f9a60dd, 0xecdbf481, 0xdf571c4e,
	0x32b4f5c6, 0xe44383be, 0x521780d3, 0xb801d6ce, 0x7aa167de, 0x99e96e6f,
	0x1f14cdc6, 0x476e7f73, 0xedb9b4bd, 0x7b331fb6, 0x710f9434, 0xdf1ce93e,
	0xfea14eb8, 0x2afee235, 0x3ea6d603, 0x333a7a71, 0xcfa83d5b, 0x06dca9af,
	0xdcfa7beb, 0xffcfa891, 0x4f6f94e0, 0x9ba78d4a, 0x7b7a5853, 0x5fe99b92,
	0xb3fe80d1, 0x689c07f4, 0xbf8afcaf, 0x65cf6d37, 0x4e0ed0e7, 0xf9892117,
	0xb624857d, 0x79dcf8df, 0x6349edc3, 0xd98a2e20, 0xc26bd591, 0xef14ac5b,
	0x99f6567f, 0x7a5d996b, 0x57d52d67, 0x4eac0ed4, 0x0f403396, 0x39ef09dd,
	0x8ac38c8e, 0x4d9d5d9d, 0xbf7c4761, 0xce433d53, 0x5d6bbf50, 0x15f2cb5d,
	0x983d573d, 0x95d657d5, 0x3f0ce5f4, 0x7ababfe9, 0x6ec3cc23, 0x5e37e824,
	0xc6d86b34, 0xdf2eb865, 0xb226f38a, 0xdefb019c, 0x0c432593, 0xf429ff60,
	0x1e443539, 0xe7e1f380, 0x949d0a7e, 0x624f6ffe, 0x2205b8fb, 0x3ce9d75d,
	0xb0fb736f, 0x67ceba3d, 0xd8c5f7b1, 0x383b7f3a, 0xf1c4c796, 0x31b18c4b,
	0x117ffdf0, 0xffc8649e, 0xa7fa78ae, 0x7a7594e3, 0x999bea88, 0xd2ff3740,
	0x26fbdad3, 0x094fef1c, 0xae7a5351, 0xfa103dea, 0xdf79f61d, 0x4ceef973,
	0xcdcf9d52, 0xf68fc07d, 0xfb1f32a0, 0x7a9aedbf, 0x9f29e907, 0xd8ed7b7a,
	0x818f2d9f, 0x1498e31f, 0xec7c7d41, 0xe7be2cc7, 0x53ef3f18, 0x3fb1cdec,
	0xf6037b2f, 0x44938749, 0xf85567ac, 0x01f98841, 0x19a86b2f, 0x43a8f700,
	0x3bf62433, 0xceb661c9, 0x70c72757, 0x9d7d5bbf, 0x847b4dc7, 0xa7dd9d75,
	0x55cac59c, 0x95909327, 0xd725d5c2, 0xca057de0, 0xd2ef1827, 0xef86db39,
	0x336757c9, 0x192eab3e, 0x7b0df182, 0x684bf9f8, 0x9fd585b6, 0x72aff3c1,
	0xf8c5fe63, 0xf3396d28, 0x9ca3102f, 0xb3ddfea5, 0xf6ee9c4d, 0x778ed8dc,
	0x98f17f60, 0x406ffd15, 0xa8ff3c42, 0x28fec74a, 0xfc8a3c3f, 0x9e93eca5,
	0x823f08c8, 0xee2f32fb, 0xe53957bf, 0x2fff1c02, 0x7f181eec, 0xb6ac958d,
	0x86b2fb50, 0x2fa8b1da, 0xd54878f9, 0x7bfcf06f, 0xfeffb71e, 0x04e5dc5a,
	0xa4e9e5fb, 0x0cb7fdee, 0x84f9e1fb, 0xd07fcfe5, 0x35f61c7e, 0xef641ff3,
	0x37d592b7, 0x0cf3dac8, 0xf034d63a, 0x75bff38f, 0x1fe04e9d, 0x4173d41f,
	0x84e9fffb, 0x83df3af3, 0x09295eec, 0xe223fad1, 0xee411bf5, 0xb22ecfc1,
	0xdda093f1, 0xcedde893, 0xe947ae46, 0x7f7565f8, 0x76fa3f4a, 0x2b6dbee9,
	0x3de28be0, 0x3a7cf70a, 0x277ec17f, 0x14de3f40, 0xc097f3a9, 0x62837307,
	0x9f1443f2, 0x9c4ea5be, 0x79de32af, 0x403f9de9, 0xfdae80bf, 0xb18af653,
	0xf6570fe0, 0xd541e427, 0x22f10c7e, 0xee1161c5, 0x3ee277c3, 0xbe77c7a7,
	0x07efd54f, 0x5987f909, 0x7fdbae5d, 0xe37411ee, 0x11e57ce7, 0x7c37408c,
	0x4dd29fc7, 0xa2e73a92, 0xb71bafbd, 0xf80fcf82, 0x17b7347a, 0xbd07f7bf,
	0x8a453be0, 0x7d76820d, 0x2788cd4b, 0xbacafb7d, 0x952b1bfa, 0xeb77ca2f,
	0x75f90104, 0x5c76fddd, 0x9dac3b27, 0xc2fde2cf, 0xbd22377d, 0x1e6c4bdb,
	0x5a7ae388, 0xa166f162, 0xb977ec7d, 0x86c5863b, 0xd3b77c81, 0x1029cb39,
	0xffa2241f, 0xda820d94, 0x1b8a6f49, 0x77dbff81, 0x59dac4df, 0x37ef6766,
	0x5ee18603, 0x41efe860, 0xd5bccc3c, 0xd89ffd82, 0x82c1dec9, 0xef5149df,
	0x671ee18f, 0x6f5c4e71, 0x8c064074, 0xfdced9a3, 0xec12be43, 0x811b4eef,
	0x830ad473, 0x561d8320, 0xc60d7a51, 0xfbfe13fb, 0xad5e8a36, 0x637dd030,
	0x2bfe5c4e, 0x5b0e1f0c, 0xc493fccc, 0x5ffdcb48, 0x42ad7d42, 0x00008000,
	0x00088b1f, 0x00000000, 0x7dc5ff00, 0xd554780b, 0x733ef0b5, 0x9992bcce,
	0x24992664, 0x8124f793, 0x49804824, 0x7515010c, 0xa6a30108, 0xc5ea4436,
	0xf090e2d6, 0x52648448, 0xaf172bbf, 0x0a4032f4, 0x35884509, 0x4e22e042,
	0x57fe2028, 0xa4542fff, 0x911c1341, 0x7fae5a22, 0xde8adaa8, 0xf80846cf,
	0x58232428, 0x5ff5ab44, 0x2673ed6b, 0xa1124e73, 0xfbe6f6da, 0x63cfb0f4,
	0x7bd7b5ef, 0x9ef6b5af, 0x5cfe0c25, 0xd8e8358c, 0xb18e2111, 0xbd0da6a5,
	0xb3dc0c62, 0x8c897fc1, 0xb3cf87dd, 0xff1afb18, 0x36f7866e, 0x062be9fc,
	0x1bf61bcf, 0xe8c4c799, 0x6ff86bef, 0xced0d3e9, 0xc7df6a1f, 0xb3cf430c,
	0xc67efff0, 0x2e8b1812, 0xe03a7f86, 0x181632bf, 0x9566302b, 0xbde5d1db,
	0xf3de1101, 0x4ec19f2d, 0x1eaf0b5f, 0x69559bee, 0xac9de7c1, 0x0fbeae1a,
	0xc0502799, 0x1dddf5d8, 0xfbc2a72f, 0x74def2f6, 0x7fde1cf8, 0x5affa723,
	0xd8c03fec, 0xaf3821e4, 0x64447eeb, 0xbe8f1a16, 0xfb3c5003, 0xb8def42c,
	0xd79109aa, 0x825df4d5, 0xc717bc4e, 0xc95bc3eb, 0x49e49ff0, 0xcd9c6016,
	0xf5bad975, 0x04b45700, 0x85d600b7, 0x573b79ad, 0x93ccc0e1, 0xec65655b,
	0x6f7618b1, 0xddb60165, 0xdfd09525, 0x91695b12, 0x83fbfa0d, 0x5e0274ad,
	0x2b4a9c71, 0x801e3f4e, 0x7b4f821a, 0xbca3f055, 0x58d39497, 0xfd1968d8,
	0xe381873d, 0x3635b42d, 0x91e113b0, 0xfa2f6a04, 0x3d63bead, 0x030007c1,
	0x9e3ff7bc, 0x6bf84015, 0xe581ab59, 0xc0589d00, 0xcf7844c0, 0x4531fcc4,
	0x62d78570, 0xddb8bae1, 0xf4115cc8, 0xdba80bab, 0xb5c38dac, 0x24be0a54,
	0xb097fd00, 0xc967ea5e, 0x4b7bf55e, 0x0ad058cb, 0x2c4debcf, 0x4ed78d18,
	0x1606f3f5, 0x5d7c3822, 0xfd551b5f, 0xc3a256b3, 0xe6633356, 0x93c98438,
	0x3f8033f5, 0xbddeaaf4, 0x8cf3f813, 0x0f05174c, 0x53a5b17d, 0x2887806c,
	0xeff84751, 0xa45ab1d7, 0xe64ac0ef, 0x6c67a319, 0x5bdd9d93, 0xd6fe0235,
	0x45ae6f3f, 0xe9b6a87e, 0xfdca8f08, 0xc69e9b34, 0x3ccd592f, 0xddd0b788,
	0xd46bc206, 0x42f88cb5, 0x26ceaf79, 0x3d8c7bd0, 0xf405e9c2, 0x6f740d9d,
	0x750677b3, 0x36b6ddf0, 0x1177edc1, 0xa03afc7d, 0x32bff5c7, 0xfe035607,
	0xadae3fcb, 0x985cfa43, 0xd08cc51b, 0x5fa6f5c5, 0x4a03f7e6, 0x00ad2017,
	0x4213e7af, 0x4b9f10cb, 0x67b4beef, 0x7e7adc0f, 0x8fafcea7, 0xd38eab85,
	0x747cffd9, 0xd5d13760, 0x3df08b15, 0x433c5aff, 0xd1ff3f3a, 0x846e5f9e,
	0xca1fcfe7, 0x21ae8b73, 0xdabbe138, 0xa97b804e, 0x071b9821, 0x80603df3,
	0xc6975c36, 0x70ed7304, 0x9b3d05ff, 0xa0a3cf4b, 0xccdbf70d, 0xd7e426de,
	0x546b2314, 0xa7fbc3be, 0x538e1c02, 0xe300b230, 0x32adbbfa, 0x85e49e1c,
	0x96e9ee30, 0x187af724, 0x7932a857, 0x1bd3ce10, 0x308d3b8d, 0x197acddf,
	0xbd0283ee, 0x395f4a7f, 0xa7da192b, 0xaf742b9e, 0x95834782, 0xf801a086,
	0xc969b7c3, 0xb1913671, 0xc76b9d1a, 0x8705d472, 0x23bbdda2, 0xb8dbe1e6,
	0xfb9f02b8, 0x07715bee, 0xe4d19dea, 0x2465d7c7, 0x69f85721, 0x10328580,
	0xb36adb9f, 0xee30833b, 0xb738f740, 0x409d4f48, 0x1b43e064, 0xcf5fb77f,
	0xa1e7283c, 0xfbd13d1e, 0xf147fb6a, 0x1f1fa092, 0x2bc45bfe, 0xcfc2a408,
	0xda22efa4, 0xce6d48e2, 0x93e7be67, 0xcfb53e48, 0x0f7ab5af, 0xfc377f20,
	0x96f7b3e2, 0x10bc70bb, 0x9ad61be9, 0x70007240, 0x7df04d07, 0x606b56ff,
	0x71ef7d27, 0x4d16bce1, 0x33cfa465, 0x2ffc7057, 0x40ea4f6d, 0xe32f6abd,
	0xcf6d2fef, 0xebed89db, 0x48bb3d65, 0xd4264d64, 0x6cd64603, 0x31abb902,
	0x90fababa, 0x8816bf0e, 0x2aef670e, 0x0ef2863f, 0xf9f09bcf, 0x192d8052,
	0x6f6f45f5, 0x0b8456c9, 0xe304a634, 0xd815eed4, 0x88f5c67a, 0x88814f0a,
	0xdb8c3676, 0x997a41d9, 0xcf08de81, 0xaf487b37, 0x7d50bea0, 0x546afecf,
	0xe8afcde3, 0x984b923f, 0x9fca126c, 0x62fa1fa2, 0x46c7ff2b, 0x09263972,
	0xf45675f1, 0xbe81b32e, 0xa4fccc59, 0x9058eaaf, 0xa078caae, 0x341eb8ff,
	0xd7883d71, 0x87d0aba8, 0xd24eb1f7, 0x6facf563, 0x02b83d64, 0xd1c4e0f4,
	0x8d6320f5, 0x7c4f6885, 0x28dc58f7, 0xa1f4c3c7, 0x3a156fac, 0x5eb81925,
	0x40457ebc, 0x78430564, 0xf3d5b3f8, 0xc8612389, 0x36def9ce, 0xb0935c99,
	0x01b2c95d, 0xa75baf3f, 0xcf089bdf, 0xa0f3127d, 0x32f747fc, 0x7fdc074f,
	0xd8fcccdc, 0x2e89eddf, 0x034e67d2, 0x54bd03e7, 0x79e10ac9, 0x106f6949,
	0x812857f5, 0x5aff50d9, 0x8fff797b, 0x22bbe15b, 0xc1eb8efc, 0xd626f7f0,
	0x7df11514, 0xb266f3e9, 0x5a0e973f, 0x2eefa803, 0xda67e7d9, 0xe781fbe0,
	0x077fa4ad, 0x10e3fd64, 0x6c61beb9, 0xd127cd2d, 0x3f57459e, 0xc8654d2b,
	0xa96dc2cb, 0x9d8ab228, 0x337bd7ae, 0x3b9d0f51, 0xa1ab6469, 0x1f3b18df,
	0x9a18c1bf, 0xdbc00375, 0x9880a2f0, 0x6f678e61, 0xbf42f429, 0xef5ff146,
	0x667d0132, 0x0f422b89, 0xe9f577c2, 0x3e119b16, 0x9ffccb29, 0xed0ddfdf,
	0x99ebf68f, 0x7bbbe911, 0x3d965cc6, 0x05d7fcba, 0x22faa7f4, 0x5ec972f8,
	0x53bebb75, 0xa975f6dd, 0x56ec93db, 0x9268d9c7, 0xc0d7f74d, 0xe3634637,
	0xaf001d87, 0xe92305f1, 0xb7bb68c3, 0xd0f38ed8, 0xbe228e85, 0x26e7998c,
	0xdd9e917a, 0x3578089f, 0x22f43b02, 0x266f25dd, 0x3325cfca, 0xfee8e7c7,
	0x08e93304, 0xf185e06f, 0x3e73f92b, 0x8fc8120e, 0x6097a3e7, 0xa2aa8bfe,
	0x8ee9ab6c, 0x097262a7, 0x7f5c09fa, 0xfd6fdaf8, 0xef489848, 0xcf1d21d5,
	0x00f786ce, 0xae76daae, 0xdeb2978f, 0x06fbe418, 0x404c27f0, 0x074875b2,
	0xa692dba0, 0xfe104950, 0x3e5716d9, 0xbe94e10e, 0xde912a92, 0x08dfb0eb,
	0x3b1ee7ff, 0xf64bbfb7, 0x23fb5b9a, 0xd3bebef8, 0xbafb6aae, 0x23fb5b92,
	0x39cb2ef1, 0xea120873, 0x7cf2a5bb, 0x3def3a2c, 0xb79404f6, 0x1874c33e,
	0x3eafe6ff, 0x17fd2035, 0xfc997f2f, 0x7cc79843, 0x5d992fee, 0x3f172fa8,
	0x07dd12f8, 0x7a7c45bb, 0x4012dd36, 0x56f2f5bb, 0x0ddb6f23, 0xb8fb3ed4,
	0x9dc5ed40, 0x29e70042, 0x9f8e5d54, 0x7afbc0ee, 0xc70d919b, 0x1f8f16ab,
	0x0c43ff6c, 0x407ea983, 0xeebe0748, 0xfa887b02, 0x4318d6da, 0x31aba17e,
	0x5f50fd06, 0xa11f2dfb, 0xb8fc5a3e, 0xc57b46e8, 0xb1eeac7a, 0xc733db0c,
	0x3f60b42d, 0x03a7e317, 0x663b6d1c, 0x2fba44da, 0x6e500656, 0xcdef4f24,
	0x31da5f70, 0xe47a85c5, 0xfe1ce3c8, 0x1ed376c5, 0xbf9ba3e4, 0x923fc912,
	0xfe8bcc74, 0x33c19b51, 0xb5d3e50e, 0xa42cf77d, 0x53b307cf, 0x33fef474,
	0x5e21b302, 0xf113cbec, 0xaa4162fe, 0x6dacb944, 0xb488abaf, 0x917669bb,
	0x733d36e8, 0x859f6245, 0xb42eeae4, 0xeb8ff52b, 0x5239afc9, 0xefefcef5,
	0x95c90c76, 0xc77ed550, 0x93ffd8f5, 0x5dca377a, 0xff6e9ed8, 0xfe17f11e,
	0x3f504b05, 0x577d7c73, 0x2b463339, 0x8b98d272, 0xeaf1727a, 0x08db5cc6,
	0x4e58607e, 0x8e5c83b6, 0x5da76c67, 0xd2c43b20, 0xe67e54e2, 0x25b7fe68,
	0xfc41e75f, 0xb3ccdc9b, 0xb049ae1b, 0xff4011fc, 0x489762bd, 0x3762bd1f,
	0xe7d27bd0, 0x6ffdeff7, 0xdd855798, 0x9df289db, 0x68853cc9, 0x5b215c37,
	0xadf22c69, 0xedb007ec, 0x8157ee46, 0xd93e469e, 0xacf6c09c, 0xbd77588f,
	0x264dfd8c, 0xfb10713d, 0xe5f93819, 0x436fc451, 0xbb89b9c6, 0x3f970f11,
	0xbe60b835, 0xf4816e96, 0xc95dc5b4, 0xdd7c6f90, 0x8282d9b3, 0x73eb3d21,
	0x9daffd73, 0x4f4e2d97, 0x211cfaf0, 0x38b3e7ea, 0x66d78d17, 0xdb4fc467,
	0xfc054796, 0x4736df00, 0xff408cc0, 0xbecb72ad, 0x740deb04, 0x3a7133ae,
	0xeb3d769b, 0x03cf9111, 0xb62c6d82, 0x063e5c5d, 0x4405e76b, 0x5da3e718,
	0xef6a7e39, 0xad7e4e9f, 0x9b2fd765, 0x5d4f11b3, 0x6fbe377a, 0xe0c5f771,
	0x75da3efc, 0x57e7063a, 0x79a44bbb, 0x493e06d7, 0xa430585c, 0xbc10be27,
	0x662f887d, 0xfa912c12, 0x175da3e2, 0xf8581713, 0x62ec90ba, 0xf978c8f1,
	0x19fa6d83, 0x9be6fefc, 0x7e3e5d38, 0x3d4018c6, 0xec19b1f8, 0xfdfe8457,
	0xd9edcad8, 0x7d657667, 0x7e8199d0, 0x4f7db849, 0xc4f50ebe, 0xfcf8dabf,
	0x0cce861d, 0x093fcb94, 0x6bee7eea, 0xf4005916, 0xc0b35d52, 0x3ff3a002,
	0x19d7ea7e, 0xda3fffa8, 0xea8cebfd, 0xdfb4f808, 0x4e215729, 0x8b75af1e,
	0x55e304c7, 0x60bc6533, 0xed578e1a, 0x7a8fbe36, 0xf4cf3586, 0x9b26e584,
	0x67df235f, 0x012fa0ed, 0xb52083df, 0x77ca87c8, 0x1e51b583, 0x9985d213,
	0x550c0202, 0x8d062ddd, 0x33c79fd8, 0xb57e81c6, 0xffa6bdf2, 0x4fce78d2,
	0xeb409742, 0x1082e8c3, 0xad6fe7e9, 0xcf402dff, 0x027a21c4, 0x9d230f9d,
	0xa3a14dea, 0xc3f88ca9, 0x34337880, 0x57b42458, 0x7f386b89, 0x91d01e85,
	0x8a88ef9f, 0x4fc0c899, 0x2d38a432, 0xce6edfa8, 0xc5d26a8d, 0x008cfde2,
	0x929e9fbe, 0x4bf9df4f, 0x13fbff39, 0x808d6059, 0x280a3743, 0x47d6ccbf,
	0xa9b480f1, 0xef7e86cc, 0xee2cb8c2, 0xbb773107, 0x17f44398, 0xe0a01e30,
	0xc80fb145, 0x3f2fa847, 0x47c44c16, 0x7e40b742, 0x9ceba8a2, 0xc68efd87,
	0xd748a557, 0x0abe2184, 0x7c49ffb7, 0x5f2a3155, 0x57c45d79, 0x7cc8d34e,
	0xdfd812e5, 0x57f33ef4, 0x492abae2, 0x5926d7c6, 0x301e84ff, 0xa00738f1,
	0x215be70c, 0xb26157f7, 0x23b44504, 0xbeb9fd6e, 0x76c4f588, 0xbd716ff0,
	0x3cfe8c92, 0xccd7535c, 0x58dd1177, 0x8ffa1f6f, 0x644c53d1, 0xebae7f2f,
	0x263f42cd, 0x7dc69ae9, 0xf3491fc8, 0xd0d68a0a, 0x8ecd2a7a, 0x2d6d0176,
	0x83f41fce, 0x559ef91f, 0x956e281a, 0xea1263ae, 0x33e586fb, 0xd11fb92a,
	0xe7836855, 0x4296a5be, 0xfec21bf4, 0xdfdcc3c6, 0x3a707868, 0x3ba337bd,
	0xfdf9156b, 0x48db982b, 0xe28fbdfc, 0xcce50d06, 0xcb30688d, 0xacd60171,
	0x8116c796, 0x0060c1f3, 0x5093e3d6, 0x78edf72f, 0xba81fd08, 0x0c378a02,
	0xc74f9932, 0x6d23b230, 0xad324f76, 0xe3cafffb, 0xd0856d5a, 0x4cbf75c6,
	0x9ed9b6df, 0x54038c64, 0x1d13306f, 0xf3f83ada, 0x01402b41, 0xbc88a7fd,
	0xe26b163f, 0xbeb86976, 0x121d2130, 0xafe532a7, 0x4a29db1d, 0xf90b75bb,
	0x683e8a45, 0x58f0e2cb, 0x2cb32a0b, 0x6f3ec66e, 0x0a2c755d, 0x9c117dfd,
	0x0be9eba3, 0x14fbfa3f, 0x0a6de41f, 0x03a63e1f, 0x59b05240, 0x5a6cbeb5,
	0x3fbf9b64, 0xb7fbfdf4, 0x3d91a595, 0xb0473f0e, 0x6d2b4ec1, 0x58e0198f,
	0x2e7a1d67, 0xea6c5f81, 0x37efe412, 0x4c1336dd, 0x8ca0a0f7, 0x0f16c3ff,
	0x999363e0, 0x848bc6a9, 0xaff4d24f, 0x2e2dfe87, 0xe515fde5, 0xbc00c733,
	0xffdb7245, 0xe007b346, 0xf757a4db, 0xbf952847, 0xde3286c7, 0xb6963dbf,
	0x90da437e, 0x43fe00bf, 0x90c25c57, 0x9deeb0df, 0x3049d68a, 0xa2edb456,
	0x62b1ed01, 0x810e7dff, 0xfcad12fc, 0x8beb26be, 0x9d6fad6f, 0xd7edfcc3,
	0x3dbfb8e2, 0xd614450b, 0x7dcfa429, 0xfa192a2b, 0xbca7e0bb, 0xca7e471e,
	0xc12fb3b9, 0x2faa81f3, 0xf0baa68e, 0xc3cc9fbd, 0xb2ef9675, 0xb7d8fa44,
	0x20080c57, 0xee6ea61f, 0x277d8367, 0xe7f852f9, 0x3fcc9b3e, 0x39433f76,
	0x2611eb69, 0xfac3bf23, 0x4007e339, 0x9ef109cb, 0xb2870893, 0xfbced49e,
	0xf48e9c42, 0x74bf2f96, 0xbff62e6b, 0x3fe8604b, 0x953fcfac, 0x57d680b8,
	0x8c2e27ef, 0x3d75ef8c, 0xdbacf846, 0x8f111fab, 0xffb8e217, 0x39f070db,
	0x8f91ea0f, 0x88e90203, 0x82d0295a, 0xad6d6e7e, 0xc59fd68e, 0x5377f981,
	0x81ae7b9c, 0xbdf9858d, 0xfa14fe8d, 0xf4ef7b57, 0x86f38f5f, 0xb5b804ff,
	0xd91172ad, 0x4d736dd9, 0x7fb38c16, 0x4c9a5f9c, 0x834ab671, 0x3bccf48d,
	0xd42ee515, 0xe9275293, 0x960d1d97, 0x9bc7b422, 0x2bd3d147, 0x374f5c1c,
	0xeffe9509, 0x8dfc5317, 0x32d3c645, 0x287fb8bb, 0xf1541bc5, 0x225e2972,
	0x7bf9a6f8, 0x0ff92067, 0xe8d17d49, 0xe798fb37, 0xb3375c13, 0x376b8b4a,
	0xe293bde1, 0x2e958e02, 0x1c99fb8a, 0x849f3f7d, 0xb449a7cf, 0xdf52615e,
	0x40ee38a3, 0x9ebdc38b, 0xed8d7cc9, 0xa8020b07, 0xbde31b6f, 0xa71878f6,
	0x0747f644, 0x5852de0e, 0x5fe4305d, 0x5344f4b5, 0xeac5b4bc, 0xae3945fa,
	0xdc973e97, 0x5332dfe8, 0xfa0677a8, 0x51c45f23, 0x7b456fbf, 0xfe01e2d3,
	0x05a07316, 0x11efeae9, 0x30e55e29, 0xd5f120b0, 0x681dd18b, 0x568ef55f,
	0xcb097c86, 0x98778a13, 0x05cc951c, 0xf9fe19ed, 0x40f68092, 0xc0ccb7e3,
	0x4bad10b8, 0x2c27141c, 0x2c7df995, 0x89acf550, 0xebe9bb58, 0xe63f21f8,
	0x247397d8, 0x37f8a9bc, 0xe297933a, 0xa37365bc, 0x6cb1fa18, 0x0ea8e86d,
	0x5e8e07f3, 0x7d6efe86, 0xd4e340a7, 0x80caffe7, 0x9d2593eb, 0xf27d5e5c,
	0x97f0027a, 0xe4c37e81, 0x8fd968f8, 0xcbfce26c, 0x22a68f7a, 0xf4e69f9e,
	0xb3de0c64, 0x564bae46, 0x7f4a7bd1, 0x3e3cd586, 0x85c72f56, 0x73d1d2c0,
	0x47e2bc4f, 0x6ffb96ac, 0xdc7957e5, 0x8e6af8d1, 0xe1ec5dfc, 0xc3942cd0,
	0xc615f010, 0x9f0ab685, 0xd87e42cc, 0xad8bab7a, 0xd813b681, 0xfbc22c48,
	0xef8082c0, 0x1adf9962, 0xf58ba6ba, 0x47971e16, 0xdd149ffb, 0x25df81d8,
	0xf64f9bdd, 0xfe3287f6, 0x055ede30, 0xfdab9dcf, 0xe017f759, 0x3bbd8178,
	0x5109bc71, 0x02480794, 0xe8e3581a, 0x28718cda, 0x097c2b27, 0xc2b3a9ed,
	0x9e2e8455, 0x7cc18f92, 0xd202ecce, 0x038ed4bf, 0xeb84ec3c, 0x8d3b7882,
	0x72b5eb03, 0x07ef0f84, 0xa1f9432c, 0x858d19a4, 0x5fe62e38, 0x1c903af0,
	0xcc8e2894, 0xa6ec76fa, 0x86d1bbf5, 0x7ae8aff8, 0x9bb46de5, 0x49d62615,
	0xff8d32f9, 0x3b98fdf1, 0x073f91eb, 0xf1dd9fcf, 0x07eb8433, 0xa25edc07,
	0xd0afda83, 0xca762bae, 0x3f3476fa, 0x7e984d70, 0xb70c0fdc, 0x207eeeff,
	0xbbfdfff7, 0x23bb5da3, 0x5e4fb1f4, 0x5ed60dbf, 0xb37b4188, 0xd80f0c29,
	0x7f2192eb, 0xf4577aa5, 0xe14728fb, 0x7fc681f5, 0x9a27b638, 0x3a1723f2,
	0x941f14cd, 0xb801efd0, 0x3ce55bce, 0xcf684248, 0x7cf3e41e, 0x7818ef9e,
	0x477ca44d, 0xffee4ed3, 0x3e78e934, 0x47cd8603, 0x67d9343c, 0xe0fc23e5,
	0xde713977, 0xcdabf3ca, 0x0dda0c7f, 0x9b63a441, 0x9e27bbd9, 0x7fdc20f2,
	0x691a2f63, 0xa43e4afe, 0x3fc7c023, 0x1a0baf9d, 0x681d7e60, 0x362f91c7,
	0x1288bcf0, 0xc87d3a4f, 0x207e81d8, 0x1d6809e6, 0xfa4592d5, 0x77c946af,
	0xb471e21c, 0x71af391a, 0x13d16aba, 0x126a9298, 0x5d71cb1a, 0x74fd6975,
	0xfb2f2f8a, 0xd6ba6cc5, 0xe2e3ab34, 0xdd23588b, 0x4a7af257, 0xb99aba3c,
	0x1dcfdc0d, 0xc0e9ff8a, 0x4b3570cf, 0xb2d768a5, 0xea356d98, 0xa81f9775,
	0x4dae0534, 0x5b674570, 0x8fe809d0, 0x288e2d48, 0x26baeba4, 0xadca395d,
	0xc1e749bf, 0xf8be14f7, 0x7fb73c5d, 0x03f6cb1f, 0x71c01448, 0x5e936b94,
	0xfdcbcb8e, 0x20ba62ad, 0xbf02755e, 0xe549b3ae, 0xa555d923, 0xa37d26bf,
	0xa16be309, 0x9dc51d74, 0x733c192f, 0xe297bf11, 0xf01f9972, 0x6c6d64d9,
	0x49cfe72e, 0x43992e56, 0x46fcf495, 0xcc7c3b89, 0xf17a8715, 0x2f8f3c58,
	0xb0b6f16a, 0xe6d6dd55, 0xea02ea2b, 0xe6f30d76, 0xf8f0e725, 0x63fde47e,
	0x9012afa8, 0xbe32594e, 0x9fd406dd, 0xa557fcca, 0xd2e9bc71, 0xbd3b35f9,
	0x41f22e74, 0xb271c636, 0xa2e3caf0, 0x3f821330, 0x408746fb, 0xb781a1fc,
	0x914dcec9, 0xd1e785bf, 0xb5f856fe, 0x4f885f70, 0xe3d5e594, 0x8d57bcc4,
	0x9fd0c0cd, 0x46f8dab8, 0xdf1d43bc, 0xfeffb708, 0x9ebe50eb, 0xbc791169,
	0x70120b14, 0x73e3643d, 0xf7b82d39, 0x05bef104, 0xa3ce3fec, 0x7f422c45,
	0x169dc664, 0x21c3479a, 0xeb6fc533, 0xa065f457, 0xed286e7d, 0xba7cc5cb,
	0xad08bf16, 0x782de8a4, 0xeb01daaf, 0x91ffb404, 0x477ad1ef, 0xe4f39f9b,
	0xebbf503b, 0x415e7b83, 0x16f56efb, 0x61a61e60, 0xfa0f6845, 0x7c1ee7b7,
	0x77fa1667, 0x79114dd5, 0x06dffc2e, 0x358bde75, 0x9c5c51c7, 0xd7efa9b5,
	0x377cd76e, 0x4ad60f2c, 0xf06cdf78, 0xbe79438e, 0xaf5e26f9, 0x474ebe70,
	0xd11a9179, 0xe8f508bd, 0x2fdab379, 0xf4e56f3e, 0xe8a1ddb8, 0xd22e776d,
	0x461edc31, 0xd22e7747, 0xbcc746b1, 0x23d4fd91, 0x4b7e811d, 0x7f9e3a65,
	0xd22e4a6e, 0x29bedcf1, 0xcdc748b9, 0xca0f56fa, 0xf79b12c5, 0xfe9788fb,
	0x07e49599, 0xca04dd61, 0xdbf2d5c9, 0xcdbf0d7c, 0x1bf1c7ff, 0x9d9a377d,
	0xa1c30fab, 0x830e73b6, 0xbde50d2b, 0x46fc64da, 0x237f877b, 0x464cd7c6,
	0xfa1c438a, 0x3dc6e2f2, 0x22dde728, 0x7f4a17f9, 0x0e6f2487, 0xde8737fa,
	0xc2fdba76, 0xca67fde8, 0x6269c8fa, 0x28778c7e, 0x07e2bbfe, 0x2aedf56a,
	0x0eedde99, 0xbee25fcf, 0x8950bac5, 0xf7cad6e7, 0xdc8b814c, 0xb825dd3f,
	0x93b73c79, 0x3d0dbbe2, 0xbf186df3, 0xe3c030fd, 0x15cf0db9, 0x2eb73c52,
	0xeb1072f0, 0x60b75878, 0xdd4375c3, 0x1663f7ae, 0x9bd68659, 0x82dcbeb0,
	0x04bec5f2, 0xe7111a0b, 0x3a7030fb, 0x7042c6a6, 0x4770867f, 0xe406423b,
	0x775806fb, 0x83529831, 0xfd8a3a14, 0xdb983836, 0x54ffd0cf, 0x3a94c3af,
	0x06956da1, 0xbadbabd2, 0xe3ea0085, 0x2b378344, 0x4b16ed0d, 0x4e9e51b3,
	0x0eddb396, 0x638411cf, 0x79ecbf28, 0x7f5111d2, 0x9635b7d3, 0xcf4fb7f8,
	0x57d4363c, 0xbeb2ad5b, 0xfd7f4892, 0xc03dbb79, 0xfbf871eb, 0x3f700e7f,
	0xc3a94ea0, 0x02505891, 0xe39a2d7a, 0x46f48939, 0xe8d41e7d, 0x92b6c8f3,
	0x79825e17, 0x39fe4d6c, 0x3e70bdf2, 0xacff223d, 0x163587ea, 0xf9d58aba,
	0x3f73f567, 0x3c82af5f, 0xe21a2f2c, 0x0a0e855f, 0xf1c836ff, 0xa9ed5f61,
	0xbebfc8b5, 0x7a86c12e, 0xf39ba96f, 0x275852ef, 0x970e2719, 0xfc09d677,
	0x46efa11b, 0xc3f7ff93, 0xffcb8a7a, 0xa9eaa3fb, 0xf3dc4c7f, 0x95ee469c,
	0xf4f12bf9, 0x05bb3cf0, 0x799a972e, 0xda97d769, 0x3eb2b838, 0x287d5abc,
	0x61f5a826, 0xd64ffdb8, 0xa309b187, 0x9e7543e9, 0x87d66fe1, 0xc37ce0ff,
	0x625b3d13, 0xa7ee3a74, 0x79a3fae3, 0x1fd69eb7, 0x2cee3cda, 0x79e1e2d1,
	0xae79514d, 0x66bb8fce, 0x2e71f9c9, 0x273f2fd7, 0xe5eadd12, 0x8f7d6dfc,
	0xd6af8dd5, 0xfe53165a, 0xbcd79b54, 0x859bed8f, 0x37e6d2a4, 0xe73ca297,
	0x79cf395c, 0x9eb8425d, 0x09eb0b20, 0x7ad54a4a, 0xc5cb65fe, 0xdd046f78,
	0xe1c00b4b, 0x4dbf811f, 0x45c59f92, 0x8125bfdc, 0x965ecbc7, 0x069c6beb,
	0x21758cd6, 0x1ed1ac9b, 0x7538af5c, 0x42680ebc, 0x09ade57c, 0x65e7a809,
	0x17fc1ebc, 0x3cbc03a6, 0xbd24efa1, 0xb8b7afe2, 0x712a0f51, 0xfdffa517,
	0xaaf21c72, 0x5a827fed, 0x7fedc3fe, 0x512ffc92, 0xf35bfbc6, 0x1b80ed69,
	0xe2305c95, 0xf798e3e3, 0xbfce1ac9, 0x1a33f5a3, 0x4247ff1f, 0xdc0983e5,
	0x75489f8f, 0x67a95704, 0xa7438ba2, 0xfbd3b445, 0x2f8c2e8d, 0xec83dc62,
	0x6e6486e3, 0xc97724b7, 0x758baa6c, 0xd4fd6097, 0xebcff87b, 0xdb23f746,
	0x7ee1f4c2, 0xf4a8db64, 0xe47e76f9, 0xcdcab69d, 0xfe8f3009, 0xb45c9ee9,
	0x00aceb73, 0x9effae3f, 0x1f30ba32, 0xf9ccddb4, 0xf9c0bb73, 0x578f2d92,
	0x2f3427e2, 0xaf3c33ff, 0xa7abe5ae, 0xe9f47a35, 0xda3d25ff, 0xa3d34ff5,
	0xdc60c45f, 0xfc7ef473, 0xd292b744, 0xa85bc25e, 0xb7986047, 0xebe1e652,
	0x57b271e5, 0xfb957865, 0xe8fb64bb, 0x86bcf448, 0xa4ee78fc, 0xc162c4c9,
	0x7ae629f5, 0x42d2a1b1, 0x4e86fdf1, 0xb0d2975e, 0x6f1e9182, 0xc52778c0,
	0xf4336705, 0xdeec2afb, 0xebce9137, 0xc5f8b1de, 0x57cf8c58, 0x06f3f431,
	0xb476f24e, 0x3e36fbdd, 0xa3e8adf7, 0xd55b427c, 0x551f54c7, 0xb5c5f5f2,
	0x2f04c5e5, 0x581c0bc5, 0x27411abf, 0x33eb9131, 0x1512cae5, 0xce287b7c,
	0x46fc0e7e, 0x1e1c5ff2, 0x941dc61b, 0xabb47638, 0x0dfbe297, 0x56f3b9fb,
	0xb0f9f222, 0x9f88d287, 0x2f4ff61a, 0x3bb60dfc, 0xefe885cd, 0xa16bbc96,
	0x07b9f738, 0xa17ea853, 0x883bde31, 0x038b5af0, 0x9a7fa2b7, 0xdfa0e309,
	0xaddf6e7b, 0xa2b70885, 0xbc6336ff, 0x6cdfde1b, 0x99b1c755, 0xa1e3a649,
	0xbc1f5a74, 0x8cbded15, 0xe5966dfd, 0x13425990, 0xf7208f67, 0x8927bc8a,
	0xe93fea3a, 0x5bca2647, 0xb360fa2b, 0x394d799e, 0x8fe47a43, 0xeeb92e09,
	0xec1fae43, 0x46ebcd9e, 0xbe45b6e4, 0x776cf82a, 0xc223fccc, 0xe904c7f1,
	0x2493e5bb, 0x17c63d75, 0x098ff782, 0xae16fd72, 0x14a281c3, 0xccbe894f,
	0x9b6ce8fd, 0xdac8f881, 0x089e78cc, 0xf9fd08f8, 0x19dea169, 0x31cf30b1,
	0x8869c16d, 0x759743df, 0xf6692744, 0x104fda71, 0x72f1f02b, 0xe4b5f436,
	0xf6c59c61, 0x4a488de6, 0x14adab57, 0xf6156d53, 0x8a44ecca, 0xe3e6377f,
	0xe96fa578, 0xd022dd79, 0x6d07e305, 0xed334b19, 0x3bc0ddf0, 0x083ed546,
	0x56cfd5ed, 0x7662bd53, 0xd7141bd7, 0x5417eeb7, 0x37ae5378, 0xbd785a26,
	0x1677bfa2, 0x734cbcd5, 0x7a957e90, 0xbfa3f5de, 0xa848b521, 0xde935879,
	0xfea333a3, 0x1f88c55a, 0x74d9b6c6, 0xb94caf48, 0xd0f0655e, 0x697a265f,
	0xf1c4a2bd, 0xf4957403, 0x1d716b7d, 0xbbeaad26, 0xd8f48fc9, 0x6035d76f,
	0x6a1f543c, 0x4f4a78a0, 0x9f3d4334, 0xfab395d9, 0x36676806, 0x350f28db,
	0xaa12fcf8, 0x3cc3f4ab, 0xcf308ec7, 0x8f3d44dc, 0x7e7225f7, 0x75a27a91,
	0x47a4cf68, 0xcf471b98, 0xe6d8f26a, 0x6d63f7c3, 0x23b9f112, 0x78895bd1,
	0x58f7ef0d, 0x7bf7c51e, 0xdc137d60, 0xe77f2eb3, 0xb147dc19, 0x1ecb8e43,
	0x8abe343e, 0x922d78e2, 0xea577880, 0xe591ef45, 0x0fbe3876, 0x76685d53,
	0x7edc1bcf, 0xbfd83bc1, 0x21fce7a4, 0x303a38b5, 0xd5baf85e, 0x37aff54b,
	0xca450536, 0x1ffad96b, 0xac45772d, 0x3db9da6b, 0xd7cbd869, 0xcc75dae1,
	0x03c8ec95, 0x24ff6a89, 0xf927fedc, 0xf8f0fe27, 0xc27d72df, 0xad3aebd4,
	0xc75da29f, 0x35bbf30d, 0xafe68dfd, 0xa5207528, 0xbf70e343, 0x43f8aad9,
	0x4c9d557e, 0xcb8f85a9, 0xabfeea4c, 0x7fbc6ce2, 0x71266eb9, 0xd6156b8d,
	0xca7e879f, 0xd4a43f28, 0x3c7528f5, 0x6f5e52fe, 0x1e81d7e3, 0x517cc2cc,
	0xa4efd52b, 0x5020a0b2, 0xafd78d1c, 0x0f1d6127, 0x6270ff7c, 0x71f3e136,
	0x49166ee6, 0x8404ba4f, 0x1e758cdf, 0x075f7cf1, 0xdb3427e2, 0x66f77540,
	0x7cc0ebac, 0xe9395560, 0xbbb014eb, 0x6a33bfc8, 0xe652fcf9, 0x90fd681a,
	0xa5f38632, 0x6029ae79, 0x38ea8612, 0x050f3a94, 0xbe32a52f, 0x3d16f253,
	0xa9507a85, 0x0311a907, 0xaa45994f, 0xe0f1e103, 0x6bf91d3a, 0xdb5e7d4a,
	0xf9005758, 0x72b1907d, 0xadabcbe4, 0x57e2d0ff, 0x8f8903a9, 0xb9451ef1,
	0x3db91149, 0x1437ea55, 0xa3a0897e, 0x6fe30cdf, 0x7c7ee1eb, 0xe081ad69,
	0x8dbbac1f, 0x758391e2, 0xbef6863a, 0xf9c8dbb4, 0xb6de334f, 0xc41606b9,
	0x9980a57e, 0x3e65daea, 0x0b1f92b8, 0x78c7cd74, 0x7b95e1ee, 0xe641fa73,
	0xa4ecac8f, 0xe859a0eb, 0x35e12714, 0xd3350f34, 0x6fcb2d91, 0xaeb19297,
	0x00219425, 0xfe731ceb, 0x09da82a4, 0xddb0f7a1, 0x793fe5b7, 0x87686c7b,
	0xda5fef00, 0x0242a932, 0x3c883c7d, 0x99d8c299, 0x7e1531c4, 0x73b077cb,
	0xdd6d329f, 0xd78827c4, 0xb6b7d67a, 0xb244e297, 0x7ae62b9d, 0x03199591,
	0xa2e54e3c, 0xe489d978, 0x5b77ca2c, 0xf7f7b3f2, 0x2334f3e2, 0x39e0d7c5,
	0xb189fdf1, 0x1773f9d3, 0x669603e7, 0xac13f5e5, 0xed7a8fcf, 0xca74d644,
	0x5ca3d7d3, 0x67d51f80, 0x80490af1, 0xef42f3cf, 0x13839432, 0x00adff33,
	0x81fcfbf9, 0xdea0c687, 0xfe00c5b9, 0x667a08f9, 0x99eb939f, 0x59a5bd41,
	0x5a767e80, 0xd04951bc, 0xde7a3b7e, 0x9efd2c2c, 0x80dd3f1b, 0xffccfba5,
	0x1494c894, 0xcfb7dc03, 0xbda37ee1, 0xbac052ac, 0x0e6635cc, 0xf2578247,
	0x9de31f90, 0xf300fc23, 0x137d7298, 0xf5a26fee, 0x8b15d787, 0xe54bd175,
	0x2ca27dfd, 0xd72ca2d7, 0xcae95bbf, 0xbb51c093, 0x1111f3ae, 0x8437e8fd,
	0xa63feb91, 0xabb87125, 0xe404d744, 0x36cfc707, 0xe802b6fd, 0x01dc1a2b,
	0x749aefc4, 0xf6f90bab, 0xb3896b25, 0x3211fa0f, 0x758c5a7f, 0x7fd26bcd,
	0x32f98c5a, 0xacedce31, 0x4b4f688c, 0x657f5172, 0x2be21ef8, 0xe318b1ba,
	0xfeb77fac, 0x82bfa162, 0xb85fdf6f, 0x6b87231f, 0x219429a9, 0x6edd9c81,
	0x5e907af6, 0x4fbfe697, 0x2965d5f9, 0xfac3de27, 0xe67a1387, 0x4c7ea3d1,
	0x8175f796, 0x8f71c6fd, 0xbef9da66, 0x8cfb5b24, 0x70e76c18, 0x0595bc3e,
	0x315e1f28, 0xbbf3ef87, 0xf536f59d, 0x38b77bc1, 0x08beaef5, 0xa5d5b879,
	0xaf9edf6e, 0x75c8576e, 0xab73df16, 0x42c1dfef, 0xf7e5f212, 0x17957ea7,
	0xb319ff79, 0x5be42ee7, 0x9f5c5fd0, 0x4d2ebc0b, 0x6635a7e1, 0x0fd40be0,
	0x17ca428e, 0xd2758f8e, 0xcc7a67fa, 0x0b9476d4, 0x32f40a31, 0x7ea9e577,
	0xebc8fff0, 0xa36655b0, 0xc39efd1f, 0xbe5145cf, 0x9993bc76, 0xe91d7132,
	0xe11a0774, 0x795135fe, 0xc0e9afb4, 0xe275af5f, 0x89ab217b, 0x8398f9ea,
	0x4e603f3f, 0xcc47e7a2, 0x3a4faa46, 0xfb40d27c, 0x4caf00df, 0x27fa7a8f,
	0x372fde4c, 0x46baa25d, 0xf0ab8f81, 0xf7404033, 0x82f2c8b7, 0x94066ce5,
	0x3be56ae3, 0xf6826ec6, 0x8f276285, 0xd1197b23, 0x318ac2e7, 0xcbf656d4,
	0xa29aa496, 0xb77b3fb0, 0x7d0e30c0, 0x00a886fd, 0x3915c3c6, 0x0df6e451,
	0xf8831edc, 0xfde06c9b, 0x4718d87b, 0xb9ce8522, 0x029dc73d, 0x4dbe4f00,
	0x4a1a8369, 0xc8c97b44, 0x70f255ff, 0xfbf0a6e9, 0x393f7c1e, 0x469dfdfc,
	0xdb940baa, 0x9f2bf742, 0x25f79d23, 0xaa7ec965, 0x7f1c1eeb, 0xeb48c997,
	0xbaf1662e, 0xc8a17e30, 0xaf758ee7, 0x3a02b6fe, 0xb777a35b, 0x6e913ce3,
	0xf98e89ab, 0x36fb500f, 0xbbf10dab, 0x86979cca, 0xe5462072, 0x58dda1a5,
	0x2abb7763, 0xc0f9da23, 0x90e373c6, 0xb41ef02e, 0xcacf2cef, 0xf3f42293,
	0xe0ee593e, 0xf83c4f3d, 0xaecd8781, 0x11979434, 0xe3e7adc6, 0xc77dff46,
	0xf0b8c275, 0x8c2b61de, 0x52e3405b, 0x2eafc03f, 0xd9977fec, 0x20c5d418,
	0x8fc8bb5f, 0x8cb8d2bb, 0xe95ea905, 0xc0ef1936, 0xf38c7e8f, 0x68eab61c,
	0x5c9b731d, 0x81387b27, 0xd5f2c78f, 0xa2632af5, 0x7baa3c60, 0xdca7d752,
	0x426f6c22, 0x1cc5b53b, 0xebf913b3, 0x8e8f9915, 0x18c7ff46, 0x995e4ff4,
	0xf5047b97, 0x55d8acf1, 0xb744c84d, 0x5f924eb1, 0x4a5cef45, 0xdb04bf7e,
	0x517a7fa0, 0x3ecb2cff, 0x3f3b0f31, 0x0632df62, 0xf5c80eed, 0xc3c9a489,
	0x55f857e1, 0x14f91b81, 0xa7cc24e5, 0x3e15f81a, 0x52747763, 0xe0e3de41,
	0xf155e1df, 0xce4560f7, 0xe95db1eb, 0xa603f343, 0xe46a659e, 0x13f3a8f3,
	0x1fd8b7dc, 0x37ae7aa5, 0x1167bd93, 0x3e93b9ae, 0x65f090c9, 0xe43cfce7,
	0x83f78053, 0xb5784dff, 0x7f52adfe, 0x954bf5ac, 0x2e05637a, 0xe32b9cad,
	0xbe2af52b, 0xa9f91d5a, 0xd205ba33, 0x22663eaf, 0xf175f1be, 0x1586e57a,
	0x55eb8dcc, 0x52b2df65, 0xc0bcff2f, 0xe7fe89e3, 0x47f42e8c, 0xbc9f58af,
	0xe64fa954, 0xb207b6ed, 0xf8095f69, 0x1f3ebca9, 0xf5c625f4, 0x9eb90ada,
	0xfdcf9b6b, 0xf90417da, 0xf7f285fb, 0x77f119b3, 0xe02e359b, 0x90a4f597,
	0xde375438, 0xfafdc1d6, 0x365cebb6, 0x963f233f, 0xc47f13af, 0x165b5ef5,
	0xbb69dbaf, 0xafbe1afb, 0x3e26e745, 0x1f8031ad, 0xdce6f3ca, 0xc8cb1ecf,
	0x3dc6d6cf, 0xe3aa75af, 0xdff6e19e, 0xc4b9ee29, 0x02712de6, 0xf02c2d9f,
	0x11b3e864, 0x04ff1e2e, 0x0bdedd7e, 0xc6b3975d, 0xb93eb831, 0xa9be3595,
	0x9d7e21cb, 0xe7f184e6, 0xcd7e078e, 0x8debf151, 0xc7ae04ce, 0x5f852e11,
	0xaf9a7cc3, 0xcef35bad, 0xecdbf7c2, 0xa036ef9d, 0x746ddf5f, 0x5e5b7af3,
	0x0fd5a86f, 0x902cf011, 0x510e3c38, 0x18ee7824, 0x91ab9e09, 0x4d3e489b,
	0x463e5c62, 0x89249f93, 0x4345adf9, 0xd98cf3f2, 0x5bc463fb, 0xf2d68e58,
	0xb830dc75, 0xd3f10b45, 0xfcf3775d, 0xfb9a2f8e, 0x49e79811, 0xcb67f186,
	0x52d5dfe3, 0xf7c76659, 0xfd7df366, 0xe1107e00, 0xcf9f92af, 0x3aa7aeee,
	0xfd32aaae, 0x457f48a9, 0x5e4a97d1, 0xfefcae69, 0x7ad9b69d, 0x53990fac,
	0xcce7cea1, 0x93e787bd, 0xeea39aee, 0xf0db2e67, 0xb217d509, 0x6fe23d46,
	0xe7ea3dee, 0xe70ceeff, 0x0f30f281, 0x7f8e4474, 0x72e7ce0c, 0xc5849bf4,
	0x7c027fdb, 0x059ff79c, 0x99971845, 0xebb75899, 0xb93f6811, 0xff6a1aed,
	0xff47f126, 0xef9f027a, 0x9976a5c8, 0xb0fbe04e, 0xf00c9f70, 0xddc97e7d,
	0xa0c565b7, 0x45fb913d, 0x7475c4f9, 0x366db794, 0x989ce7bc, 0x6597754d,
	0x707e7af2, 0xfb7e7f21, 0xa12f2b24, 0xf145d7bd, 0xbe28b2d0, 0x0ab4199e,
	0x3adbac6e, 0xe7a4685e, 0xf1646613, 0x0f60d9e7, 0xbe7cf9f1, 0x5178fd9f,
	0x98fd1074, 0x1c677aff, 0x7c223f3d, 0xdded0f32, 0x4245bd40, 0xf0a4353a,
	0x7cf8f338, 0xf00e3821, 0x8f271656, 0x5de7cf5f, 0x0a54f451, 0x695951ca,
	0xdfca1e68, 0x06298a40, 0xd97c01e9, 0xde31fc81, 0x0725bd3d, 0x942fadf9,
	0x0a97c911, 0xfc2b67dd, 0x3be6a658, 0x9d27a790, 0xabd65709, 0x0f33be2a,
	0xf168ddf1, 0x3f6b8043, 0x6a0dcbc9, 0x471e137b, 0x71da3723, 0xfc679347,
	0x438bd48b, 0x7c9275f0, 0x5cd561a4, 0xab4fca0e, 0x41bf3f22, 0x5eba0c38,
	0x29932fda, 0x0da1afb8, 0x26dd53a7, 0x391a47b2, 0xc74be052, 0x70d16d98,
	0x524ff0b8, 0xe7fe47fc, 0x9a7df5c0, 0xf3be1cfc, 0xb821b8b0, 0x90b7fc60,
	0x872d6c3e, 0x91a171e7, 0xb7ecbfcb, 0x0681712b, 0xea5dbe65, 0xf14496f9,
	0x8c4ee9fd, 0xbecc50df, 0xdc309af0, 0x65074157, 0xced93e3e, 0x5a5531ce,
	0x1fb7300d, 0x6e486bd8, 0x9d2c05ff, 0xc5adf51d, 0xe9e231fb, 0x83dfceb0,
	0xcc859feb, 0xe05b7943, 0x23393f8f, 0x5e0503fc, 0x461a9e2d, 0xf9da77d1,
	0x4433f168, 0xbc64deb7, 0xc2d1fb2a, 0x79cabdf3, 0x8708fd6a, 0x8b471d41,
	0x715de393, 0x2996f8e1, 0xb0579f1f, 0xb7c53728, 0x09c502dc, 0x404fd02b,
	0x14672b79, 0xe8b3886f, 0xe2b49f68, 0x27268c1f, 0xf5c4df37, 0x03f80549,
	0x9f1c1f7c, 0x931f969f, 0xb403df58, 0xb6b934de, 0x5dfb402e, 0x0f9d516b,
	0xf1e16152, 0x8ac9b1f0, 0x8c9bee3d, 0x1edc38f6, 0x26fb8f66, 0x27983ea3,
	0x1544f3aa, 0x361c7997, 0xd740b2ee, 0x93fbf70a, 0x95c71ed1, 0x3d464df7,
	0x93d63f32, 0x7d740c9b, 0xd62bae4f, 0x5928b3e2, 0xaf61c4a7, 0x72b54f8a,
	0xfadfe4a4, 0x38c9de2c, 0x39af128e, 0xe096f42f, 0x36f1a54b, 0xcde4fd79,
	0xbe067e42, 0xc50ba3d4, 0x81f184be, 0xbfe0e6cf, 0x39776f01, 0x0a7c427e,
	0x64a6e4fa, 0xb27927d4, 0xfae4adfd, 0xb9e6c624, 0x1be79939, 0xcbf72f09,
	0xdb299978, 0x45db0bc3, 0x3ccafbf2, 0x35305bf9, 0x67a63be1, 0x0f639201,
	0xf225b1d9, 0xe3802ebc, 0x9ff7c413, 0x5c5d92b6, 0xe50d6afc, 0x75daf26d,
	0xd76115cc, 0x54a205c6, 0xdf8c5ee7, 0x4f6aa71b, 0xbd514ce8, 0x5b2ba93f,
	0x7830bcf5, 0xb5f9ea8d, 0xed548ac7, 0xabd7bdc9, 0x76f29fde, 0x5d7daaa9,
	0xf7aa6ddf, 0x065da0f7, 0x61f0debc, 0x9ffeea95, 0x73a2cdb6, 0xfd0c6e4e,
	0x69fdf550, 0xfcc0be39, 0x987cde9e, 0x7f8502ff, 0xbeab572f, 0x2823f707,
	0xe01ea094, 0xf0360b7f, 0x80e9eefa, 0x16fec8b1, 0xfeedaab6, 0xbaa2164c,
	0xe08086b9, 0xffac320e, 0xebaf3f52, 0x5ebc20ea, 0x9e7c5f69, 0xf90ebe63,
	0xf8326561, 0xe3ab6803, 0xafd63c59, 0x57ff268d, 0x1b2e7fa2, 0x6fe8adf3,
	0x6fe9aa74, 0x1fe9a976, 0xbfa6af9d, 0x7fa6add5, 0xfd3554ec, 0xfd351eed,
	0xf4d5cbe3, 0xd354a84f, 0x9aae693f, 0x355ec9fe, 0xd56b53fd, 0x546f4f74,
	0xb9733bd3, 0xfe59ae9a, 0xb6e7d4fb, 0xe140f868, 0xe69f4527, 0x39afdf34,
	0x74c745e7, 0xf0a17c11, 0x5aca82d9, 0xdb1a0baa, 0xf1aaeffa, 0xc791fcb4,
	0xefc67ae4, 0x262f1fc8, 0xc00e73f3, 0x4d7dc496, 0x4c13de76, 0x5fee184e,
	0xd22b7a28, 0x63ae479e, 0xc367d347, 0xaebc94ec, 0xe14ed51d, 0xb43cd6ba,
	0x4f8d1dae, 0xafb0324f, 0x8a06f834, 0xe36ddd4b, 0xe28e1c70, 0x7c45f5fe,
	0x07bc1d74, 0x78054cef, 0x607ce24f, 0xe35193fc, 0x43f12e29, 0x71c7a9d6,
	0x74bd61ef, 0x7442c79d, 0x6a9b32f5, 0x5602c4bf, 0x14e39069, 0x2e3f5067,
	0xa095f535, 0xff34bd1e, 0x27947bc4, 0x557f1e3a, 0xc29c42e7, 0xc658c47c,
	0x311f31fa, 0xe15d6236, 0x04472e61, 0x0867ab1e, 0x18994f64, 0xd5527545,
	0x3d9022ff, 0x5f8cfeaa, 0x35fb44bf, 0xcd75f879, 0xad8f0572, 0xfdc01fb2,
	0x9714dc81, 0x5e62b79c, 0x6e9df90b, 0xe87bea1b, 0x7e05e78f, 0xac75a069,
	0x01e1c4d3, 0x8e5d2213, 0x4464eda3, 0xee37a467, 0x789a7287, 0xc482751c,
	0xfee1974c, 0x3f25e678, 0xe7852e30, 0x812e7ec5, 0x5ffde34a, 0x253bfd83,
	0x538a2aff, 0xe3a998ff, 0x0a34f7d4, 0x31fea714, 0xa7570bc0, 0x72fb4dcd,
	0xc22a7694, 0xc329f30b, 0x927ee0f7, 0xb8c051b3, 0x2fedb7d4, 0xfde30fdc,
	0x5be21fe0, 0x01a65b89, 0x8e8119df, 0x28cc7ebb, 0x638da6ae, 0xc1a08aa6,
	0xcf488eb1, 0xa53b8df7, 0x3c7ebe76, 0xe2a9b6ea, 0xc76f4c31, 0xf257807d,
	0xf7feb0af, 0x3ebd446c, 0x2471bbd0, 0x0a5961bf, 0x579a1bf7, 0x7f31f29a,
	0xbac7dca5, 0x9a478c3c, 0x423f705d, 0x1cf0989f, 0x76bfb827, 0xe44e6f65,
	0xc4a4b7fb, 0xd2eb3f51, 0x5c61b7ee, 0xc6e1ca6d, 0xd7f20478, 0x9b9aef66,
	0xc1ecffb8, 0xeb275ef9, 0xba1ba9a1, 0x0757ee44, 0x94d79c44, 0x91b3a5b7,
	0xfaebcaeb, 0x3e1bedd4, 0xca7db754, 0xbed34db9, 0xacb9428e, 0xe8daf997,
	0xf422b804, 0xfa3a3d4e, 0x677acf40, 0x9459c52e, 0xbf71bd78, 0x167da410,
	0x5c0244e8, 0x95ae5906, 0x0251be38, 0xd694c0da, 0x64beb95a, 0xc61b5e69,
	0x12290dd7, 0xc4c8c79d, 0x2e9fb415, 0xe7e3070c, 0x4ae85db8, 0xe4e390ea,
	0xdbcede7e, 0xe8d1ed89, 0x9594d934, 0x37bf8127, 0xceafc6d9, 0x4ae6cfe5,
	0x7bdfc3f1, 0x4d2fce4e, 0xafef31d6, 0xf723a446, 0x3f78c337, 0xb03458b8,
	0xd6def011, 0x59bbf2f5, 0xd5ef1edf, 0x3ad6b24b, 0x19539e51, 0x6e358bed,
	0x0192c558, 0x1edb0b6f, 0x8fae7da1, 0xe13d70a5, 0x9b7af913, 0xfdf02b3d,
	0x7cfeb2b3, 0x620326d2, 0x3ff640da, 0xb99bcecf, 0xf21d7eb1, 0x6367b9f9,
	0x9e7b5e89, 0x7bbad1d0, 0x70e80b1c, 0x6c41e33e, 0xd604f9f0, 0x2849ed47,
	0x642ed002, 0x6ba3e22e, 0x4cfc8859, 0xa70f9fd0, 0x441a1e00, 0x686613ef,
	0x3ef74f9f, 0x41ecf3c9, 0x32b92fb2, 0x762ae49f, 0xaed25da4, 0x214d1faf,
	0x875d5a3f, 0x9e67411f, 0xdf1e38ff, 0x9f207c41, 0x78e17397, 0x9f6a4ece,
	0x2d3f13b3, 0x6169f994, 0x6462657a, 0x959eeb7d, 0x08a563ed, 0xeb95c9b9,
	0x3caef669, 0xe22cb639, 0x1e32d3fe, 0xd2e859f3, 0xa2ffd0bb, 0xf26ed1fd,
	0x95363c83, 0xceb374df, 0xe60a74fb, 0x075cfb53, 0x56cf3474, 0xfea94f3a,
	0xcb6d8109, 0xe5cdfb42, 0xe4caef75, 0x8d9fec5c, 0x283c27c9, 0xa6143df0,
	0xfd871f17, 0xb87f9f9a, 0x757c1d30, 0x73e167e8, 0xf9372439, 0xb9279f8c,
	0x081ad9a8, 0x376e3408, 0x8f0349e1, 0xf087fc76, 0xd204816c, 0xc70ebcf7,
	0x1f79c922, 0x3d722b8f, 0x73f15eb6, 0x28c53ae5, 0xf9f0bfb9, 0xfaf0d727,
	0x6deb0b09, 0x68e1bcc7, 0x4a44e876, 0x810ec696, 0xc9fcc0ed, 0xe5c91364,
	0xebcf257a, 0xfaa2e13a, 0x9d62b835, 0xc3a649a9, 0xafdf2b3a, 0x53e1d0ab,
	0x2a7e3f59, 0x49a0d7cb, 0x2a799bc9, 0x1eea230a, 0xc86bbbab, 0x7ae2529f,
	0x3b1fb283, 0xc38ea518, 0x342cc9d5, 0x34b5a478, 0xad45e30a, 0xd757ae3c,
	0x7f3f3b7d, 0x3a51e7ab, 0xa4fa0cbf, 0xe46b14f3, 0xd59a6bf7, 0xbdc2d4fe,
	0xb4bbf25e, 0x3fd69afe, 0xd019cc03, 0xb3fd6a4e, 0x7f64524f, 0x310acdcc,
	0x437a776e, 0xd428d1ce, 0xf68c596f, 0xbf8aa4cb, 0x4d5ff3a2, 0xe78adbcc,
	0xbe02b17e, 0x77ab5e0f, 0x840cd3b2, 0x9302bd97, 0xb216d5e3, 0xf3277bf3,
	0x97def538, 0x1631dc2e, 0x043224eb, 0xe1d51d55, 0x977d3d0c, 0xa3f9ca9b,
	0xd11bae53, 0xca9f1ff6, 0x75beafeb, 0x9854c3fd, 0x43fd4442, 0xd1df577d,
	0x41d51768, 0x3d22a5c4, 0x53117e8f, 0xa21b7c40, 0x334b73f3, 0x37083c39,
	0xd3eeabd6, 0x922f327d, 0x2553721f, 0xbbf72782, 0xc351e5c2, 0xcde0be75,
	0x5c38dbc4, 0xdfa15363, 0xc4a9e081, 0x05443ac8, 0x23a57dae, 0xfa9aa7ef,
	0x1e29e15d, 0x10534f15, 0xb4f0d19e, 0x3c3230cf, 0x72e54bdf, 0xf8475ff3,
	0xcfe1de3e, 0xbf56ef85, 0xdfc1aed9, 0xa177bdd3, 0x7ef005db, 0xe03ae90f,
	0x58a44fec, 0xcebf8ca5, 0x8b3f9962, 0xa6e3fd65, 0x7be652da, 0xb1e50a67,
	0x5f16253b, 0x0592ed81, 0xa1ae55ee, 0x1d3ee0fd, 0xbd91ef3f, 0x79916463,
	0x2cdae518, 0x8a5f63cf, 0xd61e2230, 0x7fbe72a4, 0x267578e9, 0x7f3f03fa,
	0x2f50c8db, 0xbffbc934, 0x34eb6e7f, 0x0a7879e1, 0x045db11e, 0xb4219f57,
	0xe2ed8dc8, 0xcb2e4d4f, 0xf8e9e308, 0x72349b78, 0x5ca78ca3, 0xcf9a9a7f,
	0x11c236e3, 0x3715eb11, 0xce937b4d, 0x2c54d8b1, 0xd6fdee91, 0xe7e56ff8,
	0x1ff184ef, 0x0ef1337c, 0x453f2fce, 0x670837fc, 0x6d0fbe62, 0xbd7a109f,
	0x061bf300, 0x07dfcd2f, 0xc118ec78, 0xf995aa1f, 0x329f9957, 0xeb6e057f,
	0x0e880b8d, 0x324693d6, 0xf7e46b1a, 0x2b117b15, 0x2f38d1fb, 0x24d317b2,
	0x9939ef5e, 0x9a6c93d7, 0xe3d53d7a, 0x0bf393ee, 0x230ceba1, 0xacfbb79e,
	0x5f9fb78c, 0xcf17a37e, 0xeb77f37b, 0x93243f69, 0xe2779cfa, 0x2dff8939,
	0xc087b9d1, 0x5e78e54f, 0x2fc74bc3, 0xa0bae0c4, 0xb3eb9533, 0x0fae54ce,
	0xe58b2f07, 0xfc7b2754, 0xc1189b53, 0xd1c0fbff, 0xdeb471e7, 0xdd7fac5e,
	0xfeebc458, 0xb69db22c, 0x45afef1c, 0xff532df8, 0xf04428dd, 0x91aa475b,
	0x0868dbbe, 0xefd1ba25, 0x830581ec, 0xf3a2e085, 0xfdf5c262, 0x86878e36,
	0xf30c23e2, 0x7e6e96f2, 0x3c3ecc8e, 0xc38126fc, 0x47ee007d, 0x56d4fb8d,
	0x618bcf83, 0xefa1ecbc, 0xcf4e36ad, 0x7f7cc9a8, 0xbf69a6f8, 0x3539e1b3,
	0xf3a302b1, 0xf4d3b318, 0xbfab73aa, 0x00e9c997, 0xe05d1ffc, 0x94f17da0,
	0xf527595f, 0xd9d6fe12, 0x3156d8c6, 0xd73f3bc2, 0xe5133afa, 0x79a56657,
	0xb2bd465f, 0xfd00e411, 0x56f52659, 0xd87c20ce, 0x96dce90a, 0x17f27673,
	0x6f79901f, 0xbaa5eb02, 0xb06c561a, 0x762a1ca1, 0x9569cffc, 0x595fe8b1,
	0x3edd38d2, 0x03658df8, 0xbe055bda, 0xf3c12b33, 0x2f6a1bcb, 0x42ce5774,
	0xde622cbc, 0x59beb8b5, 0xf6aa26d4, 0xcb207e25, 0xd1cbc2e5, 0xc46d782c,
	0x487f5377, 0x2f0bd575, 0x0ffdd0c7, 0x0ff83ae4, 0x47ec7ce4, 0x59fcdf32,
	0xed215fe6, 0xb737ea3b, 0xff1ebe46, 0xae6a9ec3, 0xbc423edf, 0x067d0bd5,
	0x5e378ff4, 0xb7d505ff, 0x6369599e, 0xcd37e341, 0x23059e33, 0x77bf0dc6,
	0x1182ccd9, 0x9a4b0deb, 0x3431e68b, 0x3f3d0b5f, 0x0579d2b3, 0xf0aaa63c,
	0x8e7fd438, 0xfbc38f0a, 0x67e7a5cf, 0xa15fe656, 0xf4a3f1ff, 0x7f82a59f,
	0x7431dfa8, 0xf570e07f, 0xdfc0d193, 0xb7ab8387, 0x057580bd, 0xfe748c87,
	0x2ceaeb2e, 0x67fb3aa5, 0x2d01d518, 0x7bf9f43b, 0x6cb02f58, 0x638dc1a7,
	0xf343ea0c, 0xf3e823dc, 0xc7e6cc31, 0x6b942cf3, 0xd10e5a7c, 0x24df7b59,
	0x1f586c05, 0x6c97ca60, 0xac4c4f68, 0xf89ab037, 0x44fa44d7, 0xfd287b89,
	0x9e078e7e, 0xfb61b025, 0xf68ade74, 0x3ea1a5e6, 0x540e85d1, 0xff993fa3,
	0x61a3ed29, 0xbc7e4ecc, 0xb0903f12, 0x31400b30, 0xf5864ab2, 0xde19eda9,
	0xe7806989, 0xc57104ff, 0x61388278, 0xa4f31797, 0xb7f5cb0f, 0x9d7b9b0f,
	0x74bd08ee, 0xddf49a73, 0x8d3687fc, 0xfbfc9e3d, 0x0f6e413d, 0xea38466e,
	0x8bffdec5, 0xfde4fbf0, 0xf9340085, 0x47c5d5a5, 0x6a9b1ce9, 0xacd63d65,
	0xdba453cd, 0xc4a61d71, 0x5170623b, 0x2378f68b, 0x89ac17af, 0xdf9aede6,
	0x133ed3c6, 0x3d45652c, 0x7de53ac4, 0xe59c722c, 0xa0f30c82, 0xae066369,
	0xfce50633, 0x97ee85c6, 0x0ba45ce9, 0xee8963cd, 0x443e2f35, 0x4beca1e7,
	0x3dd0f391, 0x3513b256, 0x9e097746, 0x852fb3c7, 0x529d83fb, 0xc228a630,
	0x56975c3f, 0xef0d9bda, 0xab1e6b9f, 0xff073c8b, 0x6d2f595e, 0x930af594,
	0x57582542, 0xf838ae7a, 0xfda9d93a, 0xd0f38666, 0x84bcf81d, 0x68da67ce,
	0x4b6c73a4, 0x3cdb8c0f, 0xb951d717, 0x4fa73a3a, 0xf04cc077, 0xcfcf5f9c,
	0xd16fc095, 0x481fd69e, 0x4d6875a5, 0xd3f28874, 0x5cee51f5, 0x1cd53f8c,
	0x9fce81b8, 0xb8f0fd3d, 0xa70fb40c, 0x74195c12, 0x80c3debe, 0xa9f79874,
	0xbf7e3c9e, 0xe3ed0a65, 0xf68c6eb0, 0x8a2e748e, 0xe7b5efa2, 0x294bec56,
	0xfc42e81c, 0xbe91338c, 0x1b9ca85f, 0x52439f28, 0x85542c73, 0x91ad86e7,
	0x96353fd7, 0xf3a2bf8f, 0xbfdeda66, 0xe524ea87, 0xf594adf3, 0x1adc7693,
	0x67d9bfd9, 0xdfc3cd08, 0x2359a851, 0xf3c0dfe3, 0xc2ba35e9, 0xf8cb6a5c,
	0x7f39a8df, 0x7fac8b6d, 0xe3e9eb95, 0x03979d12, 0xe3033af6, 0x190fa774,
	0x6f4edf89, 0xb8fb4f1c, 0x006af194, 0xcb903637, 0x89ae7153, 0xa81ddf48,
	0x6bfe70af, 0xb950baf8, 0xa47ba35f, 0xea1de91c, 0x395f2911, 0xa0c50b68,
	0x53de521d, 0x74f9e1da, 0x037bf48b, 0x225e52fb, 0x315f03ba, 0x8bdd2be4,
	0x2f3f0f56, 0xc16eff8c, 0x8fe662b9, 0x6df53f46, 0x0ea3ad23, 0x4fc918f7,
	0xf7c93c1d, 0x3f3b0d03, 0xc0ca12c4, 0xc5ef94b8, 0x8363d254, 0xdc1da1e9,
	0x79d335af, 0xbc278335, 0x6478e453, 0x4f1e7cb2, 0x9753fa32, 0xf441cc7a,
	0xe74ae0a7, 0x2ed9f80f, 0x143fdd27, 0xe192fb4d, 0x4c9bf54a, 0x73a4efd8,
	0xfcab59d0, 0xbf7d2f7d, 0x879bc32c, 0x0e59797a, 0xefc16ff4, 0x4bbde9fb,
	0x3649ded9, 0x9149271e, 0x7ea14bc7, 0x7499bdd3, 0xc9d4f85f, 0x956f03cf,
	0x73d2f79f, 0x853bd19f, 0x95aef1e6, 0xcf308c75, 0xccee7aef, 0x44f16933,
	0xc06e0547, 0x5a67f933, 0xc69bbcbc, 0x1f0519fd, 0xd30cbe5a, 0x61f00af3,
	0x0dd683bc, 0xeb8e9cdd, 0x3eb819c7, 0x7e4f1969, 0x8e64ed28, 0xeaaf0bc8,
	0x72f880f9, 0x82d9ef50, 0x42742876, 0xa19be74f, 0x601c5140, 0x26af7f2a,
	0x0293cb9a, 0x1d72c7c7, 0xcf0b5d57, 0xd4fc7f1b, 0x2df31907, 0x03e77fb8,
	0x019dfed5, 0x73281f65, 0xc3dc60c5, 0x54c576e2, 0x587f7017, 0xdd78b824,
	0x8bbd46cb, 0xffc2af7e, 0xef5a38f0, 0x0eb8369f, 0xeb5279d0, 0x9f90e827,
	0xf75cdc5a, 0xbcf95bf8, 0x94247394, 0x78b420f3, 0xe1cf4949, 0xef33e6e7,
	0x4ee268bd, 0x5ca25731, 0xdee7414f, 0x00bfe2d4, 0x7463b5e5, 0x33af331e,
	0xfc30bb22, 0x15c319fc, 0x7fe2cf7e, 0x60caedb7, 0x6e2d5fc4, 0xd5da0c7f,
	0x5d7c6d0f, 0x2173d406, 0x3e456b9d, 0x2f933a4f, 0x6575ed19, 0x3d027a76,
	0xa1f83d27, 0xf96b9fc0, 0xc377d14c, 0x837c81f0, 0xd077e2fd, 0x8f3a7177,
	0xa0b2917b, 0x80dfaf60, 0xbd8a0875, 0x0e9209f2, 0xdbf59bf7, 0x97c8315d,
	0x71392dfd, 0x63ef30ab, 0x45162577, 0x08ef89f0, 0x2e567da3, 0x0a730f3c,
	0x99ee8b9e, 0x7db6f188, 0xbe75ea71, 0x4d5f9e16, 0xf9179bef, 0x6e74a6fc,
	0xb9d22af7, 0x674b2d3c, 0x16827d72, 0x160f9c8f, 0xe2d07ccb, 0xeb44def6,
	0x8b7bcd3e, 0xfe6563db, 0x7d6fdcd0, 0xdf28dfe1, 0x5e7d5db7, 0x03d22c52,
	0x98f0fdc6, 0xc24c2fc1, 0x9dff146b, 0xbeb84790, 0x22b57dab, 0xa6de41f7,
	0x3bd387fd, 0xc9e7467e, 0x3339d82f, 0xde712997, 0x905cfe08, 0x7f45c9e1,
	0xb455b42e, 0xb6d49ca1, 0x8b4f048b, 0x0ada6ad4, 0xebb6cff7, 0x95abcfc9,
	0xe69b39e1, 0x49ba218d, 0xde00324c, 0x18de4acf, 0xcab763f2, 0xe66be6e7,
	0x29bdef01, 0x1f808d15, 0xe133a713, 0x3e046727, 0x3a23a138, 0xfc62882d,
	0x043a0377, 0x9b3d57aa, 0xdb17bdee, 0xa6deb0fd, 0xeb5b2cf3, 0x16b7bf68,
	0x5e4d67df, 0xf2c5d7e2, 0x6a7c147c, 0x39f051c7, 0xff44f888, 0xb236d8e9,
	0x44c7be7f, 0x52f660e4, 0x075a45f7, 0xf999ef4f, 0x860efe1e, 0x63f011ef,
	0xb36f685c, 0xda11ff5f, 0xe853d03b, 0xe4f754c7, 0xdd8d3224, 0xf55ff5c6,
	0xd189cf7f, 0x96cbd845, 0x69ce9136, 0x1553196b, 0xbfde90b3, 0xd7f20770,
	0xb13b9729, 0x2dbde228, 0xe9699f32, 0x5fc8f355, 0xda9c7062, 0x979a7a0d,
	0x80419742, 0x6b70f489, 0x7ff90074, 0xfd442d30, 0xf30a742a, 0xe141d237,
	0xc5ef7827, 0x0e3c9b74, 0x67f6a78f, 0x23dc4b79, 0x47a2c9f0, 0xafec5c61,
	0x78e74add, 0x0ab8ed5d, 0x96f4c23e, 0x48da9ae5, 0x14591dc7, 0x909dd6bf,
	0x54ee98a8, 0x28192deb, 0x1fe035c7, 0x46a09c60, 0xe747bd08, 0x5d18f5a9,
	0x79afaf18, 0x38bdc964, 0xa349cd5e, 0x1ff79f0e, 0xc12265ba, 0xe02ba1a5,
	0x7e246329, 0x650acc1f, 0x07f023b8, 0xb7c9057e, 0xb8089f32, 0x57580e09,
	0xc1fd7ed1, 0x8467a02c, 0xce94381e, 0xdf782ffd, 0xe6fe2066, 0xe78445e7,
	0xd7ccd36b, 0x9bef99a6, 0xb99bf88c, 0x059f34bd, 0x787518ef, 0x6e2fc17f,
	0x5075c5cf, 0x3419faff, 0xcf38feaf, 0xfeaf9444, 0x047fe80c, 0x17e0b97d,
	0x6f82cf30, 0x99ab6798, 0x3cea35e8, 0xd83b42e3, 0x5df3cc37, 0x48cf3ccd,
	0x673a18ae, 0x70c8a0fb, 0xbd2fb19f, 0xbc0de372, 0xe277bf4d, 0xf07e73d3,
	0xf94d123d, 0x3d6e8195, 0x3d1549c5, 0x255de300, 0x1f88e83f, 0x9b5d4bfa,
	0x3d7f22a7, 0x9f30da2c, 0xdafebfd0, 0x76821fd7, 0x86d146ff, 0x297f437e,
	0x03e81fc7, 0x19fde3b2, 0xfb507795, 0x577e9e90, 0x5feb74e5, 0x25fb4f7e,
	0x462ef47b, 0x38dcabf3, 0x2f00db17, 0xcbc035ea, 0xd56fdc5d, 0x9a5bfcd3,
	0xe7c66b1f, 0xf449f6fe, 0xedc309fb, 0xb5cf1ab5, 0x1c95441b, 0xe345c932,
	0x4a917ef9, 0x3c159efb, 0xc5cd8683, 0x0f8291f5, 0x3099cf6c, 0xbc9f1784,
	0x04fd103f, 0xac884e7e, 0xd93f10cf, 0x3d604edc, 0xac31ea2e, 0x5ecd1e1b,
	0xd68ff569, 0x286626ee, 0x8fad457a, 0xb3bf34eb, 0xbda69f75, 0x9637a344,
	0x6bd79e6a, 0xbe7d839e, 0xf1b8a463, 0x5eb50cda, 0xa8f196ab, 0x1f072fc4,
	0x5a5d6816, 0xb80cb92d, 0x74d5fa0e, 0x246b9f6e, 0xe489ba66, 0xafcd02f2,
	0xc64d625a, 0x36efbc22, 0xa097ae44, 0x1c6326bf, 0x1eb8a3b4, 0x0dcaf782,
	0xdf456d11, 0x6594f02a, 0xae56fe70, 0x504e3adf, 0x456b8eae, 0x32ca19e4,
	0x14c7c846, 0x1ecfd989, 0x41d675c7, 0xbe99d691, 0x61fdb957, 0xfcdc5e5f,
	0x59cf03b4, 0x3f1861cc, 0xc5afe655, 0xc5d760e3, 0xaa1dfc18, 0xda066381,
	0x1ddd569f, 0xb0eb4a5f, 0x7888d0b8, 0x3f3ca1ff, 0xa901bfa5, 0xa476662f,
	0x62facd1f, 0xa5f822aa, 0x4ae2ebba, 0xfe02d75c, 0x1e8462fc, 0x5093dd3f,
	0x9acbeb8a, 0x714a52d7, 0xe54fd35f, 0xfebfc17e, 0x9b9406e5, 0x4f8a4683,
	0x573abc0c, 0xbc0fdf87, 0x975f2b5a, 0x034739d1, 0xe0674e67, 0xf53a31f8,
	0x33fbd87e, 0x46a55e78, 0x1b8efef7, 0x9f3fff51, 0x2226b594, 0x2ba35c4e,
	0xd3f175a2, 0x843cd0fa, 0x66fefc1b, 0xfa51abac, 0x8b8669f9, 0xf8381fbe,
	0x0fd40ec1, 0x17a637a7, 0x38195aa1, 0xe0eb4798, 0xe6d79381, 0xc0fbdd62,
	0xd46ec9c3, 0x5deb4f0b, 0xc5baf8cb, 0x57b946ea, 0x3071c3fa, 0x7070383f,
	0x0fc6094a, 0x78724e06, 0x04f14da1, 0xf58fcf78, 0x31bf4a2c, 0xac26d73a,
	0xe9af63e7, 0xff715d69, 0xb8493957, 0xa0c63bff, 0xb91297de, 0xb1d752be,
	0x507926ad, 0xebb4a5ea, 0x4a7ea50c, 0xce530ebb, 0x17aed5a9, 0x5aeb596b,
	0xaed2ebac, 0x3731c11b, 0xdfe513f9, 0x4ebfa51d, 0xf64bf7b2, 0x9f546d7e,
	0xfd97e9db, 0xe3e91359, 0xf5c7906a, 0xf00a7f14, 0x38b35f38, 0x85f4be62,
	0xc79a2c8c, 0xcebfe896, 0xeba08beb, 0x9c931d29, 0x0653d780, 0x8d167266,
	0x94bc7eb4, 0x6f7a4d51, 0x4d6375e4, 0x6c3a79e4, 0x54f23af8, 0x14b5a069,
	0x5eb53ae0, 0x0119af74, 0x1d75bfae, 0x395efda9, 0x5e5bbbff, 0x1ac29d07,
	0x5a6fb8a6, 0x55e1ab3f, 0xeb9669f0, 0xbfefb42c, 0x11d7c191, 0xcc895ff9,
	0xa3df7283, 0xe8edbaa7, 0xff374f8e, 0x5bb3f908, 0x5172cb6f, 0xe743c45e,
	0x69141d4b, 0xf760fb1f, 0xd0fb98e9, 0x96bc1cce, 0xd78411b6, 0xca450739,
	0x5d740c6f, 0x083cc44c, 0x5ef943f4, 0x6e63cf5f, 0xe0d1dfe4, 0x7e219338,
	0x4d37fd37, 0xf397d713, 0x671d03be, 0x83bf5173, 0x81933c1e, 0x2fdcdff9,
	0xfa6873e5, 0x00ff904a, 0x07dff23e, 0xbfc89703, 0x238b7534, 0x59f2ef9e,
	0xc1bbe186, 0x0f86a657, 0xe10cf9e0, 0x706ce051, 0x67680c85, 0x510754af,
	0x6ae17076, 0xeb01973c, 0xb01d701b, 0xbb245ba0, 0x18bb60b5, 0xca5d0170,
	0xc61c56f2, 0x1e6a65f3, 0x39be2813, 0x7bf69c4b, 0x7e2e778c, 0x4bf6a458,
	0x8f7ecb1d, 0xb70797fb, 0xd537d9eb, 0x4dd50c51, 0xbc0f5488, 0xf73f3778,
	0x04bd586e, 0x5bfa03fe, 0xf0042ed8, 0xdd6d5edc, 0xbf64c0c4, 0xf73427ac,
	0x1d56d63b, 0xa255e076, 0x8eb6a275, 0x248eff02, 0xb21b9d0e, 0x1486ec77,
	0x5980cfa4, 0x3eb01df9, 0x20b0ef5a, 0x7036bfdf, 0xd2064cf0, 0x67fcf7d1,
	0x4d1d9f14, 0xdf37583e, 0x53363557, 0x90eb5f60, 0x51de2fef, 0x82fbc239,
	0xabdd079c, 0x1fa0a7f7, 0x12e3b87b, 0xe41d238f, 0xfb51b6f1, 0x8f337e67,
	0x14cd057b, 0xb4ee2b8f, 0x027286dd, 0xdfe620fe, 0x56d73b7c, 0xf9b684ed,
	0x5d0bbd05, 0x0b58df2b, 0x47ca0bc9, 0x2855efe4, 0xce57b272, 0x1f7529c7,
	0x530f9c82, 0x3a943eea, 0x4a1c2d10, 0xd720881d, 0x5467b481, 0xfbc26596,
	0xfd10ba51, 0x4eb69fbe, 0x1fbab468, 0x36a9dd6d, 0x27cda06f, 0xda1e8d52,
	0xcfdf3b61, 0x8ebb0069, 0x54275b2f, 0xbbd43ffd, 0x5a4537fa, 0xfc74bd37,
	0x7a918977, 0x1bd4ad7a, 0xf3d4f183, 0xfe72f5fb, 0x26f94435, 0x0d4ff1fd,
	0xf9afa459, 0xa0f87bef, 0xd37df78d, 0x78efd524, 0x13d4c82c, 0xe664e63e,
	0x792c3b72, 0xc1dd618e, 0x80daad80, 0xf8febb7e, 0x27b47282, 0x81b5677a,
	0xca6a5f8f, 0x25d8ba42, 0xddb58b92, 0x36bdb8ca, 0x6fc95fec, 0xda6fed5a,
	0x1616ef90, 0xfce6f9cf, 0x551f9ca6, 0x7ce19bf2, 0x1beab3a7, 0xcb3f9bf3,
	0x23cbfee4, 0xccf1f5f2, 0xf37e587f, 0x94099967, 0x03359cdf, 0xbceb5886,
	0x737e7230, 0x2eaf3cd8, 0xd337b9bf, 0xcd0f7045, 0xe6fc9477, 0x2eaffeb0,
	0xffbc39bf, 0xc39bf251, 0xfccabffa, 0x9e5fb866, 0xd02a6cdf, 0xd35e9d51,
	0xaf1e46db, 0x9c3cf137, 0xa6979651, 0x7eaa9960, 0x59fab944, 0xd6179d19,
	0x59c79fb4, 0x6daadbce, 0x3b7a9f28, 0xf519278f, 0xaf5c729e, 0xf171ed1a,
	0x64cf97c8, 0x25e73cf2, 0xe7f1237b, 0xfd1b7025, 0xac6ec714, 0xda5376c4,
	0x4a649102, 0xf6b4bf93, 0x775f3c88, 0xc7b6499d, 0x5cf0d86f, 0xde6959bd,
	0xf51199c3, 0x47c9d660, 0x75947ea8, 0x7e513379, 0x7f40d9d7, 0x51f79f12,
	0x7820c71c, 0x12b8c09f, 0xe864693b, 0x7b325d57, 0x72116cf3, 0x834cbbf9,
	0xe9058fec, 0x6b3f2e5c, 0xebafaba3, 0x8959e122, 0x7dcf2a67, 0x4778442c,
	0x89cda579, 0x1efd12c9, 0x479f8c01, 0x1c32d675, 0x15e17f61, 0x72075f8b,
	0x8af9ec63, 0x5283aff2, 0xff8c0ee8, 0xd18b7674, 0x48fdf891, 0xf4d28b96,
	0x3c62274f, 0x8bbf01ac, 0x92f2fcc5, 0x06cf943c, 0xc2226863, 0x5fd0f87d,
	0xb95ea226, 0x7e84b3d4, 0xbc2f754f, 0x10ddf64f, 0x3bcc886a, 0xa7caf36b,
	0x5d3c7932, 0xcf6f7f7b, 0xe384149a, 0xc42b8c69, 0xdffcbee1, 0xce3e60e6,
	0xa28f3cc4, 0x37a060fe, 0x75d1bd68, 0x0ce788a7, 0x6785bc36, 0x0e69020c,
	0x9c5cbb72, 0x379802ce, 0x8b79e86e, 0x61a0277e, 0x4b86c1b2, 0x9e42a8cd,
	0x6c9a8eb7, 0x3ec8f3a2, 0x1be3e14f, 0xe0e70ed0, 0x91e333f7, 0x5c69d96e,
	0xcb21bf7f, 0xe55718f7, 0x83c72857, 0x2d75783f, 0xf0417ade, 0x906f297a,
	0xfd53726c, 0x8d903395, 0x1fff9775, 0xd93f6e28, 0x00008000, 0x00088b1f,
	0x00000000, 0x7dd5ff00, 0xd554787b, 0x733ef8b5, 0xc24c99e6, 0x08109de4,
	0x49027793, 0x58a40218, 0xc48f0ed1, 0x08036820, 0x204c2282, 0x09331e40,
	0x8b62db0f, 0x1414f0cd, 0x8aa6b86d, 0x0804ed16, 0x341d0602, 0x0ed0d060,
	0xa51f1420, 0x87da2a91, 0x02a2897c, 0xf1042481, 0xfeb7ade2, 0x9f7b5ad6,
	0x88219ccc, 0x8ff7bded, 0x3b9f7e1f, 0xf67d9cfb, 0x5ef5ed63, 0xf6f9ef6b,
	0x23f7f85b, 0x0d56f4c6, 0xfe19a363, 0x632c5893, 0x37f48d43, 0xbbd03bdb,
	0xff15222c, 0xe49644f2, 0x61a35632, 0xaa19af0e, 0xbb18a253, 0x496d4a05,
	0xfe7834ee, 0x2947e8ad, 0xfd4d5b19, 0x61ed5a45, 0xf6fed1d6, 0x3fbccc1f,
	0xafee61d7, 0x18b19bbd, 0xbbde8798, 0xac628d94, 0x6db665c7, 0x7dec664b,
	0x6ddf057c, 0xc9f0699f, 0xeb758ce1, 0x01a41bcc, 0x3a147d8c, 0x958c78f7,
	0x47666db1, 0xeb3ff622, 0xb1eb49de, 0xb2891d2e, 0xbbfe832e, 0x180bdb4b,
	0xc9b27bcc, 0x3bdf0431, 0xb1218e8d, 0x834bc4b0, 0x6403991d, 0xe604b3e8,
	0x979d8093, 0x3bf496e4, 0x7f1f3e7f, 0x2e10699d, 0xde97012e, 0x0c01d4e6,
	0x657ae9c6, 0xf9831e40, 0xb9586974, 0x314a0737, 0x50b573df, 0x97dffc1a,
	0x97d3de7b, 0x1d8afb42, 0x07e7e9ef, 0x98c5dfac, 0x1e0bbf1d, 0x01fb8edf,
	0xf5785fe3, 0x017eafe5, 0x3d5e755d, 0x1852c190, 0xd22e92ab, 0xfddabeba,
	0xbeb15cde, 0x3f7d715b, 0xd249eded, 0xde9cbac3, 0x2f847ac3, 0xd3eb116b,
	0xd77c64f6, 0x6d34bafa, 0xf76f0845, 0x98d2c901, 0xd5ceffec, 0x62515efc,
	0x477bcc34, 0xc56cbe44, 0x184fd0f6, 0x8303dfcc, 0x7c187164, 0x28fdfccb,
	0xf08659f0, 0x2bbdf681, 0xc2427c04, 0x3f70d8f3, 0xcff1947c, 0xae67c104,
	0xe710a7b6, 0x84657731, 0xf84c9dc6, 0xbca3f846, 0x3d42b79f, 0xfe091aee,
	0x3f73f307, 0xde68792c, 0x735fd78c, 0x851e7847, 0xe57341ba, 0xef50e9fd,
	0xb6d8d5c9, 0x21adabc1, 0x19f3198c, 0x9fd893fb, 0x8f5074e7, 0xf01be7a4,
	0xff087c79, 0x8d29fe3e, 0x5f7c0d67, 0xe120fe32, 0xb36af6e1, 0x4ab1864d,
	0x60cf5599, 0x5d980b0a, 0x6cff708f, 0xb50e3fdc, 0x58973ac3, 0xff08551d,
	0xa49a5179, 0x8e1e69f7, 0x4e015361, 0x63872c6c, 0xe183dc30, 0x74598d3f,
	0x9b632fd8, 0xea00ac34, 0x8594be16, 0x7ef83eb8, 0x70ebb33a, 0x41cc19bc,
	0xe9754eed, 0xe0e80ced, 0x8307a014, 0xdccbdf79, 0xf3367cf4, 0xf33f7950,
	0x5807fb51, 0x3a15d53b, 0x179ffc00, 0x8bfff1cd, 0x66f09938, 0x7fc615b5,
	0xf06f342f, 0xd4c7580a, 0x19d333a7, 0x431f59f6, 0xbcd9b9f0, 0x8e1c4aa7,
	0x63c75669, 0xe2defeb8, 0x43d7cfab, 0x8fa31a3f, 0x4f8faff0, 0x78118c4c,
	0xa27cddf8, 0x09e397ad, 0x0139be60, 0xd88770e0, 0x55ec3bd2, 0x85bd7053,
	0x61b999b2, 0xcac6da7f, 0xf9c0031e, 0x74557d84, 0x86754cb4, 0x9366d4fb,
	0xd8b9c03d, 0xb0b1561f, 0xc3ff5051, 0x0d6d9d08, 0x219dade1, 0xfa2dde5e,
	0x78e6bc2b, 0xbf3c0073, 0x1b5a6e5b, 0x41e2f501, 0x03da4fba, 0xf4526af0,
	0xd9d22d3e, 0xe7ea699d, 0x6ea07253, 0x62efd7f4, 0xf7c23275, 0x76ea51ee,
	0x802e1187, 0x61ad7b57, 0x830f9fd1, 0xa1b287bf, 0xfa7ecadf, 0x3fc2b1f8,
	0x77d15ca6, 0x58ce3cc3, 0xbf08cd1d, 0x367d7765, 0x5a65c717, 0xb091c7f6,
	0x3293eace, 0x7fde147b, 0xcf627402, 0xad6cec64, 0x5e81d991, 0x50b5af3e,
	0x3c6d5cfd, 0xad6a1795, 0xcdac5e54, 0xb55df7a2, 0x926baa36, 0xbf610e4b,
	0xd65c37f3, 0x58ee803a, 0xbf8d015d, 0x9b57e05c, 0x4509a7c6, 0xd926d9fa,
	0xe59c611a, 0xa1f1b6a6, 0x8de5b700, 0x61d836c9, 0x3de2d956, 0x99650a1e,
	0xb708a4af, 0x2589d171, 0x5d74b1c7, 0x50039893, 0xe4b949fb, 0xae9fc42d,
	0x79993ff7, 0xa2ff3c17, 0x7f8d0c76, 0xe34ed6be, 0x5316d677, 0xf8ec9899,
	0xb7b3b613, 0xb28f1c76, 0x265c6ee2, 0xa9abb8fc, 0xf5089b43, 0x4764bb42,
	0xceddbbba, 0xd7d81e3c, 0x03873a2d, 0x824b73f7, 0x387486d1, 0x73da772e,
	0xad48220f, 0x3f60bf8e, 0x28acee33, 0x1eee7ec4, 0x76c5aa53, 0x58c37ef7,
	0xcf1fb254, 0x2cb7866e, 0xfa5f8f88, 0x7778449d, 0xf1fd6349, 0xb78f08ad,
	0xe8f08665, 0xa154c2d5, 0x868fdeff, 0xa7b0dc7a, 0xc6a7f6cb, 0xa65b3f21,
	0x0645c6b3, 0x20ceb1f0, 0xf7b9d63e, 0xf281f107, 0xfbd233ad, 0x0f915fd5,
	0x10f9cc7d, 0x9fcfde63, 0x8e653e45, 0x76fee1b7, 0xa22cd8e9, 0x7424b613,
	0x6a8df01a, 0xe01ba0bd, 0x0cef5823, 0xa04af361, 0xe252f05e, 0x1c03a478,
	0xe7e99acf, 0x3d2f1933, 0xab0bf29d, 0xde5dbc7f, 0x167d7f85, 0x1a3c97ea,
	0xd2e40eb7, 0x7aede625, 0xc3b5d71d, 0xaf846b6c, 0xc86d24b2, 0xdefc488a,
	0x25977443, 0x802bb559, 0xe97eec8f, 0x81bf81b9, 0x5ac06fa7, 0x37fbc0c7,
	0x9f128736, 0x3b674379, 0x7fbf02b3, 0xc2ff7f8e, 0xd27d0f13, 0xaee3e582,
	0xc21887fc, 0x5ae0923e, 0x43151ff6, 0x2586cf11, 0x7f4036c2, 0xf926be2f,
	0xe58c794c, 0x9d5e1fd6, 0xbe19f300, 0x103343b5, 0xa43b11ca, 0x0b0e5835,
	0xc3213e2b, 0x2b6484fb, 0x536463cd, 0xe4889cb2, 0xd7f3d032, 0xa1be911f,
	0xea7243d6, 0xc81f8f2f, 0x50c8fafc, 0xf7017bc9, 0xe9d84d65, 0xac77927c,
	0xdfd9fa8e, 0xf7cffd3a, 0x09dc3ad3, 0xa9779c46, 0xc1f246de, 0x3c406ee3,
	0xb2c8e4bb, 0x5a348a3d, 0xf7067ee2, 0xd62392f7, 0x80e2f286, 0x43fe1dc6,
	0x4b467f6c, 0xc76d7ceb, 0xa83ae17b, 0x31d6680f, 0x8d77bc13, 0xe93921e8,
	0x38656c1a, 0xefe7e0ee, 0x54f84628, 0xa06fef37, 0x9b469c7e, 0xf7caed04,
	0x728e395f, 0xb6624d93, 0x66afc474, 0xa26c7f5e, 0xb47286dd, 0xaf2ae1bc,
	0xbd5095b7, 0x6b277644, 0xa302fdb1, 0x7dfa11ad, 0xd625c85a, 0x8b7c479e,
	0xdfead650, 0x35e0c7af, 0xec92dfbe, 0xf662584e, 0x439033cb, 0x7de19363,
	0xdf7f9e82, 0x24fefe36, 0x94f7cb82, 0x4f3f4a43, 0x84db99eb, 0xe5cf5172,
	0x0bf02365, 0x7fe80fc4, 0x5f8c7252, 0x52ca266e, 0x3bac336e, 0xe70369f1,
	0x9c73dfb3, 0x93d60359, 0xb8f454dc, 0xac1fa11a, 0xfdf026c1, 0x0663b311,
	0xc850b38e, 0xe6b5a659, 0xcfb1dea0, 0xcf899f6c, 0x73d0469d, 0xeebf2434,
	0xcb56f5c3, 0x06a5d7a0, 0xc8e675e8, 0xdebf25ef, 0xd81ddb37, 0x1f6df7df,
	0x17f9e62d, 0x90e8cf31, 0x2d830f24, 0xc444f422, 0xd9b5af64, 0x43c8de01,
	0x65090fd9, 0x67581a7d, 0xff5e11cc, 0xdd4b4349, 0xfd8cb1da, 0xc39df10c,
	0x180ce091, 0x533f50c0, 0xe28d879e, 0x30e910f8, 0x1711de92, 0x92c464b5,
	0x5a66fc00, 0xc78448df, 0x7d94ffa3, 0xff6dea12, 0xde20f665, 0x39bbcf04,
	0x7efea259, 0x06b73122, 0x9eb2ebf1, 0xdaeab5da, 0xbe197c5f, 0xb1c8ad6b,
	0x03c861b9, 0xec46dfb0, 0xf49e9a67, 0x5dd456a8, 0xeceb7da0, 0x6f7be258,
	0x741f38e8, 0xdfe10ecf, 0xf820009b, 0x079c557e, 0x8681b4f5, 0x62e4ef25,
	0x89426bff, 0x9e755a6e, 0xffd8290d, 0xbfd451c3, 0x759edc6c, 0x23e35016,
	0x48d68fc1, 0xec65fbbe, 0xe19eb2ef, 0xbe11f578, 0xd7a81ac4, 0xf6a50c57,
	0x4648811f, 0xc23eb13d, 0xf67c809e, 0xe2653fc0, 0xa023f57f, 0x34fe266e,
	0xb54fde8b, 0xfd404427, 0xf52fb13e, 0xa7c69e0d, 0x1679f1a2, 0x665033f5,
	0x325da84b, 0x3aafe7ef, 0xeee39dfe, 0xebea2d50, 0x10128920, 0xa596cf7e,
	0x0707e433, 0x84bfc793, 0x9eeac4f8, 0x259bba26, 0x3fd28ef8, 0x402c607e,
	0x9bff8c3d, 0x84d1b0bd, 0xdca335f4, 0x841201d4, 0x3abe547d, 0xcffd0acc,
	0x033ec870, 0x4f7605f0, 0x2f4fbda1, 0xedfec148, 0x95be112f, 0x6f937629,
	0x77f5c201, 0x28f6463d, 0xafb08de9, 0x2bc8fdb9, 0xfbd07da5, 0xd3c576e0,
	0x1a29768c, 0xc78312ed, 0x2799eb00, 0x831ac7f4, 0xd1d2266f, 0x61c72663,
	0xf2a6bf1c, 0x79ea1e42, 0x06b2d3d1, 0x6fddf8e0, 0x6d031a81, 0x39fd88cf,
	0xf7178c83, 0xed184967, 0xc7751337, 0xaf48a22f, 0xdc1c6096, 0x87574fff,
	0xcc3d436d, 0x2c27b7a1, 0x165ffdc4, 0x19c47a4a, 0xefd817e0, 0xe1046719,
	0x555f9ccf, 0x72748bbd, 0x784f44a6, 0xeb95a675, 0x215f7f69, 0xa700f4fb,
	0x9ed769ae, 0xbaef80ca, 0xb05a7e56, 0xd5f6ca05, 0x39424b7f, 0x6bb56732,
	0xa7377e0a, 0xc8dde572, 0x9f446f67, 0x41069c73, 0xbaff5c84, 0x1bff6c94,
	0xda7a33ae, 0xafe422b5, 0xcf9cab03, 0x61e7842c, 0xe2768e29, 0x6af6fa17,
	0x1bf54784, 0xdea1271f, 0x85f07ddb, 0xf4a1c77d, 0xd2ce3986, 0x2477d5fb,
	0x84cec3af, 0x05ad54dd, 0xeffb053e, 0x239c714e, 0x65f44df8, 0x751777e0,
	0x3708456d, 0xe9fbf2b6, 0x1b5a17cb, 0xbf68480f, 0x5356b485, 0x70f27b29,
	0x2f929d1e, 0x38454a5c, 0x7587dc82, 0xc2f8b45f, 0x854f1023, 0x4bb55cfe,
	0x1a9a3ebd, 0xfe1567e0, 0x7955df01, 0xf109bb65, 0x38f4798d, 0x55f6e0df,
	0x7dda9cf0, 0xcc95e7cf, 0xb4479fcb, 0xe22b713c, 0x7cf996a5, 0x76179fb0,
	0xfdc36fa7, 0x85ffb4bf, 0x35fb408c, 0xbe7ebcb8, 0x1117fd7c, 0x178e00bf,
	0xf10e89e1, 0xb2a0c9ab, 0x2776badb, 0x78c17e10, 0xbb5d3f84, 0x068f3d33,
	0x412eb5f0, 0x2de6ccf7, 0xd48b9a98, 0xfd402de8, 0x6673a148, 0xdd91e6f4,
	0x43cde595, 0x13e1433b, 0x419bc4ac, 0x0cde3dcf, 0xed007f6c, 0xdc7fb350,
	0x1b1317ca, 0x02301f48, 0xf5851c9f, 0xaeb0db61, 0xf5b37bf4, 0xabd16e65,
	0x751ed9ea, 0x448a787d, 0x1ecf7b7c, 0xcabf62bd, 0x56601ec2, 0x5cad1f65,
	0xfcb822ef, 0xe5c0af45, 0xb402c4c1, 0x14afe1f7, 0x77b7379a, 0xf77b70f7,
	0x224708c0, 0xaec543f2, 0xf501103e, 0x7c87941c, 0x815d4ade, 0x57bcf043,
	0x625165ff, 0x3b3f7c3b, 0xce19fb85, 0x67eddad5, 0x16896141, 0x73ce7778,
	0x15fd1634, 0x8d1c77e7, 0x50befdc5, 0x2cf5227b, 0xbee77ec8, 0x7be448c6,
	0xc347ddce, 0x6739de51, 0xf5027cef, 0xd96ee726, 0xe780eb8b, 0xa2fcf8b1,
	0xfdf858f7, 0x8edcfcf0, 0xdc1ff228, 0x3c2a5f08, 0x0367ece3, 0x976c35e6,
	0xdeb97e1a, 0xa8b67820, 0x66d00beb, 0x7faffd1a, 0xaea7c237, 0xaea13c8f,
	0x83fef17f, 0xcacd1133, 0x3213f765, 0x2b7f75ea, 0xfe7c813a, 0xc2d781dc,
	0x71f30fc9, 0x57d471d9, 0xc3516f17, 0x4249f615, 0x29deedf9, 0xf0ac3c91,
	0xff43d304, 0x2ad8ca74, 0x1596ffc5, 0xcc951788, 0x7c9b5c7d, 0xe64efb7d,
	0x7f47699d, 0xa73f8acf, 0xefe91d9e, 0x66ef16f7, 0xc129da3d, 0x2e88dee3,
	0x456ed999, 0x18e943bf, 0x2b87eefe, 0xb14fb026, 0x15ef4dbf, 0x3e95be21,
	0x2c7c9126, 0x4df3357d, 0xfb1dc3e4, 0xe549df66, 0x878262cc, 0xdc590fe2,
	0xa0c2f92a, 0xf1c3196e, 0xc916e174, 0xf3de60c3, 0x7e541ad7, 0xea4db29b,
	0x57aa2c79, 0x72dc5fbf, 0xfa096bf8, 0xaf3e372f, 0xbe553947, 0x6fe410d5,
	0xfd451cf2, 0x231cf2b9, 0xc772b8fb, 0xfcfe86b7, 0x3ac50b51, 0xb98dbd14,
	0x4eb8676f, 0x3d819aae, 0xbe03ff8d, 0xb1c03edd, 0xafc6253d, 0xbeb0fdcf,
	0xb9f84641, 0x96a7e398, 0x7d13b254, 0x459f30a1, 0xf293d006, 0xfad2ce49,
	0x40196cae, 0xce78087e, 0x0afcf04c, 0xf9402b6b, 0xcc39a57b, 0x6d57fdc6,
	0x2fa81605, 0xafc23a86, 0x9c11d59c, 0x6577c89c, 0x80f6378e, 0x057ee379,
	0xd71d59d6, 0xdf5a9da7, 0x15478461, 0x70efa76b, 0x39db031f, 0x811f5d61,
	0x06f2e91e, 0xb36ccf7d, 0x98d68f90, 0x357fb4f5, 0x021adf2d, 0xbc7a2bdf,
	0xfe285762, 0xde56dfb1, 0xadf88217, 0xfd5b7a13, 0xe3becf46, 0x8a759eb0,
	0x89b36dbf, 0x0d7dcff8, 0x9e839f9c, 0xaceb8196, 0xeb4d9cdf, 0x27b24fbe,
	0x781d43af, 0xbff091aa, 0xdcf4023e, 0x48efd268, 0x8e7d001f, 0xd99ec9f4,
	0x0936cf7a, 0x0faf3af5, 0x5ffad3f5, 0xf203bf73, 0x1f37d241, 0x51fe9137,
	0x1feb953f, 0xe8e39bf5, 0x94e2bffb, 0xe3df5013, 0x3c7fa9f3, 0x32a1eb97,
	0x31c58eff, 0x7de81f9a, 0x7980c619, 0x9576fa29, 0x1291d1c5, 0x88fadeb0,
	0xca0b309e, 0xefa8f289, 0x851bc725, 0x3801ea7c, 0xacfa7fa0, 0x935c7254,
	0x2bd76fec, 0x78c17df8, 0x8ed14efb, 0x9a65d8fc, 0x08fe8fa9, 0x94f653e6,
	0x3926bac6, 0x7b76fe00, 0xecffae06, 0xee3e5366, 0x9c1199d3, 0xe78c175f,
	0x13d83f76, 0xfe506df6, 0xf2a34523, 0x8c43fe87, 0xd2b54863, 0x7216cebc,
	0xa8d85fbf, 0x80aff212, 0xa4af362e, 0x4865f91f, 0x994176e5, 0xdbede4be,
	0x028f99fa, 0xeb913617, 0x4a9767fd, 0x3d610f24, 0x17a81619, 0xfc8987fc,
	0x5c856732, 0xf003f651, 0x59c93468, 0x1162c7c1, 0xf1fa467f, 0x178129e7,
	0x6b0bc46e, 0xf1a8fe20, 0xffb13ee3, 0x7fae71ec, 0x7af047d6, 0x37d9e3fd,
	0xedfe9fc0, 0xf5bd6502, 0xb07dfc0d, 0x9078003d, 0xdfe01a92, 0xa603c60f,
	0x3b468cf5, 0x507846eb, 0x90b39b28, 0x42972fcf, 0x2f6fa86c, 0x7cb1f417,
	0x4c7c2321, 0xa4244b64, 0x93e678d7, 0x6d658ec8, 0xb6efec26, 0x0079801e,
	0x9ae8fe1d, 0xf0059591, 0x422c71c3, 0x4c609f55, 0xb42fb550, 0xdfdeab24,
	0x7aad9f11, 0x423ac93f, 0x759c9f55, 0x5dfdaa8b, 0xfaaa71b6, 0x524cc78f,
	0x9f6a9fb5, 0x99dbaaaa, 0x6ff38b45, 0xf245ddad, 0xdeb577ff, 0x8213d454,
	0x70d632e1, 0x8dab55e4, 0x77db99b1, 0xfc02d54f, 0xb2380ec6, 0x73ea193c,
	0xebc4bfb7, 0x24ae4789, 0xddaf405b, 0x0faf32fe, 0x0525723b, 0x7bb7f3ea,
	0x4656fd79, 0xf6d97476, 0x39dd537d, 0x985befe4, 0xf334780a, 0x686392da,
	0x6ab07dae, 0xa464c2da, 0xe268e771, 0xe19c4ae3, 0xee3886bf, 0xde547dc7,
	0xa757ed2b, 0xddf7d096, 0x37ff3997, 0xf314fea3, 0x7f6097ef, 0x39e3b8d1,
	0xa378d868, 0xcc51e299, 0xe7d8bba8, 0x29be0617, 0xff4319d9, 0xac2d6b5a,
	0x65e11d25, 0x6b57d2a4, 0x6d48f2a1, 0xd66f953c, 0xc019595a, 0x166d78f3,
	0x6d6a2795, 0xdaedfcf4, 0x5bbe5431, 0x64f2a76b, 0x6d95316d, 0x4a5425b5,
	0x073668d6, 0xdb4ec6f9, 0xc3c21d06, 0x1cf88dad, 0xfb3fc7c6, 0xbc7e5be3,
	0x95cfb2d5, 0x7bc6857d, 0x2a77764d, 0x2c831be9, 0x9ffa879f, 0x5386358f,
	0x11ac6b3c, 0x6fac21e4, 0x06b7d6ac, 0x55cd7af1, 0x780d5d66, 0xb4ec387d,
	0x35e4f515, 0xf7848da3, 0x566d97d2, 0x36dc1ff4, 0xd8c9ea0a, 0x748acdae,
	0xf3b47581, 0x23bc5ac6, 0x71ac3e50, 0xe9ab6d99, 0x8b412fbd, 0x6de897ed,
	0xfc4c1fa8, 0xfb0137d2, 0xb7accdbf, 0xffd07f62, 0x186fa451, 0x3b7f618f,
	0x269f32ae, 0x66d3e70f, 0x577e88b5, 0x519371f3, 0x20f6dede, 0xab9ac79f,
	0x3f52964b, 0xe37dcc73, 0x1ae3414a, 0x09dc7bbf, 0x69b8c052, 0xe1b8c15f,
	0x7aab5c7c, 0x66f5195c, 0x09e92758, 0x78b62d63, 0x7d4ab3e4, 0x21cfbe22,
	0x9bc91e3f, 0xb26dacdb, 0x320f9e05, 0x071abe70, 0x4029a66a, 0xbefe2aee,
	0x75f15f1d, 0x2afad576, 0x0a26be91, 0x9ea265bd, 0x98bc2165, 0x83fc8426,
	0xc737f285, 0xecbea113, 0x80c234a0, 0xb250da6c, 0x2d59ec95, 0x9a2c3fe7,
	0x6da667cb, 0xda0178ab, 0xb44d8a9d, 0x1cbb8a3d, 0x01a5807f, 0x29ac2e3f,
	0x7ef941ce, 0x5f11d58a, 0xf1dc247a, 0xf4cfd226, 0x1a57e01c, 0x0718dc81,
	0xbe250e2b, 0x73287ddf, 0xd3e3da34, 0x0cfdd60c, 0xed9df9e8, 0x4ebd119f,
	0x2d1d601b, 0x39deb059, 0x7ffc0b55, 0xbf759c5a, 0xee2def04, 0xbc4ea6cf,
	0x5314f505, 0x3e00d9dd, 0xa846f2e2, 0x092d35ea, 0x3f7a8175, 0x4728bbe9,
	0xa45a4ac6, 0x8a98a733, 0x10f8e359, 0x7c55d4f1, 0xd7e7cf49, 0xdfee7a43,
	0x398bdc85, 0x79437002, 0xe48c2930, 0x96cbfa01, 0xb1cf1f21, 0x4976c68e,
	0x84709eba, 0xda37f77f, 0x7dd90f62, 0x04f7e13d, 0x6f9e51f8, 0x3079e995,
	0xe34a6cbd, 0xcd26b5f2, 0xa1f709bc, 0xa468de3a, 0x1172f5b2, 0x96d333ee,
	0x099da1a4, 0x72bf6fda, 0xdc6997f6, 0xaf5e4aae, 0x6041fe17, 0x7b6530a5,
	0x6eea5308, 0xc372ba06, 0xa514434f, 0x64e00ed4, 0xaf0d74fa, 0x31ff0dbb,
	0x6f6aab51, 0xef7df6c7, 0xfcc51fd1, 0xfda687df, 0x5ab5e6f7, 0xcbe21e31,
	0x9749e622, 0xb74397ae, 0x762a47a7, 0x73f3ed06, 0x7fb226d1, 0x57c064d3,
	0x50c4cfc0, 0x771bf92f, 0xc2fe3898, 0xa1dca832, 0x21f5efe1, 0x7d4307a0,
	0xce31d430, 0x23ba40f5, 0xbe863d32, 0x5efc1667, 0x27df47de, 0xa78d2f30,
	0xaf438fbc, 0x0419b439, 0xb1cb1072, 0xb85fa6b2, 0x971b4b6d, 0xa5718697,
	0x2cfb375a, 0x8574ce40, 0xdc08af86, 0xdefc6aa7, 0x78ddf81c, 0xdef94efa,
	0x67fffa05, 0x09b7c451, 0x1a695c5f, 0xc7db87bb, 0xdfa84a6f, 0xca3d36b0,
	0xd3bbe563, 0xbc7167c0, 0x62ef81f7, 0xdbf011f9, 0xff3680cf, 0xca8b3b5a,
	0xe83ad7bf, 0x72da99f9, 0x976bdb2a, 0x6a4ff3d0, 0xf3395057, 0x4851b0fe,
	0xab2d3527, 0x780167d8, 0x1ceaf2ed, 0xd3c37181, 0x97c7fae3, 0xa72f8162,
	0x3f7ffb93, 0x3b7f794f, 0xd06eb7df, 0x04af5033, 0x896b5bfc, 0xd1beb1bc,
	0x4be3c61d, 0xdeb8b28b, 0xebc09dd7, 0x5474d213, 0x16d86bb7, 0x96517efc,
	0xa46be79e, 0x2dd77973, 0x7f80a5fc, 0x8f32bfd4, 0x7ef286e7, 0x349e7694,
	0x9fa7b14d, 0x8d36fef9, 0x44fc23b7, 0x31f101bb, 0xab3f0039, 0xc19f84ad,
	0x3a7b7178, 0x819a675f, 0xca225de3, 0xc4338c26, 0xf3183c99, 0x31daf987,
	0xe243bdee, 0x7e1d78f8, 0x769db86a, 0x3f427e1d, 0x73c02704, 0x1072f909,
	0xb96528fe, 0xd8b6fba0, 0x9c109fb0, 0x9416755b, 0x00c9b727, 0xd35efc58,
	0x1afd127b, 0x5661b189, 0x3e14598c, 0x1fd25e62, 0x3ffad8ff, 0x3d1f7f5d,
	0xdd7fd7aa, 0xe6bc45ba, 0xf89baefb, 0xc44bf209, 0xc3f87e9f, 0x7f0a6963,
	0x2db3f8e0, 0xe90ebecd, 0x69325ba3, 0x6dd35e31, 0xbc1178e2, 0x7c5945de,
	0xdc7e0ade, 0x1a31f88e, 0xa57587fb, 0x37d3d7fa, 0xf5a090ff, 0x7794662d,
	0x0a8fbc11, 0xd758095f, 0xfda369b3, 0xf40c6370, 0x907ef80b, 0xbc714cd3,
	0x8d0b74c8, 0xc5f31ddb, 0xb6f0cddc, 0x89cb8d20, 0x1c7868df, 0x7ddbe141,
	0xde7925cf, 0x3f151cd4, 0xf467a867, 0x7d10321c, 0xfcac34f9, 0x70a7b415,
	0xf0fb00a8, 0xbd8f4143, 0x306b46b3, 0x95f5d63e, 0x2e794dd9, 0xa0ce7b03,
	0x05b5d1de, 0x03f20014, 0xb148a7d8, 0xbf442d8c, 0xf4e31588, 0x5f178a46,
	0x6590fd00, 0xe5ef3b42, 0xd477a833, 0x2333233c, 0xe67e4e80, 0x97c44cea,
	0x16748745, 0x3cb6a7d2, 0xedf10279, 0x8ac966f3, 0x19abbef2, 0xc8718d96,
	0x098f30fa, 0x1d4117da, 0x25de2fdb, 0x1712ac7b, 0x70bf1813, 0x333ef18a,
	0x5fa0a755, 0x3f33c263, 0xa2f978a1, 0x41c58906, 0x2cb747bf, 0xf5009e3f,
	0x364ab7cf, 0x635bb403, 0xf386df0a, 0xe937922f, 0xb41fa207, 0x9a773f81,
	0xffa3ce8b, 0xb33772a1, 0xb2efd0f9, 0xf4ec8c2f, 0xbceaf545, 0xeaadf287,
	0x23f0857a, 0x3f50ee57, 0xf3a93677, 0x89a54e28, 0x366c893c, 0xf5a2fc82,
	0x2807a491, 0xf646f4fc, 0xe7197d97, 0x197d8c93, 0xf95d7e8b, 0x4fa4d5d0,
	0x553ebccc, 0x7ea03bd4, 0x17df2ae9, 0x4ad52e05, 0x8d813fdc, 0xab3ac2f2,
	0x182c990f, 0xf83eaa2f, 0xfcc33869, 0xbbf690b6, 0x975f3e89, 0x636a1f29,
	0x2ef14c8b, 0xbb69ab57, 0xbd5be006, 0x35bd3dff, 0x94bee10c, 0x983b80f4,
	0x8dda3d7b, 0xb5868d3e, 0x91b51e11, 0x7bd98dff, 0xfb1f9116, 0xf282c9a0,
	0x0ff5fab5, 0xf58fdf8f, 0xe13312fd, 0x276e0e3e, 0x8cf4593c, 0xf864f14c,
	0xf02a4537, 0xfb8c89e3, 0x1decfb8a, 0xc59cf140, 0xcfb8efb8, 0x64d6efb0,
	0xed1d13c4, 0x32dda2fb, 0x65b35fbd, 0x7fdb1e8d, 0xabfbe1ee, 0xbc917bec,
	0xf2b9f692, 0x139fbe39, 0x2a7c699e, 0xb760f104, 0x4777e18e, 0xfc81bbe1,
	0xe81e153b, 0xbbfef10f, 0x73f2251a, 0x41c1e1f5, 0xe01e1f43, 0x07866f3c,
	0x67249f40, 0xbb07866f, 0xabb098d2, 0x468b1ec7, 0x7c27f6fd, 0x3b23733e,
	0xd5e14b5d, 0x25774999, 0x29cf3d23, 0x19afbede, 0x57f8f4ca, 0x193d9f49,
	0x8f484f6e, 0x6318fde1, 0xe08e9f29, 0xbfcfe6f7, 0xddf6c0ce, 0xbeb753c9,
	0xd7fb4c96, 0x8eeff381, 0x73f2e508, 0xe891e4af, 0x0067c1b9, 0x1f021538,
	0xbf643a45, 0xa1df9033, 0x07dee63b, 0xd8f8c3df, 0x6e1b66e3, 0x76e7648f,
	0x1feb555d, 0x27bf423e, 0xabb42e6b, 0x97613eec, 0x885da155, 0x2ec09bef,
	0x49ff880c, 0x77d23f96, 0x6853d363, 0xb6c6b29d, 0x1db7ec85, 0xc9fa8acc,
	0x119efcf5, 0x56fc57bf, 0x82c7d437, 0xdf9fbef8, 0xb98c3d73, 0x7da04507,
	0x0a87d8a7, 0xfc2c5a3f, 0xfa7ec7bd, 0xd70a36b6, 0x8de003b9, 0x7c0adb74,
	0x91fd1a28, 0xa93f153a, 0x40bfed16, 0x9e3802bc, 0xa0392f73, 0xc6f90391,
	0x3f6227df, 0x9fbcddce, 0x8417c46a, 0x153df303, 0x00f18d12, 0x2b21f91d,
	0x2d23e099, 0xb59f3661, 0xa3b1be1f, 0xbbaa3d61, 0x0552f8c1, 0x222e1afa,
	0x9baa6f18, 0xa4e6edd5, 0x25093f03, 0x2dfb927e, 0xe4129ff0, 0x7cfda32d,
	0x19ce50a3, 0x2f59f680, 0xba400eb3, 0xcb5c91bd, 0x1ca402dc, 0xc7b66fd0,
	0x38aab4c8, 0xcf554585, 0xdaabc6f5, 0xaab16f0f, 0x65f08fde, 0x3c8fdea9,
	0x47d55361, 0xb5518db7, 0x7647c1ff, 0xf696fd55, 0x5bfb5562, 0xeaa895cf,
	0x9eb039bd, 0xddcb88ef, 0xdaa92f11, 0x549ab24f, 0x42a683fd, 0x159c99f0,
	0x6bde7aa1, 0x51ba70e6, 0xd4d977bf, 0xed762afd, 0xfba8c78f, 0xf7576a9f,
	0x61f77dfb, 0x2d49c827, 0x205da2b0, 0x53dcb137, 0xdd07700b, 0x9e36a9a2,
	0x5ad52fea, 0x66d6f4a9, 0x6a57f3d1, 0xae6f546d, 0x03f5431d, 0xbd63cfa0,
	0x2c7bf405, 0x1ebd075f, 0x5e0cdf9f, 0x27b8c5c7, 0x8b6fb8c4, 0xccdb1971,
	0xe04dfee5, 0xfef8aef2, 0x0dbef8a4, 0xf1f9d7bf, 0x5a3c55d0, 0x76e80d73,
	0x3d79e45c, 0xcbec13fa, 0xaed08bda, 0x664b79ef, 0x982e80db, 0x36a273c3,
	0x1452e51a, 0xe9280fcf, 0xc4fd0779, 0x2d53fbd5, 0xd8d8f718, 0xf893e7f2,
	0xb659abbe, 0xd23e7f22, 0xf63869f2, 0x201af173, 0x6790947f, 0x5afb9f18,
	0xf0a3faa2, 0x49f50ade, 0x259140fb, 0x3925e539, 0xa94d3175, 0xca0cf47b,
	0xfa7da692, 0xee178a76, 0x016ff7a3, 0xefdeaadd, 0xb7bd506a, 0x538c7b60,
	0x67643d6b, 0xfa51685f, 0x677b51f3, 0xfd47649a, 0xa3aec2f8, 0xcebf31eb,
	0x0a34afb5, 0x4d5581e3, 0xf82ec5ef, 0x3a5ff80e, 0xca0e62f0, 0xe841d77f,
	0xcfefeccf, 0xea275075, 0xb4cefe7c, 0xc891457d, 0x86249bb7, 0xd59173db,
	0x5552be51, 0xf913a34b, 0xfdd65568, 0x74f7f43a, 0xff61657b, 0xa73ffcf3,
	0xcc7d7185, 0x017c257b, 0xef7bfbf4, 0x88edbbb1, 0xc347ad87, 0x66eedc71,
	0x5cd76559, 0xed7ae74c, 0x276e74c5, 0x1a3e6c5d, 0x1b1ef98e, 0xdc3947bd,
	0xff5a3eb5, 0x86ef5111, 0x22dde092, 0xae2bfad3, 0x4a0fb4c9, 0x2e99ff7f,
	0x5a933f53, 0x5d70c3d2, 0x3c7cbca7, 0x60219309, 0xa569499c, 0xb7ff3865,
	0x968f67e3, 0xfee48f49, 0x93a1eef8, 0x628f911b, 0xbb3fbfdc, 0xf7832a2b,
	0x15e45c7b, 0xeaf695be, 0xf70081f1, 0x46a38bb7, 0xed100c90, 0xfeb83342,
	0xa477a45a, 0x65389ca1, 0x7bff92b6, 0x186a7175, 0x2c11efee, 0x76f179f1,
	0x3654278a, 0x594ef1f3, 0xef11c2da, 0x948f354e, 0xfa516f51, 0x31b8e1d3,
	0xb7ddf801, 0xa7da6e6f, 0x19834f72, 0x1feff1fb, 0x58652e7f, 0x9edbfda8,
	0x7ea266f7, 0x942b2a74, 0x7ae38af4, 0x6aafa71e, 0xa9edfae2, 0x3906c4d6,
	0x6522ce20, 0x4b367b08, 0xd5dafb43, 0xeeed13a2, 0x76aa646f, 0x3b5fbe3a,
	0x78b1f3d4, 0xbd409e3a, 0x8c9cf9da, 0xea7338ea, 0xfae2c496, 0x9eaad8bf,
	0xb380b95f, 0x8d8be753, 0xe757c00d, 0x31ba3ec1, 0x541f9e13, 0xfb4ac4e8,
	0xa9e3eca9, 0x2bcf992c, 0x2f7940de, 0x848d7dce, 0xdf797ed7, 0x477a8c96,
	0xbe78cfe2, 0x5aeccdeb, 0xb0081f45, 0x75da188b, 0xd1d4e2ba, 0xdcbf149a,
	0x7dba55ff, 0xb468c66c, 0xb9224a97, 0x230d647e, 0xc3ea083f, 0xfeff9003,
	0xb71c29fd, 0xfe4759b7, 0x60f1974e, 0x7afbc625, 0x3020406d, 0x3aaddedf,
	0xcc5fb08f, 0x122e97a8, 0x5617e97a, 0x718c8147, 0x5a1a55d1, 0xf649b397,
	0x97647e60, 0xf69777e0, 0xf118ff25, 0xb64279d4, 0xc1333da0, 0xb1abfc9b,
	0x936e48a3, 0xe5ed573e, 0x2ef56d7a, 0x4558f489, 0xfd0970bf, 0xb7a173e2,
	0x87aabe7e, 0x2487b3eb, 0x5fb264f6, 0xbd0970cf, 0x5a6f25c2, 0x8bc3f98f,
	0x81f5a8b7, 0x7ac3d68a, 0xfe826ff4, 0xb55e7aa2, 0x79775d4b, 0xbec575d5,
	0xb3e8cb2b, 0x1ed1b247, 0x0e347d01, 0xb121e0e9, 0xb27d8a9f, 0x8716d73c,
	0x6b51bef4, 0x13f153bd, 0x0e6abc20, 0xf3815abd, 0x6c4338f6, 0x78ac2f64,
	0xfddae083, 0xba43b725, 0xbfad19e3, 0x76f8719b, 0xaefc70b7, 0x231e49d1,
	0x02328f7e, 0x9e4a33fb, 0xba87a855, 0x2f89c37b, 0x8c1c5e61, 0xb7366cb7,
	0x0be8ed37, 0xaedca985, 0x3f2281d0, 0xb7f74e25, 0x88e5db6b, 0x44f0fe00,
	0x273bd706, 0xe5a33c8a, 0x5f923661, 0xcfdc8d03, 0xe3c8d03c, 0x9eb503df,
	0x7fefe455, 0x1ff7f158, 0x717e4118, 0xfbfb9997, 0xe448f657, 0x47b87eff,
	0x8818fa42, 0xfa80effe, 0xe39f7c44, 0x988603d7, 0x671c247b, 0xbfdcc3c7,
	0xa9f7c8ad, 0xe70e8b5a, 0x9499f8a7, 0x3f32a1b8, 0xffc05ce5, 0x302cfcf9,
	0x7e7fb33f, 0xf003dfb0, 0x6ca32bfb, 0x4d241fa4, 0xfc4dd905, 0x83f10960,
	0xf800793e, 0x0af6113e, 0x8de202c5, 0x22e1eb73, 0xb6d0379e, 0x0a2bbf1e,
	0x1228ebe7, 0x2145dcf9, 0x83257cbc, 0x88ae97fb, 0xa4a66872, 0x32cb4fd2,
	0xdd22afed, 0x1c966496, 0xf73952c0, 0xfc8fecb0, 0xbf3043dc, 0x4f84e787,
	0x910e8057, 0x44b03def, 0xf4a9a4b2, 0x355f4e31, 0x1d1f51fc, 0x3b71fd55,
	0xdb7309d1, 0x3162b2db, 0xf7d3813f, 0x4b2615bc, 0xd45d005a, 0xd30fbb08,
	0x5f2fd154, 0xb729fa21, 0x0cb9d054, 0x0b588ac7, 0xf23561da, 0xffcff245,
	0xd35774ab, 0x4cfbaea2, 0x617dff1c, 0xa73fd912, 0x4931e883, 0x438347d0,
	0xc37078a2, 0x5fee5a37, 0x3f91239b, 0xe43c066d, 0x5da2edf9, 0x23ca38f9,
	0x8a55019b, 0x8b47d59b, 0xc5347578, 0xeb11eef3, 0x2cf2219e, 0xc9bce98e,
	0xe639ffe8, 0xffb0da32, 0x714bccd9, 0x8dac39f5, 0xd5a1d3ca, 0xb9d47dfb,
	0xefda307b, 0xe40c3a1f, 0xbb586a77, 0x7af90c2d, 0xc16b5b1e, 0x62801b38,
	0xbf23b7d7, 0xc94e3c7f, 0x38bd05ef, 0xf613f10e, 0xe0066aff, 0x9bd839c3,
	0xbfebfcf8, 0x3f60faaf, 0x3e7521e5, 0x7bcceaf8, 0x3d55da19, 0x2e551f64,
	0x38a3a559, 0x65b59b89, 0x55f7f815, 0xdf6577d9, 0xcad5f6fa, 0x857daaac,
	0x38420d35, 0x12a717c9, 0xccadfa5f, 0x6cdeee50, 0xffb8155f, 0xe2cfec48,
	0x057f9c83, 0x0fb2b7ef, 0xa579e2f7, 0x5bb79254, 0x81989f69, 0x3e3065f8,
	0x00bf6cdc, 0xd5f07352, 0xd9036884, 0xce1a8997, 0x4917134f, 0x9fbc4fe4,
	0x43b50e39, 0xeff43339, 0xb177c23a, 0xbec4736f, 0x773cc87d, 0xefff2565,
	0x66595bed, 0xcc666e49, 0x4c1b74f5, 0x4ba237a7, 0x27f6d5a7, 0x187a5e45,
	0x3d1063d2, 0xdf6bd107, 0xbfe0da3e, 0xac747d80, 0xecba2708, 0xe9b96fdb,
	0xfc45c9fb, 0x2d4efd03, 0xfc97c792, 0x8255e83d, 0x4e7ec085, 0xa9d354ce,
	0x5c0a6fb2, 0x3bc7e46e, 0x847ae7ad, 0xc532a7fb, 0x7c963f2d, 0xc7c82cc7,
	0x79d14fb2, 0xc7fda534, 0x2f06daab, 0x1e3e7e85, 0x7ad3cbc7, 0xd4a8f79e,
	0x1fdc21ed, 0xc18271f8, 0x58fdeb8d, 0xf28f1eca, 0x67e963e2, 0x9c7af377,
	0xd9f58ade, 0x502de371, 0xfc53ad3f, 0xff05ab87, 0xf1f950f5, 0xa44c1fec,
	0x937b1276, 0x1fcbfa05, 0x3e5fc892, 0xce39580f, 0xd3fc792f, 0x7ee798c5,
	0x23a9e7e6, 0x4cb7ae28, 0xe3ca1fdd, 0x723bf264, 0x6bf6f17b, 0x00d2ba3d,
	0x0727d3b9, 0xcfe65e27, 0xf9d346cb, 0x5b0172bf, 0xb736647b, 0x1cfc3d8f,
	0x7a6722a5, 0x0e6abc4f, 0x179e8bf4, 0x7abee47e, 0x8149e3f6, 0xcef0ea72,
	0x9fb032c7, 0xcf3bbd72, 0x35cfcf06, 0xf50926fc, 0x8f9df289, 0xbb7e9064,
	0xda066373, 0x1edbe529, 0x3d53b0cb, 0x927641d4, 0x73bbaf96, 0x1fdb2def,
	0x513b900d, 0x98bedcd9, 0x885c3c63, 0xc39dee7a, 0xff43ad2e, 0x25cffa7b,
	0x03fb6e0b, 0xca1d6dac, 0x1c59b9bf, 0x91bd59df, 0xf3c332f8, 0x8dcfb054,
	0x40ed77d9, 0xeb3b7d3a, 0xca195d53, 0xf52d4cdd, 0x36799737, 0x7afc61c5,
	0x64696483, 0x5307ed81, 0xad74b27c, 0x468f8fa4, 0x023116f9, 0x991dc7ed,
	0xf9d70411, 0xc71c461b, 0xf25773e7, 0x3c1a77e7, 0x9fb0a7cd, 0x6794f5a7,
	0x2521fc04, 0x477e6f30, 0x9bbe9ea6, 0xbd2249b7, 0xfd27195e, 0xc086d8a9,
	0xe450ee75, 0x89e7aef2, 0xf6e728ef, 0xef7caca6, 0x9e2b78cd, 0xc9ec730f,
	0x7f27f784, 0x0f9a79fd, 0x3c8c4f9e, 0x4df6839f, 0x6cf1deba, 0x9b7bae05,
	0x46dff281, 0x71ca25e5, 0xc1ff3ed0, 0x39624f71, 0xb3e9656f, 0xb71fc815,
	0x34f04718, 0x65bf3e60, 0xfc834d92, 0xbdc368f3, 0xe76e11f3, 0xbd246d7e,
	0x6643597c, 0x7e87eb1c, 0xd805f294, 0xec0c0c7f, 0xf95235ae, 0xce85ad62,
	0x8daded87, 0xb5cbfaa7, 0x2cd92a56, 0x2ccb5f8e, 0xa8dc6f9c, 0x42d791bf,
	0xd5f41599, 0xcc4c1b51, 0xde23fc0a, 0xeb863f60, 0xdaea1f4c, 0x2bac51b6,
	0xe11fbe1d, 0x70809e4e, 0xe971b518, 0xf7695471, 0xeb3b7265, 0x921b539d,
	0xaf176e90, 0x02be78ec, 0x59937fde, 0xa1f91272, 0xf265eb71, 0xf83d1c1b,
	0x77845cc8, 0x5f0336f9, 0xb9f7589f, 0x3dc4675f, 0xdfbbfd0b, 0x5f1d91d2,
	0xf9e3b5b3, 0xd82e508d, 0x881f54b4, 0xbd77dfef, 0xdcf98aef, 0x046eae8c,
	0xae9d7f87, 0xfa224b1e, 0x957406d9, 0x55d3eff3, 0x0455cacd, 0x92ac94bf,
	0x73f708ab, 0xd212773a, 0xdbecb9d3, 0x87ddcf08, 0xc2bf8224, 0xafef955f,
	0x6956f588, 0x26c69bbc, 0x55ebf9fb, 0x7be08a36, 0x1917e0f8, 0x6d5ed7a8,
	0xeb9dfd99, 0xf6eb003e, 0xccbfa265, 0xfbf06548, 0xd523bd02, 0x102beb06,
	0xefc1e279, 0xa0388b07, 0x7fc75f12, 0x0a766fe8, 0xc5f204b9, 0xe3e6003d,
	0x217c956c, 0xdcb5c768, 0x8e1b5e71, 0x9f624672, 0x8c91fca8, 0x6720127d,
	0x9bdf346f, 0x4fd8d595, 0xfeef9fba, 0xf30d23e0, 0x5bd3c805, 0x2f9843da,
	0xfb3edc60, 0x29e99e03, 0xa0d0937e, 0xbcc04b9c, 0xd983aea6, 0xbce20e74,
	0xd763ef9e, 0xb873d001, 0x01c9867f, 0x0fe72b79, 0x9f21e676, 0xf56f5e0d,
	0x1f849deb, 0x2e4796ce, 0x32db1d93, 0xef36bce9, 0xbc3febe6, 0xf70f33b3,
	0xbdaebcef, 0x2ea9ed00, 0xee1e7b7d, 0x9c1bf543, 0x70abff9f, 0x6c579e50,
	0x9d008580, 0xc2464b57, 0x22f94293, 0x4eba05f9, 0xf540bf70, 0x4fc4edc1,
	0x5fb95b7b, 0x56d346a6, 0x8c7e8714, 0x91c71d25, 0x73c6f59f, 0xdc5aa93b,
	0x55363063, 0x4f6d41c8, 0x78d39e12, 0xe481f100, 0xf0efb72b, 0xd7a4045e,
	0x49d78d1a, 0xa1794af9, 0x172de30c, 0xf9e19e90, 0xebc915dc, 0x79cfcf11,
	0x3f91f262, 0x8ff793be, 0xfde3f26a, 0x9322d43e, 0xf2ab223e, 0xe1d6fbc1,
	0x0c427991, 0x509af453, 0x8d743e55, 0xd263fade, 0xf1e6df67, 0x9ca19ab6,
	0x9cebd89e, 0x0f6b5c9e, 0xfa03e3eb, 0x13a5949b, 0xf3475c78, 0xfff7f3be,
	0x9b9cba20, 0x359c5f6e, 0xc3f39c5a, 0x7807e2fe, 0x2bb44924, 0xcd17c7f0,
	0x2faec2ad, 0x4d7de996, 0x0e30cc8b, 0x28c3e2c7, 0xd598a00f, 0x9de55e51,
	0x82963bcc, 0x27f6da33, 0x93f7856e, 0xc48f2f7f, 0x83b02d7c, 0x145d5e28,
	0x7cc348e2, 0x491ad3a6, 0x6a3bd5c0, 0x6b3c806a, 0x631d7914, 0x58e48965,
	0xe928424f, 0xb9669329, 0x4fea04e6, 0x0ede1af9, 0x89bd21fa, 0x79f87a79,
	0xde4f5f19, 0xd73c80b4, 0x5d0fbf99, 0x79917242, 0x180ccd47, 0x971640e7,
	0xde30579b, 0x2352780d, 0xf285aae2, 0x3ea14f37, 0x8f10ecbd, 0x24d69e27,
	0x58f9887f, 0xc25a8e74, 0xdcfccaf3, 0xbb30733a, 0x3727e91d, 0xd4f9ce86,
	0xe61895ec, 0x341f55b5, 0x513f436c, 0x163daeb5, 0xcb6379f1, 0xe7c47a07,
	0xe6b38c1a, 0xdccef3f2, 0x3e246e6f, 0x2461635e, 0x992d5cbf, 0xceffa21f,
	0x514b8275, 0xb23df697, 0xe36f91cf, 0xfbcd5578, 0x32771ec8, 0xcee3d91f,
	0xf4de3526, 0xbfeff7c6, 0x5565903f, 0x2da4c7d1, 0x62663e9c, 0x3e99b0fe,
	0xa4ec3f27, 0xc086b8f8, 0xb20749f3, 0x9760beb8, 0x1ea1d73b, 0xd9229dd3,
	0x3baae824, 0xf516bdc4, 0xd7067723, 0xf77fba6b, 0xc445a8e2, 0xa6a33c5f,
	0x85bafac3, 0xc3693b1e, 0x301cad66, 0xdcad499f, 0xc21dd8ef, 0xbed00fca,
	0x7ee1063b, 0xd25e9cbc, 0x1efe8592, 0x5bc9cf7d, 0xce243fd1, 0x63af0533,
	0xbd0bf0b8, 0x2a53ce2d, 0x989c9ef3, 0xf319f9c8, 0x171d1e10, 0xbc9487e7,
	0x90fbe51a, 0xd765496c, 0xfb8e9c80, 0xc60978ae, 0x9c44ca69, 0x69c44ca6,
	0xa69c44ca, 0xca69c44c, 0x4ca69c44, 0x44ca69c4, 0xc44ca69c, 0x9c44ca69,
	0x69c44ca6, 0xa7161f28, 0x4b6ef94a, 0x1e8e51eb, 0xe81b5a47, 0x0c8e9faf,
	0xb7540faa, 0xa9291d3f, 0x6a2503eb, 0xb4b59edf, 0x1f8cf31e, 0x00917cc0,
	0xf17768ff, 0x1b8c0295, 0x4d9c8c4f, 0xd82f6576, 0x1277c895, 0x10171db2,
	0x4c4e27ee, 0xfc4cdb48, 0xccfe44d0, 0x530df7d3, 0x971ca39d, 0xde2d7235,
	0x2cce313f, 0x75db7389, 0x3b144bc3, 0xd099fa0f, 0xcb4a3a5a, 0xf50580f9,
	0x59d942e2, 0x4b2ce386, 0x7e448d30, 0x71c32dbb, 0xff002b35, 0x4e2e068a,
	0xb8e7fd43, 0xfa21face, 0xd47fdd65, 0xc559b9d1, 0x2bb4a77f, 0x672718cf,
	0x2b20dc63, 0xf63e6d75, 0x7c85440f, 0x4d67aecd, 0x26bb3f38, 0x533ba254,
	0xf94b5598, 0xc77f6211, 0xec1eb95b, 0x91b55bd3, 0x190977e8, 0x10f98d17,
	0x9e7ec5c7, 0xb6f9fb10, 0x6b8c4fd8, 0x71e74c4d, 0xae312c2d, 0x0f92a585,
	0xc4ab2e36, 0xecf04d9c, 0x0a782249, 0xca9ddeff, 0x4de63d39, 0x56e0bd42,
	0x0a6f9f81, 0xb334b2be, 0xe49b2a24, 0x5dce9784, 0x59bf0956, 0x286388a7,
	0xf3be54eb, 0x9dc7cf7f, 0x31b99c36, 0x135ecd6e, 0x4083aff9, 0xb4fa80ef,
	0xdf88e2d7, 0xa790e728, 0x3efae48d, 0x3f9c557b, 0x468eb78c, 0xfc23583a,
	0x7e1e5da6, 0xd915d60e, 0x04e78196, 0x28fd04ba, 0xb23ce575, 0x66ea1f2b,
	0xd703b9ff, 0x3c0cb6b4, 0x9925d077, 0x775fe834, 0x4fefe36d, 0xa572fa09,
	0xfb94fe88, 0x24de8c1e, 0x43ee87dc, 0xf9e125af, 0xbecd47ba, 0xfbbf9c45,
	0xe64579f8, 0xa47cc0cb, 0x067bc94e, 0xf6a36ef3, 0x9e606718, 0xfbcea76d,
	0xf6e3d63c, 0xb4baf084, 0xf0258cef, 0x09378c7d, 0xf6a372f3, 0x9e606698,
	0xbecc676e, 0x016c23e7, 0x672bdd75, 0x757ebdf0, 0xd3cc0cc8, 0x9cf06c9d,
	0x797c45a8, 0x6995e399, 0x11cffeef, 0xb907556e, 0xef7e3e7e, 0xa0af8bfe,
	0x461fddfc, 0xd9a9fd71, 0x6b3784c9, 0x09b0be0e, 0x1f6bacf1, 0xda3febf7,
	0xbff3c1f4, 0x0c0676a0, 0xdebf4073, 0x19c60c51, 0x3dd767b4, 0x50e4ee38,
	0xcf5897ef, 0xf3431a1d, 0xe9c51c9c, 0xfc687f36, 0xaec3a40c, 0x8a7f7bfd,
	0x00f26af2, 0x3e715c50, 0x3ff3f22f, 0x4f66af95, 0x2bbe3b44, 0xf62e6dac,
	0x40c7bd5f, 0x5f2bbbe7, 0x30fba38d, 0xd0a766e6, 0xd6862a7c, 0xd53ca125,
	0xe77bbebc, 0x9db1a22f, 0x353ae289, 0xab9f5c91, 0x960a1b94, 0xdf6dfed2,
	0xf79c1bf9, 0x59c5136e, 0x0277d02b, 0xe99d8af5, 0xe37f8fe4, 0x8b9d3fbf,
	0x6f2850fb, 0x5f3bf3a5, 0x106930ee, 0xf6f4a70e, 0xc65e7801, 0x76474a7d,
	0x57a88565, 0xdce7e69c, 0x8bdb432b, 0xeba2ff68, 0x569e5092, 0x37743d46,
	0x5cb27bce, 0x35da3cf7, 0xc50305ec, 0x06efce18, 0xe777c1b8, 0x8594751b,
	0x8c3bb5da, 0x4a77a3ce, 0x5ef17375, 0x6f237710, 0x23aa69d7, 0x331bba78,
	0x68123ee9, 0x76de50c7, 0xcf559b4a, 0x90be37cf, 0x85e77687, 0xfec9933d,
	0xa157f054, 0xc11dca97, 0xb9f8e7e7, 0x37f14ad3, 0x3999b8b3, 0xe1746fc0,
	0xcf5d33c0, 0x17f7ff32, 0x4e74749a, 0xd6c0c2bb, 0x42afde62, 0x7789950f,
	0x2afae314, 0xa8190d35, 0x6c8c549f, 0x71748b9f, 0xf18cc4de, 0x211deed0,
	0x579b2a97, 0xf73d454d, 0x2179f346, 0xd5f1d39b, 0xae9f2e78, 0x813c98b6,
	0xf2e0c571, 0xf2ccb5ef, 0xfebfba6e, 0x79f512c0, 0x5ef477c2, 0xd563da27,
	0x9c7f9c91, 0x3a4df681, 0x7e7023f4, 0xba856f37, 0x91d9b3fd, 0xbeb57e34,
	0x9be5033d, 0xd9d3ffd2, 0xdb682e42, 0xe0abdee9, 0xdaa326ef, 0x45e47c81,
	0xb2b71e7e, 0xf3a0ea59, 0x58d20820, 0x8d2b3c3f, 0x03e60f6e, 0xf10fb7f5,
	0xa01f6205, 0x934391af, 0x26cabc69, 0xaee79d13, 0x470f690a, 0xd619c87d,
	0xbb68e74e, 0x36d9975e, 0x4ad17db1, 0xf1fe29ff, 0x85607f14, 0xf5376757,
	0x072c1e37, 0xf18b8dfd, 0xf145006f, 0x2a0f1e50, 0xe7e5096f, 0x74ed2dc7,
	0xbcf83a9e, 0x12d3ae25, 0x2d5d8f40, 0xed0363db, 0x93b377f1, 0x83a9fc45,
	0xbffba6e8, 0x3c42493f, 0xb5b0d4a8, 0x20bc9718, 0x500ef3f1, 0x170e73a7,
	0xf2b37c44, 0xe208732b, 0x4eab85cf, 0xa92ee3a2, 0xcfdcf89d, 0x7f1064f7,
	0x13b5d2e8, 0x9a19ab9f, 0xed11ebc3, 0xfd6f9173, 0xc46de87c, 0xda12bac7,
	0xa379e2e7, 0x307d4a59, 0x61bf3923, 0x6e1984cf, 0xe79bce33, 0x3aedb04b,
	0x7103f70b, 0x70162f78, 0x6ba79682, 0x59d0cec9, 0x146c3e51, 0x19c0ab79,
	0xfd97ebfd, 0xacc5d4f4, 0x3e919b7b, 0x383df9cb, 0xbd353fa0, 0xecde7a82,
	0x27c7ba58, 0x3c4a6e18, 0xebf23a31, 0x234fb845, 0x51971cc3, 0xda72ba2e,
	0x6c008ec9, 0xfd543927, 0x93d9033b, 0x9d9ebadd, 0xc342bfc8, 0x9db1571c,
	0x7eb6df53, 0x0cf78494, 0xd5471fb4, 0x7ce54efd, 0xdf1c0be3, 0xf3b672ba,
	0x1e2210f3, 0xc3f813a9, 0x406988c0, 0x3ef890fc, 0xf5796d1f, 0x5d37e45d,
	0xa7c4a96d, 0x7ce9e983, 0xc8e193cb, 0xb9023e37, 0xf7b00eee, 0x817d2a3f,
	0x30b3fee2, 0xfd7cc3df, 0x6fdede39, 0xc7dd93a6, 0x473c0536, 0xd757ac7c,
	0x7882e183, 0x81d153e9, 0x0a73e79b, 0xdf1aab7a, 0xf433f746, 0x5d41a7d5,
	0x091fa80e, 0xc7b507aa, 0x3fa8fef3, 0xd119b3d8, 0xefb073bb, 0x7be9d934,
	0x1aee3e79, 0xdf546b90, 0x93794a1f, 0xb720bd9a, 0x42dcb9a2, 0xde155179,
	0xaea9fe46, 0xe78a06fd, 0x45f83eae, 0xf01fae12, 0x5530fc91, 0x458b5f07,
	0xb66a7dfb, 0xf903c695, 0x2ff94b18, 0xa2c60ffb, 0x773ca1bd, 0x2219bc6a,
	0xf90f3f0f, 0x25dcf287, 0x1ce832fb, 0xf746d4af, 0xf3154c3f, 0x2ea06a76,
	0x5bcc5d63, 0x0ecf74e2, 0x82a8fbf2, 0x50e26df7, 0x3f80cfce, 0xc6de51e4,
	0xa03fdceb, 0xc10a83f0, 0xf3e08e57, 0x16ff4e1c, 0x9f041e25, 0xf7dd2056,
	0x288e27c3, 0xc84b6470, 0xca1f637f, 0x4f7cade7, 0x12ff72fd, 0xa37eafbd,
	0x07252f33, 0xf72ab3bf, 0x51f9f96b, 0x20bf9faa, 0x3e27881f, 0x0b175ab0,
	0x5e7caaeb, 0x2a837ba2, 0x822aace6, 0x76b16ce6, 0xcdf91169, 0x7cd69f30,
	0xf182bcfd, 0x27086fe8, 0xde2297e4, 0xc793b953, 0x78e82e7b, 0x0df80cbc,
	0x9e2febe5, 0xe908aab8, 0x4bb4616f, 0xdf0f681f, 0xceebffac, 0x55592fa5,
	0x9d0fd714, 0x7cd8ae57, 0xdf5d863c, 0xa1a3855f, 0xfd7ad628, 0x17de6573,
	0xc73cca4c, 0xe10262eb, 0x11556b31, 0xd8b963de, 0x83c2eff8, 0x41c2fbaf,
	0x2ee50f83, 0x3ee297c0, 0xa25b5fb7, 0xacdea3f2, 0xa1e60abf, 0xe68dc738,
	0x253a5c1f, 0x9fca69df, 0x246afa05, 0x09ba033a, 0x90acef18, 0x87fe7dbf,
	0x7421d2f2, 0x74a3878f, 0x21ffa048, 0x1c0c04b8, 0x10dca1a8, 0x87409537,
	0xc0fd6d73, 0x79bf6943, 0x9ea3f728, 0x72863c45, 0x67aae4e0, 0xb7e4615e,
	0xcc687e79, 0xbc7dcf8d, 0xf7fff820, 0x2131f73e, 0x643bb794, 0xa77fa0b2,
	0xe4d7d0fb, 0x675eedff, 0x0ae3c59e, 0xef009666, 0x6ee7c78f, 0x8ef3f40b,
	0xc1c7c61b, 0x3e74dd73, 0xddf74b3f, 0xb09ca3fe, 0xe911ff3e, 0x14a1391b,
	0xb96ae94f, 0xbbadf242, 0xe305b475, 0x1e6d5d1e, 0xcd5bd233, 0x2c67ff7f,
	0xd6aee1ca, 0xacff28cf, 0x282f9beb, 0xc8a36d2f, 0x22d23c0f, 0xacdabaf2,
	0xbbbcf861, 0x6c22d3f8, 0xfd28a8f7, 0x4fee03fe, 0x3fc54a56, 0xfaf968d0,
	0x89e6dc09, 0xa0175f91, 0x993b007c, 0xfbf103ee, 0xdf71ac09, 0x7e891795,
	0xee74b482, 0xfd12c027, 0x09147804, 0x475804fd, 0xe896013f, 0xe8e7c027,
	0xfa3ac027, 0x7e8eb009, 0x9fa3ac02, 0x13f44b00, 0xc52ff3e0, 0x506e8c39,
	0xd31fb8d2, 0x797e7c4c, 0x2ebf8f23, 0x51e3c43f, 0xca241bcb, 0x1873c2c3,
	0xcbaeef28, 0x791669cb, 0x14cdde39, 0x2fd9abdf, 0xf04b70db, 0x80db86bc,
	0xc73d39f9, 0xb353bfd0, 0xb2adb24f, 0x3459f3e2, 0xa3ad8d8f, 0xcf839c3f,
	0xbc36751b, 0xf5bbabf7, 0xaffa2c6a, 0xc91b5b2a, 0xee31350f, 0xb3f69e90,
	0x3fe86249, 0xf6e0699d, 0xa7864bb0, 0x250714f9, 0x6865d97d, 0x6aa53b23,
	0x3c096497, 0xe6335da7, 0xbe83f132, 0xc9af283c, 0xa392a652, 0x85479e76,
	0x5f595a7f, 0x6f11789c, 0x453797d2, 0x1e80477a, 0xc3e308b4, 0x86fe5cf8,
	0xc0b887ce, 0xfa928da0, 0x8a0aabc9, 0xeeb6571b, 0x9ff78f5b, 0xfb8fc704,
	0xc505dbce, 0x130c078d, 0xfc11e1f1, 0xaff1479c, 0x87eef6cb, 0x0ceb7af1,
	0x642497a4, 0xc587623b, 0x9d85fe60, 0x0ec72bfc, 0x3aaec899, 0xe55339bb,
	0x0794295f, 0x99637f91, 0xbd79224e, 0x0831c32d, 0xbc509bbf, 0x132afc80,
	0x6e88c3e2, 0xcf2c3c15, 0x061a4928, 0xd72cbbf8, 0x42abfe4a, 0xf509fb03,
	0xa0b5f227, 0x5c2aba24, 0x1ef07923, 0xa3665287, 0xecf32b73, 0xe53bdefc,
	0x8c79ba9e, 0x78282de7, 0x44b36cb5, 0x1a3903fa, 0xc97e3162, 0xf5af39e1,
	0xc97f740f, 0x27b88302, 0xdbe3c34f, 0x7cf28f89, 0xd3788596, 0x01ffde13,
	0x904b13f2, 0x876bbfa7, 0x41d08ee7, 0xb79f5c49, 0xa5ff61c6, 0xef28eb6f,
	0xaeee30b7, 0xf5c9070c, 0x809f9489, 0x3b7da7d7, 0xa5f8bbec, 0x98e13f3a,
	0xae1064ae, 0x29e238fb, 0x541c73f9, 0x4e5b5dbe, 0x51b7e2a5, 0x0fbb11f2,
	0xc70fb6bd, 0xf7e1ac2f, 0xbcf0dede, 0xe7ff485d, 0x07f394ce, 0xb97c8ab7,
	0x91a9cd44, 0xf13a7e78, 0xd70db32b, 0x8877185f, 0x8aa56bce, 0x97a6e7fe,
	0xb3fdc34c, 0x7e373387, 0x3a967187, 0x2e116780, 0xb83f4240, 0x5ee78ed7,
	0x16490e7a, 0x8ebe8bca, 0x875e6e4f, 0x69353af9, 0xadfd0592, 0x85752145,
	0x517fd0b1, 0xf90db24a, 0xf70b4d74, 0xc94176a3, 0x0f56fdf7, 0xf8c5dbdd,
	0x8a775a3d, 0xdd397b7d, 0x8c5870b1, 0x4164f9ff, 0x57addd37, 0xcdf03e78,
	0xe83bacfd, 0xb26612de, 0xe1a6f729, 0x361e4fbe, 0x0aadfc98, 0xc536f4de,
	0x79bc436d, 0x87971868, 0xa7bce673, 0x69613d43, 0xc441e3a6, 0x9765b9d3,
	0x3ad2c5d7, 0x2983f7fb, 0x7ec1f379, 0xfafe40b0, 0xff2f917f, 0x2a12ed6e,
	0xa0aed64f, 0x4dd6adb2, 0x5fc3bfef, 0x09eb875a, 0xa33297f6, 0x4dc90075,
	0x87ee67a0, 0x028ff20e, 0xe8026b1d, 0xc46b4278, 0x70280dfc, 0x9f74f5ea,
	0x2f2be626, 0x3fdd1337, 0x3f5fac3b, 0x332702a9, 0x997b55f9, 0x3de11f29,
	0xab552b3e, 0x043bf781, 0x90ef95dc, 0x483d702e, 0x5d225817, 0x99fc0368,
	0x6481e9cf, 0xef397147, 0xa26f3926, 0x0abf5c7d, 0xf78485f8, 0xfc54591f,
	0xbf1062e2, 0x3ee48300, 0xcad5a73a, 0xbc9493f3, 0x5c50f1cd, 0x7f87efcb,
	0x18ff3978, 0x8ddde21c, 0x0eae0ce3, 0x63e0bca1, 0xc74f8e3a, 0xb7bcf236,
	0xefc25632, 0x8f9eba5d, 0xbb9ea384, 0xcce7aa20, 0x82fda06f, 0xafa4ccc7,
	0x54584fac, 0x23e13ff0, 0x68e715bf, 0x1659e3dc, 0xacdf17e6, 0x031ee7ec,
	0x9de50f7e, 0xd6bf6461, 0xbaa6fd08, 0xa8f442cc, 0xd6ace79c, 0x63d63b7a,
	0x9e30e8bb, 0x7465a1bf, 0xcd29cacf, 0xab6f7e40, 0x7753aba0, 0x5f5e52a6,
	0x7f7e1aec, 0x125dcf50, 0x313bafdd, 0x5087df94, 0xbe7129a8, 0xd4dfef00,
	0xcfad73f0, 0x32077de1, 0x7bf72bee, 0x728fcff8, 0x38b12c3d, 0x903bee8c,
	0x6a3dee03, 0x67b80e4e, 0x3fbf367c, 0xdca3dbb3, 0x6732535b, 0x3f577c29,
	0xd95bdf9b, 0xa38faccd, 0x1e5ddfdf, 0x023dee22, 0x7fca3639, 0x7f81e51f,
	0xa7adfd72, 0x4ae74342, 0x575847eb, 0x1feabae1, 0xff7bd2b6, 0x3e1c47bd,
	0x26c7ba37, 0x35f1dc2a, 0x7df07de2, 0x25494f36, 0xf7e217b3, 0x5b8266b9,
	0xa1ff3a24, 0x43d9b1dd, 0x7089df1f, 0x8d1d641c, 0x31fcf67a, 0xe0120511,
	0xd416a247, 0xf43fc019, 0x3f3dd33d, 0xcc1eb51b, 0x15a41da7, 0x82b5fbe7,
	0x219743bf, 0xaeded4f9, 0x93e97a87, 0xe51d998b, 0xfba32253, 0x3c8cd36e,
	0x31df0dbe, 0x230dd12c, 0xdc63dca3, 0x803a53ef, 0xc71a5ff7, 0x867f783c,
	0xc940491e, 0x9e3e04cf, 0xff0a6586, 0xbe9f3c3e, 0xf7f86b77, 0x43942d76,
	0x4ffdf952, 0x140ceb3d, 0x647d2cd7, 0x29c3c930, 0xe4e7d5e3, 0x79e1c81f,
	0x22794a07, 0x8be2aac7, 0x5366d7f3, 0xdafe707c, 0x3bd42ed9, 0x74a14d1c,
	0x9ef3afae, 0x2f785ded, 0x59ec957a, 0xe7ac01f4, 0x3d238e6c, 0xc933ed07,
	0x343f773a, 0xa8e33f98, 0x1c5cf31e, 0x5e97a9de, 0xf76ef287, 0xdf7893be,
	0xc8f7dddd, 0x8cddfdf4, 0xd6ccefdf, 0xef2ffbf2, 0xc6d65f72, 0x8d77ff43,
	0xde0fc895, 0xa124b261, 0xf62a573e, 0xf9c396cb, 0xc1fae94f, 0xdf376819,
	0x7ef37185, 0x1cfccae4, 0xf795d7ce, 0x95302643, 0xde2e52dd, 0x0ef58b97,
	0xcbefe549, 0x523a1836, 0xf9d4b1c3, 0xcbaca132, 0x0e5b7f1b, 0x8525378c,
	0x38416d15, 0x88fdc43e, 0x6f36261d, 0x65860e5a, 0x2815fd99, 0x9259c63b,
	0x710cdee8, 0x0b42e9ff, 0xe31d47e7, 0x2c67bf78, 0x399161ed, 0x1ef05e9c,
	0x0b6205d4, 0x4e98accf, 0x4ac171f2, 0x5caf9d23, 0x64e9ebf8, 0x97a82c77,
	0xdb255ce9, 0x1507bea4, 0xb3f70ef7, 0xf844936c, 0x4d8d6430, 0x9ef1718f,
	0xa1df20cd, 0x97d9994d, 0xccbcf286, 0x56fba266, 0xdeb037d8, 0x99efbc02,
	0x95c33f91, 0xeb8d98eb, 0xa52bad29, 0x7343457b, 0x1aa7e41c, 0xea1a7602,
	0x70e6cf29, 0x60029fbc, 0xb41e7ba1, 0xa7e809ed, 0x479e5448, 0x84cc325a,
	0x7486264f, 0x64b3a1d8, 0xd63a7ce0, 0xeb483499, 0xbc735653, 0x6a377c02,
	0x9fbf31f3, 0x8ddd2085, 0x6734f812, 0x01a4b695, 0xbc4083ea, 0x7ee24586,
	0x7abc208f, 0x0b71cf3f, 0x87b9cde2, 0x77e418d9, 0xe66d360b, 0xc6fb12f3,
	0x3e746db4, 0x72635cf2, 0x95f7c63e, 0x6f3f7c7d, 0xc09cd2fc, 0xa247bbfd,
	0x9cf5837d, 0x97513940, 0xb867ff37, 0x187e785e, 0x78ca75f7, 0x1403e51f,
	0xf1864eca, 0x4678def4, 0x32f4eef7, 0x1bbd674e, 0x141f24b4, 0x18e856fa,
	0xe78ed5f6, 0xfb7d9563, 0x1413d2bf, 0x21f0013e, 0xbbd0a07e, 0x3c1417c2,
	0x3043f851, 0x3005cc7e, 0xdf4f9edf, 0xf8521f13, 0x9343ae0f, 0xca0be7ef,
	0x8c36eb3e, 0x541f90d3, 0x7ca173ec, 0x086bef71, 0xe9337287, 0x31707d1b,
	0x492e091b, 0xf782d67a, 0x6a59aeb9, 0xc02478ef, 0x5cbfbf2e, 0x81f18e7d,
	0x8bf3ea25, 0xcfa856f3, 0xf159ce2f, 0x0fe863e7, 0x78ee193a, 0xcce7f711,
	0xee7f3f2f, 0xdbfe7843, 0xe7485e5f, 0xc6c5f0f6, 0x95dc71a7, 0xed1e6221,
	0xf52b5e7c, 0x8487efc4, 0xf0967bf0, 0x7ccbee1f, 0x34ade9c6, 0xca24e239,
	0xfee2bfad, 0x823c63a4, 0xb119cfef, 0x7e11f33f, 0xeba5f780, 0x70e93cb8,
	0x981fe44b, 0xdbd056bf, 0xe4b9f506, 0x7b58124f, 0xfcffaa68, 0x670f27f2,
	0x2a7d2124, 0x1b1d95e7, 0x696679f8, 0x3bd209c5, 0x56bdca1c, 0xad7ba0ee,
	0xe7e71c56, 0xe7d5db9e, 0xd9474389, 0x603fe4f5, 0x9f99dedc, 0xb9e78475,
	0x141649d4, 0x79e26541, 0x754906d9, 0x0e54ed5e, 0x94962f3f, 0x4c7ee5a3,
	0x7fa42de4, 0x505c91d7, 0x04f814f0, 0xab2b9f9d, 0x145fa11b, 0x8be6ffc0,
	0x34b20be7, 0x93cf2a54, 0xd93c7872, 0xfd054489, 0xa2959a3e, 0xcb7c485f,
	0xa54afe4a, 0xfcacfcfd, 0xcfdf68f5, 0x9a2e34df, 0x19e3d005, 0x31249f31,
	0xf80de71f, 0x133e5f73, 0x33f749fe, 0x5bdd91d7, 0x2f8bd2f9, 0x95fb7de1,
	0x7c90337f, 0xe22e1ca8, 0x829e39de, 0xe5d714e9, 0xc5aaa9e7, 0xf17c4f7e,
	0xe7d470e3, 0xbdf99a6b, 0x607650d1, 0x9cb2bd59, 0x1b6af2ec, 0xf5e443d0,
	0xbe6fd779, 0xee70b7f4, 0x6a2775ef, 0x7cc177d0, 0xaffbe889, 0xfc94fe6e,
	0xbb4fa804, 0x947f5147, 0x7dfc1dc7, 0x384df48d, 0x09db37b7, 0xae87852e,
	0xf63cd2c6, 0x763f215f, 0xb175a1cd, 0x7dd67e8e, 0xf0be7e5d, 0xfd88d43b,
	0x2e9b61aa, 0xd177f9d3, 0x4b7b706f, 0xfd9f38ae, 0xca03f603, 0x4d32d713,
	0xbd6e7de0, 0xcceff49e, 0xc2d9ac4f, 0x6af651cf, 0x3e3003ad, 0x45ce2dd6,
	0x919bb705, 0x25e3e5cb, 0x147423a0, 0x14c93774, 0xe26ee96f, 0xa6eab4fe,
	0x79e38f27, 0x6c306ad4, 0x73bed861, 0x32cdd53b, 0x8de60633, 0xd44ffe61,
	0xf559e78d, 0xffdd1862, 0xec95e152, 0x5e9f308d, 0x02626fb0, 0xcb9f93e6,
	0xe0caa9f1, 0x95fec02d, 0x5ae567f9, 0x4549fa55, 0xbe7493eb, 0x9175da15,
	0x2872f13e, 0x9eab71e3, 0xcecf3893, 0xce2923ad, 0x57dde154, 0xa6c07e4d,
	0xb91fca50, 0x979f53a0, 0x778c5dbe, 0xbbcf2e7b, 0x453cc4eb, 0x9925fefc,
	0x4f385afc, 0x920bc3a4, 0x2262af3a, 0x2583177e, 0xc405db87, 0xf6fed1d9,
	0xf08ede15, 0x45ff6834, 0xbca99fcb, 0x30afb45b, 0xbca1e5b7, 0x9439a2fc,
	0xd17eafce, 0x37a29bfc, 0xde4bbc60, 0x0052d171, 0xeae6955d, 0x156c7ef8,
	0x513d70e7, 0x97875ce2, 0x94d9d3d6, 0xe83da128, 0x9d56f912, 0x6b86afcd,
	0x3cdd6e88, 0xdeeff3ce, 0xdd7c5627, 0xe50f627d, 0xc779e0c7, 0x627dd576,
	0x57fd5bff, 0x4d66e78b, 0x47a71889, 0xfcb4e22f, 0xbc2c4777, 0x9d2fe29d,
	0x2f7adc3b, 0xef657b9e, 0x0f7ef8e8, 0xf68d3eb2, 0x453fdccc, 0xbf88bd91,
	0x2ff58237, 0xabf1e5df, 0x3f0523b9, 0xbca76f89, 0xae648e95, 0x48373837,
	0xab700ecc, 0x0372fc02, 0x991e9d68, 0x58fea039, 0xe88fcf2e, 0x0fd7fc04,
	0x79413e27, 0x1ec06725, 0x5ff87ba3, 0x675d71e1, 0xcf032f8a, 0xf88a75e3,
	0x97d233be, 0x5efd0511, 0x9ce27814, 0xb408cbe6, 0x7cdb9c47, 0x5172df94,
	0x7be1afe4, 0xf339b7f4, 0x648ebb79, 0x9b9d174b, 0x50c61fd8, 0x16bcd76f,
	0x7ae87846, 0xf02db4c1, 0x8116db1c, 0xfcf517a7, 0x4ef76dfe, 0xf08a9f3e,
	0xa2e7ea3a, 0x908aefc0, 0x19df9a3a, 0x42b82e71, 0x3a1debcf, 0xf7def746,
	0xf5f7e6ec, 0x3b68485c, 0xd85ce380, 0x9e794d9d, 0x459ec91d, 0xe79ef42d,
	0x31ee547b, 0xe75e70f8, 0x39d18777, 0x6e5fe29c, 0xef5f78a1, 0x7e84830e,
	0x8c31f382, 0x6f9c19ce, 0x7d39218c, 0xff92b25e, 0x515bfcf1, 0xed655fd4,
	0x524f3a0a, 0xf5026c09, 0x518b284d, 0xf8df3b4f, 0x2fd2124c, 0xdd6037d4,
	0xfee6eac1, 0x1774e91c, 0x0b845dff, 0x1d91fe7b, 0xca517f18, 0xb28638e0,
	0x16fbca9f, 0xb92d8f41, 0xcd6fcf5c, 0x5cbc10b5, 0x52a7dea1, 0xbe9c7d68,
	0x1f64ce01, 0x7dd13d01, 0x07bc6738, 0xa7e82563, 0x3b30b5f2, 0x9d0ef5ca,
	0x0437e32f, 0x3bf15087, 0xb8ec8c34, 0xc8a33bf3, 0x99ed068e, 0x33bf39fa,
	0x94a5f297, 0xa8298fbc, 0xe63ed1a3, 0xe50b7c12, 0xcf7479ad, 0xca508ef1,
	0xe47ca98b, 0x03ca1a07, 0x5dbeb991, 0x2982d2f9, 0xb8c76ea2, 0x7fcfe549,
	0xfc8bc0a1, 0xa71e4a87, 0xd751f053, 0xc00eb723, 0x27f657bc, 0xaed5f299,
	0x619e7968, 0x794c5c30, 0x1d54df9c, 0xd6e88e78, 0xbf8e7809, 0xf2255443,
	0x70f6abb0, 0xfad548bf, 0xfe269f5b, 0x30c75278, 0xf7a2f6cf, 0xb840f0c9,
	0xcb7c115f, 0xda8dbdff, 0xfe7b4157, 0x34e13bfd, 0xca3a9d9f, 0xafde0e0b,
	0x1efdfdef, 0xbefadff9, 0xbff20bd2, 0x15ecb89f, 0xbfd3f6d6, 0x32681f21,
	0x94f4dcd9, 0xea75d1e7, 0x79f88bbc, 0x87f11302, 0xaf4e08ce, 0x78f2d45f,
	0xc9fad57e, 0x81bca2bf, 0x0ce9d353, 0xff4f62d1, 0x826bb371, 0x6ca2bb3f,
	0x5d0e9003, 0x1fd81fb0, 0xe79d0fec, 0xd1d27f66, 0x39ebc1f7, 0xa3ebbe2d,
	0xff3cbdc3, 0xdf2073b8, 0x3297ce97, 0x4474ee49, 0xf986bc70, 0x19d99d92,
	0x584a4bc1, 0x0b183cc0, 0x71ce87c7, 0x3b97b25e, 0x76547da5, 0x9577f8e8,
	0x6aefc42b, 0x871e78f8, 0x15367113, 0xd4d9dbef, 0xf206fa86, 0x2a7c82e3,
	0xebc8867d, 0x3c073bef, 0x24aebb26, 0x678bea4f, 0xfba63f23, 0xe90fc9f5,
	0x753f23d5, 0xd9cf7d08, 0x2eeffd74, 0x12eef3f0, 0xcf0efde5, 0x147b9493,
	0x8aa71f29, 0xe5567873, 0x5eae2896, 0x056976b5, 0x92d57de2, 0x3d23f7cd,
	0xd2a8eb28, 0x8fb462b2, 0xe699243a, 0xc1e1d8a3, 0xfdf029e3, 0xc65f32a1,
	0x6724eae3, 0xcf6ed680, 0x19bd72b3, 0x9fd075aa, 0x89b4ad73, 0xec5649c6,
	0x053ebe4d, 0xc197184e, 0x9ec542bc, 0x95fad1bf, 0x3e68de79, 0xbf38f2d3,
	0xfeb648ee, 0xf7ee2c6a, 0x27e2651f, 0x3919be57, 0xf43bf220, 0xfae4b436,
	0xfe61f3f2, 0x844750f3, 0x2cf2527e, 0x7e61ae9c, 0xad8ccf38, 0xb3f87bea,
	0x43eba876, 0x9cf5d49b, 0xaf3d7566, 0xbdb75d55, 0x21dfaea9, 0x84e055c6,
	0x3b9e3076, 0x1fce25d8, 0xe78c1da0, 0xc60ed087, 0x58c1da3a, 0xcf8c1da2,
	0x3ac60ed1, 0x4758c1da, 0xc99ad83b, 0xd12c60ed, 0x4fe7c60e, 0xed7e71e4,
	0x42fee06c, 0xc53b07d8, 0xbf2b67c7, 0x20f600ef, 0x8315a3ea, 0x5cc3af48,
	0xfa17ca6e, 0x8845b5e5, 0x1cc32347, 0xc18bcb3f, 0xf5b6a8bc, 0x283ed809,
	0x6f99c85f, 0xa19fa332, 0xeb17dd7d, 0x0d090d51, 0xf6c4ac73, 0x6b911e4a,
	0x3dfa51c5, 0xd655f6b9, 0xef88fd3f, 0xd83bf913, 0x4fd268c5, 0x7a3ef12a,
	0x4652fc99, 0x6f38fe46, 0x2fbf7f54, 0xf3f79c13, 0xd8fbe4ef, 0x47547455,
	0xaeadfff0, 0xfcf90127, 0x748dbba7, 0xe2a7eabf, 0x659b243c, 0x648efd54,
	0x71edbc5f, 0xcf26e289, 0xfbf245e7, 0xfe804e77, 0x553c8fdd, 0x46d705ca,
	0x595beeaa, 0xe0d249b0, 0x1cf44338, 0xccb4ec8e, 0xd8a6df7f, 0xb968f24e,
	0x16e66398, 0xd9fe6a8d, 0xfe15109e, 0x1915db0c, 0x03133bf4, 0xb787ed55,
	0xcefd04a4, 0xeff550c4, 0xeab3dc1f, 0xd3d7da30, 0xb5548d37, 0x3af482bb,
	0xff2ae50a, 0x92b2a55d, 0x05f2835b, 0xfc2d3cc5, 0x4f5d72d9, 0x7ed023c7,
	0x9204fef9, 0x4f206507, 0xef2251ec, 0x9260f806, 0x7c4f5ee4, 0xdfa241bb,
	0xe4205b3f, 0x96a15b0d, 0x1e5ae5bf, 0xe30b3b77, 0xdce83ea3, 0xb6e7471f,
	0xb72c7c15, 0x3e447b30, 0xe5b6d7e6, 0xf1591da1, 0xc402f6d6, 0x90dc972b,
	0xf08fbf84, 0x89d9e4a0, 0x442f3f07, 0x05bd8bee, 0xc7656bde, 0xe7d43cc9,
	0x393e8c4e, 0xb17ce006, 0x4373a649, 0x6c5f3a49, 0x7f8fd9be, 0x084b3a49,
	0x1d437fee, 0xfd06f7bf, 0x1fa47255, 0xa2ea1a3f, 0xfeccd242, 0x30f82b75,
	0xb41bef44, 0x8af5d71c, 0xd02af489, 0x5d3e49a3, 0xfe932139, 0x724e3e56,
	0xd62b9e93, 0x54779ca9, 0xd85673d6, 0x9d966c83, 0xf141ecf0, 0xe1f662fe,
	0xc3ac2b3c, 0x2492db59, 0x34d71f23, 0x20d04ced, 0x23ce385e, 0xa437955d,
	0xb2e7887f, 0x19903f2b, 0x567c5be6, 0x16fc213f, 0xeaf733d4, 0xfea0536c,
	0x3a76dd48, 0xf5a958df, 0x2d2ed1e8, 0xe740dddf, 0xf710ee58, 0x55da2d25,
	0x62f9764a, 0xccec84b6, 0xb81e4a73, 0x78f94780, 0xe605ab69, 0xf39c325d,
	0x5f7172d7, 0xde1f7284, 0xbefc5d95, 0xf64a7be7, 0xcac8efd1, 0xbd305da2,
	0xbd3bbef4, 0x4cfd0630, 0x5df6c95e, 0xf8673ce7, 0xa63e89b2, 0xf2a64b5f,
	0xc8c36b9e, 0x7f00faee, 0x45e50c8d, 0xfbbd904e, 0xe89fcf2e, 0xfe50d72d,
	0x17deb944, 0xa1f71d3d, 0x6f7e4b52, 0x98cfe017, 0xf07f9e7c, 0xc64b2843,
	0x0cdbcfaa, 0xaaaa189c, 0x740162cf, 0x89985304, 0xf501e0c9, 0xaaa4a67b,
	0x7bdee3e8, 0x43d10586, 0xc53dffbe, 0xcaa87e71, 0x74ad74db, 0x00fdf95b,
	0xa1cfd5e3, 0x7678495c, 0x177beaa7, 0x976fe69b, 0xb7a77fcc, 0x4daff094,
	0xb952f68f, 0xcf91e786, 0xe7887472, 0x161cf4ed, 0x21cba2a2, 0xb90fb6a9,
	0x7cf1d45c, 0x9ebfe15d, 0xf6a77f85, 0xa3611727, 0xfbf8b8c5, 0x707fe875,
	0xb68ef5a8, 0x970ebcc0, 0xb2b90bf0, 0xe5c85fb8, 0xbc63d36e, 0x4dafe00d,
	0xd7549004, 0xa0187bf1, 0x923131bd, 0x5fe657d7, 0xf61e4f7f, 0x9fdf0d77,
	0x5e914b90, 0x8b57df82, 0xd1aaf6fb, 0xf74e139f, 0x45fef38b, 0x067e0abf,
	0xf70489e7, 0xcadc3f53, 0xed76d2f3, 0xa6a87ba3, 0xda73f097, 0x7e54ef4e,
	0xcf083dee, 0x057f7e14, 0xb9e90cf0, 0x84a3ddf7, 0x5ae5bd67, 0xfddbcf1b,
	0xdb54786e, 0x18339fb9, 0x7ac116ff, 0xa2c87cf0, 0x91e6c966, 0x4b843b78,
	0xbf625e30, 0x4bc0fd89, 0xdc1f5381, 0x3e53de82, 0xfdfc28cd, 0xc26f7e1a,
	0xe0517075, 0xe45ffa28, 0xcefefc60, 0xf343c966, 0x8d8fea09, 0xe5bfa609,
	0xbbd43f94, 0xe9166255, 0x769870e6, 0x8651fb8d, 0xf775f2a4, 0xa86c97ec,
	0xa6bccf97, 0xf87de7a5, 0xd6e3c252, 0x55094cf7, 0xfe1f5bd1, 0x997a7094,
	0x9f962d71, 0xc65ffd13, 0x8fe19ba3, 0xf8511712, 0x566e9fb7, 0x767bff13,
	0x8e27f0b8, 0x0f89a366, 0x637a7e08, 0xe3cdd43d, 0xb3bf7d65, 0x09c9576a,
	0x5fa0b7f4, 0xfa0bd141, 0x0eb5afe0, 0xa94fbc08, 0x9e29e414, 0x07942f93,
	0x43affe51, 0x7e14f5f8, 0xadfd10ec, 0xcaaa9b5f, 0xd3ac7483, 0x69357f91,
	0xa5951455, 0x7b9d0b26, 0x97255d2c, 0x64fc1ca0, 0x18ec5c63, 0xd64fa3c0,
	0x40a7a2e9, 0x343c9f17, 0xa5ef092a, 0x215d64fd, 0x366e9f95, 0x77f40acc,
	0xe1e1e52b, 0xfd74df5c, 0x5f9223f2, 0x86ef3497, 0x5b3a42cf, 0xd31c3fb7,
	0xfdd6ab27, 0x7202c0b9, 0xd1c68f7b, 0x9be29c36, 0x99b7240d, 0xf50f21a5,
	0xa86f453e, 0x8718575c, 0xcff9ddf2, 0x7ca3cfa3, 0xc5d2ac77, 0xfce9ffa2,
	0x0aff3cfb, 0x0be916e4, 0x3d3dc4e7, 0x29431ae7, 0xe81cf6ef, 0xa9cf18b7,
	0x59e70f90, 0x75b47254, 0xb2ff8e26, 0xb3d71951, 0xb5c71e33, 0xc5bf29b9,
	0x407d2ab1, 0xa5117e7f, 0xf5c2d9ac, 0x1f8a9db8, 0x777bf857, 0x51947b89,
	0xfa73c75f, 0x1d63afa8, 0x512c75f5, 0xffe7c75f, 0xf7e1661c, 0xa1e9ad3c,
	0xf25005df, 0xfdffae13, 0x8be51b16, 0xb823f7b1, 0x17fb153c, 0xdfff9f3c,
	0x7a65bf7e, 0xfb556cf1, 0xaaa52519, 0xfd0ffff7, 0x00ad6dfe, 0x0000ad6d,
	0x00088b1f, 0x00000000, 0x5bedff00, 0xd554787b, 0x5e675fb5, 0xe4932499,
	0x18920424, 0x02424e12, 0x933c1251, 0x46110f17, 0xc0544248, 0x8c122f89,
	0x3c2484f1, 0xe290c124, 0x6bf5a377, 0x2d120306, 0x506f78d4, 0x54263eb4,
	0x4368b6a8, 0x6d2da545, 0xaac51047, 0x7eadb735, 0xa1c5b57e, 0x2c5ed45a,
	0xde8bd411, 0x5ad77b5e, 0x9ccc9cfb, 0xdaf6b849, 0x3fdef7af, 0x2b7e7e0e,
	0xf67d9f6b, 0xf6bd7b59, 0x67bdaf6f, 0x685afd79, 0xfbff0375, 0xa0dffe2b,
	0xd7f1306d, 0x5a05b9ad, 0xf5fc228b, 0xcf4c9b9d, 0x603b207d, 0x1ec1c02a,
	0xe00e2500, 0xa66e3d67, 0xd0b57b5f, 0x1f6315a3, 0x6000b7fa, 0xe75b22de,
	0x1bc22790, 0x01b54334, 0xf268044c, 0xa454d2fa, 0x2942c839, 0x01a41f53,
	0x8015554c, 0x086c800a, 0x801df449, 0xc97f2ce1, 0xcfb17ed8, 0x3a1e25e7,
	0xdf00c8a3, 0x3bd5a752, 0x759f90b2, 0xf22a6ca8, 0x08750c6f, 0x6743a2fe,
	0xf7dbaf88, 0x1cc77add, 0x57c2afe4, 0x878402e7, 0x2803eb52, 0xf905bce7,
	0x6c72d4db, 0xeea9cd7b, 0x1b72b186, 0x5adde694, 0x344de628, 0x3d3323d4,
	0xf4c993d4, 0x5a051ef9, 0xf42f009d, 0xda3d3114, 0x2ffb72a3, 0x7d33667a,
	0xf4c7c7a5, 0x4cb53d97, 0x4cfc7b87, 0xcf53d57f, 0x1a3d37f4, 0xcf46f7bf,
	0xf66fa61a, 0x6ffb7274, 0xfe99ba7b, 0xedc027ae, 0xf589540b, 0x54001288,
	0x3fa7ac02, 0xddeb7551, 0x267d909e, 0x79c07dfe, 0x31d86c32, 0x01f2401f,
	0x24dea374, 0x911a1d25, 0x384276f6, 0xc30f8ed1, 0x6813d48e, 0xbc73fa5f,
	0xc0141af9, 0xf18c2701, 0xf113f3b0, 0xfe54cbbe, 0x44f964fe, 0xd2bda462,
	0xa2aa5beb, 0x1f6ae0fd, 0x16e5d5cb, 0x453e7d72, 0x5fda92bb, 0xb0aabbcf,
	0x7b5dfb0c, 0x0a48f3b6, 0x06dd7a3e, 0x93f3c66b, 0xd827e4a9, 0x793bbe7f,
	0x34485c26, 0xaf380837, 0x2f708ef9, 0x9ffca3a4, 0x1e7b7280, 0x2e4973c0,
	0x474efe60, 0xe9790e30, 0xe2fe6063, 0xf7be6074, 0xe03b6193, 0x3565f3f8,
	0xf089efd3, 0xa4086e05, 0x49b909a4, 0xa8a202ce, 0xc38faaa7, 0xe0fd008b,
	0x894b8f62, 0x3b671543, 0x4a571020, 0xf8c379df, 0xd8b8d02e, 0xfbe173ee,
	0x21027e8f, 0x8395ca1b, 0x2fd9e2fd, 0x77ce8801, 0x18fddb0f, 0xddb1930f,
	0xb60e7c8d, 0x9f73c5db, 0xf1f0ec83, 0xe1ec3db0, 0x9e2290e7, 0x91696c07,
	0x267219ef, 0x52fc7039, 0x54b92fd1, 0xf9f8877c, 0x425790f2, 0x3c3b7b39,
	0x0321e92a, 0xb94abb9f, 0xefcecfbf, 0xd265790f, 0x0547bb43, 0x296a079c,
	0xfdca5090, 0xc7ec4e58, 0xac7d54f2, 0x65fa8f81, 0x8fa71a82, 0x03cf16e3,
	0xe9c5ce34, 0xe9072ca1, 0x06a5d3a3, 0x923e38c4, 0x8a25fa93, 0x547b217e,
	0x8a7c16dc, 0x9ca326f2, 0x9d79c369, 0xbb87f61e, 0xc27c4fd9, 0x8592ae1f,
	0xf3a2803f, 0xfe187fba, 0x4c2ca572, 0x76d155b2, 0xe3f8bf92, 0x6227dfe4,
	0x9a4aff9c, 0xbf45e85a, 0x3681b3a9, 0xf48ffc54, 0xffb09f17, 0x1bcf6c64,
	0x7d8637eb, 0xfc31ff0c, 0x0c8fd620, 0x6dec303f, 0x5feb17bc, 0xeb157eb1,
	0xc2ddf34f, 0xdbc764ce, 0x24feb1a5, 0xc8343c7d, 0xd5bbb7f2, 0x3fac6938,
	0xb9c1fac5, 0x73cc49fd, 0xec451fac, 0xeaf8fa4f, 0xc79c347e, 0x1ee8d8f3,
	0xff0c8fd7, 0xf0c9fc31, 0xa0461ba3, 0x351f0526, 0x205e559f, 0x9b4f3b3a,
	0x02d17e4a, 0xabb0d497, 0x7f12f6c8, 0x977ed8d2, 0x6389bf50, 0xcba801fb,
	0x51e7281d, 0xa17709c5, 0xa3c72f1c, 0x022250bf, 0xf68bc79f, 0xd1e7a45b,
	0xebc9d0a3, 0x3ff0041c, 0x4dd2af6c, 0xf578a8bc, 0x2aabf212, 0xe10ff38f,
	0xe6b175a8, 0xf4cdfe2f, 0x6c749add, 0x693f5a8f, 0x004984c5, 0x2ee3e997,
	0xb71e7e86, 0xdfb9b276, 0x23edb065, 0xb2f7ce3b, 0x59fb7302, 0xf39d2935,
	0x51e41e6b, 0x5502ad7e, 0x6cdb05c8, 0x4f1e972c, 0xa6ddbad9, 0x8798762a,
	0xcd06abfa, 0xf9fd4941, 0x247cbb3f, 0x300862ef, 0x9904297f, 0x1e210e5e,
	0x002e2967, 0xe0015fc4, 0x3dddbe24, 0x50c2eb92, 0xded76f5a, 0x30ff9196,
	0x429e9b47, 0x04b5e3fd, 0x70f3ea2f, 0x9bc6b2e2, 0xca8b7bf0, 0x7bd01516,
	0x0c94aa87, 0x90f1e319, 0xad0a6a7b, 0xce0f14ff, 0xbe5c48b4, 0x0162eb84,
	0x71875bae, 0x047a24dd, 0x5c02cdd7, 0x75c45ebf, 0x8acbf893, 0x57bd0136,
	0x88e048a3, 0xfef1b79a, 0x7022f2e5, 0xbaf7384c, 0x1fccf974, 0x6fd0d64d,
	0x5e9d4e5f, 0x6744c905, 0x5f7cd155, 0x09b0cd4e, 0x5a62e71a, 0x36816cf2,
	0x7e10de6e, 0x0d5ef917, 0x7a5cef7f, 0xab1af436, 0x5fcf434f, 0xe315af41,
	0x0aaa75e9, 0x769fbebc, 0x0b3eb53f, 0x1448ebdf, 0x6cf7cd79, 0xffa26412,
	0xe76d3d76, 0x8901f57c, 0x0be34598, 0x5f75b53d, 0x80328e04, 0x40207af7,
	0x3dd55e7a, 0xdea1db87, 0xdc3f2367, 0x37dfe468, 0x66fe612f, 0xdd8b87dd,
	0xe39262da, 0x1a686964, 0xef782b22, 0xb9e4dec1, 0x9f0f9df8, 0xf04babb4,
	0xd95dbb79, 0x2f0f22a6, 0xf4ddd5db, 0xe70e5ffe, 0xf4f1495e, 0x673e0e28,
	0xdddb5eac, 0x40148f42, 0x79658f34, 0x90478e7e, 0x1c4532cb, 0x149a3662,
	0x11932dc1, 0x7fd1ba43, 0x7a09741f, 0x99531c2e, 0x94a77980, 0x341e73fb,
	0x31ef87ec, 0x54e38d9f, 0xbec99e62, 0x8bd8213b, 0x7d9649fa, 0x8f097837,
	0xb7cf0154, 0x1da3b0cb, 0x9dfb069d, 0x9c7a174e, 0x9beed30f, 0x51d57c87,
	0xf9f10427, 0x7a780a69, 0x2905299e, 0x7a3e9d5f, 0xb6794ec6, 0x0982493a,
	0x79e84eb4, 0x06d32e23, 0x881e544a, 0x89401257, 0xa2c4e3f2, 0xa49f1334,
	0x9fea679e, 0xf4df3b32, 0x8177d53c, 0xda84f9e9, 0xd13f1352, 0x3fd4d73f,
	0x89a17ea3, 0x332ed2cf, 0x735ecff5, 0xf23789a5, 0x8268b651, 0xa615ce9c,
	0xaf74a7f7, 0x0bcff534, 0x6e7a68dc, 0xc5de484f, 0x1be032f9, 0x6a71c22e,
	0xf6a671f5, 0x01fa9975, 0x4956dbaa, 0x7dfe2271, 0xa8f6b93b, 0xf5acf684,
	0x71425aac, 0xab7fd85a, 0x12fb4e59, 0xc5d22a47, 0x55ff398a, 0x45f99a67,
	0x1c24e79e, 0xe6c9161a, 0xe9dd9bfc, 0x788ff130, 0x1339bcf5, 0xfcde5266,
	0x176bfb52, 0xab1fec98, 0x3507f427, 0x1d71fd44, 0x2f5c900d, 0x9d6838b5,
	0x6cd3be9f, 0x6683f3ff, 0xcc78cffb, 0x2192ff6c, 0x3c2ffdb3, 0x37bfb660,
	0xd97fb664, 0x2bfdb351, 0x9ff6cd86, 0xfed9a6f5, 0xcb9e5f86, 0x66c2734e,
	0xd24d00ff, 0x4ec6ffa4, 0xf66fbd17, 0x2cfb589f, 0x9a937840, 0xd490f64e,
	0xedd5f290, 0x6bd93af5, 0x685ec446, 0xf48d809f, 0xd849393d, 0x85233427,
	0xd47d55ec, 0x1fe4410e, 0x4be7998a, 0xca6ded0e, 0xa52a2f5f, 0x16bf9499,
	0x3cf77280, 0xdda6ab94, 0xd87086a6, 0xf0fe31e3, 0x5ded2c9b, 0x13f50bca,
	0xc8bae4ce, 0xe9b4463f, 0x534c8fb4, 0x94c9f381, 0x607e3104, 0x049fb021,
	0x7b07b56e, 0xb663dc71, 0xf3f2897e, 0x24ed64d6, 0xe286ef7d, 0xf61f9e4e,
	0xa6fde890, 0x12e5c79f, 0x780534df, 0xe1c50bff, 0x48a4ba8a, 0xc6ca6c5e,
	0x3e875c76, 0x37fbeaf6, 0x7be39f15, 0xfb15eeff, 0x765524e2, 0x2e6cce11,
	0xfb105f06, 0xb72bb6e1, 0xf1f484a9, 0xd274fc4a, 0xc54d80c7, 0xa7610714,
	0x28f94292, 0x761d92f0, 0x120f024b, 0x71d1cb8e, 0xdc8c3655, 0xdf4e724f,
	0xf575a609, 0x1c1ba0fc, 0xf19f7a51, 0x4be26c98, 0xfd4d3286, 0x98a03c2f,
	0x45437b9e, 0x4765e7a6, 0x315f1355, 0x7fd4db3c, 0x133e9bd6, 0x6b5c273f,
	0xfbd17fea, 0x453f137e, 0x99fafb12, 0x3f42f9a5, 0xce22060a, 0xea6b69b3,
	0x6335e120, 0x69e06fbf, 0xe7cfbfe8, 0x74d6ff46, 0xb8f035ff, 0xa85d9f81,
	0xab9fb240, 0xc1ebc1cf, 0xc7c0b764, 0xe3ee6dda, 0xa7047252, 0xc0da781b,
	0xf6a810a5, 0xf83baf45, 0x745f589e, 0x66e06f3c, 0x503f0f03, 0x38dfb0ac,
	0x4abae337, 0x6708e0fe, 0x14d73ad1, 0x41d6e307, 0xfd8a94e6, 0x86fcac4a,
	0x7fdfb15c, 0xfd1658a0, 0xbb7771f5, 0x38ff06e1, 0x54a6a678, 0xf3b7d5f8,
	0xb14a0bfd, 0xf54ec3ff, 0xff79d5cd, 0x26f4eff3, 0x78459a7d, 0x2142e9a9,
	0x76cda37f, 0x1e6a3f83, 0xbf85cbb3, 0x42c9741a, 0x805e3bc4, 0xdaffbe2f,
	0x23c41e7d, 0xb83b770f, 0xe94572be, 0x02810d05, 0xa3e043c2, 0xbe20a671,
	0xa610fb27, 0x4bc17da0, 0xefc00c54, 0x9cb644dd, 0xc5979d18, 0x0834ec7e,
	0x76ee9ffb, 0xcce30305, 0x6303f0c3, 0x67107b3e, 0x3cf7103a, 0xe8933886,
	0x3a6710f7, 0x45ee6710, 0x93fc4a1c, 0xa1d30a3d, 0xff6e229e, 0xfcca8f61,
	0xccd99efe, 0x63e3d33f, 0x2d4f40fe, 0xf8f71fd3, 0x9bf0ddb9, 0xfb197d58,
	0x14fec32c, 0x146eb486, 0x92e3f8c4, 0x94bd85db, 0x2eff4e0d, 0x1b12e29c,
	0x11a54ad4, 0x4cbefe7d, 0xf49071e8, 0x51fa2150, 0x5fab9ffc, 0x2538bdb5,
	0x51fa4c5c, 0xfc71e452, 0x28ffa0c0, 0x1f7a187d, 0xc68e8fdd, 0x7387889b,
	0x6fb1a5c5, 0x72a7da8e, 0x63c6c5dc, 0xeac6dc6c, 0xed45ff9d, 0xb3f747b7,
	0x8f451d46, 0x462ec353, 0xdc213b5c, 0x5825f940, 0xfd25ab60, 0xc7324d6e,
	0x42a5abd1, 0x71eb37bf, 0x27915c74, 0xbf11ecd9, 0x7881db6c, 0xdfbd1f01,
	0x45cc9f5d, 0x1bee00b3, 0xdf39e6a3, 0x17349fe7, 0x701cadfb, 0xf342a0c2,
	0x68ebc35a, 0xfebcc073, 0x78c382e1, 0x249b75b2, 0x6bf3803f, 0xee7d8be9,
	0x1ab1fc63, 0x2b420738, 0xbb922e68, 0x6fdcdfad, 0x5c6fbeb5, 0xfedcd3bd,
	0x3d7d52f3, 0xfc654155, 0x7de6edd3, 0xcfbd1acc, 0xa704ffa8, 0x0d75e8a6,
	0xa1a4478e, 0x9bfda8b8, 0x2e5f13b2, 0xb7a8f08b, 0x0f5a2284, 0x42d43b37,
	0x19bfac65, 0x4775237a, 0xb8a6ffd7, 0xa56f8e46, 0xf133eafa, 0xefc07fbc,
	0x3cfa415f, 0x512ed479, 0x9bbd439c, 0xfbd346e3, 0xc1d80c9f, 0xb939fa8e,
	0x75482e3f, 0xaf6d0f87, 0xfa4f9b5c, 0x5f687924, 0xff1e6b51, 0x679203b4,
	0x3bd89e53, 0x238c0d51, 0xb0b54197, 0xcf9cff78, 0x4c9d3d37, 0x27f6c9fb,
	0xed7f1cec, 0x549e1c4f, 0xfef79510, 0xf9e0ea58, 0x9da6cf7d, 0x61da452c,
	0xfda5cc1f, 0x079f8ddc, 0xa25d1267, 0xe7624dd7, 0xe6d79a33, 0xa73fec49,
	0xd79c7e71, 0x1f9e256a, 0x78a045e6, 0x75701d7a, 0x20ea71c3, 0xe2944e94,
	0xd7c17017, 0x1db0e6fa, 0x6f898e28, 0x79e1cd0e, 0xdabbd35c, 0xc25d8099,
	0x9d56dff7, 0x86f888a0, 0x40e7c8e9, 0x8a0ce13d, 0x714fea73, 0x9ce2944e,
	0xd6755f9e, 0x7d5de3cb, 0x271e22f6, 0xe78f2cb1, 0xf6f36535, 0x2eff840d,
	0xa49c0c78, 0x8c53b087, 0xafa7ab13, 0x676879eb, 0x776f3999, 0x6f38926d,
	0x4d5ad177, 0xf38976fc, 0xe99fc1b6, 0xc16af9d7, 0xe08b6d7f, 0x9f4f4ec3,
	0x4be62294, 0x279a0175, 0xed0f9a51, 0x75eaf763, 0x51079a04, 0x53b5079a,
	0xf29e22be, 0xaf94f115, 0x457ca788, 0xb515f294, 0x2e7f04af, 0x1e2f0fd5,
	0x151f8c41, 0xbace0b27, 0x7f0a2aa1, 0x26a9025c, 0xcb3b917e, 0xce5abfd4,
	0x9c5f3d33, 0xf9e9be79, 0xc4d78aa5, 0xc7345e5f, 0x7aa97fd4, 0x62bf8989,
	0xfea6a5f6, 0x133abe75, 0x836d557f, 0xfe35ffa9, 0xe5f3d366, 0xcf4d6bf5,
	0x9a273ce9, 0xe89cf3a7, 0x139e74fe, 0x6e86fcfd, 0x73de74c9, 0xf269a603,
	0x139d96bb, 0x153a3fd8, 0xe6196d7f, 0xbf13b7cf, 0x4f99d9b8, 0x96b83e76,
	0x23abb6fc, 0xee761541, 0xb77615af, 0x48f3b081, 0x36f9db03, 0xd5abe097,
	0xfc1c790c, 0x5528e743, 0x428e714e, 0x8851ce94, 0x510a39d2, 0x2aa9473a,
	0x4428e714, 0xda851ce9, 0x28851ce9, 0xa510a39d, 0x74a21473, 0xce94428e,
	0x39d28851, 0xe747bd0a, 0x1ce94428, 0x1ce9da85, 0xa39d2885, 0x9431fb50,
	0x0c53ce83, 0x172f08b9, 0xe873f698, 0x9cfda687, 0x2f09e26c, 0xbc27f747,
	0xf09cfd1c, 0xc273f472, 0xe13cd1cb, 0x84fee8e5, 0x3bf9a397, 0x2f8e154b,
	0xefd1cdc2, 0xe68e6e11, 0x4703fa4b, 0xf4b416a8, 0x4f3f3fc1, 0x3d249c34,
	0xfef8c92c, 0x3a06a153, 0x4bc70aff, 0xae2aa9b9, 0x0d0bd27f, 0x676bc855,
	0x67ee38cb, 0xec8d88c2, 0xb25f61ad, 0xe082169b, 0x92d58c2e, 0xf9f8b2cf,
	0x03643317, 0xf2be70d7, 0xe1c607ee, 0xb850cc5f, 0x055f78dd, 0xe8d44ed9,
	0xefc7e11f, 0xa37dfb17, 0x28cbe71f, 0xf49d7039, 0xb7bbe9ba, 0x42ef4a79,
	0x9363da7f, 0x41ee8718, 0x38e5753c, 0x7aa7e979, 0xdb63da5e, 0xdf012877,
	0xd496691b, 0x34f4385d, 0x96751c07, 0x4b3a9e92, 0x2eec2f09, 0xd5e7d54b,
	0x92caf739, 0xdd46dc88, 0x2f84f30e, 0x2382e748, 0xefc56ae0, 0xb831fc5c,
	0xb9b708da, 0xf7a05e04, 0x2336df68, 0x4576f920, 0xca0ff7f9, 0x05a7fac4,
	0xc56dcc36, 0x3b7b19f6, 0x8e11b6e7, 0x7def104b, 0xd66491f7, 0xd2cdb2e3,
	0x67ce3b2e, 0x0df05ede, 0xba03bf62, 0xcaf633dc, 0xaefe56ae, 0x9a8b6aec,
	0xb983f35f, 0x85f6852e, 0xfaa2ae10, 0xb04b941f, 0xc37a221b, 0xf34f3df9,
	0x42a1869b, 0x8f75d7f5, 0x1bbff7c5, 0x431d47e5, 0xa6fe26a9, 0xeffd5903,
	0x3acff946, 0x0e4d03fa, 0xdd690308, 0xbe4dd76a, 0xd8f76f5e, 0x7af0b7fc,
	0x91711ee7, 0x4f2e2efe, 0xf5a74ead, 0x85a820fc, 0xcde577e4, 0x5ca2265b,
	0xdaa7d05a, 0xe757d215, 0xf51fe611, 0x53eecf33, 0x7af1f2c9, 0x85203d38,
	0xcb155112, 0x74b68302, 0x360697e4, 0xff512739, 0x1c12a0bd, 0xe60a25c0,
	0x55e64697, 0x78b6c30c, 0x0e05fc89, 0x3ff2884f, 0x93571ccc, 0x275578bf,
	0x39d47f90, 0x9be52764, 0x8a31bc58, 0xd7d06447, 0x9ce5e2e3, 0x1d3a8ea7,
	0xf81b1eb4, 0xb21659a8, 0x64ecd99e, 0x34fcd1fc, 0x1e7a0fe2, 0x119a3783,
	0x18132887, 0x5a21a877, 0xce5ff7c7, 0x0df6a175, 0xa8ca57af, 0x05e53f9f,
	0x5fa2a4f7, 0xdf7f29ff, 0x08f3b3b5, 0x4f9c48b7, 0x299c3711, 0x6f363d43,
	0xfb4c9239, 0x29e070ab, 0x36671bc6, 0x751648ef, 0xd10e7104, 0xa8c9ebaa,
	0xf6e9b4cf, 0x893c2568, 0xe603f84a, 0x5e74df2d, 0x74b64377, 0x45719796,
	0x90043e2c, 0xc83aa0df, 0x5dcf9c1a, 0xd6deadc8, 0x8c26477c, 0xde068bc5,
	0x777fa75c, 0xb36766ed, 0x0f7c42eb, 0xac1ebc82, 0xaffb9a0d, 0xbae771d3,
	0xc9edccc7, 0x53b831e5, 0x4d7d0fdf, 0xeafcd3ef, 0xf7186be1, 0x7cf93a74,
	0xc09371ad, 0x820fb041, 0x8bf11285, 0x37c8f16c, 0xa553ed3e, 0x35e6fc71,
	0x092d0f1d, 0xeb3eb3c7, 0x1e7226ce, 0x366cf2b9, 0xcd9ed7f3, 0xecfcba62,
	0x6a9da2f9, 0x70e76830, 0xf3a414b5, 0x38eb5fb3, 0x33b39ae8, 0x40e9f9f8,
	0x69f1fb06, 0xc4fa63f4, 0x5d3f3d4c, 0x130e93e0, 0xd4e25ccc, 0xe7c44cb6,
	0x7181064b, 0x4bc252e5, 0xe13d7e38, 0x071409a7, 0x3e34d579, 0x30a0d2ee,
	0x8360e28f, 0x0718f7ee, 0xc7c379c0, 0x2eaaacf9, 0xd7efc768, 0x646cfb6b,
	0xb5ffc36f, 0xf10771c0, 0x4b92034b, 0x047de629, 0xff0d93ef, 0xa6838d8e,
	0xe4aebd44, 0xd1a37511, 0x8b0912ba, 0x28086dfb, 0x6fb47c2b, 0x79dfdaa7,
	0xf75161ba, 0x79e2c549, 0xc5657eed, 0x5f9ac466, 0x68d0eeb5, 0x46bdb1b3,
	0xa2ede710, 0xeae18540, 0x6d938a0c, 0x4a5de952, 0x95299e44, 0x262abb0b,
	0x52bfec46, 0xbb8c2b8f, 0x7477da0c, 0x019859dd, 0x8302e0e3, 0x299ea0b6,
	0xc2529abe, 0x99684b37, 0x55f072ce, 0x037c46cd, 0xe2e93cfa, 0x42b9ca03,
	0xbfde1fe7, 0x1e7db7f4, 0xedf30fd6, 0x08ae17e5, 0x791dff14, 0xca648970,
	0x769b1e83, 0xe5057963, 0xd90d70bf, 0xc478b135, 0xd58b7645, 0x86dbf5cf,
	0x3d474fb6, 0x70ae5c3c, 0xf5746f3e, 0x089f793b, 0xadd52741, 0xbac58a5a,
	0xf7250e02, 0x51073e3a, 0xcc67beb8, 0xb7840ffb, 0xbdcbd1c7, 0x445ea2e5,
	0x2e9958f8, 0xc25131f0, 0x86ff74c7, 0x84f131f0, 0x3e12898f, 0xc7c276a6,
	0x263e13c4, 0xf131f09e, 0x12898f84, 0x7bf6a63e, 0x5be3be6d, 0xd80f9ed1,
	0x459efb82, 0xae9ddd3f, 0xfca395f5, 0xb8bf400f, 0xcf1a021c, 0xf386fd0f,
	0x427e68c4, 0x465772ff, 0xf76568fc, 0xf2db4f3b, 0xdad4fe23, 0xbbfdd1f7,
	0x22563fd1, 0xd678a41e, 0xdc50a4fa, 0xd9fb73cc, 0x70263723, 0xab723cbc,
	0xa36ef38b, 0x3b88f86b, 0xb7cfa22f, 0x29d9ffba, 0x50a864f2, 0x745771c1,
	0xf794abc6, 0x1ffa54a7, 0x8b137922, 0x174bb655, 0xdfff04d9, 0x520dac9d,
	0x7e184afb, 0x35fb1321, 0x5cd5fd7d, 0xc1d37e7a, 0xdfe5173c, 0x3bde03e6,
	0x5f7a1532, 0x6df643db, 0xc22ec8f6, 0xa737eb17, 0x94db7af2, 0xe8b5ea21,
	0x65de7cf1, 0xb867e3d8, 0x9df8d2fe, 0xeb927738, 0x424fbe94, 0x4ceb3905,
	0xf3afc6fd, 0xd8c3f519, 0x8ea455fa, 0x3e5f68f2, 0x41d23fd5, 0xeac655ed,
	0x09ceb46b, 0x5b127ea2, 0x578d18e7, 0xf8e32bc2, 0x7d72a9d3, 0x53efae9f,
	0xa9f746db, 0x841935c5, 0x6491efe7, 0x7ab733aa, 0x9073e594, 0x84ea3d6f,
	0xd22c29db, 0xf2165714, 0xf24a7723, 0x46f7b22e, 0x46ade72f, 0xa3ce09b2,
	0x8e1ce775, 0xd220d6db, 0xf7c773b2, 0xce1cf775, 0x2bcd11f9, 0x9c9173e4,
	0x274e32ad, 0xf4b4ef0a, 0xb1271c4b, 0xa2e5dbfc, 0xdb88d85e, 0xf5dfd207,
	0x2b5cf31b, 0xb0893ea9, 0xe698aba7, 0x78c4fc25, 0x7df1fb0f, 0xf0f92587,
	0x08d5f902, 0x16f28bce, 0x6a34af7d, 0x7e3495fc, 0x3fb1f7d4, 0xca0fb5e3,
	0x66bdfc9d, 0x479de719, 0x51396654, 0x91a7ac0f, 0xc29e38ed, 0xb7bd61df,
	0x954e8284, 0x167ba1e4, 0x8390afc8, 0xcacefa4e, 0xebae5ecd, 0x77c4db6b,
	0x5754beb4, 0x8739e109, 0xc689caec, 0xe477e879, 0xa9b48d97, 0x1979674f,
	0x9ea2b707, 0xa67f08d2, 0x8cf5ee21, 0x2eb357d5, 0xaa7f6b7f, 0xdff63719,
	0x34fb24e3, 0xac4aebe8, 0x842a721d, 0x7cdcac1f, 0x7de80b89, 0x92a5cf87,
	0xffbeba7c, 0x2efe21b8, 0x1869073a, 0x4799cfb8, 0x842a91f7, 0x0854e73f,
	0x0fc92f3d, 0x8ebdd215, 0x2af10d91, 0xf720d9c9, 0xf5477cf3, 0x43f503bd,
	0xb3f644b8, 0x024fd1be, 0x75af7f74, 0x88df6cc0, 0x6e3c493c, 0xc73340eb,
	0xe6872adf, 0xd8e5a392, 0x84a15cf9, 0xb8c0697a, 0x91fd6897, 0x9ff25cb5,
	0xe7963b13, 0x4e513cf2, 0x2aa537be, 0xece59935, 0x86d7ec37, 0x899534ff,
	0x57be3678, 0xf9e0e15e, 0xb57c5794, 0xd6dd6d38, 0x5a5ef7cc, 0xa4954132,
	0x23538f2f, 0x6d788d3e, 0x2d91ebd0, 0x8b40eadb, 0x7eb837ca, 0x1c70fe77,
	0x885574fd, 0xdd0ac27d, 0xe7cfa89e, 0xd75eaa21, 0x31b3dba8, 0x34f71cdf,
	0x697b8d1e, 0x8d5bc885, 0x1b85430b, 0x8dfd238a, 0x89a636ef, 0xc9ffc8f7,
	0xf5d52ecf, 0xb8bbfd42, 0x3794cdbf, 0xc6f3465a, 0x28932dde, 0xf893ec6f,
	0xbb6baa7c, 0x4f5d75c0, 0xeb7d7124, 0xfd9ebadf, 0xefd8b5e5, 0x360ef74f,
	0xb90d7cd1, 0x4f22435a, 0xa29e21b4, 0x5f4ab1bc, 0xd62ddff7, 0xa22a2bea,
	0x13cbfdfa, 0x562e28d3, 0xfc4f790c, 0x21de7816, 0x7bbf37ca, 0xcfaf27e2,
	0xabeb2255, 0x7d958f31, 0xf66ceaff, 0xcc4deb44, 0x95a2aef3, 0xf6172be0,
	0xcb57fda2, 0x17cf8966, 0xf8c5dba0, 0xac77b0d3, 0xfc63341f, 0x7e2278b6,
	0x5cffd860, 0xb3b0c9b8, 0xdec37f61, 0xf6181f86, 0xb404ec36, 0x7ee146ce,
	0xebafee43, 0xfdd0af72, 0xdc7a1bf7, 0xe79358ad, 0x9ef1c55a, 0xbf216ae7,
	0xb4379fd7, 0xed47db9a, 0xf7e68f24, 0x4e2e283b, 0x9d3b090f, 0x7514e6de,
	0xec63bdc8, 0xbeeb4b94, 0xbd6ac721, 0xd7a6d8de, 0x38e9570d, 0xbdb4ed18,
	0xaedf2a22, 0xa9d8447e, 0x7f57c9e5, 0xe78563ff, 0xf6d8f227, 0x2b8bc638,
	0xbdb1f687, 0x71eefa1a, 0x87bf61e6, 0xf94cf22a, 0x2bd3a5ba, 0x457cbd53,
	0xe293a0df, 0xa10aa1ff, 0x6f7f58b7, 0x1b01efd4, 0x47f5a57a, 0x8cf75a8a,
	0xf6f794fe, 0x6e3677e1, 0xfba64f88, 0x5e77c633, 0xa5b8fdd0, 0xbe8d3533,
	0xfcd9d2d7, 0x1957da2d, 0xee363f79, 0xf11789de, 0xa3c712b0, 0x12e77cb8,
	0x21e39735, 0xa0cc5ce6, 0xf6edd53f, 0xdd2f546d, 0x1c4ec957, 0x90f49c7a,
	0x4a82537d, 0x0505c8e7, 0x977d20e1, 0x76e498fc, 0x7ba45e61, 0xe1ed052f,
	0x028e488f, 0x885cf710, 0x7389a526, 0xefc8498e, 0x2367b142, 0xfa0bb7cd,
	0x7c1fae8e, 0x90e7a21e, 0xf9a0ae1e, 0x73ade6c7, 0x3fc30ae1, 0xf362718d,
	0xf7e6b9d4, 0xbf38dfd6, 0x7af4f277, 0xeb9a9149, 0xdd36efc6, 0xfaa55d3d,
	0xd3cd97d1, 0x95ce2095, 0xce8be746, 0x9c6d3b3a, 0x7d8816f9, 0x3be7b9d0,
	0x9c693d50, 0xef398ef9, 0xb8c4e3d5, 0x3e7a3eeb, 0x47ce2fd2, 0xdd7091de,
	0x886f7d22, 0xc6657be7, 0xbcfa8cbc, 0xea379751, 0xbbaae7ef, 0x4d22b5ff,
	0x93845baf, 0x26364f08, 0x121ff1e8, 0x45d7b53c, 0xfdeb1bb5, 0x949c3931,
	0xdf9f9516, 0x43d7d4ed, 0x78a76f08, 0x40a9ee86, 0xfd638e75, 0x8ad924ef,
	0x7c853fc9, 0x9d1b7bc6, 0xca6eb1ea, 0xf8e25b73, 0xa6e23b7e, 0xd48ea83b,
	0xfae54816, 0x65ddf5cc, 0x38e27627, 0x56ce6fd7, 0x38ebd719, 0xff9e957f,
	0xdf363712, 0xeffa8b31, 0xc70993cc, 0x2efc79b7, 0x0e25bfaa, 0x19f2b9d4,
	0x807d8af7, 0x51b55e71, 0xdfc53f02, 0x148fca6a, 0x0ae7b657, 0xbd59bd68,
	0x25ffe053, 0x73a3e836, 0xfebd29cd, 0x0fca2c9a, 0xe12a4bf7, 0xf3107849,
	0xc31fb1a8, 0xe251d1dc, 0x7d24aacf, 0x0efd05fd, 0xd680bfc7, 0x67cd3b58,
	0x4efb47c8, 0xf3417c40, 0x2f487921, 0xf1f9ebf7, 0x24f1c0d8, 0xcfa238a5,
	0x78d02e29, 0x07531cdf, 0x192a72ea, 0xcc6fd4a9, 0x92929279, 0x8d3f951a,
	0xaa36b373, 0x7f9194fb, 0xff224e34, 0xc7cfd568, 0xc45818ee, 0x55e0db7c,
	0x2e5fc893, 0x65313922, 0x7d53deb6, 0x33fd006f, 0x6b47d757, 0x8465a2c7,
	0x8aecd68b, 0x4d7da54b, 0x1b9033ae, 0x075b438d, 0xf602e6b7, 0xbe307f7f,
	0x9579f29e, 0xf745575c, 0x983d566b, 0xad47b5ea, 0x452b8b0b, 0xb1d8ddfc,
	0x71ea8328, 0x7e1c5fed, 0xda9fce98, 0xc7194c70, 0x912864ff, 0xf7b5adef,
	0xdbb5c81c, 0x2da2fea8, 0xb3ae3d24, 0x0e76bc1d, 0xb82977e5, 0x2bfb8b27,
	0x0de7d6e3, 0xfc47a27a, 0x1be3a3ce, 0x1f38f26f, 0xd6595eda, 0x77b7ef80,
	0xe34c953c, 0xebf1dbac, 0x75c6d94a, 0x139565ad, 0x3dc1dc69, 0x7717ed32,
	0xf5a4ce0e, 0x61476db8, 0x2ef778ca, 0x3fc9afc9, 0x4c901cd7, 0x07d78be7,
	0x6a871853, 0xb9d17021, 0xe30326b6, 0xd0edf7dc, 0x81baeb4d, 0x4d768c4b,
	0x29fbc3d7, 0xff64b9fd, 0xcbee7bb5, 0x83e375a5, 0xee37c124, 0xca0bfe59,
	0x71a3da43, 0x803b7f02, 0x404b6df1, 0x993865e0, 0x30fbf62e, 0xfd09a134,
	0x44cac6e4, 0xceed6f1e, 0x2139d332, 0xdb8e0be2, 0x4b501c0f, 0x1de94c72,
	0xbf3f92f1, 0x91b508e5, 0x3c42df3d, 0x8b1de74a, 0xbdff852b, 0xe1af6fd5,
	0x0818437b, 0xeade2b84, 0xce892a7f, 0x561c0d11, 0xcf9dff6d, 0x69e9784e,
	0x70eb4bc9, 0xef30f162, 0x97af4063, 0xbf8597ac, 0x59c8fd75, 0xb8ce9d93,
	0x1dda5b8a, 0xf678d721, 0x4dc751ba, 0x7dfefca3, 0xdf6b2fbc, 0xfb41702b,
	0x05c671d0, 0xd0e8ce06, 0xdedd74e3, 0x8c138ce3, 0x17efd6f7, 0x2fd8e97a,
	0x6c8b9bda, 0x27c5bd46, 0x597ed015, 0xe5fbfe62, 0xe4dbaf8b, 0xae6be688,
	0x544054db, 0x31d0f816, 0xaefcb8c2, 0x7ef15fa2, 0x3eb363a6, 0xa8cef22e,
	0x4e4dddef, 0xa7da2153, 0xc57de87a, 0xf63a0784, 0xa850fd8b, 0xef8fa123,
	0x38f7aebf, 0x7876f688, 0xb07f3d78, 0xf74456d3, 0x02527dd3, 0xfa83b9e3,
	0x4087adbd, 0xa05ad3dc, 0x9adacfdf, 0xff22edac, 0x492184cf, 0x124233d4,
	0xa7ea77c9, 0xf8d195ef, 0x4fc2e3f3, 0xf1f00551, 0xa3afebca, 0x29f992f3,
	0xf8d232e1, 0x10accfe3, 0x29f8467c, 0x81c943aa, 0x9aabafab, 0x95d477f3,
	0xd20e49e6, 0x579ebb7f, 0x69ed363d, 0xece3ab92, 0x6ba89749, 0x6e28b88c,
	0x847e4c7e, 0xe10f13ed, 0x51f6923e, 0x1f78799f, 0xd3a13198, 0x8a03b84b,
	0xefd465c3, 0xf743bd20, 0x084f3ec0, 0x28303dd2, 0xeede71f0, 0xa03fd78a,
	0xa7ded8f8, 0xfa425975, 0x33e06c39, 0xe937705b, 0x277d0a4b, 0xaa7de71a,
	0x4e3f93c7, 0x215ec79c, 0x807e7339, 0xb4572caf, 0xfe9c905f, 0x77897b7c,
	0x1587dd2a, 0xe94fbdf7, 0x5e06b6e7, 0x367fa85e, 0xb9e7df47, 0x50f4cbce,
	0x12f719fc, 0xba0f9f25, 0x5edfef31, 0xe485a87c, 0x9b88e6fe, 0x70b0f77f,
	0xabec4124, 0xf5e5abce, 0x973e37b5, 0x38a483f1, 0x1ffb11a0, 0xe885b62a,
	0xc137fede, 0xe0cbe7cd, 0xb6dbc18e, 0x2d7fbe78, 0x33f17c1d, 0xedb26f5a,
	0xc14e1d1f, 0x93ff6679, 0x9f62f6a4, 0x1e27d3a6, 0xe3690d7a, 0x68fb5dd9,
	0xd64cbf3e, 0x1cf9a5de, 0x5c7b5d3b, 0x537f5543, 0x62ab721e, 0x79e8831d,
	0xb3e5bc1c, 0x445b34e4, 0x272353be, 0x9cb6789e, 0xd3eb9ba8, 0x45da0f0b,
	0x9e462b3d, 0xdf0a9953, 0x6c7ec703, 0x5b1e539f, 0x0b87f690, 0x937e1e0f,
	0xf7485be4, 0xe0df699b, 0x5e8c9e76, 0x49c940ef, 0xb939faa5, 0x23b35fe8,
	0x7d26e0f9, 0xabd49a5d, 0xad1176bc, 0x81d92f97, 0x51680eea, 0x7cd883f6,
	0x25c26bf0, 0x59a43788, 0xe5b6e702, 0x5c59a5f9, 0x90e60ca7, 0x8fb3cfdf,
	0x7f2d2f7f, 0x1a1fd896, 0x5bb58d76, 0x7d0c5dac, 0x23e1b2c3, 0xb9eb1229,
	0x5fa16ee4, 0xec77be99, 0x60b657b3, 0xff79c298, 0xf9eb1971, 0xbf7e9bff,
	0xf7e29e7c, 0xbcf3a372, 0x6799e715, 0xacc9679a, 0xf32bff89, 0x37f03ce4,
	0x3cd873cf, 0xa1bd49cf, 0x37e4e9f8, 0xb38c6c3b, 0x428bef62, 0x6d1e7011,
	0x3d7027b2, 0xbf104b55, 0x9182c837, 0x33e43623, 0x7379c020, 0x84b86d4a,
	0x8031c6f0, 0xb0ae4987, 0xf6d3e44d, 0x67ecf959, 0x8b386193, 0x08e1377f,
	0xb59e1057, 0xf453bfbb, 0x034bae2e, 0x3df70677, 0xdee0e38b, 0xca01e660,
	0xf8136b57, 0xd054ee5c, 0x77e27016, 0x5e455206, 0xc698681a, 0x4214e5b8,
	0x53ca6ea3, 0x578c09f5, 0xdbc35207, 0x42f3d167, 0xff200d45, 0x69f617cc,
	0x753e693b, 0x1ddf3e6e, 0x383c8af0, 0xef9f36b0, 0xc8c4fc93, 0x3893db73,
	0x05d40dcf, 0xe7e78f1f, 0x464cd1e7, 0xd0607dfd, 0xb5754597, 0x2adac909,
	0x7679e3b2, 0xe40f3eb1, 0x7bd23b61, 0x1b437f25, 0x61e2538d, 0x090dc379,
	0xa1c1ee4f, 0x95300be3, 0xeeb1fb62, 0x35c73e24, 0xd8ea33c6, 0xefc70253,
	0x16053d27, 0x0efd1142, 0xcfdd6dee, 0x3e4bbd0c, 0x74cc7bf1, 0x1d86cf5d,
	0x4f4b7f0c, 0x935fbf10, 0x377e136e, 0x3d790f7a, 0xc9e43df0, 0x2efd0a28,
	0x554e29ae, 0x29cddf48, 0xde2837da, 0x7da0377a, 0x610f34ec, 0xfbf46387,
	0xd7f071ca, 0x005e7a9d, 0x4d1877fd, 0x934bf220, 0x6e8bbbf1, 0x202eeff3,
	0xee95393c, 0x2d3fb34f, 0xfe2e7ba0, 0xae4f9c6d, 0xd2faf1f6, 0x2bdefba4,
	0xf71f69ff, 0x3d0ed0be, 0xd7882caf, 0xfd3df806, 0x0e0627f7, 0x5efbc57f,
	0xc727ad0e, 0x3271796e, 0xfec919d1, 0xf71ec8fb, 0x435a7c36, 0x59dbdc4b,
	0xcd1dfe61, 0xe79f0ddb, 0xb6fe5d70, 0xffffd917, 0x390d7956, 0xc91f7ae8,
	0x5a8b5161, 0xb516a2d4, 0x6a2d45a8, 0xd45a8b51, 0xa8b516a2, 0x516a2d45,
	0xa2d45a8b, 0x45a8b516, 0x8b516a2d, 0x16a2d45a, 0x2d45a8b5, 0x5a8b516a,
	0xb516a2d4, 0x6a2d45a8, 0xd45a8b51, 0xa8b516a2, 0x516a2d45, 0xa2d45a8b,
	0x45a8b516, 0x8b516a2d, 0x16a2d45a, 0x2d45a8b5, 0xfe8b516a, 0x02ffd05f,
	0x893d542b, 0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41,
	0x0bb10008, 0xdfe64892, 0x7ed084da, 0x5abd53ba, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x0fb6db6d, 0x7c2f01ff, 0x80004bc0,
	0x00008000, 0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41, 0x0bb10008,
	0xdfe64892, 0x7ed084da, 0x5abd53ba, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d,
	0xdb6db6db, 0xb6db6db6, 0x0fb6db6d, 0x7c2f01ff, 0x80004bc0, 0x00008000,
	0x00088b1f, 0x00000000, 0xc5edff00, 0x30000d41, 0x0bb10008, 0xdfe64892,
	0x7ed084da, 0x5abd53ba, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db,
	0xb6db6db6, 0x0fb6db6d, 0x7c2f01ff, 0x80004bc0, 0x00008000, 0x00088b1f,
	0x00000000, 0xc5edff00, 0x30000d41, 0x0bb10008, 0xdfe64892, 0x7ed084da,
	0x5abd53ba, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x6db6db6d, 0xdb6db6db, 0xb6db6db6, 0x6db6db6d, 0xdb6db6db, 0xb6db6db6,
	0x0fb6db6d, 0x7c2f01ff, 0x80004bc0, 0x00008000, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0x00100000, 0x00000000, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff,
	0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x00100000, 0x00000000,
	0xfffffff3, 0x320fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x30efffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd,
	0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3,
	0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xfffffffa, 0x302fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd,
	0xfffffff7, 0x31efffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x302fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xfffffff3, 0x310fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd,
	0xfffffff1, 0x310fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xfffff406, 0x1cbfffff,
	0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd,
	0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0008cf3c, 0xcdcdcdcd, 0xfffffffa, 0x302fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xfffffff7, 0x30efffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd,
	0xfffffff5, 0x304fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0040cf3c, 0xcdcdcdcd, 0xfffffff3, 0x31efffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x310fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd,
	0xfffffff6, 0x305fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0002cf3c, 0xcdcdcdcd, 0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3,
	0xcf300014, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd,
	0xfffffffa, 0x302fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0010cf3c, 0xcdcdcdcd, 0xffffff97, 0x056fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cc000, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x310fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd,
	0xfffffff3, 0x320fffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3,
	0x0000cf3c, 0xcdcdcdcd, 0xfffffff1, 0x310fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xfffffff6, 0x305fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf300, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd,
	0xfffff406, 0x1cbfffff, 0x0c30c305, 0xc30c30c3, 0xcf300014, 0xf3cf3cf3,
	0x0004cf3c, 0xcdcdcdcd, 0xfffffff2, 0x304fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffff8a, 0x042fffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd,
	0xffffff97, 0x05cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cc000, 0xf3cf3cf3,
	0x0020cf3c, 0xcdcdcdcd, 0xfffffff5, 0x310fffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf300, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0001cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0008cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0040cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0002cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0010cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0000cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0001cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0004cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0008cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0020cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0040cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0000cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0001cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0002cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0004cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0008cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3,
	0xcf3cf3cc, 0xf3cf3cf3, 0x0010cf3c, 0xcdcdcdcd, 0xffffffff, 0x30cfffff,
	0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3, 0x0020cf3c, 0xcdcdcdcd,
	0xffffffff, 0x30cfffff, 0x0c30c30c, 0xc30c30c3, 0xcf3cf3cc, 0xf3cf3cf3,
	0x0040cf3c, 0xcdcdcdcd, 0x00100000, 0x00070100, 0x00028170, 0x000b8198,
	0x00020250, 0x00010270, 0x000f0280, 0x00010370, 0x00080000, 0x00080080,
	0x00028100, 0x000b8128, 0x000201e0, 0x00010200, 0x00070210, 0x00020280,
	0x000f0000, 0x000800f0, 0x00028170, 0x000b8198, 0x00020250, 0x00010270,
	0x000b8280, 0x00080338, 0x00100000, 0x00080100, 0x00028180, 0x000b81a8,
	0x00020260, 0x00018280, 0x000e8298, 0x00080380, 0xcccccccc, 0xcccccccc,
	0xcccccccc, 0xcccccccc, 0x00002000, 0xcccccccc, 0xcccccccc, 0xcccccccc,
	0xcccccccc, 0x00002000
};

#endif /*__BNX2X_INIT_VALUES_H__*/
